------------------------------------------------------------------------------
--  This file is a part of the GRLIB VHDL IP LIBRARY
--  Copyright (C) 2012, Aeroflex Gaisler AB - all rights reserved.
--
-- ANY USE OR REDISTRIBUTION IN PART OR IN WHOLE MUST BE HANDLED IN 
-- ACCORDANCE WITH THE GAISLER LICENSE AGREEMENT AND MUST BE APPROVED 
-- IN ADVANCE IN WRITING.
------------------------------------------------------------------------------

library ieee, cycloneiii;
use ieee.std_logic_1164.all;
use cycloneiii.cycloneiii_components.all;
library altera;
use altera.altera_primitives_components.all;

library altera_mf;
use altera_mf.altera_mf_components.all;

entity grfpw_0_cycloneiii is
port(
  rst :  in std_logic;
  clk :  in std_logic;
  holdn :  in std_logic;
  cpi_flush :  in std_logic;
  cpi_exack :  in std_logic;
  cpi_a_rs1 : in std_logic_vector(4 downto 0);
  cpi_d_pc : in std_logic_vector(31 downto 0);
  cpi_d_inst : in std_logic_vector(31 downto 0);
  cpi_d_cnt : in std_logic_vector(1 downto 0);
  cpi_d_trap :  in std_logic;
  cpi_d_annul :  in std_logic;
  cpi_d_pv :  in std_logic;
  cpi_a_pc : in std_logic_vector(31 downto 0);
  cpi_a_inst : in std_logic_vector(31 downto 0);
  cpi_a_cnt : in std_logic_vector(1 downto 0);
  cpi_a_trap :  in std_logic;
  cpi_a_annul :  in std_logic;
  cpi_a_pv :  in std_logic;
  cpi_e_pc : in std_logic_vector(31 downto 0);
  cpi_e_inst : in std_logic_vector(31 downto 0);
  cpi_e_cnt : in std_logic_vector(1 downto 0);
  cpi_e_trap :  in std_logic;
  cpi_e_annul :  in std_logic;
  cpi_e_pv :  in std_logic;
  cpi_m_pc : in std_logic_vector(31 downto 0);
  cpi_m_inst : in std_logic_vector(31 downto 0);
  cpi_m_cnt : in std_logic_vector(1 downto 0);
  cpi_m_trap :  in std_logic;
  cpi_m_annul :  in std_logic;
  cpi_m_pv :  in std_logic;
  cpi_x_pc : in std_logic_vector(31 downto 0);
  cpi_x_inst : in std_logic_vector(31 downto 0);
  cpi_x_cnt : in std_logic_vector(1 downto 0);
  cpi_x_trap :  in std_logic;
  cpi_x_annul :  in std_logic;
  cpi_x_pv :  in std_logic;
  cpi_lddata : in std_logic_vector(31 downto 0);
  cpi_dbg_enable :  in std_logic;
  cpi_dbg_write :  in std_logic;
  cpi_dbg_fsr :  in std_logic;
  cpi_dbg_addr : in std_logic_vector(4 downto 0);
  cpi_dbg_data : in std_logic_vector(31 downto 0);
  cpo_data : out std_logic_vector(31 downto 0);
  cpo_exc :  out std_logic;
  cpo_cc : out std_logic_vector(1 downto 0);
  cpo_ccv :  out std_logic;
  cpo_ldlock :  out std_logic;
  cpo_holdn :  out std_logic;
  cpo_dbg_data : out std_logic_vector(31 downto 0);
  rfi1_rd1addr : out std_logic_vector(3 downto 0);
  rfi1_rd2addr : out std_logic_vector(3 downto 0);
  rfi1_wraddr : out std_logic_vector(3 downto 0);
  rfi1_wrdata : out std_logic_vector(31 downto 0);
  rfi1_ren1 :  out std_logic;
  rfi1_ren2 :  out std_logic;
  rfi1_wren :  out std_logic;
  rfi2_rd1addr : out std_logic_vector(3 downto 0);
  rfi2_rd2addr : out std_logic_vector(3 downto 0);
  rfi2_wraddr : out std_logic_vector(3 downto 0);
  rfi2_wrdata : out std_logic_vector(31 downto 0);
  rfi2_ren1 :  out std_logic;
  rfi2_ren2 :  out std_logic;
  rfi2_wren :  out std_logic;
  rfo1_data1 : in std_logic_vector(31 downto 0);
  rfo1_data2 : in std_logic_vector(31 downto 0);
  rfo2_data1 : in std_logic_vector(31 downto 0);
  rfo2_data2 : in std_logic_vector(31 downto 0));
end grfpw_0_cycloneiii;

architecture beh of grfpw_0_cycloneiii is
  signal devclrn : std_logic := '1';
  signal devpor : std_logic := '1';
  signal devoe : std_logic := '0';
  signal \GRFPU0.GRFPU_X0.ST4.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.V.STDATA_14\ : std_logic_vector(24 downto 1);
  signal \GRFPC0.OP1_0_IV_I_A2\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP2\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP2_I_M2\ : std_logic_vector(45 downto 5);
  signal \GRFPC0.RFA2.FID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.FSR.RD\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\ : std_logic_vector(121 downto 16);
  signal \GRFPU0.MULO.MRES\ : std_logic_vector(119 downto 66);
  signal \GRFPU0.MULO.DRES_S\ : std_logic_vector(118 downto 66);
  signal \GRFPU0.FPMUL0.CSADD.S1_1\ : std_logic_vector(68 to 68);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\ : std_logic_vector(121 downto 16);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IND\ : std_logic_vector(17 downto 16);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\ : std_logic_vector(17 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\ : std_logic_vector(35 downto 18);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\ : std_logic_vector(17 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\ : std_logic_vector(35 downto 18);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\ : std_logic_vector(13 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2\ : std_logic_vector(115 downto 98);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\ : std_logic_vector(35 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.DIVROM0.RADDR\ : std_logic_vector(7 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.DBUF\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.LZCNT\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.GUARDS\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPOP\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.R_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2\ : std_logic_vector(52 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES\ : std_logic_vector(55 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST2.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE1\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.RAW2\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.IDCST\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.IDCST\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RAW1\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.DIFF\ : std_logic_vector(53 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.DIFFIN1\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF1\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF2\ : std_logic_vector(43 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.INTI1\ : std_logic_vector(29 downto 2);
  signal \GRFPU0.GRFPU_X0.ITER.ND_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.CMPI1\ : std_logic_vector(30 downto 0);
  signal \GRFPU0.GRFPU_X0.CMPI1_0_A2\ : std_logic_vector(27 downto 5);
  signal \GRFPU0.GRFPU_X0.CMPI2\ : std_logic_vector(30 downto 0);
  signal \GRFPU0.GRFPU_X0.CMPI2_0_A2\ : std_logic_vector(27 downto 5);
  signal \GRFPU0.GRFPU_X0.ST1.IDCST\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.IDCST\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.UN1_ST3.REG\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.UN13_EXP\ : std_logic_vector(7 downto 1);
  signal \GRFPU0.GRFPU_X0.UN38_EXP\ : std_logic_vector(7 downto 1);
  signal \GRFPU0.GRFPU_X0.UN3_EXP\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.UN23_EXP\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.ITER.EXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.UN28_EXP\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_ITER.EXP\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\ : std_logic_vector(62 downto 53);
  signal \GRFPU0.GRFPU_X0.ST4.SGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.AEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MSGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_37\ : std_logic_vector(51 downto 18);
  signal \GRFPU0.GRFPU_X0.ST4.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_3\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.INTI2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L4_3\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_7\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\ : std_logic_vector(8 to 8);
  signal \GRFPU0.GRFPU_X0.UN1_INTO\ : std_logic_vector(31 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.ITER.TZR\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2\ : std_logic_vector(51 downto 29);
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1\ : std_logic_vector(53 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_7\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2\ : std_logic_vector(53 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\ : std_logic_vector(54 downto 20);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\ : std_logic_vector(56 downto 22);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\ : std_logic_vector(54 downto 20);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\ : std_logic_vector(20 to 20);
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX\ : std_logic_vector(23 downto 0);
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3\ : std_logic_vector(22 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\ : std_logic_vector(62 downto 34);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\ : std_logic_vector(57 downto 48);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\ : std_logic_vector(54 downto 48);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.L4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.BIAS_4_0\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4\ : std_logic_vector(49 downto 0);
  signal \GRFPU0.GRFPU_X0.S3ADDI\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2_M\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1_V\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\ : std_logic_vector(63 downto 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\ : std_logic_vector(61 downto 57);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_S\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47\ : std_logic_vector(51 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\ : std_logic_vector(50 downto 29);
  signal \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXP_M_M\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXP_M\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ITADDI2_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ADDSUBI2_1\ : std_logic_vector(53 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_6\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\ : std_logic_vector(61 downto 34);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M3\ : std_logic_vector(40 downto 39);
  signal \GRFPU0.GRFPU_X0.INTI1_0_X2\ : std_logic_vector(28 downto 0);
  signal \GRFPU0.GRFPU_X0.CMPI1_I\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.CMPI2_I\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\ : std_logic_vector(35 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\ : std_logic_vector(38 downto 23);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\ : std_logic_vector(34 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\ : std_logic_vector(11 downto 4);
  signal \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\ : std_logic_vector(52 downto 5);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\ : std_logic_vector(48 downto 4);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M2_I_M3\ : std_logic_vector(62 to 62);
  signal \GRFPU0.GRFPU_X0.INTI1_0_X2_0_X2\ : std_logic_vector(30 to 30);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_A2\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.CMPI1_I_I_A2\ : std_logic_vector(23 to 23);
  signal \GRFPU0.GRFPU_X0.CMPI2_I_I_A2\ : std_logic_vector(23 to 23);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\ : std_logic_vector(41 downto 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\ : std_logic_vector(62 downto 6);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M3\ : std_logic_vector(15 downto 11);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\ : std_logic_vector(30 downto 2);
  signal \GRFPU0.GRFPU_X0.DIFFIN1_I_M3_I_M2\ : std_logic_vector(39 to 39);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\ : std_logic_vector(40 downto 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2\ : std_logic_vector(17 downto 16);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FIFO.INST_0\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FIFO.INST_1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.EX.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.R.STATE\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.FOP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.MEM.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FIFO.VCNT_1\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.FIFO.VCNT_0\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.DIV.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.MEM.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.MEM.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR2.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.FIFO.WR\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR.CTRL.VCNT\ : std_logic_vector(0 to 0);
  signal \GRFPC0.RFA.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPR.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.FSR.AEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.TEM\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FIFO.PC_0\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FIFO.PC_1\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FPR.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.RFA2.RS2SEL\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.RS1SEL\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.DIV.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.MEM.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR2.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.R.FSR.FCC\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.D.LDLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.D.STDLCK\ : std_logic_vector(15 downto 0);
  signal \GRFPC0.DIV.RESULT\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.D.STLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.EX.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.STDATA\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.R.FSR.CEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.FTT\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.DIV.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR2.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.MEM.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.EX.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.RFA.RS2\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.RFA.RS1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPUSEL_1\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FPUSEL_6\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\ : std_logic_vector(23 downto 1);
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.RS1_6_0_X\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2_I_M2\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1_I_M2\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.INST_I_0_M3\ : std_logic_vector(13 to 13);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.V.STDATA_14_I_M2\ : std_logic_vector(19 downto 0);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\ : std_logic_vector(29 downto 10);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.INST_I_M2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_4\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_13\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST\ : std_logic_vector(31 downto 5);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_O2_0_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\ : std_logic_vector(31 downto 2);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\ : std_logic_vector(97 to 97);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I\ : std_logic_vector(58 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\ : std_logic_vector(55 downto 51);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.INST_I\ : std_logic_vector(12 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\ : std_logic_vector(46 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\ : std_logic_vector(51 downto 29);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\ : std_logic_vector(51 downto 31);
  signal \GRFPC0.OP1_0_IV\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_7\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.INST_I_A2_0\ : std_logic_vector(10 downto 3);
  signal \GRFPC0.INST_I_M5\ : std_logic_vector(19 to 19);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_12_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_A2_1\ : std_logic_vector(14 downto 3);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4\ : std_logic_vector(15 downto 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\ : std_logic_vector(15 downto 1);
  signal \GRFPC0.FP_PIPELINE.6.1.REGDEPX_116\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\ : std_logic_vector(43 to 43);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\ : std_logic_vector(47 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\ : std_logic_vector(59 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\ : std_logic_vector(58 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\ : std_logic_vector(58 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\ : std_logic_vector(54 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\ : std_logic_vector(28 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\ : std_logic_vector(50 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\ : std_logic_vector(58 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\ : std_logic_vector(21 downto 0);
  signal \GRFPU0.GRFPU_X0.MULO_I_M_0\ : std_logic_vector(85 downto 64);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_2_I_I_A2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\ : std_logic_vector(34 downto 7);
  signal \GRFPU0.GRFPU_X0.MULO_M\ : std_logic_vector(119 downto 70);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\ : std_logic_vector(60 downto 7);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\ : std_logic_vector(37 downto 10);
  signal \GRFPU0.GRFPU_X0.L2_0_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.S3ADDI_0\ : std_logic_vector(50 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\ : std_logic_vector(53 downto 51);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\ : std_logic_vector(53 downto 43);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_A2_1_0_A2\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\ : std_logic_vector(54 downto 28);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\ : std_logic_vector(58 to 58);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1_1\ : std_logic_vector(24 to 24);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\ : std_logic_vector(62 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\ : std_logic_vector(49 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\ : std_logic_vector(59 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\ : std_logic_vector(34 downto 11);
  signal \GRFPU0.GRFPU_X0.REST_2\ : std_logic_vector(5 downto 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\ : std_logic_vector(53 downto 50);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\ : std_logic_vector(49 downto 48);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\ : std_logic_vector(57 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\ : std_logic_vector(57 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\ : std_logic_vector(60 downto 34);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2\ : std_logic_vector(62 downto 61);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_9\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_O2\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_1\ : std_logic_vector(60 downto 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_1_1\ : std_logic_vector(61 to 61);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\ : std_logic_vector(60 downto 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\ : std_logic_vector(62 downto 56);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.L1_0_1_2_I_I_A3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_X2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\ : std_logic_vector(57 downto 29);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.TZI2\ : std_logic_vector(22 downto 3);
  signal \GRFPU0.GRFPU_X0.L1_2_4\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_1_4\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_4\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4_I_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_4_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_4_0_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_1_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_5\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_4_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_0\ : std_logic_vector(58 downto 56);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_6\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2_0\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0\ : std_logic_vector(57 downto 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1_1\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_2\ : std_logic_vector(53 downto 49);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\ : std_logic_vector(55 downto 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_O2\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.UN1_ST3.EMINM1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1\ : std_logic_vector(2 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2\ : std_logic_vector(56 to 56);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I_M2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.FLOP4_1\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_0\ : std_logic_vector(51 downto 38);
  signal \GRFPC0.FIFO.RD_I_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\ : std_logic_vector(0 to 0);
  signal \GRFPC0.UN1_PENDEXC_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.UN1_PENDEXC_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.RFA2.FOP_0_0_X2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_25_IV_0_O2_I_A2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_A2\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.TZI\ : std_logic_vector(21 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_A4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0_6\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_1_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1_3\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_5_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_4_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_0_4_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.EXPOP\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_1_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\ : std_logic_vector(58 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_I_I_A2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\ : std_logic_vector(5 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\ : std_logic_vector(5 downto 1);
  signal \GRFPU0.GRFPU_X0.L4_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_2\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_1_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_I_A4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.EXPT_CNST_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_0\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\ : std_logic_vector(62 downto 11);
  signal \GRFPU0.GRFPU_X0.EXPT_CNST_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M3\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\ : std_logic_vector(22 downto 2);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_M2\ : std_logic_vector(23 downto 22);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_A4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_0\ : std_logic_vector(49 downto 2);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.TZI_I_M2\ : std_logic_vector(12 downto 4);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_3_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_3_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\ : std_logic_vector(40 downto 14);
  signal \GRFPU0.GRFPU_X0.L1_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_4_1_4_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.REST_1_2\ : std_logic_vector(7 downto 6);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_0\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_U\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.REST_1_1_U\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_I_M3\ : std_logic_vector(15 downto 11);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M3\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M3\ : std_logic_vector(54 to 54);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_7\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_3\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_6\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_4_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_4_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_7_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_2_1_6_0_I\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O3_0\ : std_logic_vector(24 to 24);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\ : std_logic_vector(61 downto 57);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\ : std_logic_vector(61 downto 57);
  signal \GRFPU0.GRFPU_X0.L1_1_7\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_7\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_6\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_7\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\ : std_logic_vector(61 downto 57);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_5_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_0_2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_1_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\ : std_logic_vector(50 downto 13);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\ : std_logic_vector(48 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\ : std_logic_vector(53 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\ : std_logic_vector(59 downto 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\ : std_logic_vector(31 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\ : std_logic_vector(45 downto 14);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\ : std_logic_vector(33 downto 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\ : std_logic_vector(46 downto 11);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.L1_1_1_2_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_2\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.REN1_2_I_M\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L1_5_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_3\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_6\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_6_1_2_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_2_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_1_4\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_1\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.L1_3_1_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_4_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_2_1_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\ : std_logic_vector(53 downto 35);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_3\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_6\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_10\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_13\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_15\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\ : std_logic_vector(52 downto 9);
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_O2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_O2_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L3_0_3_I_S\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0\ : std_logic_vector(2 downto 1);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0\ : std_logic_vector(2 downto 1);
  signal \GRFPU0.GRFPU_X0.L1_2_1_2_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\ : std_logic_vector(54 downto 20);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\ : std_logic_vector(54 downto 20);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A2_0\ : std_logic_vector(42 to 42);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\ : std_logic_vector(51 downto 25);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.UN33_REST_I_A2\ : std_logic_vector(20 downto 11);
  signal \GRFPU0.GRFPU_X0.REST_1_1_2\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.REST_1_2_2\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.REST_2_2\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_12\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.MULO_I_M\ : std_logic_vector(120 downto 72);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\ : std_logic_vector(54 downto 39);
  signal \GRFPU0.GRFPU_X0.L1_6_1_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\ : std_logic_vector(19 downto 14);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M2\ : std_logic_vector(22 to 22);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_5\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_2\ : std_logic_vector(24 downto 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_I_M2\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_M2\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\ : std_logic_vector(54 downto 28);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1\ : std_logic_vector(41 downto 21);
  signal \GRFPU0.GRFPU_X0.L1_5_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\ : std_logic_vector(58 to 58);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\ : std_logic_vector(56 downto 2);
  signal \GRFPU0.GRFPU_X0.L1_5_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\ : std_logic_vector(52 downto 51);
  signal \GRFPU0.GRFPU_X0.L3_0_3\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_3_I_A4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_4_1_3_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\ : std_logic_vector(51 downto 33);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\ : std_logic_vector(4 downto 3);
  signal \GRFPU0.GRFPU_X0.L1_4_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_1_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M2\ : std_logic_vector(17 to 17);
  signal \GRFPU0.GRFPU_X0.L1_3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_0\ : std_logic_vector(16 to 16);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_1\ : std_logic_vector(16 to 16);
  signal \GRFPU0.GRFPU_X0.UN1_RND_INC\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RNDOP_32_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\ : std_logic_vector(59 downto 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\ : std_logic_vector(59 downto 53);
  signal \GRFPU0.GRFPU_X0.L1_3_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\ : std_logic_vector(44 downto 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_4\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3_I_M4\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_M2\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_XX_MM\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_2_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_6_I\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_3\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\ : std_logic_vector(51 downto 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O3\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_1\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_0\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.L1_0_5_0_O3\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.TZI2_I_0_M3\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I_M2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.TZI2_I_M2\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_O3\ : std_logic_vector(10 downto 6);
  signal \GRFPU0.GRFPU_X0.L1_0_2_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_7\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\ : std_logic_vector(54 downto 31);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\ : std_logic_vector(52 downto 28);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\ : std_logic_vector(48 downto 17);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I\ : std_logic_vector(17 downto 12);
  signal \GRFPC0.FP_PIPELINE.UN4_CNTX\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M2\ : std_logic_vector(45 to 45);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\ : std_logic_vector(45 downto 41);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_A2_3\ : std_logic_vector(46 to 46);
  signal \GRFPU0.GRFPU_X0.REST_1_2_IV\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_2_IV\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\ : std_logic_vector(54 to 54);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\ : std_logic_vector(47 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2\ : std_logic_vector(41 downto 33);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2\ : std_logic_vector(45 to 45);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\ : std_logic_vector(49 downto 34);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1\ : std_logic_vector(49 to 49);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2\ : std_logic_vector(49 to 49);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_A2\ : std_logic_vector(50 to 50);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\ : std_logic_vector(33 downto 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\ : std_logic_vector(56 downto 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_2\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M2\ : std_logic_vector(17 downto 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV\ : std_logic_vector(60 to 60);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_0\ : std_logic_vector(38 downto 23);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_1\ : std_logic_vector(45 to 45);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_2\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_0\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_1\ : std_logic_vector(46 to 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M4\ : std_logic_vector(53 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_4\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2\ : std_logic_vector(51 to 51);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1\ : std_logic_vector(44 to 44);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4\ : std_logic_vector(44 to 44);
  signal \GRFPU0.GRFPU_X0.COMB.RMND_7_I_M3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_2\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_7\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_6\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_1\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_2\ : std_logic_vector(62 to 62);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_0\ : std_logic_vector(62 to 62);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_9\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.ADIFF_1\ : std_logic_vector(8 downto 1);
  signal \GRFPU0.GRFPU_X0.RNDOP_32_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53\ : std_logic_vector(18 to 18);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_14\ : std_logic_vector(5 downto 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\ : std_logic_vector(53 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\ : std_logic_vector(58 downto 56);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4\ : std_logic_vector(19 to 19);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_A3_0_0_A2\ : std_logic_vector(9 to 9);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_7\ : std_logic_vector(6 downto 4);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_2\ : std_logic_vector(5 downto 4);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_4\ : std_logic_vector(5 downto 3);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_5\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0\ : std_logic_vector(34 to 34);
  signal \GRFPU0.GRFPU_X0.L1_3_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.EXP_14\ : std_logic_vector(5 downto 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0_M2\ : std_logic_vector(34 to 34);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_I_M3\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2_I_M2\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\ : std_logic_vector(58 downto 54);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\ : std_logic_vector(58 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M4\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_2\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_2\ : std_logic_vector(16 to 16);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_3\ : std_logic_vector(16 to 16);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_M2\ : std_logic_vector(45 to 45);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\ : std_logic_vector(19 to 19);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.STATE_45_0_M2_0\ : std_logic_vector(24 to 24);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2_0\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.L1_4_1_0\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_0\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_3\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.UN1_RAW1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_DP\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_O3\ : std_logic_vector(50 to 50);
  signal \GRFPU0.GRFPU_X0.L1_6_1_3_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2_0\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REN1_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.OP2_4\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.OP2_3\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP2_4_X\ : std_logic_vector(63 downto 32);
  signal \GRFPC0.OP2_6\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_X\ : std_logic_vector(20 to 20);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\ : std_logic_vector(9 downto 8);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_114\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6_X\ : std_logic_vector(21 to 21);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_1\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5\ : std_logic_vector(21 to 21);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_0\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\ : std_logic_vector(28 downto 7);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_4\ : std_logic_vector(21 downto 9);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\ : std_logic_vector(27 downto 7);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0_X\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_IV_I_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX_120\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_1\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_246\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_248\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_540_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_558\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.0.STDEP_545\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_536_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_532_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_2_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_0_A2_0_A2_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_A2_1_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_27_0_A2_0_A2_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VDIV.RD_1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_0_X\ : std_logic_vector(9 to 9);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_18_X\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\ : std_logic_vector(8 to 8);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_X\ : std_logic_vector(15 downto 8);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\ : std_logic_vector(20 downto 8);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_M2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_484_0_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_251\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_20\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_19_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_250_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_10\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_9\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5\ : std_logic_vector(31 downto 15);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_A2_X\ : std_logic_vector(14 to 14);
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_1_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\ : std_logic_vector(25 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_X\ : std_logic_vector(25 downto 5);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_488_3_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.RS2_1_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\ : std_logic_vector(23 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_M2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_212_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_5_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.DEP_2_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_164_0_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A3_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_6_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_I_I_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_16\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_12\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_1_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_0\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1_0\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_4_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A2_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.0.STDEP_545_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FID_1_IV_0_A3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.RS1_6_X\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.INST_0_M_9\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_568_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_212_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_32\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_34\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_A4_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_0_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_24\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_22\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_20_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_9_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_0_O2_I_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_42_0_IV_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_11_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\ : std_logic_vector(31 downto 19);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.1.REGDEPX_242\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_594_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_562_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_550_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_M2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_50\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_14_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_53\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_13\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_2\ : std_logic_vector(8 to 8);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_18\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_1\ : std_logic_vector(8 to 8);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_1\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.0.REGDEPX_186\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_7_0_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_17_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_13\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M4\ : std_logic_vector(27 to 27);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_M2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.EXSEL_1_X\ : std_logic_vector(2 to 2);
  signal \GRFPC0.MEMSEL_1_X\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_6_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_M2\ : std_logic_vector(4 to 4);
  signal \GRFPC0.OP2_5\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP2_2\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP2_1\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP1_I_A2\ : std_logic_vector(32 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_O2\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\ : std_logic_vector(31 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_A2\ : std_logic_vector(8 to 8);
  signal \GRFPU0.GRFPU_X0.RES_1_4_I_M2\ : std_logic_vector(57 to 57);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.WRDATA_3_0\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.WRDATA_3\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\ : std_logic_vector(58 to 58);
  signal \GRFPC0.FP_PIPELINE.WRDATA_6_X\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.STDATA_0\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.STDATA_1_X\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.WREN_17_IV\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.DIV.RD_M\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_1\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FPO_I_M\ : std_logic_vector(48 downto 6);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A2_1_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_4_I_O3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A2_0_A2_0_A2_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_92_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_94\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.1.REGDEPX_98\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.1.REGDEPX_100\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX_102\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX_104\ : std_logic_vector(1 to 1);
  signal \GRFPC0.INST_I_0_M2_X\ : std_logic_vector(13 to 13);
  signal \GRFPC0.INST_I_0_M2_0_X\ : std_logic_vector(13 to 13);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR2.CTRL.RD_I_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\ : std_logic_vector(18 downto 1);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_0_O2_I_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_M4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_X3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_M2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_3_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_M2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.VFIFO.INST_0_4_X\ : std_logic_vector(18 to 18);
  signal \GRFPC0.VFIFO.INST_1_4_X\ : std_logic_vector(18 to 18);
  signal \GRFPC0.FP_PIPELINE.8.1.REGDEPX_152\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_18_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DBGDATA_4_I_M3_X\ : std_logic_vector(13 to 13);
  signal \GRFPC0.OP2_I_M3_1\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP2_I_M3_2\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP2_I_M3\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP2_I_M3_4\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP2_I_M3_3_X\ : std_logic_vector(45 to 45);
  signal \GRFPC0.OP2_I_M3_0\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.WRDATA_I_M3_0\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.WRDATA_I_M3\ : std_logic_vector(45 to 45);
  signal \GRFPC0.OP2_I_M3_3\ : std_logic_vector(13 to 13);
  signal \GRFPC0.WRDATA_I_M3_1\ : std_logic_vector(13 to 13);
  signal \GRFPC0.WRDATA_I_M3_X\ : std_logic_vector(13 to 13);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFO2_I_M_0_X\ : std_logic_vector(30 downto 18);
  signal \GRFPC0.FP_PIPELINE.WRDATA_6\ : std_logic_vector(30 downto 12);
  signal \GRFPC0.RFO1_I_M_0\ : std_logic_vector(19 downto 11);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.OP2_6_I_M2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.OP2_5_I_M2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.OP2_3_I_M2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.OP2_2_I_M2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.OP2_1_I_M2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_350\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FID_1_IV_0_A2_1\ : std_logic_vector(3 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_264\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_580_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.1.REGDEPX_263\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_266\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FID_1_IV_0_A2\ : std_logic_vector(5 downto 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_3_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_23_IV_I_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_16\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_22_IV_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_13_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RES_1_5\ : std_logic_vector(62 downto 44);
  signal \GRFPU0.GRFPU_X0.RES_1_4\ : std_logic_vector(62 downto 44);
  signal \GRFPU0.GRFPU_X0.RES_1_3\ : std_logic_vector(62 downto 44);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_A4\ : std_logic_vector(58 to 58);
  signal \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\ : std_logic_vector(58 downto 36);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_96\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_21\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_98\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_22_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_93\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_23_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_9_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.WRADDR_1_0\ : std_logic_vector(3 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_9_0_A2_0_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_463\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_465\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_274\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_1_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_6_M1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_354_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_590\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_580_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.0.STDEP_345\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_288_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_288_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_288_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A4_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A4_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_M2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_5\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_2\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_M3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.1.REGDEPX_188\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.1.REGDEPX_190\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\ : std_logic_vector(7 downto 6);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_156\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_158\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\ : std_logic_vector(27 downto 8);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_7\ : std_logic_vector(9 to 9);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6\ : std_logic_vector(9 to 9);
  signal \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_I_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.0.REGDEPX_272_IV_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.15.0.REGDEPX_274_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3\ : std_logic_vector(7 downto 6);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_0\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.0.REGDEPX_58\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_394_0_IV_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_390_0_IV_I_A5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_12\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.CPI_M_X\ : std_logic_vector(396 downto 392);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M2\ : std_logic_vector(19 to 19);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_1_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_269\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_161\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_143\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_35\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_18_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_6_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1\ : std_logic_vector(4 to 4);
  signal \GRFPC0.RS1_3_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR2.RREG.RES_I_M\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\ : std_logic_vector(3 downto 1);
  signal \GRFPC0.DIV.EXCT_M\ : std_logic_vector(4 downto 2);
  signal \GRFPC0.WR2.RREG.RES_M\ : std_logic_vector(4 downto 2);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_273_0_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0_A5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_2\ : std_logic_vector(19 to 19);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_14\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_21_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_X\ : std_logic_vector(19 to 19);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_1_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_14\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_140\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX_286\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX_284\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_374\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_373\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_160\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.1.REGDEPX_154\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX_106\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_43\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_41\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_SGNF_1_SQMUXA_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_X2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2_X\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_17\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_18\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.DEP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_16\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_5_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_6\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_O2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_0\ : std_logic_vector(5 downto 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2\ : std_logic_vector(12 to 12);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_176_I_M_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_216_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.STDEP_585_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.0.STDEP_185_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VITER.R_I_33_IV_TZ\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.STDEP_345_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_550_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.0.STDEP_225_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_598_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_554_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.0.STDEP_185_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_350_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_1_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_340_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_4_0_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_TZ_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\ : std_logic_vector(58 downto 37);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\ : std_logic_vector(56 downto 38);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17_D\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_D\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_D\ : std_logic_vector(56 downto 55);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_239_A1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_A0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_419_A0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A3\ : std_logic_vector(52 downto 38);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_5_1_5_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_4_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_4_2\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\ : std_logic_vector(49 to 49);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\ : std_logic_vector(50 downto 39);
  signal \GRFPU0.GRFPU_X0.L4_D\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2\ : std_logic_vector(44 to 44);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_4_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_2_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_2_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_3_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_3_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_2_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_2_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_1\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\ : std_logic_vector(40 downto 17);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\ : std_logic_vector(47 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\ : std_logic_vector(47 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0\ : std_logic_vector(40 to 40);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_1_D\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_XX\ : std_logic_vector(59 downto 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_YY\ : std_logic_vector(59 downto 53);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_1_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_X\ : std_logic_vector(27 to 27);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_212_0_A2_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\ : std_logic_vector(15 downto 8);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1_0\ : std_logic_vector(23 to 23);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\ : std_logic_vector(28 downto 15);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\ : std_logic_vector(21 to 21);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_5_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_190_I_M_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_5_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_15_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_10_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_9_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_0_A3_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_3_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_23_IV_I_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV_I_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_24_IV_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\ : std_logic_vector(33 downto 32);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_0\ : std_logic_vector(9 to 9);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0\ : std_logic_vector(8 to 8);
  signal \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_3_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_7_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A2_0_0_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_1\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_1_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0_0\ : std_logic_vector(59 to 59);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_1_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_XX\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_YY\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\ : std_logic_vector(50 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\ : std_logic_vector(50 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_XX\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_YY\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16_D\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0_A0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\ : std_logic_vector(59 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_S\ : std_logic_vector(37 to 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_D\ : std_logic_vector(37 to 37);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_284_0_IV_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_0_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0_X\ : std_logic_vector(9 to 9);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_14_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.WREN_17_IV_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_0\ : std_logic_vector(8 to 8);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_0_X\ : std_logic_vector(20 to 20);
  signal \GRFPC0.FP_PIPELINE.REN1_2_I_M_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1_0\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.DEP_2_I_I_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_0_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_5_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_16_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_2_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_0_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_3_0_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_2_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_4_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_4_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_1_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_5_0_A2_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_6_1_5_0_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_5_I_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A4_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_5_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.REST_1_2_0\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_0\ : std_logic_vector(22 downto 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2_TZ_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0_TZ_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_0_10_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.REST_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_1_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_4_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_A4_0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_A2_1_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_1_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_2_X\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_0_X\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_8_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_2_0_A2_0_0\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_O3_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M_0\ : std_logic_vector(63 to 63);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_243_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_6_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_333_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_5_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_10_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_10_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_0\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_0\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3_TZ_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_I_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\ : std_logic_vector(36 to 36);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_1\ : std_logic_vector(61 downto 32);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_2\ : std_logic_vector(61 downto 32);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\ : std_logic_vector(51 downto 39);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\ : std_logic_vector(51 downto 39);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0\ : std_logic_vector(61 downto 36);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\ : std_logic_vector(30 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\ : std_logic_vector(36 downto 4);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_0_7_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_0\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV_0\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_0\ : std_logic_vector(56 to 56);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2\ : std_logic_vector(58 downto 56);
  signal \GRFPU0.GRFPU_X0.L2_0_9_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\ : std_logic_vector(40 downto 39);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_1\ : std_logic_vector(60 downto 59);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_4_0\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.L3_0_4_2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.L3_0_3_1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.OP1_0_IV_0\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP1_0_IV_1\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.OP1_0_IV_2\ : std_logic_vector(63 downto 40);
  signal \GRFPC0.OP1_0_IV_3\ : std_logic_vector(61 downto 0);
  signal \GRFPC0.OP1_0_IV_I_A2_0\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP1_0_IV_I_A2_1\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP1_0_IV_I_A2_3\ : std_logic_vector(45 downto 13);
  signal \GRFPC0.OP1_0_IV_4_X\ : std_logic_vector(6 to 6);
  signal \GRFPC0.OP1_0_IV_4\ : std_logic_vector(62 downto 40);
  signal \GRFPC0.OP1_0_IV_5\ : std_logic_vector(56 downto 31);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2_0\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_4_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.INST_I_A2_0_0\ : std_logic_vector(12 downto 11);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\ : std_logic_vector(54 downto 20);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_0\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\ : std_logic_vector(21 to 21);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_7\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\ : std_logic_vector(18 downto 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\ : std_logic_vector(12 downto 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_0\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_2\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\ : std_logic_vector(60 to 60);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0\ : std_logic_vector(18 downto 6);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0_0\ : std_logic_vector(10 to 10);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\ : std_logic_vector(45 downto 23);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_1\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_2\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_6\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_7\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_8\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2_0\ : std_logic_vector(12 to 12);
  signal \GRFPC0.INST_I_0\ : std_logic_vector(14 to 14);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A5_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_3\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\ : std_logic_vector(61 downto 57);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_3\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_4\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_15\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_28\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_30\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_33\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_35\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_36\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_37\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_40\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_43\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_1\ : std_logic_vector(22 to 22);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\ : std_logic_vector(30 downto 7);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\ : std_logic_vector(36 downto 7);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\ : std_logic_vector(18 downto 6);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_11\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_12\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_13\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\ : std_logic_vector(62 downto 61);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\ : std_logic_vector(62 downto 61);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_O2_0\ : std_logic_vector(46 to 46);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FIFO.RD_I_M_0_X\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2_1\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_4\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_10\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_1\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\ : std_logic_vector(31 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\ : std_logic_vector(33 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0\ : std_logic_vector(17 to 17);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_2\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\ : std_logic_vector(33 downto 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\ : std_logic_vector(20 downto 14);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0_0\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3_0\ : std_logic_vector(12 to 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1\ : std_logic_vector(44 to 44);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_4\ : std_logic_vector(44 to 44);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_10\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_4_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\ : std_logic_vector(54 downto 50);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1\ : std_logic_vector(54 downto 51);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_3\ : std_logic_vector(54 to 54);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_2\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\ : std_logic_vector(45 downto 43);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\ : std_logic_vector(50 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\ : std_logic_vector(58 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\ : std_logic_vector(58 downto 54);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\ : std_logic_vector(48 downto 46);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_O2_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3_1\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_2\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_8\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_1\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\ : std_logic_vector(53 downto 38);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_1\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_2\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_0\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_2\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_0\ : std_logic_vector(38 to 38);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_10_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2_0\ : std_logic_vector(56 to 56);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV_0\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_11_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_0\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\ : std_logic_vector(42 to 42);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A1_1\ : std_logic_vector(44 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_1\ : std_logic_vector(44 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_0\ : std_logic_vector(56 to 56);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_1\ : std_logic_vector(56 to 56);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_1\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_17_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O2_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_O2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\ : std_logic_vector(29 to 29);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I\ : std_logic_vector(61 downto 32);
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.V.STDATA_14_M_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.V.STDATA_14_M_1_0_A2\ : std_logic_vector(14 to 14);
  signal \GRFPC0.V.STDATA_14_I_M_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.V.STDATA_14_I_M_4\ : std_logic_vector(14 to 14);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_O2\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FID_1_IV_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FID_1_IV_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FID_1_IV_0_A3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.INST_1_M_2\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\ : std_logic_vector(23 to 23);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.CPI_M_1_X\ : std_logic_vector(64 to 64);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\ : std_logic_vector(33 to 33);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\ : std_logic_vector(33 to 33);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\ : std_logic_vector(38 to 38);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\ : std_logic_vector(32 to 32);
  signal \GRFPU0.GRFPU_X0.L1_0_A2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L2_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\ : std_logic_vector(31 to 31);
  signal \GRFPU0.GRFPU_X0.L1_0_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L2_0_9\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\ : std_logic_vector(54 to 54);
  signal \GRFPU0.GRFPU_X0.L1_4_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L1_0_10\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L3_0_4\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.RNDOP_14_IV\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0_7\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L1_2_0_A3\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_0_5_0_A2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\ : std_logic_vector(56 to 56);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\ : std_logic_vector(19 to 19);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\ : std_logic_vector(58 to 58);
  signal \GRFPU0.GRFPU_X0.L1_0_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L2_0_10\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\ : std_logic_vector(10 to 10);
  signal \GRFPC0.FIFO.INST_1_I_M_2\ : std_logic_vector(25 to 25);
  signal \GRFPC0.CPI_I_M_1_X\ : std_logic_vector(64 to 64);
  signal \GRFPC0.INST_I_X\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.L3\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.L3_2_0_A2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.IDOUT_I_M2\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.INST_A\ : std_logic_vector(31 downto 5);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_3_A\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_10_A\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_6_A\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_13_A\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.INST_I_M2_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_M5_A\ : std_logic_vector(19 to 19);
  signal \GRFPU0.GRFPU_X0.RES_1_3_A\ : std_logic_vector(62 downto 44);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3_A\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6_A\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10_A\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13_A\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\ : std_logic_vector(59 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\ : std_logic_vector(28 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\ : std_logic_vector(52 downto 29);
  signal \GRFPU0.GRFPU_X0.L1_5_5_A\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3_A\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0_A\ : std_logic_vector(40 downto 39);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_14_A\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.REST_2_A\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1_A\ : std_logic_vector(44 to 44);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1_A\ : std_logic_vector(48 downto 46);
  signal \GRFPU0.GRFPU_X0.L3_1_1_A\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_5_A\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_4_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_4_6_A\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_MUX_15_A\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15_A\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4_I_I_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_5_A\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_4_4_A\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_5_0_A\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2_A\ : std_logic_vector(37 to 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\ : std_logic_vector(33 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_6_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_6_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_A\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\ : std_logic_vector(59 downto 9);
  signal \GRFPC0.INST_I_A\ : std_logic_vector(12 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\ : std_logic_vector(46 downto 8);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\ : std_logic_vector(49 downto 32);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\ : std_logic_vector(51 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0_A\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0_A\ : std_logic_vector(17 to 17);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1_A\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.L3_1_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.WRDATA_6_A\ : std_logic_vector(30 downto 12);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BIAS_4_0_A\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A\ : std_logic_vector(39 to 39);
  signal \GRFPC0.OP1_0_IV_A\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1_A\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2_A\ : std_logic_vector(58 to 58);
  signal \GRFPC0.OP1_0_IV_5_A\ : std_logic_vector(56 to 56);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\ : std_logic_vector(62 downto 0);
  signal \GRFPU0.GRFPU_X0.INTI2_1_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\ : std_logic_vector(55 downto 34);
  signal \GRFPU0.GRFPU_X0.L4_A\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_274_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\ : std_logic_vector(34 downto 10);
  signal \GRFPC0.OP1_0_IV_I_A2_A\ : std_logic_vector(45 downto 13);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_A\ : std_logic_vector(58 downto 57);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_A\ : std_logic_vector(36 to 36);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1_A\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7_A\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9_A\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1_A\ : std_logic_vector(54 to 54);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0_A\ : std_logic_vector(51 to 51);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_A\ : std_logic_vector(60 downto 59);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_A\ : std_logic_vector(28 downto 21);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25_A\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1_A\ : std_logic_vector(61 to 61);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_A\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_3_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_1_A\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_A\ : std_logic_vector(59 to 59);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\ : std_logic_vector(49 downto 22);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_532_3_A\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A\ : std_logic_vector(33 downto 24);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14_A\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0_A\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1_A\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A\ : std_logic_vector(63 to 63);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX_120_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REN1_1_IV_A\ : std_logic_vector(2 downto 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_264_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_A\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_A\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1_A\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9_A\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8_S\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2_S\ : std_logic_vector(0 to 0);
  signal \GRFPC0.OP1_0_IV_5_A_S\ : std_logic_vector(56 to 56);
  signal \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2_S\ : std_logic_vector(0 to 0);
  signal \GRFPC0.OP1_0_IV_3_S\ : std_logic_vector(59 downto 36);
  signal \GRFPC0.OP1_0_IV_2_S\ : std_logic_vector(62 downto 40);
  signal \GRFPU0.GRFPU_X0.L1_3_2_S\ : std_logic_vector(1 to 1);
  signal \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\ : std_logic_vector(4 downto 1);
  signal \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\ : std_logic_vector(51 downto 29);
  signal \RETGRFPC0.OP2\ : std_logic_vector(31 downto 0);
  signal \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\ : std_logic_vector(59 downto 37);
  signal \GRFPU0.GRFPU_X0.L4_4_REP1\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_4_REP2\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.L4_4_REP3\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.L3_REP1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\ : std_logic_vector(10 to 10);
  signal \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\ : std_logic_vector(29 to 29);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.OP1_I_A2_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\ : std_logic_vector(58 to 58);
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.RFA2.RS1SEL_REP1\ : std_logic_vector(6 downto 0);
  signal \GRFPC0.RFA2.RS1SEL_REP2\ : std_logic_vector(6 downto 0);
  signal \GRFPC0.RFA2.RS2SEL_REP1\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS2SEL_REP2\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS2SEL_REP3\ : std_logic_vector(2 to 2);
  signal \GRFPC0.RFA2.RS2SEL_REP4\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FIFO.RD_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_REP2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_REP3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_REP4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\ : std_logic_vector(48 to 48);
  signal \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST3.REG_REP1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.ST3.REG_REP2\ : std_logic_vector(63 to 63);
  signal \GRFPU0.MULO.MRES_BUF\ : std_logic_vector(121 downto 120);
  signal \GRFPC0.V.STDATA_14_REP1\ : std_logic_vector(11 downto 6);
  signal \GRFPC0.V.STDATA_14_REP0\ : std_logic_vector(6 to 6);
  signal \GRFPC0.V.STDATA_14_REP2\ : std_logic_vector(6 to 6);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\ : std_logic_vector(13 downto 2);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_RETO\ : std_logic_vector(115 to 115);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_RETO\ : std_logic_vector(115 downto 98);
  signal \GRFPU0.FPMUL0.CSADD.S1_1_RETI\ : std_logic_vector(68 to 68);
  signal \GRFPC0.FPUSEL_6_M3_RETO\ : std_logic_vector(0 to 0);
  signal \GRFPU0.MULO.MRES_RETI\ : std_logic_vector(88 downto 66);
  signal \GRFPC0.FPUSEL_6_M2_RETO\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_RETO\ : std_logic_vector(63 to 63);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\ : std_logic_vector(24 downto 20);
  signal \GRFPC0.FPUSEL_6_M1_RETO\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M_RETO\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M_RETO\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.L3_REP1_REP1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\ : std_logic_vector(21 to 21);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_REP2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_REP1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\ : std_logic_vector(21 to 21);
  signal \GRFPC0.V.STDATA_14_I\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.ST3.FLOP_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.MULO.MRES_BUF_I\ : std_logic_vector(121 to 121);
  signal CPO_DATAZ : std_logic_vector(31 downto 0);
  signal CPO_CCZ : std_logic_vector(1 downto 0);
  signal CPO_DBG_DATAZ : std_logic_vector(31 downto 0);
  signal RFI1_WRDATAZ : std_logic_vector(31 downto 0);
  signal RFI2_RD1ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_RD2ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRDATAZ : std_logic_vector(31 downto 0);
  signal CLK_INTERNAL : std_logic ;
  signal CPI_EXACK_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL_0 : std_logic ;
  signal CPI_A_RS1_INTERNAL_1 : std_logic ;
  signal CPI_A_RS1_INTERNAL_2 : std_logic ;
  signal CPI_A_RS1_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL : std_logic ;
  signal CPI_D_PC_INTERNAL_0 : std_logic ;
  signal CPI_D_PC_INTERNAL_1 : std_logic ;
  signal CPI_D_PC_INTERNAL_2 : std_logic ;
  signal CPI_D_PC_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL_4 : std_logic ;
  signal CPI_D_PC_INTERNAL_5 : std_logic ;
  signal CPI_D_PC_INTERNAL_6 : std_logic ;
  signal CPI_D_PC_INTERNAL_7 : std_logic ;
  signal CPI_D_PC_INTERNAL_8 : std_logic ;
  signal CPI_D_PC_INTERNAL_9 : std_logic ;
  signal CPI_D_PC_INTERNAL_10 : std_logic ;
  signal CPI_D_PC_INTERNAL_11 : std_logic ;
  signal CPI_D_PC_INTERNAL_12 : std_logic ;
  signal CPI_D_PC_INTERNAL_13 : std_logic ;
  signal CPI_D_PC_INTERNAL_14 : std_logic ;
  signal CPI_D_PC_INTERNAL_15 : std_logic ;
  signal CPI_D_PC_INTERNAL_16 : std_logic ;
  signal CPI_D_PC_INTERNAL_17 : std_logic ;
  signal CPI_D_PC_INTERNAL_18 : std_logic ;
  signal CPI_D_PC_INTERNAL_19 : std_logic ;
  signal CPI_D_PC_INTERNAL_20 : std_logic ;
  signal CPI_D_PC_INTERNAL_21 : std_logic ;
  signal CPI_D_PC_INTERNAL_22 : std_logic ;
  signal CPI_D_PC_INTERNAL_23 : std_logic ;
  signal CPI_D_PC_INTERNAL_24 : std_logic ;
  signal CPI_D_PC_INTERNAL_25 : std_logic ;
  signal CPI_D_PC_INTERNAL_26 : std_logic ;
  signal CPI_D_PC_INTERNAL_27 : std_logic ;
  signal CPI_D_PC_INTERNAL_28 : std_logic ;
  signal CPI_D_PC_INTERNAL_29 : std_logic ;
  signal CPI_D_PC_INTERNAL_30 : std_logic ;
  signal CPI_D_INST_INTERNAL : std_logic ;
  signal CPI_D_INST_INTERNAL_0 : std_logic ;
  signal CPI_D_INST_INTERNAL_1 : std_logic ;
  signal CPI_D_INST_INTERNAL_2 : std_logic ;
  signal CPI_D_INST_INTERNAL_3 : std_logic ;
  signal CPI_D_INST_INTERNAL_4 : std_logic ;
  signal CPI_D_INST_INTERNAL_6 : std_logic ;
  signal CPI_D_INST_INTERNAL_7 : std_logic ;
  signal CPI_D_INST_INTERNAL_8 : std_logic ;
  signal CPI_D_INST_INTERNAL_9 : std_logic ;
  signal CPI_D_INST_INTERNAL_10 : std_logic ;
  signal CPI_D_INST_INTERNAL_11 : std_logic ;
  signal CPI_D_INST_INTERNAL_12 : std_logic ;
  signal CPI_D_INST_INTERNAL_13 : std_logic ;
  signal CPI_D_INST_INTERNAL_14 : std_logic ;
  signal CPI_D_INST_INTERNAL_15 : std_logic ;
  signal CPI_D_INST_INTERNAL_16 : std_logic ;
  signal CPI_D_INST_INTERNAL_17 : std_logic ;
  signal CPI_D_INST_INTERNAL_19 : std_logic ;
  signal CPI_D_INST_INTERNAL_20 : std_logic ;
  signal CPI_D_INST_INTERNAL_21 : std_logic ;
  signal CPI_D_INST_INTERNAL_22 : std_logic ;
  signal CPI_D_INST_INTERNAL_23 : std_logic ;
  signal CPI_D_INST_INTERNAL_29 : std_logic ;
  signal CPI_D_INST_INTERNAL_30 : std_logic ;
  signal CPI_D_CNT_INTERNAL : std_logic ;
  signal CPI_D_CNT_INTERNAL_0 : std_logic ;
  signal CPI_D_TRAP_INTERNAL : std_logic ;
  signal CPI_D_ANNUL_INTERNAL : std_logic ;
  signal CPI_D_PV_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL_0 : std_logic ;
  signal CPI_A_PC_INTERNAL_1 : std_logic ;
  signal CPI_A_PC_INTERNAL_2 : std_logic ;
  signal CPI_A_PC_INTERNAL_3 : std_logic ;
  signal CPI_A_PC_INTERNAL_4 : std_logic ;
  signal CPI_A_PC_INTERNAL_5 : std_logic ;
  signal CPI_A_PC_INTERNAL_6 : std_logic ;
  signal CPI_A_PC_INTERNAL_7 : std_logic ;
  signal CPI_A_PC_INTERNAL_8 : std_logic ;
  signal CPI_A_PC_INTERNAL_9 : std_logic ;
  signal CPI_A_PC_INTERNAL_10 : std_logic ;
  signal CPI_A_PC_INTERNAL_11 : std_logic ;
  signal CPI_A_PC_INTERNAL_12 : std_logic ;
  signal CPI_A_PC_INTERNAL_13 : std_logic ;
  signal CPI_A_PC_INTERNAL_14 : std_logic ;
  signal CPI_A_PC_INTERNAL_15 : std_logic ;
  signal CPI_A_PC_INTERNAL_16 : std_logic ;
  signal CPI_A_PC_INTERNAL_17 : std_logic ;
  signal CPI_A_PC_INTERNAL_18 : std_logic ;
  signal CPI_A_PC_INTERNAL_19 : std_logic ;
  signal CPI_A_PC_INTERNAL_20 : std_logic ;
  signal CPI_A_PC_INTERNAL_21 : std_logic ;
  signal CPI_A_PC_INTERNAL_22 : std_logic ;
  signal CPI_A_PC_INTERNAL_23 : std_logic ;
  signal CPI_A_PC_INTERNAL_24 : std_logic ;
  signal CPI_A_PC_INTERNAL_25 : std_logic ;
  signal CPI_A_PC_INTERNAL_26 : std_logic ;
  signal CPI_A_PC_INTERNAL_27 : std_logic ;
  signal CPI_A_PC_INTERNAL_28 : std_logic ;
  signal CPI_A_PC_INTERNAL_29 : std_logic ;
  signal CPI_A_PC_INTERNAL_30 : std_logic ;
  signal CPI_A_INST_INTERNAL : std_logic ;
  signal CPI_A_INST_INTERNAL_0 : std_logic ;
  signal CPI_A_INST_INTERNAL_1 : std_logic ;
  signal CPI_A_INST_INTERNAL_2 : std_logic ;
  signal CPI_A_INST_INTERNAL_3 : std_logic ;
  signal CPI_A_INST_INTERNAL_4 : std_logic ;
  signal CPI_A_INST_INTERNAL_5 : std_logic ;
  signal CPI_A_INST_INTERNAL_6 : std_logic ;
  signal CPI_A_INST_INTERNAL_7 : std_logic ;
  signal CPI_A_INST_INTERNAL_8 : std_logic ;
  signal CPI_A_INST_INTERNAL_9 : std_logic ;
  signal CPI_A_INST_INTERNAL_10 : std_logic ;
  signal CPI_A_INST_INTERNAL_11 : std_logic ;
  signal CPI_A_INST_INTERNAL_12 : std_logic ;
  signal CPI_A_INST_INTERNAL_13 : std_logic ;
  signal CPI_A_INST_INTERNAL_14 : std_logic ;
  signal CPI_A_INST_INTERNAL_15 : std_logic ;
  signal CPI_A_INST_INTERNAL_16 : std_logic ;
  signal CPI_A_INST_INTERNAL_17 : std_logic ;
  signal CPI_A_INST_INTERNAL_18 : std_logic ;
  signal CPI_A_INST_INTERNAL_19 : std_logic ;
  signal CPI_A_INST_INTERNAL_20 : std_logic ;
  signal CPI_A_INST_INTERNAL_21 : std_logic ;
  signal CPI_A_INST_INTERNAL_22 : std_logic ;
  signal CPI_A_INST_INTERNAL_23 : std_logic ;
  signal CPI_A_INST_INTERNAL_24 : std_logic ;
  signal CPI_A_INST_INTERNAL_25 : std_logic ;
  signal CPI_A_INST_INTERNAL_26 : std_logic ;
  signal CPI_A_INST_INTERNAL_27 : std_logic ;
  signal CPI_A_INST_INTERNAL_28 : std_logic ;
  signal CPI_A_INST_INTERNAL_29 : std_logic ;
  signal CPI_A_INST_INTERNAL_30 : std_logic ;
  signal CPI_A_CNT_INTERNAL : std_logic ;
  signal CPI_A_CNT_INTERNAL_0 : std_logic ;
  signal CPI_A_TRAP_INTERNAL : std_logic ;
  signal CPI_A_ANNUL_INTERNAL : std_logic ;
  signal CPI_A_PV_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL_0 : std_logic ;
  signal CPI_E_PC_INTERNAL_1 : std_logic ;
  signal CPI_E_PC_INTERNAL_2 : std_logic ;
  signal CPI_E_PC_INTERNAL_3 : std_logic ;
  signal CPI_E_PC_INTERNAL_4 : std_logic ;
  signal CPI_E_PC_INTERNAL_5 : std_logic ;
  signal CPI_E_PC_INTERNAL_6 : std_logic ;
  signal CPI_E_PC_INTERNAL_7 : std_logic ;
  signal CPI_E_PC_INTERNAL_8 : std_logic ;
  signal CPI_E_PC_INTERNAL_9 : std_logic ;
  signal CPI_E_PC_INTERNAL_10 : std_logic ;
  signal CPI_E_PC_INTERNAL_11 : std_logic ;
  signal CPI_E_PC_INTERNAL_12 : std_logic ;
  signal CPI_E_PC_INTERNAL_13 : std_logic ;
  signal CPI_E_PC_INTERNAL_14 : std_logic ;
  signal CPI_E_PC_INTERNAL_15 : std_logic ;
  signal CPI_E_PC_INTERNAL_16 : std_logic ;
  signal CPI_E_PC_INTERNAL_17 : std_logic ;
  signal CPI_E_PC_INTERNAL_18 : std_logic ;
  signal CPI_E_PC_INTERNAL_19 : std_logic ;
  signal CPI_E_PC_INTERNAL_20 : std_logic ;
  signal CPI_E_PC_INTERNAL_21 : std_logic ;
  signal CPI_E_PC_INTERNAL_22 : std_logic ;
  signal CPI_E_PC_INTERNAL_23 : std_logic ;
  signal CPI_E_PC_INTERNAL_24 : std_logic ;
  signal CPI_E_PC_INTERNAL_25 : std_logic ;
  signal CPI_E_PC_INTERNAL_26 : std_logic ;
  signal CPI_E_PC_INTERNAL_27 : std_logic ;
  signal CPI_E_PC_INTERNAL_28 : std_logic ;
  signal CPI_E_PC_INTERNAL_29 : std_logic ;
  signal CPI_E_PC_INTERNAL_30 : std_logic ;
  signal CPI_E_INST_INTERNAL : std_logic ;
  signal CPI_E_INST_INTERNAL_0 : std_logic ;
  signal CPI_E_INST_INTERNAL_1 : std_logic ;
  signal CPI_E_INST_INTERNAL_2 : std_logic ;
  signal CPI_E_INST_INTERNAL_3 : std_logic ;
  signal CPI_E_INST_INTERNAL_4 : std_logic ;
  signal CPI_E_INST_INTERNAL_5 : std_logic ;
  signal CPI_E_INST_INTERNAL_6 : std_logic ;
  signal CPI_E_INST_INTERNAL_7 : std_logic ;
  signal CPI_E_INST_INTERNAL_8 : std_logic ;
  signal CPI_E_INST_INTERNAL_9 : std_logic ;
  signal CPI_E_INST_INTERNAL_10 : std_logic ;
  signal CPI_E_INST_INTERNAL_11 : std_logic ;
  signal CPI_E_INST_INTERNAL_12 : std_logic ;
  signal CPI_E_INST_INTERNAL_13 : std_logic ;
  signal CPI_E_INST_INTERNAL_14 : std_logic ;
  signal CPI_E_INST_INTERNAL_15 : std_logic ;
  signal CPI_E_INST_INTERNAL_16 : std_logic ;
  signal CPI_E_INST_INTERNAL_17 : std_logic ;
  signal CPI_E_INST_INTERNAL_18 : std_logic ;
  signal CPI_E_INST_INTERNAL_19 : std_logic ;
  signal CPI_E_INST_INTERNAL_20 : std_logic ;
  signal CPI_E_INST_INTERNAL_21 : std_logic ;
  signal CPI_E_INST_INTERNAL_22 : std_logic ;
  signal CPI_E_INST_INTERNAL_23 : std_logic ;
  signal CPI_E_INST_INTERNAL_24 : std_logic ;
  signal CPI_E_INST_INTERNAL_25 : std_logic ;
  signal CPI_E_INST_INTERNAL_26 : std_logic ;
  signal CPI_E_INST_INTERNAL_27 : std_logic ;
  signal CPI_E_INST_INTERNAL_28 : std_logic ;
  signal CPI_E_INST_INTERNAL_29 : std_logic ;
  signal CPI_E_INST_INTERNAL_30 : std_logic ;
  signal CPI_E_TRAP_INTERNAL : std_logic ;
  signal CPI_E_ANNUL_INTERNAL : std_logic ;
  signal CPI_E_PV_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL_0 : std_logic ;
  signal CPI_M_PC_INTERNAL_1 : std_logic ;
  signal CPI_M_PC_INTERNAL_2 : std_logic ;
  signal CPI_M_PC_INTERNAL_3 : std_logic ;
  signal CPI_M_PC_INTERNAL_4 : std_logic ;
  signal CPI_M_PC_INTERNAL_5 : std_logic ;
  signal CPI_M_PC_INTERNAL_6 : std_logic ;
  signal CPI_M_PC_INTERNAL_7 : std_logic ;
  signal CPI_M_PC_INTERNAL_8 : std_logic ;
  signal CPI_M_PC_INTERNAL_9 : std_logic ;
  signal CPI_M_PC_INTERNAL_10 : std_logic ;
  signal CPI_M_PC_INTERNAL_11 : std_logic ;
  signal CPI_M_PC_INTERNAL_12 : std_logic ;
  signal CPI_M_PC_INTERNAL_13 : std_logic ;
  signal CPI_M_PC_INTERNAL_14 : std_logic ;
  signal CPI_M_PC_INTERNAL_15 : std_logic ;
  signal CPI_M_PC_INTERNAL_16 : std_logic ;
  signal CPI_M_PC_INTERNAL_17 : std_logic ;
  signal CPI_M_PC_INTERNAL_18 : std_logic ;
  signal CPI_M_PC_INTERNAL_19 : std_logic ;
  signal CPI_M_PC_INTERNAL_20 : std_logic ;
  signal CPI_M_PC_INTERNAL_21 : std_logic ;
  signal CPI_M_PC_INTERNAL_22 : std_logic ;
  signal CPI_M_PC_INTERNAL_23 : std_logic ;
  signal CPI_M_PC_INTERNAL_24 : std_logic ;
  signal CPI_M_PC_INTERNAL_25 : std_logic ;
  signal CPI_M_PC_INTERNAL_26 : std_logic ;
  signal CPI_M_PC_INTERNAL_27 : std_logic ;
  signal CPI_M_PC_INTERNAL_28 : std_logic ;
  signal CPI_M_PC_INTERNAL_29 : std_logic ;
  signal CPI_M_PC_INTERNAL_30 : std_logic ;
  signal CPI_M_INST_INTERNAL : std_logic ;
  signal CPI_M_INST_INTERNAL_0 : std_logic ;
  signal CPI_M_INST_INTERNAL_1 : std_logic ;
  signal CPI_M_INST_INTERNAL_2 : std_logic ;
  signal CPI_M_INST_INTERNAL_3 : std_logic ;
  signal CPI_M_INST_INTERNAL_4 : std_logic ;
  signal CPI_M_INST_INTERNAL_5 : std_logic ;
  signal CPI_M_INST_INTERNAL_6 : std_logic ;
  signal CPI_M_INST_INTERNAL_7 : std_logic ;
  signal CPI_M_INST_INTERNAL_8 : std_logic ;
  signal CPI_M_INST_INTERNAL_9 : std_logic ;
  signal CPI_M_INST_INTERNAL_10 : std_logic ;
  signal CPI_M_INST_INTERNAL_11 : std_logic ;
  signal CPI_M_INST_INTERNAL_12 : std_logic ;
  signal CPI_M_INST_INTERNAL_13 : std_logic ;
  signal CPI_M_INST_INTERNAL_14 : std_logic ;
  signal CPI_M_INST_INTERNAL_15 : std_logic ;
  signal CPI_M_INST_INTERNAL_16 : std_logic ;
  signal CPI_M_INST_INTERNAL_17 : std_logic ;
  signal CPI_M_INST_INTERNAL_18 : std_logic ;
  signal CPI_M_INST_INTERNAL_19 : std_logic ;
  signal CPI_M_INST_INTERNAL_20 : std_logic ;
  signal CPI_M_INST_INTERNAL_21 : std_logic ;
  signal CPI_M_INST_INTERNAL_22 : std_logic ;
  signal CPI_M_INST_INTERNAL_23 : std_logic ;
  signal CPI_M_INST_INTERNAL_24 : std_logic ;
  signal CPI_M_INST_INTERNAL_25 : std_logic ;
  signal CPI_M_INST_INTERNAL_26 : std_logic ;
  signal CPI_M_INST_INTERNAL_27 : std_logic ;
  signal CPI_M_INST_INTERNAL_28 : std_logic ;
  signal CPI_M_INST_INTERNAL_29 : std_logic ;
  signal CPI_M_INST_INTERNAL_30 : std_logic ;
  signal CPI_M_CNT_INTERNAL : std_logic ;
  signal CPI_M_CNT_INTERNAL_0 : std_logic ;
  signal CPI_M_TRAP_INTERNAL : std_logic ;
  signal CPI_M_ANNUL_INTERNAL : std_logic ;
  signal CPI_M_PV_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL_0 : std_logic ;
  signal CPI_X_PC_INTERNAL_1 : std_logic ;
  signal CPI_X_PC_INTERNAL_2 : std_logic ;
  signal CPI_X_PC_INTERNAL_3 : std_logic ;
  signal CPI_X_PC_INTERNAL_4 : std_logic ;
  signal CPI_X_PC_INTERNAL_5 : std_logic ;
  signal CPI_X_PC_INTERNAL_6 : std_logic ;
  signal CPI_X_PC_INTERNAL_7 : std_logic ;
  signal CPI_X_PC_INTERNAL_8 : std_logic ;
  signal CPI_X_PC_INTERNAL_9 : std_logic ;
  signal CPI_X_PC_INTERNAL_10 : std_logic ;
  signal CPI_X_PC_INTERNAL_11 : std_logic ;
  signal CPI_X_PC_INTERNAL_12 : std_logic ;
  signal CPI_X_PC_INTERNAL_13 : std_logic ;
  signal CPI_X_PC_INTERNAL_14 : std_logic ;
  signal CPI_X_PC_INTERNAL_15 : std_logic ;
  signal CPI_X_PC_INTERNAL_16 : std_logic ;
  signal CPI_X_PC_INTERNAL_17 : std_logic ;
  signal CPI_X_PC_INTERNAL_18 : std_logic ;
  signal CPI_X_PC_INTERNAL_19 : std_logic ;
  signal CPI_X_PC_INTERNAL_20 : std_logic ;
  signal CPI_X_PC_INTERNAL_21 : std_logic ;
  signal CPI_X_PC_INTERNAL_22 : std_logic ;
  signal CPI_X_PC_INTERNAL_23 : std_logic ;
  signal CPI_X_PC_INTERNAL_24 : std_logic ;
  signal CPI_X_PC_INTERNAL_25 : std_logic ;
  signal CPI_X_PC_INTERNAL_26 : std_logic ;
  signal CPI_X_PC_INTERNAL_27 : std_logic ;
  signal CPI_X_PC_INTERNAL_28 : std_logic ;
  signal CPI_X_PC_INTERNAL_29 : std_logic ;
  signal CPI_X_PC_INTERNAL_30 : std_logic ;
  signal CPI_X_INST_INTERNAL : std_logic ;
  signal CPI_X_INST_INTERNAL_0 : std_logic ;
  signal CPI_X_INST_INTERNAL_1 : std_logic ;
  signal CPI_X_INST_INTERNAL_2 : std_logic ;
  signal CPI_X_INST_INTERNAL_3 : std_logic ;
  signal CPI_X_INST_INTERNAL_4 : std_logic ;
  signal CPI_X_INST_INTERNAL_5 : std_logic ;
  signal CPI_X_INST_INTERNAL_6 : std_logic ;
  signal CPI_X_INST_INTERNAL_7 : std_logic ;
  signal CPI_X_INST_INTERNAL_8 : std_logic ;
  signal CPI_X_INST_INTERNAL_9 : std_logic ;
  signal CPI_X_INST_INTERNAL_10 : std_logic ;
  signal CPI_X_INST_INTERNAL_11 : std_logic ;
  signal CPI_X_INST_INTERNAL_12 : std_logic ;
  signal CPI_X_INST_INTERNAL_13 : std_logic ;
  signal CPI_X_INST_INTERNAL_14 : std_logic ;
  signal CPI_X_INST_INTERNAL_15 : std_logic ;
  signal CPI_X_INST_INTERNAL_16 : std_logic ;
  signal CPI_X_INST_INTERNAL_17 : std_logic ;
  signal CPI_X_INST_INTERNAL_18 : std_logic ;
  signal CPI_X_INST_INTERNAL_19 : std_logic ;
  signal CPI_X_INST_INTERNAL_20 : std_logic ;
  signal CPI_X_INST_INTERNAL_21 : std_logic ;
  signal CPI_X_INST_INTERNAL_22 : std_logic ;
  signal CPI_X_INST_INTERNAL_23 : std_logic ;
  signal CPI_X_INST_INTERNAL_24 : std_logic ;
  signal CPI_X_INST_INTERNAL_25 : std_logic ;
  signal CPI_X_INST_INTERNAL_26 : std_logic ;
  signal CPI_X_INST_INTERNAL_27 : std_logic ;
  signal CPI_X_INST_INTERNAL_28 : std_logic ;
  signal CPI_X_INST_INTERNAL_29 : std_logic ;
  signal CPI_X_INST_INTERNAL_30 : std_logic ;
  signal CPI_X_CNT_INTERNAL : std_logic ;
  signal CPI_X_CNT_INTERNAL_0 : std_logic ;
  signal CPI_X_TRAP_INTERNAL : std_logic ;
  signal CPI_X_ANNUL_INTERNAL : std_logic ;
  signal CPI_X_PV_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL_0 : std_logic ;
  signal CPI_LDDATA_INTERNAL_1 : std_logic ;
  signal CPI_LDDATA_INTERNAL_2 : std_logic ;
  signal CPI_LDDATA_INTERNAL_3 : std_logic ;
  signal CPI_LDDATA_INTERNAL_4 : std_logic ;
  signal CPI_LDDATA_INTERNAL_5 : std_logic ;
  signal CPI_LDDATA_INTERNAL_6 : std_logic ;
  signal CPI_LDDATA_INTERNAL_7 : std_logic ;
  signal CPI_LDDATA_INTERNAL_8 : std_logic ;
  signal CPI_LDDATA_INTERNAL_9 : std_logic ;
  signal CPI_LDDATA_INTERNAL_10 : std_logic ;
  signal CPI_LDDATA_INTERNAL_11 : std_logic ;
  signal CPI_LDDATA_INTERNAL_12 : std_logic ;
  signal CPI_LDDATA_INTERNAL_13 : std_logic ;
  signal CPI_LDDATA_INTERNAL_14 : std_logic ;
  signal CPI_LDDATA_INTERNAL_15 : std_logic ;
  signal CPI_LDDATA_INTERNAL_16 : std_logic ;
  signal CPI_LDDATA_INTERNAL_17 : std_logic ;
  signal CPI_LDDATA_INTERNAL_18 : std_logic ;
  signal CPI_LDDATA_INTERNAL_19 : std_logic ;
  signal CPI_LDDATA_INTERNAL_20 : std_logic ;
  signal CPI_LDDATA_INTERNAL_21 : std_logic ;
  signal CPI_LDDATA_INTERNAL_22 : std_logic ;
  signal CPI_LDDATA_INTERNAL_23 : std_logic ;
  signal CPI_LDDATA_INTERNAL_24 : std_logic ;
  signal CPI_LDDATA_INTERNAL_25 : std_logic ;
  signal CPI_LDDATA_INTERNAL_26 : std_logic ;
  signal CPI_LDDATA_INTERNAL_27 : std_logic ;
  signal CPI_LDDATA_INTERNAL_28 : std_logic ;
  signal CPI_LDDATA_INTERNAL_29 : std_logic ;
  signal CPI_LDDATA_INTERNAL_30 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_0 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_1 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_2 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_0 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_1 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_2 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_4 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_5 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_6 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_7 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_8 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_9 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_10 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_11 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_12 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_13 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_14 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_15 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_16 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_17 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_18 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_19 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_20 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_21 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_22 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_23 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_24 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_25 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_26 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_27 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_28 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_29 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_30 : std_logic ;
  signal RFO1_DATA1_INTERNAL : std_logic ;
  signal RFO1_DATA1_INTERNAL_0 : std_logic ;
  signal RFO1_DATA1_INTERNAL_1 : std_logic ;
  signal RFO1_DATA1_INTERNAL_2 : std_logic ;
  signal RFO1_DATA1_INTERNAL_3 : std_logic ;
  signal RFO1_DATA1_INTERNAL_4 : std_logic ;
  signal RFO1_DATA1_INTERNAL_5 : std_logic ;
  signal RFO1_DATA1_INTERNAL_6 : std_logic ;
  signal RFO1_DATA1_INTERNAL_7 : std_logic ;
  signal RFO1_DATA1_INTERNAL_8 : std_logic ;
  signal RFO1_DATA1_INTERNAL_9 : std_logic ;
  signal RFO1_DATA1_INTERNAL_10 : std_logic ;
  signal RFO1_DATA1_INTERNAL_11 : std_logic ;
  signal RFO1_DATA1_INTERNAL_12 : std_logic ;
  signal RFO1_DATA1_INTERNAL_13 : std_logic ;
  signal RFO1_DATA1_INTERNAL_14 : std_logic ;
  signal RFO1_DATA1_INTERNAL_15 : std_logic ;
  signal RFO1_DATA1_INTERNAL_16 : std_logic ;
  signal RFO1_DATA1_INTERNAL_17 : std_logic ;
  signal RFO1_DATA1_INTERNAL_18 : std_logic ;
  signal RFO1_DATA1_INTERNAL_19 : std_logic ;
  signal RFO1_DATA1_INTERNAL_20 : std_logic ;
  signal RFO1_DATA1_INTERNAL_21 : std_logic ;
  signal RFO1_DATA1_INTERNAL_22 : std_logic ;
  signal RFO1_DATA1_INTERNAL_23 : std_logic ;
  signal RFO1_DATA1_INTERNAL_24 : std_logic ;
  signal RFO1_DATA1_INTERNAL_25 : std_logic ;
  signal RFO1_DATA1_INTERNAL_26 : std_logic ;
  signal RFO1_DATA1_INTERNAL_27 : std_logic ;
  signal RFO1_DATA1_INTERNAL_28 : std_logic ;
  signal RFO1_DATA1_INTERNAL_29 : std_logic ;
  signal RFO1_DATA1_INTERNAL_30 : std_logic ;
  signal RFO1_DATA2_INTERNAL : std_logic ;
  signal RFO1_DATA2_INTERNAL_0 : std_logic ;
  signal RFO1_DATA2_INTERNAL_1 : std_logic ;
  signal RFO1_DATA2_INTERNAL_2 : std_logic ;
  signal RFO1_DATA2_INTERNAL_3 : std_logic ;
  signal RFO1_DATA2_INTERNAL_4 : std_logic ;
  signal RFO1_DATA2_INTERNAL_5 : std_logic ;
  signal RFO1_DATA2_INTERNAL_6 : std_logic ;
  signal RFO1_DATA2_INTERNAL_7 : std_logic ;
  signal RFO1_DATA2_INTERNAL_8 : std_logic ;
  signal RFO1_DATA2_INTERNAL_9 : std_logic ;
  signal RFO1_DATA2_INTERNAL_10 : std_logic ;
  signal RFO1_DATA2_INTERNAL_11 : std_logic ;
  signal RFO1_DATA2_INTERNAL_12 : std_logic ;
  signal RFO1_DATA2_INTERNAL_13 : std_logic ;
  signal RFO1_DATA2_INTERNAL_14 : std_logic ;
  signal RFO1_DATA2_INTERNAL_15 : std_logic ;
  signal RFO1_DATA2_INTERNAL_16 : std_logic ;
  signal RFO1_DATA2_INTERNAL_17 : std_logic ;
  signal RFO1_DATA2_INTERNAL_18 : std_logic ;
  signal RFO1_DATA2_INTERNAL_19 : std_logic ;
  signal RFO1_DATA2_INTERNAL_20 : std_logic ;
  signal RFO1_DATA2_INTERNAL_21 : std_logic ;
  signal RFO1_DATA2_INTERNAL_22 : std_logic ;
  signal RFO1_DATA2_INTERNAL_23 : std_logic ;
  signal RFO1_DATA2_INTERNAL_24 : std_logic ;
  signal RFO1_DATA2_INTERNAL_25 : std_logic ;
  signal RFO1_DATA2_INTERNAL_26 : std_logic ;
  signal RFO1_DATA2_INTERNAL_27 : std_logic ;
  signal RFO1_DATA2_INTERNAL_28 : std_logic ;
  signal RFO1_DATA2_INTERNAL_29 : std_logic ;
  signal RFO1_DATA2_INTERNAL_30 : std_logic ;
  signal RFO2_DATA1_INTERNAL : std_logic ;
  signal RFO2_DATA1_INTERNAL_0 : std_logic ;
  signal RFO2_DATA1_INTERNAL_1 : std_logic ;
  signal RFO2_DATA1_INTERNAL_2 : std_logic ;
  signal RFO2_DATA1_INTERNAL_3 : std_logic ;
  signal RFO2_DATA1_INTERNAL_4 : std_logic ;
  signal RFO2_DATA1_INTERNAL_5 : std_logic ;
  signal RFO2_DATA1_INTERNAL_6 : std_logic ;
  signal RFO2_DATA1_INTERNAL_7 : std_logic ;
  signal RFO2_DATA1_INTERNAL_8 : std_logic ;
  signal RFO2_DATA1_INTERNAL_9 : std_logic ;
  signal RFO2_DATA1_INTERNAL_10 : std_logic ;
  signal RFO2_DATA1_INTERNAL_11 : std_logic ;
  signal RFO2_DATA1_INTERNAL_12 : std_logic ;
  signal RFO2_DATA1_INTERNAL_13 : std_logic ;
  signal RFO2_DATA1_INTERNAL_14 : std_logic ;
  signal RFO2_DATA1_INTERNAL_15 : std_logic ;
  signal RFO2_DATA1_INTERNAL_16 : std_logic ;
  signal RFO2_DATA1_INTERNAL_17 : std_logic ;
  signal RFO2_DATA1_INTERNAL_18 : std_logic ;
  signal RFO2_DATA1_INTERNAL_19 : std_logic ;
  signal RFO2_DATA1_INTERNAL_20 : std_logic ;
  signal RFO2_DATA1_INTERNAL_21 : std_logic ;
  signal RFO2_DATA1_INTERNAL_22 : std_logic ;
  signal RFO2_DATA1_INTERNAL_23 : std_logic ;
  signal RFO2_DATA1_INTERNAL_24 : std_logic ;
  signal RFO2_DATA1_INTERNAL_25 : std_logic ;
  signal RFO2_DATA1_INTERNAL_26 : std_logic ;
  signal RFO2_DATA1_INTERNAL_27 : std_logic ;
  signal RFO2_DATA1_INTERNAL_28 : std_logic ;
  signal RFO2_DATA1_INTERNAL_29 : std_logic ;
  signal RFO2_DATA1_INTERNAL_30 : std_logic ;
  signal RFO2_DATA2_INTERNAL : std_logic ;
  signal RFO2_DATA2_INTERNAL_0 : std_logic ;
  signal RFO2_DATA2_INTERNAL_1 : std_logic ;
  signal RFO2_DATA2_INTERNAL_2 : std_logic ;
  signal RFO2_DATA2_INTERNAL_3 : std_logic ;
  signal RFO2_DATA2_INTERNAL_4 : std_logic ;
  signal RFO2_DATA2_INTERNAL_5 : std_logic ;
  signal RFO2_DATA2_INTERNAL_6 : std_logic ;
  signal RFO2_DATA2_INTERNAL_7 : std_logic ;
  signal RFO2_DATA2_INTERNAL_8 : std_logic ;
  signal RFO2_DATA2_INTERNAL_9 : std_logic ;
  signal RFO2_DATA2_INTERNAL_10 : std_logic ;
  signal RFO2_DATA2_INTERNAL_11 : std_logic ;
  signal RFO2_DATA2_INTERNAL_12 : std_logic ;
  signal RFO2_DATA2_INTERNAL_13 : std_logic ;
  signal RFO2_DATA2_INTERNAL_14 : std_logic ;
  signal RFO2_DATA2_INTERNAL_15 : std_logic ;
  signal RFO2_DATA2_INTERNAL_16 : std_logic ;
  signal RFO2_DATA2_INTERNAL_17 : std_logic ;
  signal RFO2_DATA2_INTERNAL_18 : std_logic ;
  signal RFO2_DATA2_INTERNAL_19 : std_logic ;
  signal RFO2_DATA2_INTERNAL_20 : std_logic ;
  signal RFO2_DATA2_INTERNAL_21 : std_logic ;
  signal RFO2_DATA2_INTERNAL_22 : std_logic ;
  signal RFO2_DATA2_INTERNAL_23 : std_logic ;
  signal RFO2_DATA2_INTERNAL_24 : std_logic ;
  signal RFO2_DATA2_INTERNAL_25 : std_logic ;
  signal RFO2_DATA2_INTERNAL_26 : std_logic ;
  signal RFO2_DATA2_INTERNAL_27 : std_logic ;
  signal RFO2_DATA2_INTERNAL_28 : std_logic ;
  signal RFO2_DATA2_INTERNAL_29 : std_logic ;
  signal RFO2_DATA2_INTERNAL_30 : std_logic ;
  signal \GRFPC0.R.FSR.NONSTD\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD0\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD1\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD2\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD3\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD4\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_ADD5\ : std_logic ;
  signal \GRFPC0.RFA2.FLUSH\ : std_logic ;
  signal GND : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.CS_DP_R\ : std_logic ;
  signal \GRFPU0.FPMUL0.CS_ITER_R_0_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.CSADD.UN335_C1\ : std_logic ;
  signal \GRFPU0.FPMUL0.CSADD.UN332_C2\ : std_logic ;
  signal \GRFPU0.FPMUL0.CSADD.UN303_MC2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD78\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD78\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_0_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_1_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_3\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_2_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_3_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_4_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_3\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_5_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_5_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_1\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_7_6_0__ROM\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_0\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_0_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_0_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_0_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_0_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_1_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_1_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_1_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_1_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_1_6__ROM_3\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_2_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_2_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_2_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_2_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_3_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_3_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_3_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_3_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_4_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_4_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_4_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_5_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_5_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_5_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_5_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_5_6__ROM_5\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_7_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_7_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_7_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_8_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_8_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_8_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_8_6__ROM_2\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_9_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_9_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_9_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_9_6__ROM_4\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_10_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_11_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_11_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_11_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_12_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_12_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_13_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_13_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_14_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_14_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_14_6__ROM_1\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_15_6_0__ROM\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_15_6__ROM_0\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_15_6__ROM_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.ODDEXP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SGNFEQ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.LOB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMAX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ADD\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.IOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.MOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.ADDOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.STICKYI_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_8_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_ADD11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_2__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_3__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_4__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_6__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_7__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_8__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_9__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_10__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_11__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_12__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_13__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_15__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_16__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_17__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_0__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_2__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_3__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_4__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_5__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_6__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_7__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_8__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_55__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_7__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_4__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_1_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_1__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3209\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3210\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3211\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3212\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3215\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3216\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DIFFIN116\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ITCIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ALLOW_0_2__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.RDY_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.RDY_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_2__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_3__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_4__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_2__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_4__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_5__G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.STICKY_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_22__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_20__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_8__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10132\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_0__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN1_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ITER_OF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1_U\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.INF_0_SQMUXA_43_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.QSNAN_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_61\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_62\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_63\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.LD\ : std_logic ;
  signal \GRFPC0.FIFO.FULL\ : std_logic ;
  signal \GRFPC0.RFA.RS2D\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.EX.RREG.RESV\ : std_logic ;
  signal \GRFPC0.DIV.VALID\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.DIV.PEND\ : std_logic ;
  signal \GRFPC0.DIV.RDD\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.LD\ : std_logic ;
  signal \GRFPC0.EX.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD\ : std_logic ;
  signal \GRFPC0.RFA.ST\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.LD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.FPR.RDY\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR2.EXC\ : std_logic ;
  signal \GRFPC0.DIV.EXC\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.RFA.RS1D\ : std_logic ;
  signal \GRFPC0.RFA.LD\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP\ : std_logic ;
  signal \GRFPC0.RFA2.DIVLCK\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\ : std_logic ;
  signal \GRFPC0.DIV.EXEC\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.WR.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN77_PENDEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2503_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2_0_A2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3529_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4238_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.RFA.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN962_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2285_REGDEPX2\ : std_logic ;
  signal \GRFPC0.UN1_DIV.EXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FIFOV2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_OP_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE10\ : std_logic ;
  signal \GRFPC0.FIFO_INC_5_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN24_FPUSTART\ : std_logic ;
  signal \GRFPC0.DIV.RS1V\ : std_logic ;
  signal \GRFPC0.D.FSTLCK\ : std_logic ;
  signal \GRFPC0.D.FLDLCK\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.RFA.AFSR\ : std_logic ;
  signal \GRFPC0.RFA.RDWR\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.UN1_WRENX10_I\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_1__G0\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_1__G0\ : std_logic ;
  signal \GRFPC0.REGDEP_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.REGDEP_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G0\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_0__G0_I\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G0_0\ : std_logic ;
  signal \GRFPC0.DIV.VALID_0_0_G0_X\ : std_logic ;
  signal \GRFPC0.DIV.EXEC_0_0_G0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES_U\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\ : std_logic ;
  signal \GRFPC0.N_20423\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_1_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\ : std_logic ;
  signal \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2049_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN27_PENDEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3608_REGDEPX2_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDBL_1_1_U\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN8_OP_7_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_I_I_A2_1_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5120_REGDEPX2_1_I_O2\ : std_logic ;
  signal N_6 : std_logic ;
  signal N_7 : std_logic ;
  signal N_8 : std_logic ;
  signal N_9 : std_logic ;
  signal N_10 : std_logic ;
  signal N_11 : std_logic ;
  signal N_12 : std_logic ;
  signal N_13 : std_logic ;
  signal N_14 : std_logic ;
  signal N_15 : std_logic ;
  signal N_16 : std_logic ;
  signal N_17 : std_logic ;
  signal N_18 : std_logic ;
  signal N_19 : std_logic ;
  signal N_20 : std_logic ;
  signal N_21 : std_logic ;
  signal N_22 : std_logic ;
  signal N_23 : std_logic ;
  signal N_24 : std_logic ;
  signal N_25 : std_logic ;
  signal N_26 : std_logic ;
  signal N_27 : std_logic ;
  signal N_28 : std_logic ;
  signal N_29 : std_logic ;
  signal N_30 : std_logic ;
  signal N_31 : std_logic ;
  signal N_32 : std_logic ;
  signal N_33 : std_logic ;
  signal N_34 : std_logic ;
  signal N_35 : std_logic ;
  signal N_36 : std_logic ;
  signal N_37 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1S2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2S2_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13452_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13472_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19845_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19861_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19862_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19857_I_0_G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20002_I_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19993_I_0_G0\ : std_logic ;
  signal \GRFPC0.N_17807_I_0_G0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.DIV.EXC_1_0_G0_I\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_2__G0_0\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_1__G0_I\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_2__G0_I\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_3__G0_I\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_4__G0_I\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_5__G0_I\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_6__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_7__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_8__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_9__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_10__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_11__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_12__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_13__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_14__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_15__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_16__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_17__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_18__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_19__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_20__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_21__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_22__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_23__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_24__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_25__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_26__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_27__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_28__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_29__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_30__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_31__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_32__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_33__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_34__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_35__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_36__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_37__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_38__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_39__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_40__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_41__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_42__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_43__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_44__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_45__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_46__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_47__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_48__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_49__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_50__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_51__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_52__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_53__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_54__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_55__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_56__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_57__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_58__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_59__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_60__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_61__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_62__G0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_63__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_0__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_2__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_3__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_6__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_7__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_8__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_9__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_10__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_11__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_12__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_13__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_14__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_15__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_16__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_17__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_18__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_19__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_20__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_21__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_22__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_23__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_24__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_25__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_26__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_27__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_28__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_29__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_30__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_31__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_32__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_33__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_34__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_35__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_36__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_37__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_38__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_39__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_40__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_41__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_42__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_43__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_44__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_45__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_46__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_47__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_48__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_49__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_50__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_51__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_52__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_53__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_54__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_55__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_56__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_57__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_58__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_59__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_60__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_61__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_62__G0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_63__G0\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_2__G0_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD78\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD12\ : std_logic ;
  signal N_31274 : std_logic ;
  signal N_31275 : std_logic ;
  signal N_31276 : std_logic ;
  signal N_31277 : std_logic ;
  signal N_31278 : std_logic ;
  signal N_31279 : std_logic ;
  signal N_31280 : std_logic ;
  signal N_31281 : std_logic ;
  signal N_31282 : std_logic ;
  signal N_31283 : std_logic ;
  signal N_31284 : std_logic ;
  signal N_31285 : std_logic ;
  signal N_31286 : std_logic ;
  signal N_31287 : std_logic ;
  signal N_31288 : std_logic ;
  signal N_31289 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_54\ : std_logic ;
  signal N_35714 : std_logic ;
  signal N_35715 : std_logic ;
  signal N_35717 : std_logic ;
  signal N_35718 : std_logic ;
  signal N_35719 : std_logic ;
  signal N_35720 : std_logic ;
  signal N_35721 : std_logic ;
  signal N_35722 : std_logic ;
  signal N_35723 : std_logic ;
  signal N_35724 : std_logic ;
  signal N_35725 : std_logic ;
  signal N_35726 : std_logic ;
  signal N_35727 : std_logic ;
  signal N_35728 : std_logic ;
  signal N_35729 : std_logic ;
  signal N_35730 : std_logic ;
  signal N_35731 : std_logic ;
  signal N_35732 : std_logic ;
  signal N_35733 : std_logic ;
  signal N_35734 : std_logic ;
  signal N_35735 : std_logic ;
  signal N_35736 : std_logic ;
  signal N_35737 : std_logic ;
  signal N_35738 : std_logic ;
  signal N_35739 : std_logic ;
  signal N_35740 : std_logic ;
  signal N_35741 : std_logic ;
  signal N_35742 : std_logic ;
  signal N_35743 : std_logic ;
  signal N_35744 : std_logic ;
  signal N_35745 : std_logic ;
  signal N_35746 : std_logic ;
  signal N_35747 : std_logic ;
  signal N_35748 : std_logic ;
  signal N_35749 : std_logic ;
  signal N_35750 : std_logic ;
  signal N_35751 : std_logic ;
  signal N_35752 : std_logic ;
  signal N_35753 : std_logic ;
  signal N_35754 : std_logic ;
  signal N_35755 : std_logic ;
  signal N_35756 : std_logic ;
  signal N_35757 : std_logic ;
  signal N_35758 : std_logic ;
  signal N_35759 : std_logic ;
  signal N_35760 : std_logic ;
  signal N_35761 : std_logic ;
  signal N_35762 : std_logic ;
  signal N_35763 : std_logic ;
  signal N_35764 : std_logic ;
  signal N_35765 : std_logic ;
  signal N_35766 : std_logic ;
  signal N_35767 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\ : std_logic ;
  signal N_35796 : std_logic ;
  signal N_35798 : std_logic ;
  signal N_35799 : std_logic ;
  signal N_35800 : std_logic ;
  signal N_35801 : std_logic ;
  signal N_35802 : std_logic ;
  signal N_35803 : std_logic ;
  signal N_35804 : std_logic ;
  signal N_35805 : std_logic ;
  signal N_35806 : std_logic ;
  signal N_35807 : std_logic ;
  signal N_35808 : std_logic ;
  signal N_35809 : std_logic ;
  signal N_35810 : std_logic ;
  signal N_35811 : std_logic ;
  signal N_35812 : std_logic ;
  signal N_35813 : std_logic ;
  signal N_35814 : std_logic ;
  signal N_35815 : std_logic ;
  signal N_35816 : std_logic ;
  signal N_35817 : std_logic ;
  signal N_35818 : std_logic ;
  signal N_35819 : std_logic ;
  signal N_35820 : std_logic ;
  signal N_35821 : std_logic ;
  signal N_35822 : std_logic ;
  signal N_35823 : std_logic ;
  signal N_35824 : std_logic ;
  signal N_35825 : std_logic ;
  signal N_35826 : std_logic ;
  signal N_35827 : std_logic ;
  signal N_35828 : std_logic ;
  signal N_35829 : std_logic ;
  signal N_35830 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\ : std_logic ;
  signal N_35838 : std_logic ;
  signal N_35839 : std_logic ;
  signal N_35840 : std_logic ;
  signal N_35841 : std_logic ;
  signal N_35842 : std_logic ;
  signal N_35843 : std_logic ;
  signal N_35844 : std_logic ;
  signal N_35875 : std_logic ;
  signal N_35876 : std_logic ;
  signal N_35877 : std_logic ;
  signal N_35878 : std_logic ;
  signal N_35879 : std_logic ;
  signal N_35880 : std_logic ;
  signal N_35881 : std_logic ;
  signal N_35882 : std_logic ;
  signal N_35883 : std_logic ;
  signal N_35884 : std_logic ;
  signal N_35885 : std_logic ;
  signal N_35886 : std_logic ;
  signal N_35887 : std_logic ;
  signal N_35888 : std_logic ;
  signal N_35889 : std_logic ;
  signal N_35890 : std_logic ;
  signal N_35891 : std_logic ;
  signal N_35892 : std_logic ;
  signal N_35893 : std_logic ;
  signal N_35894 : std_logic ;
  signal N_35895 : std_logic ;
  signal N_35896 : std_logic ;
  signal N_35897 : std_logic ;
  signal N_35898 : std_logic ;
  signal N_35899 : std_logic ;
  signal N_35900 : std_logic ;
  signal N_35901 : std_logic ;
  signal N_35902 : std_logic ;
  signal N_35903 : std_logic ;
  signal N_35904 : std_logic ;
  signal N_35905 : std_logic ;
  signal N_35906 : std_logic ;
  signal N_35907 : std_logic ;
  signal N_35908 : std_logic ;
  signal N_35909 : std_logic ;
  signal N_35910 : std_logic ;
  signal N_35911 : std_logic ;
  signal N_35912 : std_logic ;
  signal N_35913 : std_logic ;
  signal N_35914 : std_logic ;
  signal N_35915 : std_logic ;
  signal N_35916 : std_logic ;
  signal N_35917 : std_logic ;
  signal N_35918 : std_logic ;
  signal N_35919 : std_logic ;
  signal N_35920 : std_logic ;
  signal N_35921 : std_logic ;
  signal N_35922 : std_logic ;
  signal N_35923 : std_logic ;
  signal N_35924 : std_logic ;
  signal N_35925 : std_logic ;
  signal N_35926 : std_logic ;
  signal N_35929 : std_logic ;
  signal N_35930 : std_logic ;
  signal N_35932 : std_logic ;
  signal N_35933 : std_logic ;
  signal N_35934 : std_logic ;
  signal N_35935 : std_logic ;
  signal N_35936 : std_logic ;
  signal N_35937 : std_logic ;
  signal N_35938 : std_logic ;
  signal N_35939 : std_logic ;
  signal N_35940 : std_logic ;
  signal N_35941 : std_logic ;
  signal N_35942 : std_logic ;
  signal N_35943 : std_logic ;
  signal N_35944 : std_logic ;
  signal N_35945 : std_logic ;
  signal N_35946 : std_logic ;
  signal N_35947 : std_logic ;
  signal N_35948 : std_logic ;
  signal N_35949 : std_logic ;
  signal N_35950 : std_logic ;
  signal N_35951 : std_logic ;
  signal N_35954 : std_logic ;
  signal N_35955 : std_logic ;
  signal N_35957 : std_logic ;
  signal N_35958 : std_logic ;
  signal N_35959 : std_logic ;
  signal N_35960 : std_logic ;
  signal N_35961 : std_logic ;
  signal N_35962 : std_logic ;
  signal N_35963 : std_logic ;
  signal N_35964 : std_logic ;
  signal N_35965 : std_logic ;
  signal N_35966 : std_logic ;
  signal N_35967 : std_logic ;
  signal N_35968 : std_logic ;
  signal N_35969 : std_logic ;
  signal N_35970 : std_logic ;
  signal N_35971 : std_logic ;
  signal N_35972 : std_logic ;
  signal N_35973 : std_logic ;
  signal N_35974 : std_logic ;
  signal N_35975 : std_logic ;
  signal N_35976 : std_logic ;
  signal N_35977 : std_logic ;
  signal N_35978 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\ : std_logic ;
  signal N_36014 : std_logic ;
  signal N_36015 : std_logic ;
  signal N_36017 : std_logic ;
  signal N_36018 : std_logic ;
  signal N_36019 : std_logic ;
  signal N_36020 : std_logic ;
  signal N_36021 : std_logic ;
  signal N_36022 : std_logic ;
  signal N_36023 : std_logic ;
  signal N_36024 : std_logic ;
  signal N_36025 : std_logic ;
  signal N_36026 : std_logic ;
  signal N_36027 : std_logic ;
  signal N_36028 : std_logic ;
  signal N_36029 : std_logic ;
  signal N_36030 : std_logic ;
  signal N_36031 : std_logic ;
  signal N_36032 : std_logic ;
  signal N_36033 : std_logic ;
  signal N_36034 : std_logic ;
  signal N_36035 : std_logic ;
  signal N_36036 : std_logic ;
  signal N_36037 : std_logic ;
  signal N_36038 : std_logic ;
  signal N_36039 : std_logic ;
  signal N_36040 : std_logic ;
  signal N_36041 : std_logic ;
  signal N_36042 : std_logic ;
  signal N_36043 : std_logic ;
  signal N_36044 : std_logic ;
  signal N_36045 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_5\ : std_logic ;
  signal N_36051 : std_logic ;
  signal N_36052 : std_logic ;
  signal N_36054 : std_logic ;
  signal N_36055 : std_logic ;
  signal N_36056 : std_logic ;
  signal N_36057 : std_logic ;
  signal N_36058 : std_logic ;
  signal N_36059 : std_logic ;
  signal N_36060 : std_logic ;
  signal N_36061 : std_logic ;
  signal N_36062 : std_logic ;
  signal N_36063 : std_logic ;
  signal N_36064 : std_logic ;
  signal N_36065 : std_logic ;
  signal N_36066 : std_logic ;
  signal N_36067 : std_logic ;
  signal N_36068 : std_logic ;
  signal N_36069 : std_logic ;
  signal N_36070 : std_logic ;
  signal N_36071 : std_logic ;
  signal N_36072 : std_logic ;
  signal N_36073 : std_logic ;
  signal N_36074 : std_logic ;
  signal N_36075 : std_logic ;
  signal N_36076 : std_logic ;
  signal N_36077 : std_logic ;
  signal N_36078 : std_logic ;
  signal N_36079 : std_logic ;
  signal N_36080 : std_logic ;
  signal N_36081 : std_logic ;
  signal N_36082 : std_logic ;
  signal N_36083 : std_logic ;
  signal N_36084 : std_logic ;
  signal N_36085 : std_logic ;
  signal N_36086 : std_logic ;
  signal N_36087 : std_logic ;
  signal N_36088 : std_logic ;
  signal N_36089 : std_logic ;
  signal N_36090 : std_logic ;
  signal N_36091 : std_logic ;
  signal N_36092 : std_logic ;
  signal N_36093 : std_logic ;
  signal N_36094 : std_logic ;
  signal N_36095 : std_logic ;
  signal N_36096 : std_logic ;
  signal N_36097 : std_logic ;
  signal N_36098 : std_logic ;
  signal N_36099 : std_logic ;
  signal N_36100 : std_logic ;
  signal N_36101 : std_logic ;
  signal N_36104 : std_logic ;
  signal N_36105 : std_logic ;
  signal N_36107 : std_logic ;
  signal N_36108 : std_logic ;
  signal N_36109 : std_logic ;
  signal N_36110 : std_logic ;
  signal N_36111 : std_logic ;
  signal N_36112 : std_logic ;
  signal N_36113 : std_logic ;
  signal N_36114 : std_logic ;
  signal N_36115 : std_logic ;
  signal N_36116 : std_logic ;
  signal N_36117 : std_logic ;
  signal N_36118 : std_logic ;
  signal N_36119 : std_logic ;
  signal N_36120 : std_logic ;
  signal N_36121 : std_logic ;
  signal N_36122 : std_logic ;
  signal N_36123 : std_logic ;
  signal N_36124 : std_logic ;
  signal N_36125 : std_logic ;
  signal N_36126 : std_logic ;
  signal N_36127 : std_logic ;
  signal N_36128 : std_logic ;
  signal N_36129 : std_logic ;
  signal N_36130 : std_logic ;
  signal N_36131 : std_logic ;
  signal N_36132 : std_logic ;
  signal N_36133 : std_logic ;
  signal N_36134 : std_logic ;
  signal N_36135 : std_logic ;
  signal N_36136 : std_logic ;
  signal N_36137 : std_logic ;
  signal N_36138 : std_logic ;
  signal N_36139 : std_logic ;
  signal N_36140 : std_logic ;
  signal N_36141 : std_logic ;
  signal N_36142 : std_logic ;
  signal N_36143 : std_logic ;
  signal N_36144 : std_logic ;
  signal N_36145 : std_logic ;
  signal N_36146 : std_logic ;
  signal N_36147 : std_logic ;
  signal N_36148 : std_logic ;
  signal N_36149 : std_logic ;
  signal N_36150 : std_logic ;
  signal N_36151 : std_logic ;
  signal N_36152 : std_logic ;
  signal N_36153 : std_logic ;
  signal N_36154 : std_logic ;
  signal N_36155 : std_logic ;
  signal N_36156 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\ : std_logic ;
  signal N_36162 : std_logic ;
  signal N_36163 : std_logic ;
  signal N_36164 : std_logic ;
  signal N_36165 : std_logic ;
  signal N_36166 : std_logic ;
  signal N_36167 : std_logic ;
  signal N_36168 : std_logic ;
  signal N_36169 : std_logic ;
  signal N_36170 : std_logic ;
  signal N_36171 : std_logic ;
  signal N_36172 : std_logic ;
  signal N_36173 : std_logic ;
  signal N_36174 : std_logic ;
  signal N_36175 : std_logic ;
  signal N_36176 : std_logic ;
  signal N_36177 : std_logic ;
  signal N_36178 : std_logic ;
  signal N_36179 : std_logic ;
  signal N_36180 : std_logic ;
  signal N_36181 : std_logic ;
  signal N_36182 : std_logic ;
  signal N_36183 : std_logic ;
  signal N_36184 : std_logic ;
  signal N_36185 : std_logic ;
  signal N_36186 : std_logic ;
  signal N_36187 : std_logic ;
  signal N_36188 : std_logic ;
  signal N_36189 : std_logic ;
  signal N_36190 : std_logic ;
  signal N_36191 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\ : std_logic ;
  signal N_36196 : std_logic ;
  signal N_36197 : std_logic ;
  signal N_36198 : std_logic ;
  signal N_36199 : std_logic ;
  signal N_36200 : std_logic ;
  signal N_36201 : std_logic ;
  signal N_36202 : std_logic ;
  signal N_36203 : std_logic ;
  signal N_36204 : std_logic ;
  signal N_36205 : std_logic ;
  signal N_36206 : std_logic ;
  signal N_36207 : std_logic ;
  signal N_36208 : std_logic ;
  signal N_36209 : std_logic ;
  signal N_36210 : std_logic ;
  signal N_36211 : std_logic ;
  signal N_36212 : std_logic ;
  signal N_36213 : std_logic ;
  signal N_36214 : std_logic ;
  signal N_36215 : std_logic ;
  signal N_36216 : std_logic ;
  signal N_36217 : std_logic ;
  signal N_36218 : std_logic ;
  signal N_36219 : std_logic ;
  signal N_36220 : std_logic ;
  signal N_36221 : std_logic ;
  signal N_36222 : std_logic ;
  signal N_36223 : std_logic ;
  signal N_36224 : std_logic ;
  signal N_36225 : std_logic ;
  signal N_36226 : std_logic ;
  signal N_36227 : std_logic ;
  signal N_36228 : std_logic ;
  signal N_36229 : std_logic ;
  signal N_36230 : std_logic ;
  signal N_36231 : std_logic ;
  signal N_36232 : std_logic ;
  signal N_36233 : std_logic ;
  signal N_36234 : std_logic ;
  signal N_36235 : std_logic ;
  signal N_36236 : std_logic ;
  signal N_36237 : std_logic ;
  signal N_36238 : std_logic ;
  signal N_36239 : std_logic ;
  signal N_36240 : std_logic ;
  signal N_36241 : std_logic ;
  signal N_36242 : std_logic ;
  signal N_36243 : std_logic ;
  signal N_36244 : std_logic ;
  signal N_36245 : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_10\ : std_logic ;
  signal N_36250 : std_logic ;
  signal N_36251 : std_logic ;
  signal N_36252 : std_logic ;
  signal N_36253 : std_logic ;
  signal N_36254 : std_logic ;
  signal N_36255 : std_logic ;
  signal N_36256 : std_logic ;
  signal N_36257 : std_logic ;
  signal N_36258 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\ : std_logic ;
  signal N_36264 : std_logic ;
  signal N_36265 : std_logic ;
  signal N_36266 : std_logic ;
  signal N_36267 : std_logic ;
  signal N_36268 : std_logic ;
  signal N_36269 : std_logic ;
  signal N_36270 : std_logic ;
  signal N_36271 : std_logic ;
  signal N_36272 : std_logic ;
  signal N_36273 : std_logic ;
  signal N_36274 : std_logic ;
  signal N_36275 : std_logic ;
  signal N_36276 : std_logic ;
  signal N_36277 : std_logic ;
  signal N_36278 : std_logic ;
  signal N_36279 : std_logic ;
  signal N_36280 : std_logic ;
  signal N_36281 : std_logic ;
  signal N_36282 : std_logic ;
  signal N_36283 : std_logic ;
  signal N_36284 : std_logic ;
  signal N_36285 : std_logic ;
  signal N_36286 : std_logic ;
  signal N_36287 : std_logic ;
  signal N_36288 : std_logic ;
  signal N_36289 : std_logic ;
  signal N_36290 : std_logic ;
  signal N_36291 : std_logic ;
  signal N_36292 : std_logic ;
  signal N_36293 : std_logic ;
  signal N_36294 : std_logic ;
  signal N_36295 : std_logic ;
  signal N_36296 : std_logic ;
  signal N_36297 : std_logic ;
  signal N_36298 : std_logic ;
  signal N_36299 : std_logic ;
  signal N_36300 : std_logic ;
  signal N_36301 : std_logic ;
  signal N_36302 : std_logic ;
  signal N_36303 : std_logic ;
  signal N_36304 : std_logic ;
  signal N_36305 : std_logic ;
  signal N_36306 : std_logic ;
  signal N_36307 : std_logic ;
  signal N_36308 : std_logic ;
  signal N_36309 : std_logic ;
  signal N_36310 : std_logic ;
  signal N_36311 : std_logic ;
  signal N_36312 : std_logic ;
  signal N_36313 : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\ : std_logic ;
  signal N_36321 : std_logic ;
  signal N_36322 : std_logic ;
  signal N_36323 : std_logic ;
  signal N_36324 : std_logic ;
  signal N_36325 : std_logic ;
  signal N_36326 : std_logic ;
  signal N_36327 : std_logic ;
  signal N_36328 : std_logic ;
  signal N_36329 : std_logic ;
  signal N_36334 : std_logic ;
  signal N_36335 : std_logic ;
  signal N_36336 : std_logic ;
  signal N_36337 : std_logic ;
  signal N_36338 : std_logic ;
  signal N_36339 : std_logic ;
  signal N_36343 : std_logic ;
  signal N_36344 : std_logic ;
  signal N_36345 : std_logic ;
  signal N_36346 : std_logic ;
  signal N_36347 : std_logic ;
  signal N_36348 : std_logic ;
  signal N_36352 : std_logic ;
  signal N_36353 : std_logic ;
  signal N_36354 : std_logic ;
  signal N_36355 : std_logic ;
  signal N_36356 : std_logic ;
  signal N_36357 : std_logic ;
  signal N_36358 : std_logic ;
  signal N_36359 : std_logic ;
  signal N_36360 : std_logic ;
  signal N_36365 : std_logic ;
  signal N_36366 : std_logic ;
  signal N_36367 : std_logic ;
  signal N_36368 : std_logic ;
  signal N_36369 : std_logic ;
  signal N_36370 : std_logic ;
  signal N_36371 : std_logic ;
  signal N_36372 : std_logic ;
  signal N_36373 : std_logic ;
  signal N_36378 : std_logic ;
  signal N_36379 : std_logic ;
  signal N_36380 : std_logic ;
  signal N_36381 : std_logic ;
  signal N_36382 : std_logic ;
  signal N_36383 : std_logic ;
  signal N_36384 : std_logic ;
  signal N_36385 : std_logic ;
  signal N_36386 : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_CARRY_0\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_CARRY_1\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_CARRY_2\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_CARRY_3\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN17_OP_7_3\ : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3\ : std_logic ;
  signal \GRFPC0.FPRIN.ALLOW_0_0__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_29__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_30__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_32__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_33__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_34__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_35__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_36__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_37__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_38__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_39__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_40__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_41__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_42__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_43__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_44__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_45__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_46__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_47__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_48__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_49__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_50__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_51__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G0_I_O4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.ODDEXP_0_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__G0_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__G0_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPOP_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.DIV.PEND_1_0_G0_I_O4\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1_X\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G1_X\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.FIFO.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV_0_0_G1_X\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR_0_0_G1_X\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.NONSTD_0_0_G2\ : std_logic ;
  signal \GRFPC0.R.FSR.NONSTD_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_3__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_4__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_44__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_47__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_50__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_53__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_56__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_59__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_62__G3\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_1__G3\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_0__G0_I_M4_X\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_1__G0_I_M4_X\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_1__G3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_2__G3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_3__G3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_4__G3\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_0__G1_X\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.INST_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.INST_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.INST_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0_2__G2_X\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0_2__G2_X\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1_X\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_X\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.SEQERR_0_0_G1_0_1326_A2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDWR_0_0_G1_0_1385_A2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.LD_0_0_G1_0_1395_A2_X\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.DIV_0_0_G1_0_1405_A2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.CCWR_0_0_G1_0_1418_A2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.LD_0_0_G1_0_1460_A2_X\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.LD_0_0_G1_0_1551_A2_X\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_1622_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_1698_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.STDFQ_0_0_G1_0_1712_A2\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1809_A2\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXP_1_SQMUXA_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I\ : std_logic ;
  signal \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_X\ : std_logic ;
  signal \GRFPC0.WR.CTRL.SEQERR_0_0_G1_0_1431_I\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDWR_0_0_G1_0_1446_I\ : std_logic ;
  signal \GRFPC0.WR.CTRL.DIV_0_0_G1_0_1470_I\ : std_logic ;
  signal \GRFPC0.WR.CTRL.CCWR_0_0_G1_0_1485_I\ : std_logic ;
  signal \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.SEQERR_0_0_G1_0_1516_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDWR_0_0_G1_0_1534_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.DIV_0_0_G1_0_1562_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.CCWR_0_0_G1_0_1580_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_0__G0_0_X\ : std_logic ;
  signal G_2026_X : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.DIV.PEND_1_0_G1_0_I_A5_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I_X2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_OP_7_1\ : std_logic ;
  signal \GRFPC0.RDWR_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1403_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN5_FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.RDY_F0_I_X2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I\ : std_logic ;
  signal \GRFPC0.RDWR_5_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A3\ : std_logic ;
  signal N_45794_2 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3857_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_2_0_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4185_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1_U\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GUARD_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_5_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_233\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_BCO_LSB_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN68_BCO_LSB_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXP57_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPINC_SP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCUF_1_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_58_I_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0_A4_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_58_I_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.MULO_M_299\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN_1_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_X2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.NXX_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDEC_SP_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPINC\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDEC_SP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_2_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF_0_0_G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.RDY_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC18LTO10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_26\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_FIFO_CLR\ : std_logic ;
  signal \GRFPC0.VFIFO.FULL_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.CNTX14\ : std_logic ;
  signal \GRFPC0.VFIFO.FULL_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.FULL_6_F0\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.WR_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RS1V.TMP_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_7_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V18_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_0\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M12_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M16_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M21_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M8_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M20_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M17_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M9_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M11_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M7_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M22_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN7_G_SP_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_0_385\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_O4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW_1_SQMUXA_INV_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EMAXP112\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V_0_I_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V_0_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.V_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN28_BCO_LSB_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN18_BCO_LSB_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7211_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M12_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M22_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M16_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLTO4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.LOB_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_ANC3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_13_C4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_13_ANC3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_13_C2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_13_SUM2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN118_BCO_LSB_0_1_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18LT10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_SN_M1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN11_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN22_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_77\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_78\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.FLOP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_REST_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_REST\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG127\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD_I_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.QSNAN12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST1.SIGN1_0_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_SWAP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.QSNAN12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN242_BCO_MSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN243_BCO_LSB_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN8_OP_7_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN20_FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_15_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4415_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.STATE_23_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.TMP\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN22_REN1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.DIFF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN238_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN168_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ODDEXP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST1.FLTYPE2_65\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_C2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCV12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCV18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RDY_0_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_BCO_LSB_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN128_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN33_BCO_LSB_0_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG71_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_4_0_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_4_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4171_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_SUM2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VCS_ITER_1_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_8_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18471_I_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_5\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_M4\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_X2\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_M_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA_2_SUM2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I_A4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_CCV12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_REST_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG108\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_3_SQMUXA_S4_2_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN8_SIGN1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN1_2_I_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1175_0_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RNDBIT_4_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I_M4\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_0_7_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18308_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_74_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_LESS_0_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.STICKY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LT2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M16_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M8_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M7_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0_X2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN83_BCO_LSB_0_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20664\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN14_REN1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3231_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_6\ : std_logic ;
  signal \GRFPC0.UN1_FIFO.INST_0_12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_113_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX_0_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_107\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4_1\ : std_logic ;
  signal \GRFPC0.UN1_STDEP2194\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O2_9\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_131_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL0_0_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL1_I_0_A2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_46\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.STDEP2195\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_82_I_I_A2\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_84_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_14\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_92_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_84\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_28_I_0_O2\ : std_logic ;
  signal \GRFPC0.N_201\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.RDD_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_122_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3354_DEP\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_166_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_80_I_I_A2_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_4_I_I_A2_I_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP11_0_A2_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP10_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_I_O2_0_O3_0_O5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_10_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX_0_A4_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_98_I_I_A2_I_O2\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_135_0_A2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_119_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_M_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK27_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_14_I_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_26_I_I_A3_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_23_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_20_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_21_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN348_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_2_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_9_I_O4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.PENDEXC23\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_87_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1226_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_1_0_A2_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1247_DEP\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_27_I_I_A3_I\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_107_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_3_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_19_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_12_I_I_A2_I_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_96_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0_1078\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL0_0_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_110\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_I_M2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP682\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP683\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_26\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_133\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP851_0_A2_0\ : std_logic ;
  signal \GRFPC0.N_19572_1_I_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL1_I_0_A2_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.STDEP_456_SEL0_0_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL1_I_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3871_DEP_0_A3\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_129_I_I_A2_I_O4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_7_I_I_A4_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_0_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_9\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_108_I_M2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G3\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_94_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_A3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.N_17807_I_0_G1\ : std_logic ;
  signal \GRFPC0.RFAREG.R.STATE_4_M2S2\ : std_logic ;
  signal \GRFPC0.UN1_VDIV.EXEC7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.ORV.TMP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN5_SHARE_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_13\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_M_4_X\ : std_logic ;
  signal \GRFPC0.VRFA.SEQERR_5_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_M_0\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_128\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_132_I_0_O2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.ORV.TMP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN17_SHARE\ : std_logic ;
  signal \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VD.FLDLCK_1_828\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_SHARE\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN56_PENDEXC_X\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2S4\ : std_logic ;
  signal \GRFPC0.FCC_VALID_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G2_0\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_M\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP172\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_0\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_123\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3944_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX_0_A2_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX_2_0_A3_0_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1240_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A2_0_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3840_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3855_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX\ : std_logic ;
  signal \GRFPC0.UN1_FIFO.INST_0_16_I_I2_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1_M5_I_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_D\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_5\ : std_logic ;
  signal \GRFPC0.UN1_WR2.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_G0_0_M3\ : std_logic ;
  signal \GRFPC0.DIV.EXC_1_0_G3\ : std_logic ;
  signal \GRFPC0.DIV.EXC_1_0_G0_I_O4\ : std_logic ;
  signal \GRFPC0.VDIV.EXC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.VDIV.EXC_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F1\ : std_logic ;
  signal \GRFPC0.VDIV.EXC_1_SQMUXA_0_O2\ : std_logic ;
  signal \GRFPC0.VDIV.PEND_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_137_I_I_A2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_124_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_85_I_I_A2_I_O2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_108_I_0_0_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4256_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4791_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2919_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_105_I_0_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4527_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_13\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_104_0_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_143_0_A2_I\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G3\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_88_I_I_A2_I\ : std_logic ;
  signal \GRFPC0.N_24899_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6606_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_0_A2_1_A2_0_A2\ : std_logic ;
  signal \GRFPC0.N_25984_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2_0_A2_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6592_REGDEPX2_0_A2_0_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4776_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2_1_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7004_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_0_A2_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_2_0_A2_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2_2_I_O3_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2_1_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_0_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.UN1_FIFO.INST_0_9\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_111\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\ : std_logic ;
  signal \GRFPC0.N_21857\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_653\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP119\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP146\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_EX.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP30\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXSEL4_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10\ : std_logic ;
  signal \GRFPC0.UN1_EX.CTRL.RDD_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP160\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP173\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_0_A2\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP161\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1\ : std_logic ;
  signal \GRFPC0.V.FSR.NONSTD_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_4__G4\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_4__G5\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_4__G5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2\ : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_7__G5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4121_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5003_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6326_REGDEPX2_I_I_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_0_A2_0_0_A2_0_A3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A2_0_0_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6884_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN11_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_FLOP_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_5_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_FLTYPE45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_FLTYPE_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10\ : std_logic ;
  signal \GRFPC0.OP2_SN_M8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G3\ : std_logic ;
  signal \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\ : std_logic ;
  signal \GRFPC0.UN28_WREN_M8_I_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE6\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_0__G3_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.FPEXC_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN13_FPEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_0\ : std_logic ;
  signal \GRFPC0.UN28_WREN_M8_I_A5_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_A0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN23_HOLDN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPRDY4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6063_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4299_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3476_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.N_25113_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4328_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3372_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1212_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3858_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_0_A2_0_A2_1_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1656_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_M2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_A4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_101\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2886_REGDEPX2_0_A3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2915_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6473_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.UN1_DIV.RDD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP14\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP133\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_7__G0_I_M4\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP79\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL0_0_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_1_0_A3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN1988_DEP\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_141_0_A2\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_2__G0_0_A3_X\ : std_logic ;
  signal \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_M5\ : std_logic ;
  signal \GRFPC0.VDIV.VALID_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDBL_1_1_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.STATE10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_19_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX_2_0_A3_0_A2_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_182\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_145\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_169\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_106_I_0_0_O4_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_118_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_A2\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1022_DEP_2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2006_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3974_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1_0_A2\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDWR_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1004_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN30_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK19\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST4_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK23_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK23_3_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_M_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_X\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_1622_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_155\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_155_1_I_X2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_288_SEL1_I_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_1_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2_0_A2_1_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6032_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\ : std_logic ;
  signal \GRFPC0.N_19067_1_I_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_MEM.CTRL.ID_3_0_X3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_1\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G1\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M3_E_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_M2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3491_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2609_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN4931_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6443_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2_0_A3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6398_REGDEPX2_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6459_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6488_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN271_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_2__G4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6108_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6165_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2637_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5516_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5226_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2549_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2564_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3752_REGDEPX2_I_I_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_0__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_3_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1608_REGDEPX2_0_A2_1_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1592_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2_0_A2_0_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_1_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_OP_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_881\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1547_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1667_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_0_A3_0_A2_1_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4313_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6077_REGDEPX2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6929_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6900_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1167_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M6_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2_I_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5957_REGDEPX2_I_0_O3_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_0_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1196_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4666_DEP_2\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_84_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRSEL4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RESV_6_IV_I_I_O2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2352_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4648_DEP_2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN54_HOLDN\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_30\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_25\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_28\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_18\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_21\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_15\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_10\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_13\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_3\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_6\ : std_logic ;
  signal \GRFPC0.LDLOCK_14_X\ : std_logic ;
  signal \GRFPC0.LDLOCK_10\ : std_logic ;
  signal \GRFPC0.LDLOCK_13\ : std_logic ;
  signal \GRFPC0.LDLOCK_7_X\ : std_logic ;
  signal \GRFPC0.LDLOCK_3\ : std_logic ;
  signal \GRFPC0.LDLOCK_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3543_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_25311\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2_0_A2_1_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP_2\ : std_logic ;
  signal \GRFPC0.UN1_STDEP1222\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_116_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_5\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_O3_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3\ : std_logic ;
  signal \GRFPC0.N_22435\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_2\ : std_logic ;
  signal \GRFPC0.VFIFO.VCNT_0_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_0_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN888_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_I_I_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2_0_A2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4_0_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2_2_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5681_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RS1D_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_I_X3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1_M9_I_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4268_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_2_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN726_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4373_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.ID_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_4\ : std_logic ;
  signal \GRFPC0.FIFO_INC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3528_REGDEPX_1_0_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2_0_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN3078_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\ : std_logic ;
  signal \GRFPC0.N_23889\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX_0_A2_0_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M5_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M3_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_M\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_M_2_X\ : std_logic ;
  signal \GRFPC0.LDLOCK_15_X\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_M\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_M_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_M2\ : std_logic ;
  signal NN_1 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3167_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1727_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3401_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O4\ : std_logic ;
  signal \GRFPC0.OP1_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2_0_A3_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_1_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2370\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_2403\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_2586\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_O3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VEX.CTRL.LD_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_15\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_3\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_C1_1_TZ\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_TZ_X\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_TZ\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_TZ\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.RNDOP_14_IV_2372_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_2594_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_1_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_4_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_5_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_5_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_TZ\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_3_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300TT_0_M1_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A0\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_0__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2\ : std_logic ;
  signal D_M1_E : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_A4\ : std_logic ;
  signal D_M4 : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_A4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I\ : std_logic ;
  signal R_M2 : std_logic ;
  signal D_M3_0_A2 : std_logic ;
  signal D_M4_0 : std_logic ;
  signal R_M2_0 : std_logic ;
  signal D_M4_I_A4_0_1 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M3_E\ : std_logic ;
  signal D_M7 : std_logic ;
  signal D_M5 : std_logic ;
  signal D_M3_0 : std_logic ;
  signal D_M4_1 : std_logic ;
  signal D_M5_0 : std_logic ;
  signal D_M6_0 : std_logic ;
  signal D_M4_2 : std_logic ;
  signal D_M5_1 : std_logic ;
  signal D_M6_1 : std_logic ;
  signal D_M4_3 : std_logic ;
  signal D_M5_2 : std_logic ;
  signal D_M6_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8_TZ\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_S_TZ\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_S_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_TZ_TZ\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP147_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A1\ : std_logic ;
  signal \GRFPC0.INST_I_0_6_M3\ : std_logic ;
  signal R_M2_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1TT_40_M2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_M4_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G3_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.EX.RREG.RESV_0_0_G0_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.V_0_0_G0_1\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_56_I_0_G0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_1_SQMUXA_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_I_0\ : std_logic ;
  signal \GRFPC0.DIV.EXC_1_0_G3_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_A4_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_A4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.RD_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3_0\ : std_logic ;
  signal D_M2_E_4_0 : std_logic ;
  signal D_M2_E_0_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0\ : std_logic ;
  signal D_M2_E_2_0 : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_1_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_0_0_G0_0_X\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_1622_A3_0_X\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.RDWR_5_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV_0_0_G0_0_X\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV_0_0_A4_0_G0_0_X\ : std_logic ;
  signal \GRFPC0.FPRIN.ALLOW_0_0__G0_1\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_M4_E_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_3\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G7_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1_0\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_3\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP63_D\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\ : std_logic ;
  signal CARRY_PATCH0 : std_logic ;
  signal N_82060 : std_logic ;
  signal \GRFPC0.UN1_FPR.ALLOW_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A4_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_TZ\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_A0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14TT_0_M3_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M1_E\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_M4\ : std_logic ;
  signal D_M1_E_0 : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_4_0_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M3_E\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_A3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_A3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_A5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_3_1_M5_I\ : std_logic ;
  signal R_M2_2 : std_logic ;
  signal D_M4_4 : std_logic ;
  signal D_M3_1 : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_A0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_A1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0\ : std_logic ;
  signal D_M1_E_2 : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G2_A0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZTT_M3_0_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\ : std_logic ;
  signal \GRFPC0.WREN_2_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.WREN_2_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_I_O3_0_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN6_OP3_0_X\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_0_0_X\ : std_logic ;
  signal \GRFPC0.VRFA.SEQERR_5_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.CCWR_0_SQMUXA_0_X\ : std_logic ;
  signal \GRFPC0.CCWR_0_SQMUXA_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP_0_X\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_M_0\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_M_0_2_0\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_M_0_2_1_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_5_I_O2_1\ : std_logic ;
  signal \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_O2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_2_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_19_I_O4_0_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_0_X\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G3_0_X\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_5_0_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_6_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN527_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_1_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_A2_0_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_75_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG107_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_A1_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M1_E_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M1_E_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M1_E_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_3\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG71_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES4_7_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_A2_0\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A4_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_A1_0\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0_1\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_0\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3_0\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_A0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_3_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_A2_0_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_48\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_A0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_4_0\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G5_0\ : std_logic ;
  signal \GRFPC0.LDLOCK_M_3\ : std_logic ;
  signal \GRFPC0.LDLOCK_M_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN63_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN28_BCO_LSB_0\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.WR_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN14_OP_7_2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3440_I_M_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0_0\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_M_1\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_M_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_1_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_2_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LT2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16368_M_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16368_M_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_2\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_S_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_24__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_23__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_31__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_19__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_6__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_16__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_13__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_27__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_10__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_12__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_25__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_22__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_15__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_11__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_8__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_26__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_20__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_29__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_2__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_28__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_30__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_21__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_7__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_5__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_17__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_18__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_14__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_1__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_3__G3_0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_9__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_4__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_0__G3_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_2\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_109_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1S2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_55__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_108_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_18\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_87_I_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_59\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_2_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ADDI3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_1_X\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE6_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_1\ : std_logic ;
  signal \GRFPC0.UN28_WREN_M8_I_1\ : std_logic ;
  signal \GRFPC0.UN28_WREN_M8_I_3\ : std_logic ;
  signal \GRFPC0.UN28_WREN_M8_I_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_2_M_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_2\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_5\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_2_SQMUXA_2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_1183_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_A3_0_2_1\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4_0_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_3_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M6_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_M6_I_A3_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6_0\ : std_logic ;
  signal \GRFPC0.V.FSR.FCC_3_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_1\ : std_logic ;
  signal \GRFPC0.V.FSR.FCC_2_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND_0_0_G1_0_A3_1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_2_0\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_G0_0_A3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M6_0\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_4\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_6\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_6_SQMUXA_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_5_SQMUXA_S6_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_4\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_1\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_A2_2_0_X\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_2_X\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_4\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_5_X\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_3_X\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_A2_4_0\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_0_X\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_1_X\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_0\ : std_logic ;
  signal \GRFPC0.N_17807_I_0_G0_I_A3_0\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3_0_0\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_38\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_38\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I_0_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_1__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_52_M3_0_A2_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_3\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_0_X\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_2\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_3_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2_1_0\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3_0\ : std_logic ;
  signal D_M3_E_0_0 : std_logic ;
  signal D_M4_I_A4_0_0 : std_logic ;
  signal D_M3_0_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_55_M4_0_A2_1\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_7\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_9\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G3_0_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3_1\ : std_logic ;
  signal D_M4_I_0 : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_4_C_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19862_I_0_G0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1_0_3\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_5\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_5\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_24__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1_5\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_1622_A2_2\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1_1_X\ : std_logic ;
  signal \GRFPC0.FPRIN.ALLOW_0_0__G5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_0_0_X\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_133_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_1_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_170_0_A2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1_3\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP146_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20002_I_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP14_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP30_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP160_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_1_M8_I_0\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I_0\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_A4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_1\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_1\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_2\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_5__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_4__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_0__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_2__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_3__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_1__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A5_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19861_I_0_G0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_0_8\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_2_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_0_X\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP172_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_6\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_7\ : std_logic ;
  signal R_M3_0_A2_2_0 : std_logic ;
  signal R_M3_0_A2_2_1 : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_8\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_9\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_14\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1_1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_5\ : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_0_X\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_5_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_3_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_0_X\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_0\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP79_0\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP79_2\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_0_0\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_2\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G3_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_1\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_3\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_6__G0_3_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_5\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP147_0_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_4\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5_7\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_4\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_S_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_S_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6_6\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_4\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_S_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_S_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_3\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_6_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_5_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\ : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\ : std_logic ;
  signal \GRFPC0.N_19292_1_I_0_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_4_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN45_WREN\ : std_logic ;
  signal \GRFPC0.OP1_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2\ : std_logic ;
  signal \GRFPC0.V.STDATA_0_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.N_19067_1_I_I_A2_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.PENDEXC_0_SQMUXA_0_A2\ : std_logic ;
  signal \GRFPC0.UN1_WR2.EXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\ : std_logic ;
  signal \GRFPC0.N_25443_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\ : std_logic ;
  signal \GRFPC0.OP2_SN_M4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN213_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN148_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN163_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN208_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN218_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN223_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN233_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN243_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN248_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN53_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.FLOP4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_34_I_I_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN93_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN103_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN98_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN113_BCO_LSB\ : std_logic ;
  signal NN_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN88_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN18_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN28_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\ : std_logic ;
  signal \GRFPC0.UN1_PENDEXC_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES4_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN43_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN48_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN63_BCO_LSB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_67_I_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.RDY_F0_I\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_55__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_31__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_30__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_29__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_28__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_27__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_26__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_25__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_24__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_23__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_22__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_21__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_20__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_19__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_18__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_17__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_16__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_15__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_14__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_13__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_12__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_11__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_10__G3\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_9__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_8__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_7__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_6__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_5__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_4__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_3__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_2__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_1__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_2__G4\ : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\ : std_logic ;
  signal \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\ : std_logic ;
  signal \GRFPC0.DIV.EXC_0_2_X\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_0_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\ : std_logic ;
  signal \GRFPC0.V.STDATA_0_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.V.STDATA_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2\ : std_logic ;
  signal \GRFPC0.OP1_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.STDATA_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN24_OP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG107\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UINT17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_18_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_6_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_3_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_28_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_25_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_13_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_10_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_6_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_3_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_10_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_13_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_21_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2_A\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_3_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN48_BCO_LSB_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_BCO_LSB_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_BCO_LSB_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN43_BCO_LSB_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_BCO_LSB_A\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_30_A\ : std_logic ;
  signal \GRFPC0.LDLOCK_1_15_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ_A\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2_A\ : std_logic ;
  signal \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_5__G0_1_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_4__G0_1_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_0__G0_1_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_2__G0_1_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_3__G0_1_A\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0_1__G0_1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC51_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK19_A_X\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.RDY_F0_I_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2_A\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_A\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_M_A\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_A0_A\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_M_3_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G3_0_4_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_1_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_2_A\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV_0_0_G0_0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13472_I_0_G0_A\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_VALID_1_U_I_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7_4_A\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_55__G3_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_4_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_0_6_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10_A\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1_0_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_2_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_2_A\ : std_logic ;
  signal R_M3_0_A2_2_1_A : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1_A\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U_A\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_1__G2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V4_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_1_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_3_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3_A\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_A\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_5_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.NXX_1_3_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_A\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP147_0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_A\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_6_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_51_A\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_A\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44_A\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_7_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111_A\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_5_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5_7_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_A\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_0__G3_A\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_2_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4_A\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_A\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_14_A\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0_A\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_5_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20002_I_0_G0_A\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03_C\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03_C\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_1_S\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_S\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_8_S\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_S\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_6_0_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_S\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_9_S\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4_S\ : std_logic ;
  signal \RETGRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\ : std_logic ;
  signal \RETGRFPU0.GRFPU_X0.COMB.ITER_OF\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_0__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_1__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_4__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_8__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_10__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_14__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_16__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_25__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_27__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_29__G3\ : std_logic ;
  signal \RETGRFPC0.DIV.RESULT_0_0_31__G3\ : std_logic ;
  signal \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\ : std_logic ;
  signal N_114503 : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_53_REP0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_53_REP1\ : std_logic ;
  signal \GRFPC0.OP1_0_SQMUXA_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_51_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\ : std_logic ;
  signal \GRFPC0.OP2_SN_M4_REP1\ : std_logic ;
  signal \GRFPC0.OP2_SN_M4_REP2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\ : std_logic ;
  signal \GRFPC0.OP1_1_SQMUXA_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\ : std_logic ;
  signal \GRFPC0.OP2_SN_M8_REP1\ : std_logic ;
  signal \GRFPC0.OP2_SN_M8_REP2\ : std_logic ;
  signal \GRFPC0.OP2_SN_M8_REP3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\ : std_logic ;
  signal G_2026_X_REP1 : std_logic ;
  signal G_2026_X_REP2 : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_REP1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_REP2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_REP3\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_REP4\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_REP5\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_REP1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_REP2\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_REP3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_REP1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_REP2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_REP3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_REP4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\ : std_logic ;
  signal \GRFPC0.RFA.LD_REP1\ : std_logic ;
  signal \GRFPC0.DIV.RDD_REP1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD_REP1\ : std_logic ;
  signal \GRFPC0.DIV.VALID_REP1\ : std_logic ;
  signal \GRFPC0.RFA.RS2D_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_REP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_REP6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM_REP1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\ : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\ : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G0_E_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_I\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\ : std_logic ;
  signal \GRFPC0.DIV.INST_0_0_0__G2_I\ : std_logic ;
  signal N_114516 : std_logic ;
  signal N_114517 : std_logic ;
  signal N_114518 : std_logic ;
  signal N_114519 : std_logic ;
  signal N_114520 : std_logic ;
  signal N_114521 : std_logic ;
  signal N_114522 : std_logic ;
  signal N_114523 : std_logic ;
  signal N_114524 : std_logic ;
  signal N_114525 : std_logic ;
  signal N_114526 : std_logic ;
  signal N_114527 : std_logic ;
  signal N_114528 : std_logic ;
  signal N_114529 : std_logic ;
  signal N_114530 : std_logic ;
  signal N_114531 : std_logic ;
  signal N_114532 : std_logic ;
  signal N_114533 : std_logic ;
  signal N_114534 : std_logic ;
  signal N_114535 : std_logic ;
  signal N_114536 : std_logic ;
  signal N_114537 : std_logic ;
  signal N_114538 : std_logic ;
  signal N_114539 : std_logic ;
  signal N_114540 : std_logic ;
  signal N_114541 : std_logic ;
  signal N_114542 : std_logic ;
  signal N_114543 : std_logic ;
  signal N_114544 : std_logic ;
  signal N_114545 : std_logic ;
  signal N_114546 : std_logic ;
  signal N_114547 : std_logic ;
  signal N_114548 : std_logic ;
  signal N_114549 : std_logic ;
  signal N_114550 : std_logic ;
  signal N_114551 : std_logic ;
  signal N_114552 : std_logic ;
  signal N_114553 : std_logic ;
  signal N_114554 : std_logic ;
  signal N_114555 : std_logic ;
  signal N_114556 : std_logic ;
  signal N_114557 : std_logic ;
  signal N_114558 : std_logic ;
  signal N_114559 : std_logic ;
  signal N_114560 : std_logic ;
  signal N_114561 : std_logic ;
  signal N_114562 : std_logic ;
  signal N_114563 : std_logic ;
  signal N_114564 : std_logic ;
  signal N_114565 : std_logic ;
  signal N_114566 : std_logic ;
  signal N_114567 : std_logic ;
  signal N_114568 : std_logic ;
  signal N_114569 : std_logic ;
  signal N_114570 : std_logic ;
  signal N_114571 : std_logic ;
  signal N_114572 : std_logic ;
  signal N_114573 : std_logic ;
  signal N_114574 : std_logic ;
  signal N_114575 : std_logic ;
  signal N_114576 : std_logic ;
  signal N_114577 : std_logic ;
  signal N_114578 : std_logic ;
  signal N_114579 : std_logic ;
  signal N_114580 : std_logic ;
  signal N_114581 : std_logic ;
  signal N_114582 : std_logic ;
  signal N_114583 : std_logic ;
  signal N_114584 : std_logic ;
  signal N_114585 : std_logic ;
  signal N_114586 : std_logic ;
  signal N_114587 : std_logic ;
  signal N_114588 : std_logic ;
  signal N_114589 : std_logic ;
  signal N_114590 : std_logic ;
  signal N_114591 : std_logic ;
  signal N_114592 : std_logic ;
  signal N_114593 : std_logic ;
  signal N_114594 : std_logic ;
  signal N_114595 : std_logic ;
  signal N_114596 : std_logic ;
  signal N_114597 : std_logic ;
  signal N_114598 : std_logic ;
  signal N_114599 : std_logic ;
  signal N_114600 : std_logic ;
  signal N_114601 : std_logic ;
  signal N_114602 : std_logic ;
  signal N_114603 : std_logic ;
  signal N_114604 : std_logic ;
  signal N_114605 : std_logic ;
  signal N_114606 : std_logic ;
  signal N_114607 : std_logic ;
  signal N_114608 : std_logic ;
  signal N_114609 : std_logic ;
  signal N_114610 : std_logic ;
  signal N_114611 : std_logic ;
  signal N_114612 : std_logic ;
  signal N_114613 : std_logic ;
  signal N_114614 : std_logic ;
  signal N_114615 : std_logic ;
  signal N_114616 : std_logic ;
  signal N_114617 : std_logic ;
  signal N_114618 : std_logic ;
  signal N_114619 : std_logic ;
  signal N_114620 : std_logic ;
  signal N_114621 : std_logic ;
  signal N_114622 : std_logic ;
  signal N_114623 : std_logic ;
  signal N_114624 : std_logic ;
  signal N_114625 : std_logic ;
  signal N_114626 : std_logic ;
  signal N_114627 : std_logic ;
  signal N_114628 : std_logic ;
  signal N_114629 : std_logic ;
  signal N_114630 : std_logic ;
  signal N_114631 : std_logic ;
  signal N_114632 : std_logic ;
  signal N_114633 : std_logic ;
  signal N_114634 : std_logic ;
  signal N_114635 : std_logic ;
  signal N_114636 : std_logic ;
  signal N_114637 : std_logic ;
  signal N_114638 : std_logic ;
  signal N_114639 : std_logic ;
  signal N_114640 : std_logic ;
  signal N_114641 : std_logic ;
  signal N_114642 : std_logic ;
  signal N_114643 : std_logic ;
  signal N_114644 : std_logic ;
  signal N_114645 : std_logic ;
  signal N_114646 : std_logic ;
  signal N_114647 : std_logic ;
  signal N_114648 : std_logic ;
  signal N_114649 : std_logic ;
  signal N_114650 : std_logic ;
  signal N_114651 : std_logic ;
  signal N_114652 : std_logic ;
  signal N_114653 : std_logic ;
  signal N_114654 : std_logic ;
  signal N_114655 : std_logic ;
  signal N_114656 : std_logic ;
  signal N_114657 : std_logic ;
  signal N_114658 : std_logic ;
  signal N_114659 : std_logic ;
  signal N_114660 : std_logic ;
  signal N_114661 : std_logic ;
  signal N_114662 : std_logic ;
  signal N_114663 : std_logic ;
  signal N_114664 : std_logic ;
  signal N_114665 : std_logic ;
  signal N_114666 : std_logic ;
  signal N_114667 : std_logic ;
  signal N_114668 : std_logic ;
  signal N_114669 : std_logic ;
  signal N_114670 : std_logic ;
  signal N_114671 : std_logic ;
  signal N_114672 : std_logic ;
  signal N_114673 : std_logic ;
  signal N_114674 : std_logic ;
  signal N_114675 : std_logic ;
  signal N_114676 : std_logic ;
  signal N_114677 : std_logic ;
  signal N_114678 : std_logic ;
  signal N_114679 : std_logic ;
  signal N_114680 : std_logic ;
  signal N_114681 : std_logic ;
  signal N_114682 : std_logic ;
  signal N_114683 : std_logic ;
  signal N_114684 : std_logic ;
  signal N_114685 : std_logic ;
  signal N_114686 : std_logic ;
  signal N_114687 : std_logic ;
  signal N_114688 : std_logic ;
  signal N_114689 : std_logic ;
  signal N_114690 : std_logic ;
  signal N_114691 : std_logic ;
  signal N_114692 : std_logic ;
  signal N_114693 : std_logic ;
  signal N_114694 : std_logic ;
  signal N_114695 : std_logic ;
  signal N_114696 : std_logic ;
  signal N_114697 : std_logic ;
  signal N_114698 : std_logic ;
  signal N_114699 : std_logic ;
  signal N_114700 : std_logic ;
  signal N_114701 : std_logic ;
  signal N_114702 : std_logic ;
  signal N_114703 : std_logic ;
  signal N_114704 : std_logic ;
  signal N_114705 : std_logic ;
  signal N_114706 : std_logic ;
  signal N_114707 : std_logic ;
  signal N_114708 : std_logic ;
  signal N_114709 : std_logic ;
  signal N_114710 : std_logic ;
  signal N_114711 : std_logic ;
  signal N_114712 : std_logic ;
  signal N_114713 : std_logic ;
  signal N_114714 : std_logic ;
  signal N_114715 : std_logic ;
  signal N_114716 : std_logic ;
  signal N_114717 : std_logic ;
  signal N_114718 : std_logic ;
  signal N_114719 : std_logic ;
  signal N_114720 : std_logic ;
  signal N_114721 : std_logic ;
  signal N_114722 : std_logic ;
  signal N_114723 : std_logic ;
  signal N_114724 : std_logic ;
  signal N_114725 : std_logic ;
  signal N_114726 : std_logic ;
  signal N_114727 : std_logic ;
  signal N_114728 : std_logic ;
  signal N_114729 : std_logic ;
  signal N_114730 : std_logic ;
  signal N_114731 : std_logic ;
  signal N_114732 : std_logic ;
  signal N_114733 : std_logic ;
  signal N_114734 : std_logic ;
  signal N_114735 : std_logic ;
  signal N_114736 : std_logic ;
  signal N_114737 : std_logic ;
  signal N_114738 : std_logic ;
  signal N_114739 : std_logic ;
  signal N_114740 : std_logic ;
  signal N_114741 : std_logic ;
  signal N_114742 : std_logic ;
  signal N_114743 : std_logic ;
  signal N_114744 : std_logic ;
  signal N_114745 : std_logic ;
  signal N_114746 : std_logic ;
  signal N_114747 : std_logic ;
  signal N_114748 : std_logic ;
  signal N_114749 : std_logic ;
  signal N_114750 : std_logic ;
  signal N_114751 : std_logic ;
  signal N_114752 : std_logic ;
  signal N_114753 : std_logic ;
  signal N_114754 : std_logic ;
  signal N_114755 : std_logic ;
  signal N_114756 : std_logic ;
  signal N_114757 : std_logic ;
  signal N_114758 : std_logic ;
  signal N_114759 : std_logic ;
  signal N_114760 : std_logic ;
  signal N_114761 : std_logic ;
  signal N_114762 : std_logic ;
  signal N_114763 : std_logic ;
  signal N_114764 : std_logic ;
  signal N_114765 : std_logic ;
  signal N_114766 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48_RETO\ : std_logic ;
  signal N_1 : std_logic ;
  signal N_1_0 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47_RETO\ : std_logic ;
  signal N_2 : std_logic ;
  signal N_1_1 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46_RETO\ : std_logic ;
  signal N_2_0 : std_logic ;
  signal N_1_2 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45_RETO\ : std_logic ;
  signal N_2_1 : std_logic ;
  signal N_1_3 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44_RETO\ : std_logic ;
  signal N_2_2 : std_logic ;
  signal N_1_4 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43_RETO\ : std_logic ;
  signal N_2_3 : std_logic ;
  signal N_1_5 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42_RETO\ : std_logic ;
  signal N_2_4 : std_logic ;
  signal N_1_6 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD78_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78_RETO\ : std_logic ;
  signal N_2_5 : std_logic ;
  signal N_1_7 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD77_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77_RETO\ : std_logic ;
  signal N_2_6 : std_logic ;
  signal N_1_8 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD76_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76_RETO\ : std_logic ;
  signal N_2_7 : std_logic ;
  signal N_1_9 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD75_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75_RETO\ : std_logic ;
  signal N_2_8 : std_logic ;
  signal N_1_10 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD74_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74_RETO\ : std_logic ;
  signal N_2_9 : std_logic ;
  signal N_1_11 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73_RETO\ : std_logic ;
  signal N_2_10 : std_logic ;
  signal N_1_12 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72_RETO\ : std_logic ;
  signal N_2_11 : std_logic ;
  signal N_1_13 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71_RETO\ : std_logic ;
  signal N_2_12 : std_logic ;
  signal N_1_14 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70_RETO\ : std_logic ;
  signal N_2_13 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_RETO\ : std_logic ;
  signal \GRFPC0.EX.RREG.RESV_RETO\ : std_logic ;
  signal N_1_15 : std_logic ;
  signal \GRFPU0.FPMUL0.CSADD.UN214_C1_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.CSADD.UN211_C2_RETI\ : std_logic ;
  signal N_1_16 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69_RETO\ : std_logic ;
  signal N_2_14 : std_logic ;
  signal N_1_17 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68_RETO\ : std_logic ;
  signal N_2_15 : std_logic ;
  signal N_1_18 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67_RETO\ : std_logic ;
  signal N_2_16 : std_logic ;
  signal N_1_19 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66_RETO\ : std_logic ;
  signal N_2_17 : std_logic ;
  signal N_1_20 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65_RETO\ : std_logic ;
  signal N_2_18 : std_logic ;
  signal N_1_21 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64_RETO\ : std_logic ;
  signal N_2_19 : std_logic ;
  signal N_1_22 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63_RETO\ : std_logic ;
  signal N_2_20 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0_RETI\ : std_logic ;
  signal N_1_23 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62_RETO\ : std_logic ;
  signal N_2_21 : std_logic ;
  signal N_5 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1_RETI\ : std_logic ;
  signal N_5_0 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1_RETI\ : std_logic ;
  signal N_1_24 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61_RETO\ : std_logic ;
  signal N_2_22 : std_logic ;
  signal N_9_0 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD2_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2_RETI\ : std_logic ;
  signal N_5_1 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD2_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2_RETI\ : std_logic ;
  signal N_1_25 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60_RETO\ : std_logic ;
  signal N_2_23 : std_logic ;
  signal N_35775_RETI : std_logic ;
  signal N_35776_RETI : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_RETO\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV_RETO\ : std_logic ;
  signal N_1_26 : std_logic ;
  signal N_5_2 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD3_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3_RETI\ : std_logic ;
  signal N_6_0 : std_logic ;
  signal N_5_3 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD3_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3_RETI\ : std_logic ;
  signal N_6_1 : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_4__G4_RETO\ : std_logic ;
  signal N_1_27 : std_logic ;
  signal N_1_28 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59_RETO\ : std_logic ;
  signal N_2_24 : std_logic ;
  signal N_9_1 : std_logic ;
  signal N_35779_RETI : std_logic ;
  signal N_9_2 : std_logic ;
  signal N_35778_RETI : std_logic ;
  signal N_5_4 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD4_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_RETI\ : std_logic ;
  signal N_5_5 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD4_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UINT17_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG127_RETO\ : std_logic ;
  signal N_1_29 : std_logic ;
  signal N_1_30 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58_RETO\ : std_logic ;
  signal N_2_25 : std_logic ;
  signal N_9_3 : std_logic ;
  signal N_35781_RETI : std_logic ;
  signal N_9_4 : std_logic ;
  signal N_35780_RETI : std_logic ;
  signal N_5_6 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD5_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_RETI\ : std_logic ;
  signal N_5_7 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD5_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_RETI\ : std_logic ;
  signal N_1_31 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57_RETO\ : std_logic ;
  signal N_2_26 : std_logic ;
  signal N_9_5 : std_logic ;
  signal N_35783_RETI : std_logic ;
  signal N_9_6 : std_logic ;
  signal N_35782_RETI : std_logic ;
  signal N_5_8 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD6_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_RETI\ : std_logic ;
  signal N_5_9 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD6_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_RETI\ : std_logic ;
  signal N_1_32 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56_RETO\ : std_logic ;
  signal N_2_27 : std_logic ;
  signal N_9_7 : std_logic ;
  signal N_35785_RETI : std_logic ;
  signal N_9_8 : std_logic ;
  signal N_35784_RETI : std_logic ;
  signal N_5_10 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD7_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_RETI\ : std_logic ;
  signal N_5_11 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD7_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_RETI\ : std_logic ;
  signal N_1_33 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55_RETO\ : std_logic ;
  signal N_2_28 : std_logic ;
  signal N_9_9 : std_logic ;
  signal N_35787_RETI : std_logic ;
  signal N_9_10 : std_logic ;
  signal N_35786_RETI : std_logic ;
  signal N_5_12 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD8_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_RETI\ : std_logic ;
  signal N_5_13 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD8_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_RETI\ : std_logic ;
  signal N_1_34 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54_RETO\ : std_logic ;
  signal N_2_29 : std_logic ;
  signal N_9_11 : std_logic ;
  signal N_35789_RETI : std_logic ;
  signal N_9_12 : std_logic ;
  signal N_35788_RETI : std_logic ;
  signal N_5_14 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD9_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_RETI\ : std_logic ;
  signal N_5_15 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD9_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_RETI\ : std_logic ;
  signal N_1_35 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_77_RETO\ : std_logic ;
  signal N_2_30 : std_logic ;
  signal N_1_36 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53_RETO\ : std_logic ;
  signal N_2_31 : std_logic ;
  signal N_9_13 : std_logic ;
  signal N_35791_RETI : std_logic ;
  signal N_9_14 : std_logic ;
  signal N_35790_RETI : std_logic ;
  signal N_5_16 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD10_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_RETI\ : std_logic ;
  signal N_5_17 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD10_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_RETI\ : std_logic ;
  signal \GRFPC0.UN1_WRENX10_I_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_RETO\ : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_4_RETO\ : std_logic ;
  signal N_1_37 : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3_RETO\ : std_logic ;
  signal N_1_38 : std_logic ;
  signal N_1_39 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_76_RETO\ : std_logic ;
  signal N_2_32 : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G1_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G7_RETO\ : std_logic ;
  signal N_1_40 : std_logic ;
  signal N_1_41 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52_RETO\ : std_logic ;
  signal N_2_33 : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_4__G4_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\ : std_logic ;
  signal N_1_42 : std_logic ;
  signal N_9_15 : std_logic ;
  signal N_35793_RETI : std_logic ;
  signal N_9_16 : std_logic ;
  signal N_35792_RETI : std_logic ;
  signal N_5_18 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD11_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_RETI\ : std_logic ;
  signal N_5_19 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD11_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_RETI\ : std_logic ;
  signal N_1_43 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_75_RETO\ : std_logic ;
  signal N_2_34 : std_logic ;
  signal N_1_44 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51_RETO\ : std_logic ;
  signal N_2_35 : std_logic ;
  signal N_9_17 : std_logic ;
  signal N_35795_RETI : std_logic ;
  signal N_9_18 : std_logic ;
  signal N_35794_RETI : std_logic ;
  signal N_5_20 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD12_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_RETI\ : std_logic ;
  signal N_5_21 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD12_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_RETI\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_7__G0_I_M4_RETO\ : std_logic ;
  signal N_1_45 : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G1_0_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G7_0_X_RETO\ : std_logic ;
  signal N_1_46 : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_6__G0_3_0_RETO\ : std_logic ;
  signal N_1_47 : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_1_RETO\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_3_RETO\ : std_logic ;
  signal \GRFPC0.DIV.VALID_REP1_RETO\ : std_logic ;
  signal N_1_48 : std_logic ;
  signal N_1_49 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_74_RETO\ : std_logic ;
  signal N_2_36 : std_logic ;
  signal N_1_50 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50_RETO\ : std_logic ;
  signal N_2_37 : std_logic ;
  signal N_9_19 : std_logic ;
  signal N_35797_RETI : std_logic ;
  signal N_9_20 : std_logic ;
  signal N_35796_RETI : std_logic ;
  signal N_5_22 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_ADD13_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_RETI\ : std_logic ;
  signal N_5_23 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_ADD13_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_RETI\ : std_logic ;
  signal N_1_51 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73_RETO\ : std_logic ;
  signal N_2_38 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_REST_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3440_I_M_0_RETO\ : std_logic ;
  signal N_1_52 : std_logic ;
  signal N_1_53 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49_RETO\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49_RETO\ : std_logic ;
  signal N_2_39 : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_4__G4\ : std_logic ;
  signal N_9_21 : std_logic ;
  signal N_35799_RETI : std_logic ;
  signal N_114885 : std_logic ;
  signal N_114886 : std_logic ;
  signal N_114887 : std_logic ;
  signal N_114888 : std_logic ;
  signal N_114889 : std_logic ;
  signal N_114890 : std_logic ;
  signal N_114891 : std_logic ;
  signal N_114892 : std_logic ;
  signal N_114893 : std_logic ;
  signal N_114894 : std_logic ;
  signal N_114895 : std_logic ;
  signal N_114896 : std_logic ;
  signal N_114897 : std_logic ;
  signal N_114898 : std_logic ;
  signal N_114899 : std_logic ;
  signal N_114900 : std_logic ;
  signal N_114901 : std_logic ;
  signal N_114902 : std_logic ;
  signal N_114903 : std_logic ;
  signal N_114904 : std_logic ;
  signal N_114905 : std_logic ;
  signal N_114906 : std_logic ;
  signal N_114907 : std_logic ;
  signal N_114908 : std_logic ;
  signal N_114909 : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\ : std_logic ;
  signal N_116613 : std_logic ;
  signal N_116614 : std_logic ;
  signal N_116615 : std_logic ;
  signal N_116616 : std_logic ;
  signal N_116617 : std_logic ;
  signal N_116618 : std_logic ;
  signal N_116619 : std_logic ;
  signal N_116620 : std_logic ;
  signal N_116621 : std_logic ;
  signal N_116622 : std_logic ;
  signal N_116623 : std_logic ;
  signal N_116624 : std_logic ;
  signal N_116625 : std_logic ;
  signal N_116626 : std_logic ;
  signal N_116627 : std_logic ;
  signal N_116628 : std_logic ;
  signal N_116629 : std_logic ;
  signal N_116630 : std_logic ;
  signal N_116631 : std_logic ;
  signal N_116632 : std_logic ;
  signal N_116633 : std_logic ;
  signal N_116634 : std_logic ;
  signal N_116635 : std_logic ;
  signal N_116636 : std_logic ;
  signal N_116637 : std_logic ;
  signal N_116638 : std_logic ;
  signal N_116639 : std_logic ;
  signal N_141802 : std_logic ;
  signal N_141803 : std_logic ;
  signal RST_INTERNAL : std_logic ;
  signal HOLDN_INTERNAL : std_logic ;
  signal CPI_FLUSH_INTERNAL : std_logic ;
  signal CPI_D_INST_INTERNAL_5 : std_logic ;
  signal CPI_D_INST_INTERNAL_18 : std_logic ;
  signal CPI_D_INST_INTERNAL_24 : std_logic ;
  signal CPI_D_INST_INTERNAL_25 : std_logic ;
  signal CPI_D_INST_INTERNAL_26 : std_logic ;
  signal CPI_D_INST_INTERNAL_27 : std_logic ;
  signal CPI_D_INST_INTERNAL_28 : std_logic ;
  signal CPI_E_CNT_INTERNAL : std_logic ;
  signal CPI_E_CNT_INTERNAL_0 : std_logic ;
  signal CPI_DBG_ENABLE_INTERNAL : std_logic ;
  signal CPI_DBG_WRITE_INTERNAL : std_logic ;
  signal CPI_DBG_FSR_INTERNAL : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL : std_logic ;
  signal VCC : std_logic ;
  signal N_3 : std_logic ;
  signal N_4 : std_logic ;
  signal N_38 : std_logic ;
  signal N_39 : std_logic ;
  signal N_40 : std_logic ;
  signal N_41 : std_logic ;
  signal N_42 : std_logic ;
  signal N_43 : std_logic ;
  signal N_44 : std_logic ;
  signal N_45 : std_logic ;
  signal N_46 : std_logic ;
  signal N_47 : std_logic ;
  signal N_48 : std_logic ;
  signal N_49 : std_logic ;
  signal N_50 : std_logic ;
  signal N_51 : std_logic ;
  signal N_52 : std_logic ;
  signal N_53 : std_logic ;
  signal N_54 : std_logic ;
  signal N_55 : std_logic ;
  signal N_56 : std_logic ;
  signal N_57 : std_logic ;
  signal N_58 : std_logic ;
  signal N_59 : std_logic ;
  signal N_60 : std_logic ;
  signal N_61 : std_logic ;
  signal N_62 : std_logic ;
  signal N_63 : std_logic ;
  signal N_64 : std_logic ;
  signal N_65 : std_logic ;
  signal N_66 : std_logic ;
  signal N_67 : std_logic ;
  signal N_68 : std_logic ;
  signal N_69 : std_logic ;
  signal N_70 : std_logic ;
  signal N_71 : std_logic ;
  signal N_72 : std_logic ;
  signal N_73 : std_logic ;
  signal N_74 : std_logic ;
  signal N_75 : std_logic ;
  signal N_76 : std_logic ;
  signal N_77 : std_logic ;
  signal N_78 : std_logic ;
  signal N_79 : std_logic ;
  signal N_80 : std_logic ;
  signal N_81 : std_logic ;
  signal N_82 : std_logic ;
  signal N_83 : std_logic ;
  signal N_84 : std_logic ;
  signal N_85 : std_logic ;
  signal N_86 : std_logic ;
  signal N_87 : std_logic ;
  signal N_88 : std_logic ;
  signal N_89 : std_logic ;
  signal N_90 : std_logic ;
  signal N_91 : std_logic ;
  signal N_92 : std_logic ;
  signal N_93 : std_logic ;
  signal N_94 : std_logic ;
  signal N_95 : std_logic ;
  signal N_96 : std_logic ;
  signal N_97 : std_logic ;
  signal N_98 : std_logic ;
  signal N_99 : std_logic ;
  signal N_100 : std_logic ;
  signal N_101 : std_logic ;
  signal N_102 : std_logic ;
  signal N_103 : std_logic ;
  signal N_104 : std_logic ;
  signal N_105 : std_logic ;
  signal N_106 : std_logic ;
  signal N_107 : std_logic ;
  signal N_108 : std_logic ;
  signal N_109 : std_logic ;
  signal N_110 : std_logic ;
  signal N_111 : std_logic ;
  signal N_112 : std_logic ;
  signal N_113 : std_logic ;
  signal N_114 : std_logic ;
  signal N_115 : std_logic ;
  signal N_116 : std_logic ;
  signal N_117 : std_logic ;
  signal N_118 : std_logic ;
  signal N_119 : std_logic ;
  signal N_120 : std_logic ;
  signal N_121 : std_logic ;
  signal N_122 : std_logic ;
  signal N_123 : std_logic ;
  signal N_124 : std_logic ;
  signal N_125 : std_logic ;
  signal N_126 : std_logic ;
  signal N_127 : std_logic ;
  signal N_128 : std_logic ;
  signal N_129 : std_logic ;
  signal N_130 : std_logic ;
  signal N_131 : std_logic ;
  signal N_132 : std_logic ;
  signal N_133 : std_logic ;
  signal N_134 : std_logic ;
  signal N_135 : std_logic ;
  signal N_136 : std_logic ;
  signal N_137 : std_logic ;
  signal N_138 : std_logic ;
  signal N_139 : std_logic ;
  signal N_140 : std_logic ;
  signal N_141 : std_logic ;
  signal N_142 : std_logic ;
  signal N_143 : std_logic ;
  signal N_144 : std_logic ;
  signal N_145 : std_logic ;
  signal N_146 : std_logic ;
  signal N_147 : std_logic ;
  signal N_148 : std_logic ;
  signal N_149 : std_logic ;
  signal N_150 : std_logic ;
  signal N_151 : std_logic ;
  signal N_152 : std_logic ;
  signal N_153 : std_logic ;
  signal N_154 : std_logic ;
  signal N_155 : std_logic ;
  signal N_156 : std_logic ;
  signal N_157 : std_logic ;
  signal N_158 : std_logic ;
  signal N_159 : std_logic ;
  signal N_160 : std_logic ;
  signal N_161 : std_logic ;
  signal N_162 : std_logic ;
  signal N_163 : std_logic ;
  signal N_164 : std_logic ;
  signal N_165 : std_logic ;
  signal N_166 : std_logic ;
  signal N_167 : std_logic ;
  signal N_168 : std_logic ;
  signal N_169 : std_logic ;
  signal N_170 : std_logic ;
  signal N_171 : std_logic ;
  signal N_172 : std_logic ;
  signal N_173 : std_logic ;
  signal N_174 : std_logic ;
  signal N_175 : std_logic ;
  signal N_176 : std_logic ;
  signal N_177 : std_logic ;
  signal N_178 : std_logic ;
  signal N_179 : std_logic ;
  signal N_180 : std_logic ;
  signal N_181 : std_logic ;
  signal N_182 : std_logic ;
  signal N_183 : std_logic ;
  signal N_184 : std_logic ;
  signal N_185 : std_logic ;
  signal N_186 : std_logic ;
  signal N_187 : std_logic ;
  signal N_188 : std_logic ;
  signal N_189 : std_logic ;
  signal N_190 : std_logic ;
  signal N_191 : std_logic ;
  signal N_192 : std_logic ;
  signal N_193 : std_logic ;
  signal N_194 : std_logic ;
  signal N_195 : std_logic ;
  signal N_196 : std_logic ;
  signal N_197 : std_logic ;
  signal N_198 : std_logic ;
  signal N_199 : std_logic ;
  signal N_200 : std_logic ;
  signal N_201 : std_logic ;
  signal N_202 : std_logic ;
  signal N_203 : std_logic ;
  signal N_204 : std_logic ;
  signal N_205 : std_logic ;
  signal N_206 : std_logic ;
  signal N_207 : std_logic ;
  signal N_208 : std_logic ;
  signal N_209 : std_logic ;
  signal N_210 : std_logic ;
  signal N_211 : std_logic ;
  signal N_212 : std_logic ;
  signal N_213 : std_logic ;
  signal N_214 : std_logic ;
  signal N_215 : std_logic ;
  signal N_216 : std_logic ;
  signal N_217 : std_logic ;
  signal N_218 : std_logic ;
  signal N_219 : std_logic ;
  signal N_220 : std_logic ;
  signal N_221 : std_logic ;
  signal N_222 : std_logic ;
  signal N_223 : std_logic ;
  signal N_224 : std_logic ;
  signal N_225 : std_logic ;
  signal N_226 : std_logic ;
  signal N_227 : std_logic ;
  signal N_228 : std_logic ;
  signal N_229 : std_logic ;
  signal N_230 : std_logic ;
  signal N_231 : std_logic ;
  signal N_232 : std_logic ;
  signal N_233 : std_logic ;
  signal N_234 : std_logic ;
  signal N_235 : std_logic ;
  signal N_236 : std_logic ;
  signal N_237 : std_logic ;
  signal N_238 : std_logic ;
  signal N_239 : std_logic ;
  signal N_240 : std_logic ;
  signal N_241 : std_logic ;
  signal N_242 : std_logic ;
  signal N_243 : std_logic ;
  signal N_244 : std_logic ;
  signal N_245 : std_logic ;
  signal N_246 : std_logic ;
  signal N_247 : std_logic ;
  signal N_248 : std_logic ;
  signal N_249 : std_logic ;
  signal N_250 : std_logic ;
  signal N_251 : std_logic ;
  signal N_252 : std_logic ;
  signal N_253 : std_logic ;
  signal N_254 : std_logic ;
  signal N_255 : std_logic ;
  signal N_256 : std_logic ;
  signal N_257 : std_logic ;
  signal N_258 : std_logic ;
  signal N_259 : std_logic ;
  signal N_260 : std_logic ;
  signal N_261 : std_logic ;
  signal N_262 : std_logic ;
  signal N_263 : std_logic ;
  signal N_264 : std_logic ;
  signal N_265 : std_logic ;
  signal N_266 : std_logic ;
  signal N_267 : std_logic ;
  signal N_268 : std_logic ;
  signal N_269 : std_logic ;
  signal N_270 : std_logic ;
  signal N_271 : std_logic ;
  signal N_272 : std_logic ;
  signal N_273 : std_logic ;
  signal N_274 : std_logic ;
  signal N_275 : std_logic ;
  signal N_276 : std_logic ;
  signal N_277 : std_logic ;
  signal N_278 : std_logic ;
  signal N_279 : std_logic ;
  signal N_280 : std_logic ;
  signal N_281 : std_logic ;
  signal N_282 : std_logic ;
  signal N_283 : std_logic ;
  signal N_284 : std_logic ;
  signal N_285 : std_logic ;
  signal N_286 : std_logic ;
  signal N_287 : std_logic ;
  signal N_288 : std_logic ;
  signal N_289 : std_logic ;
  signal N_290 : std_logic ;
  signal N_291 : std_logic ;
  signal N_292 : std_logic ;
  signal N_293 : std_logic ;
  signal N_294 : std_logic ;
  signal N_295 : std_logic ;
  signal N_296 : std_logic ;
  signal N_297 : std_logic ;
  signal N_298 : std_logic ;
  signal N_299 : std_logic ;
  signal N_300 : std_logic ;
  signal N_301 : std_logic ;
  signal N_302 : std_logic ;
  signal N_303 : std_logic ;
  signal N_304 : std_logic ;
  signal N_305 : std_logic ;
  signal N_306 : std_logic ;
  signal N_307 : std_logic ;
  signal N_308 : std_logic ;
  signal N_309 : std_logic ;
  signal N_310 : std_logic ;
  signal N_311 : std_logic ;
  signal N_312 : std_logic ;
  signal N_313 : std_logic ;
  signal N_314 : std_logic ;
  signal N_315 : std_logic ;
  signal N_316 : std_logic ;
  signal N_317 : std_logic ;
  signal N_318 : std_logic ;
  signal N_319 : std_logic ;
  signal N_320 : std_logic ;
  signal N_321 : std_logic ;
  signal N_322 : std_logic ;
  signal N_323 : std_logic ;
  signal N_324 : std_logic ;
  signal N_325 : std_logic ;
  signal N_326 : std_logic ;
  signal N_327 : std_logic ;
  signal N_328 : std_logic ;
  signal N_329 : std_logic ;
  signal N_330 : std_logic ;
  signal N_331 : std_logic ;
  signal N_332 : std_logic ;
  signal N_333 : std_logic ;
  signal N_334 : std_logic ;
  signal N_335 : std_logic ;
  signal N_336 : std_logic ;
  signal N_337 : std_logic ;
  signal N_338 : std_logic ;
  signal N_339 : std_logic ;
  signal N_340 : std_logic ;
  signal N_341 : std_logic ;
  signal N_342 : std_logic ;
  signal N_343 : std_logic ;
  signal N_344 : std_logic ;
  signal N_345 : std_logic ;
  signal N_346 : std_logic ;
  signal N_347 : std_logic ;
  signal N_348 : std_logic ;
  signal N_349 : std_logic ;
  signal N_350 : std_logic ;
  signal N_351 : std_logic ;
  signal N_352 : std_logic ;
  signal N_353 : std_logic ;
  signal N_354 : std_logic ;
  signal N_355 : std_logic ;
  signal N_356 : std_logic ;
  signal N_357 : std_logic ;
  signal N_358 : std_logic ;
  signal N_359 : std_logic ;
  signal N_360 : std_logic ;
  signal N_361 : std_logic ;
  signal N_362 : std_logic ;
  signal N_363 : std_logic ;
  signal N_364 : std_logic ;
  signal N_365 : std_logic ;
  signal N_366 : std_logic ;
  signal N_367 : std_logic ;
  signal N_368 : std_logic ;
  signal N_369 : std_logic ;
  signal N_370 : std_logic ;
  signal N_371 : std_logic ;
  signal N_372 : std_logic ;
  signal N_373 : std_logic ;
  signal N_374 : std_logic ;
  signal N_375 : std_logic ;
  signal N_376 : std_logic ;
  signal N_377 : std_logic ;
  signal N_378 : std_logic ;
  signal N_379 : std_logic ;
  signal N_380 : std_logic ;
  signal N_381 : std_logic ;
  signal N_382 : std_logic ;
  signal N_383 : std_logic ;
  signal N_384 : std_logic ;
  signal N_385 : std_logic ;
  signal N_386 : std_logic ;
  signal N_387 : std_logic ;
  signal N_388 : std_logic ;
  signal N_389 : std_logic ;
  signal N_390 : std_logic ;
  signal N_391 : std_logic ;
  signal N_392 : std_logic ;
  signal N_393 : std_logic ;
  signal N_394 : std_logic ;
  signal N_395 : std_logic ;
  signal N_396 : std_logic ;
  signal N_397 : std_logic ;
  signal N_398 : std_logic ;
  signal N_399 : std_logic ;
  signal N_400 : std_logic ;
  signal N_401 : std_logic ;
  signal N_402 : std_logic ;
  signal N_403 : std_logic ;
  signal N_404 : std_logic ;
  signal N_405 : std_logic ;
  signal N_406 : std_logic ;
  signal N_407 : std_logic ;
  signal N_408 : std_logic ;
  signal N_409 : std_logic ;
  signal N_410 : std_logic ;
  signal N_411 : std_logic ;
  signal N_412 : std_logic ;
  signal N_413 : std_logic ;
  signal N_414 : std_logic ;
  signal N_415 : std_logic ;
  signal N_416 : std_logic ;
  signal N_417 : std_logic ;
  signal N_418 : std_logic ;
  signal N_419 : std_logic ;
  signal N_420 : std_logic ;
  signal N_421 : std_logic ;
  signal N_422 : std_logic ;
  signal N_423 : std_logic ;
  signal N_424 : std_logic ;
  signal N_425 : std_logic ;
  signal N_426 : std_logic ;
  signal N_427 : std_logic ;
  signal N_428 : std_logic ;
  signal N_429 : std_logic ;
  signal N_430 : std_logic ;
  signal N_431 : std_logic ;
  signal N_432 : std_logic ;
  signal N_433 : std_logic ;
  signal N_434 : std_logic ;
  signal N_435 : std_logic ;
  signal N_436 : std_logic ;
  signal N_437 : std_logic ;
  signal N_438 : std_logic ;
  signal N_439 : std_logic ;
  signal N_440 : std_logic ;
  signal N_441 : std_logic ;
  signal N_442 : std_logic ;
  signal N_443 : std_logic ;
  signal N_444 : std_logic ;
  signal N_445 : std_logic ;
  signal N_446 : std_logic ;
  signal N_447 : std_logic ;
  signal N_448 : std_logic ;
  signal N_449 : std_logic ;
  signal N_450 : std_logic ;
  signal N_451 : std_logic ;
  signal N_452 : std_logic ;
  signal N_453 : std_logic ;
  signal N_454 : std_logic ;
  signal N_455 : std_logic ;
  signal N_456 : std_logic ;
  signal N_457 : std_logic ;
  signal N_458 : std_logic ;
  signal N_459 : std_logic ;
  signal N_460 : std_logic ;
  signal N_461 : std_logic ;
  signal N_462 : std_logic ;
  signal N_0 : std_logic ;
  signal N_1_54 : std_logic ;
  signal N_2_40 : std_logic ;
  signal N_3_0 : std_logic ;
  signal N_4_0 : std_logic ;
  signal N_5_24 : std_logic ;
  signal N_6_2 : std_logic ;
  signal N_7_0 : std_logic ;
  signal N_8_0 : std_logic ;
  signal N_9_22 : std_logic ;
  signal N_10_0 : std_logic ;
  signal N_11_0 : std_logic ;
  signal N_12_0 : std_logic ;
  signal N_13_0 : std_logic ;
  signal N_14_0 : std_logic ;
  signal N_15_0 : std_logic ;
  signal N_16_0 : std_logic ;
  signal N_17_0 : std_logic ;
  signal N_18_0 : std_logic ;
  signal N_19_0 : std_logic ;
  signal N_20_0 : std_logic ;
  signal N_21_0 : std_logic ;
  signal N_22_0 : std_logic ;
  signal N_23_0 : std_logic ;
  signal N_24_0 : std_logic ;
  signal N_25_0 : std_logic ;
  signal N_26_0 : std_logic ;
  signal N_27_0 : std_logic ;
  signal N_28_0 : std_logic ;
  signal N_29_0 : std_logic ;
  signal N_30_0 : std_logic ;
  signal N_31_0 : std_logic ;
  signal N_32_0 : std_logic ;
  signal N_33_0 : std_logic ;
  signal N_34_0 : std_logic ;
  signal N_35_0 : std_logic ;
  signal N_36_0 : std_logic ;
  signal N_37_0 : std_logic ;
  signal N_38_0 : std_logic ;
  signal N_39_0 : std_logic ;
  signal N_40_0 : std_logic ;
  signal N_41_0 : std_logic ;
  signal N_42_0 : std_logic ;
  signal N_43_0 : std_logic ;
  signal N_44_0 : std_logic ;
  signal N_45_0 : std_logic ;
  signal N_46_0 : std_logic ;
  signal N_47_0 : std_logic ;
  signal N_48_0 : std_logic ;
  signal N_49_0 : std_logic ;
  signal N_50_0 : std_logic ;
  signal N_51_0 : std_logic ;
  signal N_52_0 : std_logic ;
  signal N_53_0 : std_logic ;
  signal N_54_0 : std_logic ;
  signal N_55_0 : std_logic ;
  signal N_56_0 : std_logic ;
  signal N_57_0 : std_logic ;
  signal N_58_0 : std_logic ;
  signal N_59_0 : std_logic ;
  signal N_60_0 : std_logic ;
  signal N_61_0 : std_logic ;
  signal N_62_0 : std_logic ;
  signal N_63_0 : std_logic ;
  signal N_64_0 : std_logic ;
  signal N_65_0 : std_logic ;
  signal N_66_0 : std_logic ;
  signal N_67_0 : std_logic ;
  signal N_68_0 : std_logic ;
  signal N_69_0 : std_logic ;
  signal N_70_0 : std_logic ;
  signal N_71_0 : std_logic ;
  signal N_72_0 : std_logic ;
  signal N_73_0 : std_logic ;
  signal N_74_0 : std_logic ;
  signal N_75_0 : std_logic ;
  signal N_76_0 : std_logic ;
  signal N_77_0 : std_logic ;
  signal N_78_0 : std_logic ;
  signal N_79_0 : std_logic ;
  signal N_80_0 : std_logic ;
  signal N_81_0 : std_logic ;
  signal N_82_0 : std_logic ;
  signal N_83_0 : std_logic ;
  signal N_84_0 : std_logic ;
  signal N_85_0 : std_logic ;
  signal N_86_0 : std_logic ;
  signal N_87_0 : std_logic ;
  signal N_88_0 : std_logic ;
  signal N_89_0 : std_logic ;
  signal N_90_0 : std_logic ;
  signal N_91_0 : std_logic ;
  signal N_92_0 : std_logic ;
  signal N_93_0 : std_logic ;
  signal N_94_0 : std_logic ;
  signal N_95_0 : std_logic ;
  signal N_96_0 : std_logic ;
  signal N_97_0 : std_logic ;
  signal N_98_0 : std_logic ;
  signal N_99_0 : std_logic ;
  signal N_100_0 : std_logic ;
  signal N_101_0 : std_logic ;
  signal N_102_0 : std_logic ;
  signal N_103_0 : std_logic ;
  signal N_104_0 : std_logic ;
  signal N_105_0 : std_logic ;
  signal N_106_0 : std_logic ;
  signal N_107_0 : std_logic ;
  signal N_108_0 : std_logic ;
  signal N_109_0 : std_logic ;
  signal N_110_0 : std_logic ;
  signal N_111_0 : std_logic ;
  signal N_112_0 : std_logic ;
  signal N_113_0 : std_logic ;
  signal N_114_0 : std_logic ;
  signal N_115_0 : std_logic ;
  signal N_116_0 : std_logic ;
  signal N_117_0 : std_logic ;
  signal N_118_0 : std_logic ;
  signal N_119_0 : std_logic ;
  signal N_120_0 : std_logic ;
  signal N_121_0 : std_logic ;
  signal N_122_0 : std_logic ;
  signal N_123_0 : std_logic ;
  signal N_124_0 : std_logic ;
  signal N_125_0 : std_logic ;
  signal N_126_0 : std_logic ;
  signal N_127_0 : std_logic ;
  signal N_128_0 : std_logic ;
  signal N_129_0 : std_logic ;
  signal N_130_0 : std_logic ;
  signal N_131_0 : std_logic ;
  signal N_132_0 : std_logic ;
  signal N_133_0 : std_logic ;
  signal N_134_0 : std_logic ;
  signal N_135_0 : std_logic ;
  signal N_136_0 : std_logic ;
  signal N_137_0 : std_logic ;
  signal N_138_0 : std_logic ;
  signal N_139_0 : std_logic ;
  signal N_140_0 : std_logic ;
  signal N_141_0 : std_logic ;
  signal N_142_0 : std_logic ;
  signal N_143_0 : std_logic ;
  signal N_144_0 : std_logic ;
  signal N_145_0 : std_logic ;
  signal N_146_0 : std_logic ;
  signal N_147_0 : std_logic ;
  signal N_148_0 : std_logic ;
  signal N_149_0 : std_logic ;
  signal N_150_0 : std_logic ;
  signal N_151_0 : std_logic ;
  signal N_152_0 : std_logic ;
  signal N_153_0 : std_logic ;
  signal N_154_0 : std_logic ;
  signal N_155_0 : std_logic ;
  signal N_156_0 : std_logic ;
  signal N_157_0 : std_logic ;
  signal N_158_0 : std_logic ;
  signal N_159_0 : std_logic ;
  signal N_160_0 : std_logic ;
  signal N_161_0 : std_logic ;
  signal N_162_0 : std_logic ;
  signal N_163_0 : std_logic ;
  signal N_627 : std_logic ;
  signal N_628 : std_logic ;
  signal N_629 : std_logic ;
  signal N_630 : std_logic ;
  signal N_631 : std_logic ;
  signal N_632 : std_logic ;
  signal N_633 : std_logic ;
  signal N_634 : std_logic ;
  signal N_635 : std_logic ;
  signal N_636 : std_logic ;
  signal N_637 : std_logic ;
  signal N_638 : std_logic ;
  signal N_639 : std_logic ;
  signal N_640 : std_logic ;
  signal N_641 : std_logic ;
  signal N_642 : std_logic ;
  signal N_643 : std_logic ;
  signal N_644 : std_logic ;
  signal N_645 : std_logic ;
  signal N_646 : std_logic ;
  signal N_647 : std_logic ;
  signal N_648 : std_logic ;
  signal N_649 : std_logic ;
  signal N_650 : std_logic ;
  signal N_651 : std_logic ;
  signal N_652 : std_logic ;
  signal N_653 : std_logic ;
  signal N_654 : std_logic ;
  signal N_655 : std_logic ;
  signal N_656 : std_logic ;
  signal N_657 : std_logic ;
  signal N_658 : std_logic ;
  signal N_659 : std_logic ;
  signal N_660 : std_logic ;
  signal N_661 : std_logic ;
  signal N_662 : std_logic ;
  signal N_663 : std_logic ;
  signal N_664 : std_logic ;
  signal N_665 : std_logic ;
  signal N_666 : std_logic ;
  signal N_667 : std_logic ;
  signal N_668 : std_logic ;
  signal N_669 : std_logic ;
  signal N_670 : std_logic ;
  signal N_671 : std_logic ;
  signal N_672 : std_logic ;
  signal N_673 : std_logic ;
  signal N_674 : std_logic ;
  signal N_675 : std_logic ;
  signal N_676 : std_logic ;
  signal N_677 : std_logic ;
  signal N_678 : std_logic ;
  signal N_679 : std_logic ;
  signal N_680 : std_logic ;
  signal N_681 : std_logic ;
  signal N_682 : std_logic ;
  signal N_683 : std_logic ;
  signal N_684 : std_logic ;
  signal N_685 : std_logic ;
  signal N_686 : std_logic ;
  signal N_687 : std_logic ;
  signal N_688 : std_logic ;
  signal N_689 : std_logic ;
  signal N_690 : std_logic ;
  signal N_691 : std_logic ;
  signal N_692 : std_logic ;
  signal N_693 : std_logic ;
  signal N_694 : std_logic ;
  signal N_695 : std_logic ;
  signal N_696 : std_logic ;
  signal N_697 : std_logic ;
  signal N_698 : std_logic ;
  signal N_699 : std_logic ;
  signal N_700 : std_logic ;
  signal N_701 : std_logic ;
  signal N_702 : std_logic ;
  signal N_703 : std_logic ;
  signal N_704 : std_logic ;
  signal N_705 : std_logic ;
  signal N_706 : std_logic ;
  signal N_707 : std_logic ;
  signal N_708 : std_logic ;
  signal N_709 : std_logic ;
  signal N_710 : std_logic ;
  signal N_711 : std_logic ;
  signal N_712 : std_logic ;
  signal N_713 : std_logic ;
  signal N_714 : std_logic ;
  signal N_715 : std_logic ;
  signal N_716 : std_logic ;
  signal N_717 : std_logic ;
  signal N_718 : std_logic ;
  signal N_719 : std_logic ;
  signal N_720 : std_logic ;
  signal N_721 : std_logic ;
  signal N_722 : std_logic ;
  signal N_723 : std_logic ;
  signal N_724 : std_logic ;
  signal N_725 : std_logic ;
  signal N_726 : std_logic ;
  signal N_727 : std_logic ;
  signal N_728 : std_logic ;
  signal N_729 : std_logic ;
  signal N_730 : std_logic ;
  signal N_731 : std_logic ;
  signal N_732 : std_logic ;
  signal N_733 : std_logic ;
  signal N_734 : std_logic ;
  signal N_735 : std_logic ;
  signal N_736 : std_logic ;
  signal N_737 : std_logic ;
  signal N_738 : std_logic ;
  signal N_739 : std_logic ;
  signal N_740 : std_logic ;
  signal N_741 : std_logic ;
  signal N_742 : std_logic ;
  signal N_743 : std_logic ;
  signal N_744 : std_logic ;
  signal N_745 : std_logic ;
  signal N_746 : std_logic ;
  signal N_747 : std_logic ;
  signal N_748 : std_logic ;
  signal N_749 : std_logic ;
  signal N_750 : std_logic ;
  signal N_751 : std_logic ;
  signal N_752 : std_logic ;
  signal N_753 : std_logic ;
  signal N_754 : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UINT17_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_I\ : std_logic ;
  signal N_3_I : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0_I\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_0_1_0_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\ : std_logic ;
  signal N_38_I : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_53_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_ADD11_I\ : std_logic ;
  signal CPO_EXCZ : std_logic ;
  signal CPO_CCVZ : std_logic ;
  signal CPO_LDLOCKZ : std_logic ;
  signal RFI1_REN1Z : std_logic ;
  signal RFI1_REN2Z : std_logic ;
  signal RFI1_WRENZ : std_logic ;
  signal RFI2_REN1Z : std_logic ;
  signal RFI2_REN2Z : std_logic ;
  signal RFI2_WRENZ : std_logic ;
begin
VCC <= '1';
GND <= '0';
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MU_MU_ML_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  7,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MU_ML_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  7,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IND\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IND\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_MU_MU_MU_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  18,
 width_a =>  7,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MU_MU_MU_ML_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  7,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_MU_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_MU_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_MU_MU_ML_MULADD_0_35_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  36,
 width_b =>  18,
 width_a =>  18,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(35),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MU_MU_MU_MU_MULADD_0_13_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  14,
 width_b =>  7,
 width_a =>  7,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2\(115),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(13),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_MU_MU_MU_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  18,
 width_a =>  7,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  clock0 => N_4);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_MU_MU_MU_MULADD_0_24_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "UNREGISTERED" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  25,
 width_b =>  18,
 width_a =>  7,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(24),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_4);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63_TERM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2\,
cin => N_116639);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_54_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2\(98),
cin => N_116638);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\,
cin => N_116637);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD78_TERM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
cin => N_116636);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_104_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73\,
cin => N_116635);
GRFPU0_FPMUL0_R2_RET_49_RNIIQ2A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116634,
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\);
GRFPU0_R2_RET_41_RNIG541: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116633,
dataa => N_35796);
GRFPU0_R2_RET_43_RNII541: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116632,
dataa => N_35799);
GRFPU0_FPMUL0_UN1_SIN_2_ADD14_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116631,
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\);
\GRFPU0_GRFPU_X0_UN6_SGNFX_TERM_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(23),
cin => N_116630);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_TERM_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => N_35977,
cin => N_116629);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_TERM_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => N_35978,
cin => N_116628);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD1_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116627,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116626,
dataa => \GRFPU0.GRFPU_X0.COMB.ITCIN\);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_TERM_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
cin => N_116625);
GRFPU0_GRFPU_X0_C_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116624,
dataa => VCC);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116623,
dataa => VCC);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116622,
dataa => VCC);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116621,
dataa => VCC);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD0_START: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116620,
dataa => VCC);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_80_RNIFOM43_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_RETO\(115),
cin => N_116619);
GRFPU0_R2_RET_41_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => N_35796_RETI,
cin => N_116618);
GRFPU0_FPMUL0_R2_RET_49_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_RETI\,
cin => N_116617);
GRFPU0_FPMUL0_UN1_SIN_2_ADD13_TERM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_RETI\,
cin => N_116616);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_104_RNI4353: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116615,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_RNIIG14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010101010")
port map (
cout => N_116614,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12_RETO\);
GRFPU0_R2_RET_43_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => N_35799_RETI,
cin => N_116613);
GRFPC0_RFA2_RS2SEL_RET_4_RNID9PH_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP2\(7),
dataa => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3_RETO\,
datab => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPC0_RFA2_RS2SEL_RET_4_RNID9PH_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP1\(7),
dataa => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3_RETO\,
datab => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPC0_RFA2_RS2SEL_RET_1_RNI9FGE1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP2\(6),
dataa => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_RETO\,
datab => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10_RETO\,
datad => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPC0_RFA2_RS2SEL_RET_1_RNI9FGE1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP1\(6),
dataa => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_RETO\,
datab => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10_RETO\,
datad => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPC0_RFA2_RS2SEL_RET_10_RNIVICN_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP2\(4),
dataa => \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.EXEN7_RETO\,
datad => \GRFPC0.FPUSEL_1_0_4__G4_RETO\);
GRFPC0_RFA2_RS2SEL_RET_10_RNIVICN_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_REP1\(4),
dataa => \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.EXEN7_RETO\,
datad => \GRFPC0.FPUSEL_1_0_4__G4_RETO\);
\GRFPC0_FPUSEL_6_REP2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP2\(0),
dataa => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datad => \GRFPC0.FPUSEL_6_M3_RETO\(0));
\GRFPC0_FPUSEL_6_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP1\(0),
dataa => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datad => \GRFPC0.FPUSEL_6_M3_RETO\(0));
GRFPC0_RFA2_RS1SEL_RET_17_RNIVN9U_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP2\(6),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_6__G0_3_0_RETO\);
GRFPC0_RFA2_RS1SEL_RET_17_RNIVN9U_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP1\(6),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_6__G0_3_0_RETO\);
GRFPC0_RFA2_RS1SEL_RET_7_RNIC5L91_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP2\(4),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_4__G4_RETO\);
GRFPC0_RFA2_RS1SEL_RET_7_RNIC5L91_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP1\(4),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_4__G4_RETO\);
GRFPC0_RFA2_RS1SEL_RET_13_RNI0NQ01_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP2\(3),
dataa => \GRFPC0.FPUSEL_1_0_3__G7_0_X_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datad => \GRFPC0.FPUSEL_6_0_3__G1_0_RETO\);
GRFPC0_RFA2_RS1SEL_RET_13_RNI0NQ01_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_REP1\(3),
dataa => \GRFPC0.FPUSEL_1_0_3__G7_0_X_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datad => \GRFPC0.FPUSEL_6_0_3__G1_0_RETO\);
GRFPC0_VFIFO_INST_1_1_SQMUXA_M1_E_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
dataa => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
GRFPU0_GRFPU_X0_ST1_V_RNIPV661: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.REST_2\(5));
GRFPU0_GRFPU_X0_ST1_V_RNIPV661_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.REST_2\(5));
GRFPU0_GRFPU_X0_UN223_BCO_LSB_RNIRJ9T5_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5),
dataa => \GRFPU0.GRFPU_X0.L3_2\(5),
datab => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_0\(4));
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_56_M6_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_A4\,
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD50\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
cin => N_114503);
GRFPU0_GRFPU_X0_COMB_VST4_SEL6_RNI0B6U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.SEL6\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.SEL2\,
datac => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_I\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V5_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_0\,
dataa => N_84,
datab => \GRFPC0.INST_I_1\(6),
datac => \GRFPC0.INST_I_M2\(1),
datad => \GRFPC0.INST\(5));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(6));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(4));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(5));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(2));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(3));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(0),
dataa => \GRFPC0.OP2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_5__G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G3\,
datac => \GRFPU0.GRFPU_X0.N_58_I_I\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_2__G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G3\,
datac => \GRFPU0.GRFPU_X0.N_58_I_I\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G3\,
datac => \GRFPU0.GRFPU_X0.N_58_I_I\);
\GRFPC0_INST_I_0_M2_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.INST_I_0_M2_X\(13),
dataa => N_91,
datab => \GRFPC0.FIFO.INST_1\(13),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_8__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82\);
GRFPU0_GRFPU_X0_ST2_EMINM1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_1\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_1183_0\);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G4_0\,
datab => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\);
\GRFPC0_WR_RREG_EXCT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_0__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(0),
datab => \GRFPC0.DIV.EXCT_0_0_0__G3\,
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_43__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(43),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(43),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_45__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_10__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(10),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_10__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_57__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_18__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(18),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_18__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_1__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(1),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_1__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_50__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(50),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_8__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(8),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_8__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_49__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(49),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_5__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(5),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_5__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_6__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(6),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_6__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_16__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(16),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_16__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_4__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(4),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_4__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_30__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(30),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_30__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_7__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(7),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_7__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_11__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(11),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_11__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_44__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(44),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_12__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(12),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_12__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_46__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(46),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_54__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(54),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_3__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(3),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_3__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_22__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(22),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_22__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_58__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_15__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(15),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_15__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_42__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(42),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_59__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_37__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(37),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_33__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(33),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_17__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(17),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_17__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_63__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_13__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(13),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_13__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_48__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(48),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_51__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_47__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(47),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_52__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(52),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_60__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(60),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_0__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(0),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_0__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_20__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(20),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_20__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_28__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(28),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_28__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_EXCT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_1__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\,
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_34__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_29__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(29),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_29__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_62__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(62),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_24__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(24),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_24__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_EXCT_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_5__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_14__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(14),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_14__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_21__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(21),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_21__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_31__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(31),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_31__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_27__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(27),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_27__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_56__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_2__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(2),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.DIV.RESULT_0_0_2__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_EXCT_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_3__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3),
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_53__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_9__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(9),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datac => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_32__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(32),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_23__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(23),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_23__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_38__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(38),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_26__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(26),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_26__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_19__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(19),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_19__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_35__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(35),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_EXCT_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_4__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\,
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_55__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPC0.DIV.RESULT_0_0_55__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_25__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(25),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPC0.DIV.RESULT_0_0_25__G3\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_41__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(41),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(41),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_40__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(40),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_36__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(36),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_39__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(39),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_RES_RNO_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_61__G0\,
dataa => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(61),
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_WR_RREG_EXCT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_2__G0\,
dataa => \GRFPC0.MEM.RREG.EXCT\(2),
datab => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\,
datac => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_20__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPC0_MEM_RREG_RES_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_52__G0\,
dataa => \GRFPC0.EX.RREG.RES\(52),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(52));
\GRFPC0_MEM_RREG_RES_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_54__G0\,
dataa => \GRFPC0.EX.RREG.RES\(54),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(54));
\GRFPC0_MEM_RREG_RES_RNO_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_61__G0\,
dataa => \GRFPC0.EX.RREG.RES\(61),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(61));
\GRFPC0_MEM_RREG_RES_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_41__G0\,
dataa => \GRFPC0.EX.RREG.RES\(41),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(41));
\GRFPC0_MEM_RREG_RES_RNO_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_60__G0\,
dataa => \GRFPC0.EX.RREG.RES\(60),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(60));
\GRFPC0_MEM_RREG_RES_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_43__G0\,
dataa => \GRFPC0.EX.RREG.RES\(43),
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datac => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I\(43));
\GRFPC0_MEM_RREG_RES_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_34__G0\,
dataa => \GRFPC0.EX.RREG.RES\(34),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_20__G0\,
dataa => \GRFPC0.EX.RREG.RES\(20),
datab => \GRFPC0.DIV.RESULT_0_0_20__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_32__G0\,
dataa => \GRFPC0.EX.RREG.RES\(32),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_4__G0\,
dataa => \GRFPC0.EX.RREG.RES\(4),
datab => \GRFPC0.DIV.RESULT_0_0_4__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_18__G0\,
dataa => \GRFPC0.EX.RREG.RES\(18),
datab => \GRFPC0.DIV.RESULT_0_0_18__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_15__G0\,
dataa => \GRFPC0.EX.RREG.RES\(15),
datab => \GRFPC0.DIV.RESULT_0_0_15__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_1__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_16__G0\,
dataa => \GRFPC0.EX.RREG.RES\(16),
datab => \GRFPC0.DIV.RESULT_0_0_16__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_49__G0\,
dataa => \GRFPC0.EX.RREG.RES\(49),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_1__G0\,
dataa => \GRFPC0.EX.RREG.RES\(1),
datab => \GRFPC0.DIV.RESULT_0_0_1__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_2__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(2),
datab => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_24__G0\,
dataa => \GRFPC0.EX.RREG.RES\(24),
datab => \GRFPC0.DIV.RESULT_0_0_24__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_50__G0\,
dataa => \GRFPC0.EX.RREG.RES\(50),
datab => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_19__G0\,
dataa => \GRFPC0.EX.RREG.RES\(19),
datab => \GRFPC0.DIV.RESULT_0_0_19__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_29__G0\,
dataa => \GRFPC0.EX.RREG.RES\(29),
datab => \GRFPC0.DIV.RESULT_0_0_29__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_36__G0\,
dataa => \GRFPC0.EX.RREG.RES\(36),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_22__G0\,
dataa => \GRFPC0.EX.RREG.RES\(22),
datab => \GRFPC0.DIV.RESULT_0_0_22__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_6__G0\,
dataa => \GRFPC0.EX.RREG.RES\(6),
datab => \GRFPC0.DIV.RESULT_0_0_6__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_48__G0\,
dataa => \GRFPC0.EX.RREG.RES\(48),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_53__G0\,
dataa => \GRFPC0.EX.RREG.RES\(53),
datab => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_38__G0\,
dataa => \GRFPC0.EX.RREG.RES\(38),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_2__G0\,
dataa => \GRFPC0.EX.RREG.RES\(2),
datab => \GRFPC0.DIV.RESULT_0_0_2__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_0__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(0),
datab => \GRFPC0.DIV.EXCT_0_0_0__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_28__G0\,
dataa => \GRFPC0.EX.RREG.RES\(28),
datab => \GRFPC0.DIV.RESULT_0_0_28__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_23__G0\,
dataa => \GRFPC0.EX.RREG.RES\(23),
datab => \GRFPC0.DIV.RESULT_0_0_23__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_8__G0\,
dataa => \GRFPC0.EX.RREG.RES\(8),
datab => \GRFPC0.DIV.RESULT_0_0_8__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_3__G0\,
dataa => \GRFPC0.EX.RREG.RES\(3),
datab => \GRFPC0.DIV.RESULT_0_0_3__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_5__G0\,
dataa => \GRFPC0.EX.RREG.RES\(5),
datab => \GRFPC0.DIV.RESULT_0_0_5__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_14__G0\,
dataa => \GRFPC0.EX.RREG.RES\(14),
datab => \GRFPC0.DIV.RESULT_0_0_14__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_35__G0\,
dataa => \GRFPC0.EX.RREG.RES\(35),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_42__G0\,
dataa => \GRFPC0.EX.RREG.RES\(42),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_40__G0\,
dataa => \GRFPC0.EX.RREG.RES\(40),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_55__G0\,
dataa => \GRFPC0.EX.RREG.RES\(55),
datab => \GRFPC0.DIV.RESULT_0_0_55__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_3__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_21__G0\,
dataa => \GRFPC0.EX.RREG.RES\(21),
datab => \GRFPC0.DIV.RESULT_0_0_21__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_25__G0\,
dataa => \GRFPC0.EX.RREG.RES\(25),
datab => \GRFPC0.DIV.RESULT_0_0_25__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_5__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_26__G0\,
dataa => \GRFPC0.EX.RREG.RES\(26),
datab => \GRFPC0.DIV.RESULT_0_0_26__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_EXCT_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_4__G0\,
dataa => \GRFPC0.EX.RREG.EXCT\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_9__G0\,
dataa => \GRFPC0.EX.RREG.RES\(9),
datab => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_11__G0\,
dataa => \GRFPC0.EX.RREG.RES\(11),
datab => \GRFPC0.DIV.RESULT_0_0_11__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_33__G0\,
dataa => \GRFPC0.EX.RREG.RES\(33),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_57__G0\,
dataa => \GRFPC0.EX.RREG.RES\(57),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_37__G0\,
dataa => \GRFPC0.EX.RREG.RES\(37),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_44__G0\,
dataa => \GRFPC0.EX.RREG.RES\(44),
datab => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_39__G0\,
dataa => \GRFPC0.EX.RREG.RES\(39),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_51__G0\,
dataa => \GRFPC0.EX.RREG.RES\(51),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_31__G0\,
dataa => \GRFPC0.EX.RREG.RES\(31),
datab => \GRFPC0.DIV.RESULT_0_0_31__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_12__G0\,
dataa => \GRFPC0.EX.RREG.RES\(12),
datab => \GRFPC0.DIV.RESULT_0_0_12__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_58__G0\,
dataa => \GRFPC0.EX.RREG.RES\(58),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_27__G0\,
dataa => \GRFPC0.EX.RREG.RES\(27),
datab => \GRFPC0.DIV.RESULT_0_0_27__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_10__G0\,
dataa => \GRFPC0.EX.RREG.RES\(10),
datab => \GRFPC0.DIV.RESULT_0_0_10__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_0__G0\,
dataa => \GRFPC0.EX.RREG.RES\(0),
datab => \GRFPC0.DIV.RESULT_0_0_0__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_13__G0\,
dataa => \GRFPC0.EX.RREG.RES\(13),
datab => \GRFPC0.DIV.RESULT_0_0_13__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_7__G0\,
dataa => \GRFPC0.EX.RREG.RES\(7),
datab => \GRFPC0.DIV.RESULT_0_0_7__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_45__G0\,
dataa => \GRFPC0.EX.RREG.RES\(45),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_46__G0\,
dataa => \GRFPC0.EX.RREG.RES\(46),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_56__G0\,
dataa => \GRFPC0.EX.RREG.RES\(56),
datab => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_63__G0\,
dataa => \GRFPC0.EX.RREG.RES\(63),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_47__G0\,
dataa => \GRFPC0.EX.RREG.RES\(47),
datab => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_62__G0\,
dataa => \GRFPC0.EX.RREG.RES\(62),
datab => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_30__G0\,
dataa => \GRFPC0.EX.RREG.RES\(30),
datab => \GRFPC0.DIV.RESULT_0_0_30__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_17__G0\,
dataa => \GRFPC0.EX.RREG.RES\(17),
datab => \GRFPC0.DIV.RESULT_0_0_17__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPC0_MEM_RREG_RES_RNO_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_59__G0\,
dataa => \GRFPC0.EX.RREG.RES\(59),
datab => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
datac => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
datad => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10132\,
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
\GRFPC0_WR2_RREG_EXCT_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100100000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_5__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(5),
datab => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datac => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\);
\GRFPC0_WR2_RREG_EXCT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011110000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_2__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(2),
datab => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\,
datad => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\);
\GRFPC0_WR2_RREG_EXCT_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011110000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_3__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(3),
datab => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3),
datad => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\);
\GRFPC0_WR2_RREG_EXCT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001100")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_0__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(0),
datab => \GRFPC0.DIV.EXCT_0_0_0__G3\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datad => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\);
\GRFPC0_WR2_RREG_EXCT_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001100")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datad => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\);
\GRFPC0_WR2_RREG_EXCT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001100")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_1__G0\,
dataa => \GRFPC0.WR.RREG.EXCT\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
datad => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\);
RETGRFPU0_GRFPU_X0_COMB_VEXC_5_4_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => N_114909,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\RETGRFPU0_GRFPU_X0_COMB_VEXC_5_IV_0_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101111")
port map (
combout => N_114908,
dataa => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datac => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
RETGRFPU0_GRFPU_X0_COMB_VEXC_5_1_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => N_114907,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\RETGRFPC0_DIV_EXCT_0_0_0__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => N_114906,
dataa => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
RETGRFPC0_UN1_RDWR_3_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => N_114905,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.RDWR_3_SQMUXA\,
datac => \GRFPC0.RDWR_5_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
RETGRFPC0_UN1_RDWR_3_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => N_114904,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datac => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114903,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(5),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(5),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114902,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(4),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(4),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114901,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(3),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(3),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114900,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(2),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(2),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114899,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(1),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(1),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPU0_GRFPU_X0_IDOUT_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => N_114898,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(0),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\RETGRFPC0_INST_I_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000011")
port map (
combout => N_114897,
dataa => N_82,
datab => \GRFPC0.INST_I_A2_1\(4),
datac => \GRFPC0.INST_I_A2_0\(4),
datad => \GRFPC0.INST_I_M2\(1));
\RETGRFPC0_INST_I_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000011")
port map (
combout => N_114896,
dataa => N_81,
datab => \GRFPC0.INST_I_A2_1\(3),
datac => \GRFPC0.INST_I_A2_0\(3),
datad => \GRFPC0.INST_I_M2\(1));
\RETGRFPC0_INST_I_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => N_114895,
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_A\(2));
\RETGRFPC0_INST_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => N_114894,
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_A\(1));
\RETGRFPC0_FP_PIPELINE_RS1_6_0_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001011")
port map (
combout => N_114893,
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST_I_0\(14),
datad => \GRFPC0.INST_I_A2_X\(14));
RETGRFPC0_UN1_RDWR_3_SQMUXA_4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => N_114892,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datac => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
RETGRFPC0_FP_PIPELINE_0_EXEN2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => N_114891,
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_3\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_0\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_1\);
\RETGRFPC0_FPUSEL_6_0_3__G0_E\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => N_114890,
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E_2\);
RETGRFPC0_FP_PIPELINE_1_EXEN7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => N_114889,
dataa => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
datab => \GRFPC0.FP_PIPELINE.1.EXEN7_4\);
\RETGRFPC0_FPUSEL_1_0_3__G0_E_3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => N_114888,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_A\,
datac => RFI2_RD2ADDRZ(0));
\RETGRFPC0_FPUSEL_1_0_3__G0_E_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => N_114887,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
datad => RFI2_RD2ADDRZ(1));
\RETGRFPC0_FPUSEL_1_0_3__G7_0_X\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010001010")
port map (
combout => N_114886,
dataa => N_38,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
RETGRFPC0_UN1_WRENX2_2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => N_114885,
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
datac => \GRFPC0.UN1_WRENX2_2_0_0\,
datad => \GRFPC0.UN1_WRENX2_2_2\);
GRFPU0_GRFPU_X0_VITER_STATE_23_SQMUXA_RNID90H: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datab => \GRFPU0.GRFPU_X0.VITER.STATE_23_SQMUXA\);
GRFPU0_GRFPU_X0_ST1_OP2NX_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_A3\);
GRFPU0_GRFPU_X0_ST1_SIGN2_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
dataa => \GRFPC0.OP2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_0__G0\,
dataa => \GRFPC0.R.FSR.RD\(0),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_1__G0\,
dataa => \GRFPC0.R.FSR.RD\(1),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_0\);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_1__G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_0\);
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_RNIAMNED: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G0\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G2\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_I\);
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_RNIAMNED_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G0\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_I\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_0__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD0\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_1__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD1\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_2__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD2\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_3__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD3\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_4__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD4\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\);
\GRFPU0_GRFPU_X0_ST1_IDCST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_5__G0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_1__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_2__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_3__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_4__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_5__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_6__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_7__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_8__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_9__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_10__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_11__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_12__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_13__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_15__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_16__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_17__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_RNI1INJ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datab => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNII1QK1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_0__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_2__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(7),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_3__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(8),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_4__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(9),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_5__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_6__G0_I\,
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_7__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_8__G0_I\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
GRFPC0_RFA2_RS2SEL_RET_4_RNID9PH: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.RFA2.RS2SEL\(7),
dataa => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3_RETO\,
datab => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_90_RNI38117: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(88),
cout => N_116613,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(87),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(88),
cin => N_35797_RETI);
GRFPC0_RFA2_RS1SEL_RET_7_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_4__G4\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.0.WRSEL4\,
datac => \GRFPC0.FP_PIPELINE.0.WRENX2\,
datad => \GRFPC0.FPUSEL_6_0_4__G5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_107_RNI1NBA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49_RETO\,
cin => N_116614);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_RETO\(63),
dataa => \GRFPU0.GRFPU_X0.N_3440_I_M_0_RETO\,
datab => \GRFPU0.GRFPU_X0.UN1_REST_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M_RETO\(63),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M_RETO\(63));
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_105_RNIF9F9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD74_RETO\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_74_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(2),
cin => N_116615);
GRFPU0_FPMUL0_UN1_SIN_2_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD13_RETI\,
cout => N_116616,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(79),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIG60H6_78_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD13_RETI\,
cout => N_116617,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIDQ7R3_0_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(85),
cout => N_116618,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(85),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(86),
cin => N_35794_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIDQ7R3_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(86),
cout => N_35797_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(85),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(86),
cin => N_35795_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_101_RNI4TLG: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_98_RNIG5901: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD75_RETO\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_75_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_74_RETO\);
\GRFPC0_FPUSEL_6_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPC0.FPUSEL_6_M2_RETO\(0),
dataa => \GRFPC0.DIV.VALID_REP1_RETO\,
datab => \GRFPC0.UN1_WRENX2_2_3_RETO\,
datac => \GRFPC0.FPUSEL_6_M1_RETO\(0),
datad => \GRFPC0.UN1_WRENX2_2_1_RETO\);
GRFPC0_RFA2_RS1SEL_RET_17_RNIVN9U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(6),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_6__G0_3_0_RETO\);
GRFPC0_RFA2_RS1SEL_RET_13_RNI0NQ01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(3),
dataa => \GRFPC0.FPUSEL_1_0_3__G7_0_X_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datad => \GRFPC0.FPUSEL_6_0_3__G1_0_RETO\);
GRFPC0_RFA2_RS1SEL_RET_10_RNION9U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(7),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_7__G0_I_M4_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD12_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI9E6D6_77_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD12_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI86603_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(83),
cout => N_35794_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(83),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(84),
cin => N_35792_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI86603_0_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(84),
cout => N_35795_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(83),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(84),
cin => N_35793_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_95_RNIVOF71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_92_RNI513N1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD76_RETO\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_76_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_75_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD11_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI3QC96_76_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD11_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI1QJO2_81_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(81),
cout => N_35792_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(81),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(82),
cin => N_35790_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI1QJO2_0_81_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(82),
cout => N_35793_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(81),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(82),
cin => N_35791_RETI);
GRFPC0_RFA2_RS2SEL_RET_10_RNIVICN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL\(4),
dataa => \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.EXEN7_RETO\,
datad => \GRFPC0.FPUSEL_1_0_4__G4_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_90_RNINK9U1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15_RETO\);
GRFPC0_RFA2_RS2SEL_RET_5_RNICRN21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL\(3),
dataa => \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\,
datac => \GRFPC0.FPUSEL_1_0_3__G7_RETO\,
datad => \GRFPC0.FPUSEL_1_0_3__G1_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_86_RNI0TSD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD77_RETO\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_77_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_76_RETO\);
GRFPC0_RFA2_RS2SEL_RET_1_RNI9FGE1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.RFA2.RS2SEL\(6),
dataa => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_RETO\,
datab => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0_RETO\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10_RETO\,
datad => \GRFPC0.UN1_WRENX10_I_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD10_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIU9J56_75_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD10_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIUT1H2_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(79),
cout => N_35790_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(79),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(80),
cin => N_35788_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIUT1H2_0_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(80),
cout => N_35791_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(79),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(80),
cin => N_35789_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_83_RNICG3L2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_80_RNIFOM43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD78_RETO\,
cout => N_116619,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_77_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD9_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIQTP16_74_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD9_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIM9F92_0_77_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(77),
cout => N_35788_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
cin => N_35786_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIM9F92_77_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(78),
cout => N_35789_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
cin => N_35787_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_77_RNI7CTB3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD8_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNINL0U5_73_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD8_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI9TR12_75_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(75),
cout => N_35786_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
cin => N_35784_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI9TR12_0_75_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(76),
cout => N_35787_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
cin => N_35785_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_74_RNIS7N24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18_RETO\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNILH7Q5_72_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD7_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_RETI\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD7_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI019Q1_0_73_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(73),
cout => N_35784_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
cin => N_35782_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI019Q1_73_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(74),
cout => N_35785_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
cin => N_35783_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_71_RNIB3HP4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19_RETO\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIKHEM5_71_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD6_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_RETI\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD6_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIRKMI1_71_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(71),
cout => N_35782_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
cin => N_35780_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIRKMI1_0_71_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(72),
cout => N_35783_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
cin => N_35781_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_68_RNI6VAG5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD5_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIKLLI5_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD5_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIQO4B1_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(69),
cout => N_35780_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
cin => N_35778_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIQO4B1_0_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(70),
cout => N_35781_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
cin => N_35779_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_65_RNIRQ476: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21_RETO\);
GRFPU0_GRFPU_X0_ST2_REG_RET_1_RNIOTL5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011110000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.REG\(63),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG127_RETO\,
datab => \GRFPU0.GRFPU_X0.COMB.UINT17_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_RETO\(63));
GRFPU0_FPMUL0_UN1_SIN_2_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD4_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNILTSE5_69_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD4_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIK4I31_67_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(67),
cout => N_35778_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
cin => N_35775_RETI);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIK4I31_0_67_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(68),
cout => N_35779_RETI,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
cin => N_35776_RETI);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_62_RNIAMUT6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22_RETO\);
GRFPC0_RFA2_RS1SEL_RET_7_RNIC5L91: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(4),
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datac => \GRFPC0.FPUSEL_6_0_4__G4_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD3_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
datab => \GRFPU0.FPMUL0.CSADD.UN214_C1_RETI\,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2_RETI\);
GRFPU0_FPMUL0_CSADD_UN211_C2_RNIE13B5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD3_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
datab => \GRFPU0.FPMUL0.CSADD.UN211_C2_RETI\,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2_RETI\);
\GRFPC0_FPUSEL_6_M3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000000")
port map (
combout => \GRFPC0.FPUSEL_6_M3_RETO\(0),
dataa => \GRFPC0.MEM.RREG.RESV_RETO\,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_RETO\,
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
datad => \GRFPC0.FPUSEL_6_M2_RETO\(0));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI9OUR_66_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(66),
cout => N_35776_RETI,
dataa => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI9OUR_0_66_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_35775_RETI,
dataa => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66));
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_60_RNISHOK7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(96),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD2_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2_RETI\,
dataa => \GRFPU0.FPMUL0.CSADD.S1_1_RETI\(68),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIEED65_67_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011001100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD2_RETI\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2_RETI\,
dataa => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1_RETI\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_56_RNIHDIB8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(97),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24_RETO\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010100000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0_RETI\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNIC4OV_66_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010100000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0_RETI\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_53_RNI09C29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(98),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_RETO\(98),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25_RETO\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RNI8KUR_65_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(65),
datab => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66),
datab => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_51_RNIL6PD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(99),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_49_RNIH46P9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(100),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_47_RNIB2J4A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(101),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_45_RNI300GA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(102),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_43_RNIPTCRA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(103),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_41_RNIDRP6B: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(104),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_39_RNI8P6IB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(105),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32_RETO\);
GRFPU0_FPMUL0_CSADD_UN211_C2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.FPMUL0.CSADD.UN211_C2_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
datab => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\);
GRFPU0_FPMUL0_CSADD_UN214_C1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.FPMUL0.CSADD.UN214_C1_RETI\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
datab => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\);
\GRFPC0_FPUSEL_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(0),
dataa => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datad => \GRFPC0.FPUSEL_6_M3_RETO\(0));
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_37_RNI1NJTB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(106),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33_RETO\);
\GRFPU0_FPMUL0_CSADD_S1_1_68_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.FPMUL0.CSADD.S1_1_RETI\(68),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
datab => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_35_RNIOK09C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(107),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71_RETO\,
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_32_RNI1GQVC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(108),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_30_RNIDBKMD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(109),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_27_RNIKIGBE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(110),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD74_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_24_RNIPL6NF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(111),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD75_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_21_RNIGKMPH: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(112),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD76_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_18_RNI8F0JK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(113),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD77_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_15_RNIC543O: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(114),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD78_RETO\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78_RETO\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_12_RNIDR7JR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(115),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_RETO\(115),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_RETO\(115),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_9_RNIVP0NR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(116),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44_RETO\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(8),
datab => GND,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_7_RNIFOPQR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(117),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45_RETO\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_5_RNITMIUR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(118),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46_RETO\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_3_RNI9LB2S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(119),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47_RETO\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46_RETO\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_2_RNIKJ46S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(120),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48_RETO\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47_RETO\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNO_121_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110000111100")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(121),
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48_RETO\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(10),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(10));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(9));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(8));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(7));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(6));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(5));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(4));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(3));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(2));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\);
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(10),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN13_EXP\(7),
datad => \GRFPU0.GRFPU_X0.UN3_EXP\(10));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(9),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN13_EXP\(7),
datad => \GRFPU0.GRFPU_X0.UN3_EXP\(9));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(8),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN13_EXP\(7),
datad => \GRFPU0.GRFPU_X0.UN3_EXP\(8));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(7),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN13_EXP\(7),
datad => \GRFPU0.GRFPU_X0.UN3_EXP\(7));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(6),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN3_EXP\(6),
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(6));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(5),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN3_EXP\(5),
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(5));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(4),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datac => \GRFPU0.GRFPU_X0.UN3_EXP\(4),
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(4));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(3),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.UN3_EXP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(3));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(2),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.UN3_EXP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(2));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(1),
dataa => \GRFPC0.V.STDATA_14\(6),
datab => \GRFPU0.GRFPU_X0.UN3_EXP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datad => \GRFPU0.GRFPU_X0.UN13_EXP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\(7),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(10));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(9),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\(7),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(9));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(8),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\(7),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(8));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\(7),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(7));
\GRFPC0_R_FSR_AEXC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(4),
dataa => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(4),
datab => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(4),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\);
\GRFPC0_R_FSR_AEXC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(3),
dataa => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(3),
datab => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(3),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\);
\GRFPC0_R_FSR_AEXC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(2),
dataa => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(2),
datab => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(2),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\);
\GRFPC0_R_FSR_AEXC_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(1),
dataa => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(1),
datab => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\);
\GRFPC0_R_FSR_AEXC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(0),
dataa => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(0),
datab => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\);
\GRFPC0_DIV_PC_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114766,
dataa => \GRFPC0.WR2.CTRL.PC\(31),
datab => \GRFPC0.DIV.PC\(31),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114765,
dataa => \GRFPC0.WR2.CTRL.PC\(30),
datab => \GRFPC0.DIV.PC\(30),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114764,
dataa => \GRFPC0.WR2.CTRL.PC\(29),
datab => \GRFPC0.DIV.PC\(29),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114763,
dataa => \GRFPC0.WR2.CTRL.PC\(28),
datab => \GRFPC0.DIV.PC\(28),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114762,
dataa => \GRFPC0.WR2.CTRL.PC\(27),
datab => \GRFPC0.DIV.PC\(27),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114761,
dataa => \GRFPC0.WR2.CTRL.PC\(26),
datab => \GRFPC0.DIV.PC\(26),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114760,
dataa => \GRFPC0.WR2.CTRL.PC\(25),
datab => \GRFPC0.DIV.PC\(25),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114759,
dataa => \GRFPC0.WR2.CTRL.PC\(24),
datab => \GRFPC0.DIV.PC\(24),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114758,
dataa => \GRFPC0.WR2.CTRL.PC\(23),
datab => \GRFPC0.DIV.PC\(23),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114757,
dataa => \GRFPC0.WR2.CTRL.PC\(22),
datab => \GRFPC0.DIV.PC\(22),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114756,
dataa => \GRFPC0.WR2.CTRL.PC\(21),
datab => \GRFPC0.DIV.PC\(21),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114755,
dataa => \GRFPC0.WR2.CTRL.PC\(20),
datab => \GRFPC0.DIV.PC\(20),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114754,
dataa => \GRFPC0.WR2.CTRL.PC\(19),
datab => \GRFPC0.DIV.PC\(19),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114753,
dataa => \GRFPC0.WR2.CTRL.PC\(18),
datab => \GRFPC0.DIV.PC\(18),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114752,
dataa => \GRFPC0.WR2.CTRL.PC\(17),
datab => \GRFPC0.DIV.PC\(17),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114751,
dataa => \GRFPC0.WR2.CTRL.PC\(16),
datab => \GRFPC0.DIV.PC\(16),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114750,
dataa => \GRFPC0.WR2.CTRL.PC\(15),
datab => \GRFPC0.DIV.PC\(15),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114749,
dataa => \GRFPC0.WR2.CTRL.PC\(14),
datab => \GRFPC0.DIV.PC\(14),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114748,
dataa => \GRFPC0.WR2.CTRL.PC\(13),
datab => \GRFPC0.DIV.PC\(13),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114747,
dataa => \GRFPC0.WR2.CTRL.PC\(12),
datab => \GRFPC0.DIV.PC\(12),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114746,
dataa => \GRFPC0.WR2.CTRL.PC\(11),
datab => \GRFPC0.DIV.PC\(11),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114745,
dataa => \GRFPC0.WR2.CTRL.PC\(10),
datab => \GRFPC0.DIV.PC\(10),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114744,
dataa => \GRFPC0.WR2.CTRL.PC\(9),
datab => \GRFPC0.DIV.PC\(9),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114743,
dataa => \GRFPC0.WR2.CTRL.PC\(8),
datab => \GRFPC0.DIV.PC\(8),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114742,
dataa => \GRFPC0.WR2.CTRL.PC\(7),
datab => \GRFPC0.DIV.PC\(7),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114741,
dataa => \GRFPC0.WR2.CTRL.PC\(6),
datab => \GRFPC0.DIV.PC\(6),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114740,
dataa => \GRFPC0.WR2.CTRL.PC\(5),
datab => \GRFPC0.DIV.PC\(5),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114739,
dataa => \GRFPC0.WR2.CTRL.PC\(4),
datab => \GRFPC0.DIV.PC\(4),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114738,
dataa => \GRFPC0.WR2.CTRL.PC\(3),
datab => \GRFPC0.DIV.PC\(3),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_PC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114737,
dataa => \GRFPC0.WR2.CTRL.PC\(2),
datab => \GRFPC0.DIV.PC\(2),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114736,
dataa => \GRFPC0.WR2.CTRL.INST\(31),
datab => \GRFPC0.DIV.INST\(31),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114735,
dataa => \GRFPC0.WR2.CTRL.INST\(30),
datab => \GRFPC0.DIV.INST\(30),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114734,
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.DIV.INST\(29),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114733,
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.DIV.INST\(28),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114732,
dataa => \GRFPC0.DIV.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114731,
dataa => \GRFPC0.DIV.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114730,
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.DIV.INST\(25),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114729,
dataa => \GRFPC0.WR2.CTRL.INST\(24),
datab => \GRFPC0.DIV.INST\(24),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114728,
dataa => \GRFPC0.WR2.CTRL.INST\(23),
datab => \GRFPC0.DIV.INST\(23),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114727,
dataa => \GRFPC0.WR2.CTRL.INST\(22),
datab => \GRFPC0.DIV.INST\(22),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114726,
dataa => \GRFPC0.WR2.CTRL.INST\(21),
datab => \GRFPC0.DIV.INST\(21),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114725,
dataa => \GRFPC0.WR2.CTRL.INST\(20),
datab => \GRFPC0.DIV.INST\(20),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114724,
dataa => \GRFPC0.WR2.CTRL.INST\(19),
datab => \GRFPC0.DIV.INST\(19),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114723,
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114722,
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114721,
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114720,
dataa => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114719,
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.DIV.INST\(14),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114718,
dataa => \GRFPC0.WR2.CTRL.INST\(13),
datab => \GRFPC0.DIV.INST\(13),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114717,
dataa => \GRFPC0.WR2.CTRL.INST\(12),
datab => \GRFPC0.DIV.INST\(12),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114716,
dataa => \GRFPC0.WR2.CTRL.INST\(11),
datab => \GRFPC0.DIV.INST\(11),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114715,
dataa => \GRFPC0.WR2.CTRL.INST\(10),
datab => \GRFPC0.DIV.INST\(10),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114714,
dataa => \GRFPC0.WR2.CTRL.INST\(9),
datab => \GRFPC0.DIV.INST\(9),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114713,
dataa => \GRFPC0.WR2.CTRL.INST\(8),
datab => \GRFPC0.DIV.INST\(8),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114712,
dataa => \GRFPC0.WR2.CTRL.INST\(7),
datab => \GRFPC0.DIV.INST\(7),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114711,
dataa => \GRFPC0.WR2.CTRL.INST\(6),
datab => \GRFPC0.DIV.INST\(6),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114710,
dataa => \GRFPC0.WR2.CTRL.INST\(5),
datab => \GRFPC0.DIV.INST\(5),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114709,
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114708,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114707,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114706,
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_DIV_INST_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114705,
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.DIV.INST\(0),
datac => \GRFPC0.DIV.INST_0_0_0__G2_I\);
\GRFPC0_WR2_CTRL_PC_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114704,
dataa => \GRFPC0.WR.CTRL.PC\(31),
datab => \GRFPC0.WR2.CTRL.PC\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114703,
dataa => \GRFPC0.WR.CTRL.PC\(30),
datab => \GRFPC0.WR2.CTRL.PC\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114702,
dataa => \GRFPC0.WR.CTRL.PC\(29),
datab => \GRFPC0.WR2.CTRL.PC\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114701,
dataa => \GRFPC0.WR.CTRL.PC\(28),
datab => \GRFPC0.WR2.CTRL.PC\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114700,
dataa => \GRFPC0.WR.CTRL.PC\(27),
datab => \GRFPC0.WR2.CTRL.PC\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114699,
dataa => \GRFPC0.WR.CTRL.PC\(26),
datab => \GRFPC0.WR2.CTRL.PC\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114698,
dataa => \GRFPC0.WR.CTRL.PC\(25),
datab => \GRFPC0.WR2.CTRL.PC\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114697,
dataa => \GRFPC0.WR.CTRL.PC\(24),
datab => \GRFPC0.WR2.CTRL.PC\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114696,
dataa => \GRFPC0.WR.CTRL.PC\(23),
datab => \GRFPC0.WR2.CTRL.PC\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114695,
dataa => \GRFPC0.WR.CTRL.PC\(22),
datab => \GRFPC0.WR2.CTRL.PC\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114694,
dataa => \GRFPC0.WR.CTRL.PC\(21),
datab => \GRFPC0.WR2.CTRL.PC\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114693,
dataa => \GRFPC0.WR.CTRL.PC\(20),
datab => \GRFPC0.WR2.CTRL.PC\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114692,
dataa => \GRFPC0.WR.CTRL.PC\(19),
datab => \GRFPC0.WR2.CTRL.PC\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114691,
dataa => \GRFPC0.WR.CTRL.PC\(18),
datab => \GRFPC0.WR2.CTRL.PC\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114690,
dataa => \GRFPC0.WR.CTRL.PC\(17),
datab => \GRFPC0.WR2.CTRL.PC\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114689,
dataa => \GRFPC0.WR.CTRL.PC\(16),
datab => \GRFPC0.WR2.CTRL.PC\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114688,
dataa => \GRFPC0.WR.CTRL.PC\(15),
datab => \GRFPC0.WR2.CTRL.PC\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114687,
dataa => \GRFPC0.WR.CTRL.PC\(14),
datab => \GRFPC0.WR2.CTRL.PC\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114686,
dataa => \GRFPC0.WR.CTRL.PC\(13),
datab => \GRFPC0.WR2.CTRL.PC\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114685,
dataa => \GRFPC0.WR.CTRL.PC\(12),
datab => \GRFPC0.WR2.CTRL.PC\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114684,
dataa => \GRFPC0.WR.CTRL.PC\(11),
datab => \GRFPC0.WR2.CTRL.PC\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114683,
dataa => \GRFPC0.WR.CTRL.PC\(10),
datab => \GRFPC0.WR2.CTRL.PC\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114682,
dataa => \GRFPC0.WR.CTRL.PC\(9),
datab => \GRFPC0.WR2.CTRL.PC\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114681,
dataa => \GRFPC0.WR.CTRL.PC\(8),
datab => \GRFPC0.WR2.CTRL.PC\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114680,
dataa => \GRFPC0.WR.CTRL.PC\(7),
datab => \GRFPC0.WR2.CTRL.PC\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114679,
dataa => \GRFPC0.WR.CTRL.PC\(6),
datab => \GRFPC0.WR2.CTRL.PC\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP6\);
\GRFPC0_WR2_CTRL_PC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114678,
dataa => \GRFPC0.WR.CTRL.PC\(5),
datab => \GRFPC0.WR2.CTRL.PC\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_PC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114677,
dataa => \GRFPC0.WR.CTRL.PC\(4),
datab => \GRFPC0.WR2.CTRL.PC\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_PC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114676,
dataa => \GRFPC0.WR.CTRL.PC\(3),
datab => \GRFPC0.WR2.CTRL.PC\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_PC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114675,
dataa => \GRFPC0.WR.CTRL.PC\(2),
datab => \GRFPC0.WR2.CTRL.PC\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114674,
dataa => \GRFPC0.WR.CTRL.INST\(31),
datab => \GRFPC0.WR2.CTRL.INST\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114673,
dataa => \GRFPC0.WR.CTRL.INST\(30),
datab => \GRFPC0.WR2.CTRL.INST\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114672,
dataa => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114671,
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114670,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114669,
dataa => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114668,
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.INST\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114667,
dataa => \GRFPC0.WR.CTRL.INST\(24),
datab => \GRFPC0.WR2.CTRL.INST\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114666,
dataa => \GRFPC0.WR.CTRL.INST\(23),
datab => \GRFPC0.WR2.CTRL.INST\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114665,
dataa => \GRFPC0.WR.CTRL.INST\(22),
datab => \GRFPC0.WR2.CTRL.INST\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114664,
dataa => \GRFPC0.WR.CTRL.INST\(21),
datab => \GRFPC0.WR2.CTRL.INST\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114663,
dataa => \GRFPC0.WR.CTRL.INST\(20),
datab => \GRFPC0.WR2.CTRL.INST\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114662,
dataa => \GRFPC0.WR.CTRL.INST\(19),
datab => \GRFPC0.WR2.CTRL.INST\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114661,
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114660,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114659,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114658,
dataa => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114657,
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.INST\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114656,
dataa => \GRFPC0.WR.CTRL.INST\(13),
datab => \GRFPC0.WR2.CTRL.INST\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114655,
dataa => \GRFPC0.WR.CTRL.INST\(12),
datab => \GRFPC0.WR2.CTRL.INST\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114654,
dataa => \GRFPC0.WR.CTRL.INST\(11),
datab => \GRFPC0.WR2.CTRL.INST\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114653,
dataa => \GRFPC0.WR.CTRL.INST\(10),
datab => \GRFPC0.WR2.CTRL.INST\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP5\);
\GRFPC0_WR2_CTRL_INST_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114652,
dataa => \GRFPC0.WR.CTRL.INST\(9),
datab => \GRFPC0.WR2.CTRL.INST\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114651,
dataa => \GRFPC0.WR.CTRL.INST\(8),
datab => \GRFPC0.WR2.CTRL.INST\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114650,
dataa => \GRFPC0.WR.CTRL.INST\(7),
datab => \GRFPC0.WR2.CTRL.INST\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114649,
dataa => \GRFPC0.WR.CTRL.INST\(6),
datab => \GRFPC0.WR2.CTRL.INST\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114648,
dataa => \GRFPC0.WR.CTRL.INST\(5),
datab => \GRFPC0.WR2.CTRL.INST\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114647,
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114646,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114645,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114644,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR2_CTRL_INST_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114643,
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.INST\(0),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114642,
dataa => \GRFPC0.MEM.CTRL.PC\(31),
datab => \GRFPC0.WR.CTRL.PC\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114641,
dataa => \GRFPC0.MEM.CTRL.PC\(30),
datab => \GRFPC0.WR.CTRL.PC\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114640,
dataa => \GRFPC0.MEM.CTRL.PC\(29),
datab => \GRFPC0.WR.CTRL.PC\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114639,
dataa => \GRFPC0.MEM.CTRL.PC\(28),
datab => \GRFPC0.WR.CTRL.PC\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114638,
dataa => \GRFPC0.MEM.CTRL.PC\(27),
datab => \GRFPC0.WR.CTRL.PC\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114637,
dataa => \GRFPC0.MEM.CTRL.PC\(26),
datab => \GRFPC0.WR.CTRL.PC\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114636,
dataa => \GRFPC0.MEM.CTRL.PC\(25),
datab => \GRFPC0.WR.CTRL.PC\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114635,
dataa => \GRFPC0.MEM.CTRL.PC\(24),
datab => \GRFPC0.WR.CTRL.PC\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114634,
dataa => \GRFPC0.MEM.CTRL.PC\(23),
datab => \GRFPC0.WR.CTRL.PC\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114633,
dataa => \GRFPC0.MEM.CTRL.PC\(22),
datab => \GRFPC0.WR.CTRL.PC\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114632,
dataa => \GRFPC0.MEM.CTRL.PC\(21),
datab => \GRFPC0.WR.CTRL.PC\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114631,
dataa => \GRFPC0.MEM.CTRL.PC\(20),
datab => \GRFPC0.WR.CTRL.PC\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114630,
dataa => \GRFPC0.MEM.CTRL.PC\(19),
datab => \GRFPC0.WR.CTRL.PC\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114629,
dataa => \GRFPC0.MEM.CTRL.PC\(18),
datab => \GRFPC0.WR.CTRL.PC\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114628,
dataa => \GRFPC0.MEM.CTRL.PC\(17),
datab => \GRFPC0.WR.CTRL.PC\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114627,
dataa => \GRFPC0.MEM.CTRL.PC\(16),
datab => \GRFPC0.WR.CTRL.PC\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP4\);
\GRFPC0_WR_CTRL_PC_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114626,
dataa => \GRFPC0.MEM.CTRL.PC\(15),
datab => \GRFPC0.WR.CTRL.PC\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114625,
dataa => \GRFPC0.MEM.CTRL.PC\(14),
datab => \GRFPC0.WR.CTRL.PC\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114624,
dataa => \GRFPC0.MEM.CTRL.PC\(13),
datab => \GRFPC0.WR.CTRL.PC\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114623,
dataa => \GRFPC0.MEM.CTRL.PC\(12),
datab => \GRFPC0.WR.CTRL.PC\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114622,
dataa => \GRFPC0.MEM.CTRL.PC\(11),
datab => \GRFPC0.WR.CTRL.PC\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114621,
dataa => \GRFPC0.MEM.CTRL.PC\(10),
datab => \GRFPC0.WR.CTRL.PC\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114620,
dataa => \GRFPC0.MEM.CTRL.PC\(9),
datab => \GRFPC0.WR.CTRL.PC\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114619,
dataa => \GRFPC0.MEM.CTRL.PC\(8),
datab => \GRFPC0.WR.CTRL.PC\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114618,
dataa => \GRFPC0.MEM.CTRL.PC\(7),
datab => \GRFPC0.WR.CTRL.PC\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114617,
dataa => \GRFPC0.MEM.CTRL.PC\(6),
datab => \GRFPC0.WR.CTRL.PC\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114616,
dataa => \GRFPC0.MEM.CTRL.PC\(5),
datab => \GRFPC0.WR.CTRL.PC\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114615,
dataa => \GRFPC0.MEM.CTRL.PC\(4),
datab => \GRFPC0.WR.CTRL.PC\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114614,
dataa => \GRFPC0.MEM.CTRL.PC\(3),
datab => \GRFPC0.WR.CTRL.PC\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_PC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114613,
dataa => \GRFPC0.MEM.CTRL.PC\(2),
datab => \GRFPC0.WR.CTRL.PC\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114612,
dataa => \GRFPC0.MEM.CTRL.INST\(31),
datab => \GRFPC0.WR.CTRL.INST\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114611,
dataa => \GRFPC0.MEM.CTRL.INST\(30),
datab => \GRFPC0.WR.CTRL.INST\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114610,
dataa => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114609,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114608,
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114607,
dataa => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114606,
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.INST\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114605,
dataa => \GRFPC0.MEM.CTRL.INST\(24),
datab => \GRFPC0.WR.CTRL.INST\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114604,
dataa => \GRFPC0.MEM.CTRL.INST\(23),
datab => \GRFPC0.WR.CTRL.INST\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114603,
dataa => \GRFPC0.MEM.CTRL.INST\(22),
datab => \GRFPC0.WR.CTRL.INST\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114602,
dataa => \GRFPC0.MEM.CTRL.INST\(21),
datab => \GRFPC0.WR.CTRL.INST\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114601,
dataa => \GRFPC0.MEM.CTRL.INST\(20),
datab => \GRFPC0.WR.CTRL.INST\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114600,
dataa => \GRFPC0.MEM.CTRL.INST\(19),
datab => \GRFPC0.WR.CTRL.INST\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP3\);
\GRFPC0_WR_CTRL_INST_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114599,
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114598,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114597,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114596,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114595,
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.INST\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114594,
dataa => \GRFPC0.MEM.CTRL.INST\(13),
datab => \GRFPC0.WR.CTRL.INST\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114593,
dataa => \GRFPC0.MEM.CTRL.INST\(12),
datab => \GRFPC0.WR.CTRL.INST\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114592,
dataa => \GRFPC0.MEM.CTRL.INST\(11),
datab => \GRFPC0.WR.CTRL.INST\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114591,
dataa => \GRFPC0.MEM.CTRL.INST\(10),
datab => \GRFPC0.WR.CTRL.INST\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114590,
dataa => \GRFPC0.MEM.CTRL.INST\(9),
datab => \GRFPC0.WR.CTRL.INST\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114589,
dataa => \GRFPC0.MEM.CTRL.INST\(8),
datab => \GRFPC0.WR.CTRL.INST\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114588,
dataa => \GRFPC0.MEM.CTRL.INST\(7),
datab => \GRFPC0.WR.CTRL.INST\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114587,
dataa => \GRFPC0.MEM.CTRL.INST\(6),
datab => \GRFPC0.WR.CTRL.INST\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114586,
dataa => \GRFPC0.MEM.CTRL.INST\(5),
datab => \GRFPC0.WR.CTRL.INST\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114585,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114584,
dataa => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114583,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114582,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_WR_CTRL_INST_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114581,
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.INST\(0),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114580,
dataa => \GRFPC0.EX.CTRL.PC\(31),
datab => \GRFPC0.MEM.CTRL.PC\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114579,
dataa => \GRFPC0.EX.CTRL.PC\(30),
datab => \GRFPC0.MEM.CTRL.PC\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114578,
dataa => \GRFPC0.EX.CTRL.PC\(29),
datab => \GRFPC0.MEM.CTRL.PC\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114577,
dataa => \GRFPC0.EX.CTRL.PC\(28),
datab => \GRFPC0.MEM.CTRL.PC\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114576,
dataa => \GRFPC0.EX.CTRL.PC\(27),
datab => \GRFPC0.MEM.CTRL.PC\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114575,
dataa => \GRFPC0.EX.CTRL.PC\(26),
datab => \GRFPC0.MEM.CTRL.PC\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114574,
dataa => \GRFPC0.EX.CTRL.PC\(25),
datab => \GRFPC0.MEM.CTRL.PC\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114573,
dataa => \GRFPC0.EX.CTRL.PC\(24),
datab => \GRFPC0.MEM.CTRL.PC\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP2\);
\GRFPC0_MEM_CTRL_PC_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114572,
dataa => \GRFPC0.EX.CTRL.PC\(23),
datab => \GRFPC0.MEM.CTRL.PC\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114571,
dataa => \GRFPC0.EX.CTRL.PC\(22),
datab => \GRFPC0.MEM.CTRL.PC\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114570,
dataa => \GRFPC0.EX.CTRL.PC\(21),
datab => \GRFPC0.MEM.CTRL.PC\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114569,
dataa => \GRFPC0.EX.CTRL.PC\(20),
datab => \GRFPC0.MEM.CTRL.PC\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114568,
dataa => \GRFPC0.EX.CTRL.PC\(19),
datab => \GRFPC0.MEM.CTRL.PC\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114567,
dataa => \GRFPC0.EX.CTRL.PC\(18),
datab => \GRFPC0.MEM.CTRL.PC\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114566,
dataa => \GRFPC0.EX.CTRL.PC\(17),
datab => \GRFPC0.MEM.CTRL.PC\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114565,
dataa => \GRFPC0.EX.CTRL.PC\(16),
datab => \GRFPC0.MEM.CTRL.PC\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114564,
dataa => \GRFPC0.EX.CTRL.PC\(15),
datab => \GRFPC0.MEM.CTRL.PC\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114563,
dataa => \GRFPC0.EX.CTRL.PC\(14),
datab => \GRFPC0.MEM.CTRL.PC\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114562,
dataa => \GRFPC0.EX.CTRL.PC\(13),
datab => \GRFPC0.MEM.CTRL.PC\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114561,
dataa => \GRFPC0.EX.CTRL.PC\(12),
datab => \GRFPC0.MEM.CTRL.PC\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114560,
dataa => \GRFPC0.EX.CTRL.PC\(11),
datab => \GRFPC0.MEM.CTRL.PC\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114559,
dataa => \GRFPC0.EX.CTRL.PC\(10),
datab => \GRFPC0.MEM.CTRL.PC\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114558,
dataa => \GRFPC0.EX.CTRL.PC\(9),
datab => \GRFPC0.MEM.CTRL.PC\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114557,
dataa => \GRFPC0.EX.CTRL.PC\(8),
datab => \GRFPC0.MEM.CTRL.PC\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114556,
dataa => \GRFPC0.EX.CTRL.PC\(7),
datab => \GRFPC0.MEM.CTRL.PC\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114555,
dataa => \GRFPC0.EX.CTRL.PC\(6),
datab => \GRFPC0.MEM.CTRL.PC\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114554,
dataa => \GRFPC0.EX.CTRL.PC\(5),
datab => \GRFPC0.MEM.CTRL.PC\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114553,
dataa => \GRFPC0.EX.CTRL.PC\(4),
datab => \GRFPC0.MEM.CTRL.PC\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114552,
dataa => \GRFPC0.EX.CTRL.PC\(3),
datab => \GRFPC0.MEM.CTRL.PC\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_PC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114551,
dataa => \GRFPC0.EX.CTRL.PC\(2),
datab => \GRFPC0.MEM.CTRL.PC\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114550,
dataa => \GRFPC0.EX.CTRL.INST\(31),
datab => \GRFPC0.MEM.CTRL.INST\(31),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114549,
dataa => \GRFPC0.EX.CTRL.INST\(30),
datab => \GRFPC0.MEM.CTRL.INST\(30),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114548,
dataa => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114547,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114546,
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I_REP1\);
\GRFPC0_MEM_CTRL_INST_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114545,
dataa => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114544,
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.INST\(25),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114543,
dataa => \GRFPC0.EX.CTRL.INST\(24),
datab => \GRFPC0.MEM.CTRL.INST\(24),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114542,
dataa => \GRFPC0.EX.CTRL.INST\(23),
datab => \GRFPC0.MEM.CTRL.INST\(23),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114541,
dataa => \GRFPC0.EX.CTRL.INST\(22),
datab => \GRFPC0.MEM.CTRL.INST\(22),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114540,
dataa => \GRFPC0.EX.CTRL.INST\(21),
datab => \GRFPC0.MEM.CTRL.INST\(21),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114539,
dataa => \GRFPC0.EX.CTRL.INST\(20),
datab => \GRFPC0.MEM.CTRL.INST\(20),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114538,
dataa => \GRFPC0.EX.CTRL.INST\(19),
datab => \GRFPC0.MEM.CTRL.INST\(19),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114537,
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114536,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114535,
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114534,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114533,
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.INST\(14),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114532,
dataa => \GRFPC0.EX.CTRL.INST\(13),
datab => \GRFPC0.MEM.CTRL.INST\(13),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114531,
dataa => \GRFPC0.EX.CTRL.INST\(12),
datab => \GRFPC0.MEM.CTRL.INST\(12),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114530,
dataa => \GRFPC0.EX.CTRL.INST\(11),
datab => \GRFPC0.MEM.CTRL.INST\(11),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114529,
dataa => \GRFPC0.EX.CTRL.INST\(10),
datab => \GRFPC0.MEM.CTRL.INST\(10),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114528,
dataa => \GRFPC0.EX.CTRL.INST\(9),
datab => \GRFPC0.MEM.CTRL.INST\(9),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114527,
dataa => \GRFPC0.EX.CTRL.INST\(8),
datab => \GRFPC0.MEM.CTRL.INST\(8),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114526,
dataa => \GRFPC0.EX.CTRL.INST\(7),
datab => \GRFPC0.MEM.CTRL.INST\(7),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114525,
dataa => \GRFPC0.EX.CTRL.INST\(6),
datab => \GRFPC0.MEM.CTRL.INST\(6),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114524,
dataa => \GRFPC0.EX.CTRL.INST\(5),
datab => \GRFPC0.MEM.CTRL.INST\(5),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114523,
dataa => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114522,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114521,
dataa => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114520,
dataa => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_MEM_CTRL_INST_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => N_114519,
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.INST\(0),
datac => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\);
\GRFPC0_R_FSR_TEM_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_458,
datac => \GRFPC0.R.FSR.TEM_0_0_4__G2\);
\GRFPC0_R_FSR_TEM_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_457,
datac => \GRFPC0.R.FSR.TEM_0_0_3__G2\);
\GRFPC0_R_FSR_TEM_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_456,
datac => \GRFPC0.R.FSR.TEM_0_0_2__G2\);
\GRFPC0_R_FSR_TEM_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_455,
datac => \GRFPC0.R.FSR.TEM_0_0_1__G2\);
\GRFPC0_R_FSR_TEM_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_454,
datac => \GRFPC0.R.FSR.TEM_0_0_0__G2\);
\GRFPC0_R_FSR_RD_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_1__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_462,
datac => \GRFPC0.R.FSR.RD_0_0_1__G2\);
\GRFPC0_R_FSR_RD_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_0__G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_461,
datac => \GRFPC0.R.FSR.RD_0_0_0__G2\);
GRFPC0_R_FSR_NONSTD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
dataa => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datab => N_453,
datac => \GRFPC0.R.FSR.NONSTD_0_0_G2\);
GRFPC0_DIV_PEND_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114518,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_X\,
datac => \GRFPC0.DIV.PEND_1_0_G0_I_O4\);
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114517,
dataa => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G0_I_O4\);
GRFPU0_GRFPU_X0_ITER_FLUSH0_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => N_114516,
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G1\,
datac => \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G0_E_I\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.COMB.UINT17\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(20));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD10\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD9\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD8\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD7\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD6\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD5\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD4\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M4\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M4\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datab => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M4\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(1),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(2),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(3),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(4),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(5),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(6),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(7),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(8),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(9),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_1__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(10),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
GRFPC0_FP_PIPELINE_FPUSTART_7_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
dataa => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_5\,
datad => \GRFPC0.FP_PIPELINE.FPUSTART_7_6\);
\GRFPC0_V_STDATA_14_REP2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.V.STDATA_14_REP2\(6),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_V_STDATA_14_REP1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.V.STDATA_14_REP1\(6),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_V_STDATA_14_REP0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.V.STDATA_14_REP0\(6),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_V_STDATA_14_REP1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14_REP1\(11),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPU0_GRFPU_X0_L4_4_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP1\(0),
dataa => \GRFPU0.GRFPU_X0.L3_1\(0),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(0),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
dataa => \GRFPU0.GRFPU_X0.L3_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
dataa => \GRFPU0.GRFPU_X0.L3_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
dataa => \GRFPU0.GRFPU_X0.L3_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
dataa => \GRFPU0.GRFPU_X0.L3_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
dataa => \GRFPU0.GRFPU_X0.L3_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_I_O2_REP1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_DIV_0_A2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.RREG.RESV\);
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_DIV_0_A3_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\);
\GRFPC0_FP_PIPELINE_VFIFO_RD_3_I_O2_0_X2_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
dataa => \GRFPC0.FIFO.RD_REP2\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X_RNI1AT4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => G_2026_X_REP2,
dataa => N_38,
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X_RNI1AT4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => G_2026_X_REP1,
dataa => N_38,
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\);
GRFPU0_GRFPU_X0_VITER_R_I_0_SQMUXA_1_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_ITER_NORM_RNIS0F99_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_ITER_NORM_RNIS0F99_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIVAC21_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_O3_REP1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI14VL_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_DIV_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_RFA2_RS2SEL_REP2_RNI8R532_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.OP2_SN_M8_REP3\,
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(1),
datab => \GRFPC0.RFA2.RS2SEL\(3),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(7));
\GRFPC0_RFA2_RS2SEL_REP2_RNI8R532_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.OP2_SN_M8_REP2\,
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(1),
datab => \GRFPC0.RFA2.RS2SEL\(3),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(7));
\GRFPC0_RFA2_RS2SEL_REP2_RNI8R532_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.OP2_SN_M8_REP1\,
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(1),
datab => \GRFPC0.RFA2.RS2SEL\(3),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(7));
\GRFPC0_OP1_I_A2_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.OP1_I_A2_REP1\(0),
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.OP1_1_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_RES_1_6_0_A2_1_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A2_2_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
GRFPC0_VWR2_RREG_RES_2_SQMUXA_1_I_O2_X_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\,
dataa => N_38,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\);
GRFPC0_VWR2_RREG_RES_2_SQMUXA_1_I_O2_X_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\,
dataa => N_38,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_REP1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29),
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPC0.V.STDATA_14_REP1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.UN1_SGNF_1_SQMUXA_5\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_A2_RNIEJEN4_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0_RNIK5VD1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0_RNIK5VD1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0_RNIK5VD1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0_RNIK5VD1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2_RNI3QN41_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2_RNI3QN41_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2_RNI3QN41_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_1_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101001100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_2_A2_1\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_TZ\,
datac => \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_2\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP_RNIE7023_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\);
GRFPC0_OP1_1_SQMUXA_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.OP1_1_SQMUXA_REP1\,
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.RS1_3_X\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_O2_REP2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100110001001")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_O2_REP1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100110001001")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
GRFPC0_FP_PIPELINE_UN29_WREN_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_4\,
datab => \GRFPC0.UN28_WREN_M8_I_4\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.UN28_WREN_M8_I_A5\);
GRFPC0_FP_PIPELINE_UN29_WREN_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_4\,
datab => \GRFPC0.UN28_WREN_M8_I_4\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.UN28_WREN_M8_I_A5\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_22_REP1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
dataa => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
GRFPC0_FP_PIPELINE_VRFA_LD_1_I_O4_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.UN30_OP\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_2_RNIASFP1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_O2\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_2_RNI2CHU2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_1_1_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_4\,
datad => \GRFPC0.FP_PIPELINE.VMEM.RREG.RESV_6_IV_I_I_O2_0_O2\);
GRFPC0_FP_PIPELINE_0_1_FIFO_INST_V_TMP_IV_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
\GRFPC0_FIFO_INST_0_RNIPV541_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPC0.OP2_SN_M4_REP2\,
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_1\(0),
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_FIFO_INST_0_RNIPV541_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPC0.OP2_SN_M4_REP1\,
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_1\(0),
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.FIFO.RD_REP3\(0));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\);
GRFPU0_GRFPU_X0_COMB_GETINF_UN9_MODE_0_O2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_4\,
datad => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_X2\);
GRFPU0_GRFPU_X0_COMB_VST4_REG36_RNI8ANH1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111111111")
port map (
combout => \GRFPU0.GRFPU_X0.G_51_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datad => \GRFPU0.GRFPU_X0.G_51_A\);
\GRFPU0_GRFPU_X0_REST_2_RNIAHAH1_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_REST_2_RNIAHAH1_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
GRFPU0_GRFPU_X0_COMB_VST2_REG36_0_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_TZ_TZ\,
datab => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_REST_2_RNIU3EH_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.REST_2\(5));
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA_I_O2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111101")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_REP3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_REP4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_REP3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\);
\GRFPU0_GRFPU_X0_COMB_RMND_7_I_M3_RNIRF9N4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.COMB.RMND_7_I_M3\(1),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ\,
datad => \GRFPU0.GRFPU_X0.G_16_0_A3_1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_REP3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
dataa => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\,
datad => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\,
dataa => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\,
datad => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
dataa => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\,
datad => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_RNDOP_29_IV_0_REP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111100000000011")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.MULO.MRES\(67));
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP_I_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\);
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP_I_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_1_SQMUXA_I_O2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011101010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_0_RNIPHUG4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_0_RNIPHUG4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_REP1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\);
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\);
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\);
GRFPU0_GRFPU_X0_VITER_ND_I_0_SQMUXA_7_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA_1\);
GRFPU0_GRFPU_X0_VITER_R_I_1_SQMUXA_3_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\);
GRFPU0_GRFPU_X0_COMB_RNDOP19_0_O3_RNIF1VA1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI5IDT_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\);
GRFPU0_GRFPU_X0_UN1_VALLOW_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI03G53_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_3\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_1\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNIS9HF1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.V_2_M_0\,
datab => \GRFPU0.GRFPU_X0.N_4415_M\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNIS9HF1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.V_2_M_0\,
datab => \GRFPU0.GRFPU_X0.N_4415_M\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP2_I\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X_REP1_I\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\);
GRFPC0_VMEM_RREG_RESV_1_SQMUXA_X_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
GRFPC0_VMEM_RREG_RESV_1_SQMUXA_X_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP1_I\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\,
dataa => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_REP0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
dataa => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\);
GRFPC0_FP_PIPELINE_UN68_HOLDN_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
dataa => \GRFPC0.WR2.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.UN68_HOLDN_A\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.UN28_WREN_M8_I_A5_2\);
GRFPC0_FP_PIPELINE_VDIV_VALID2_REP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID2_4\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_1\);
GRFPC0_FP_PIPELINE_VDIV_VALID2_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID2_4\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_1\);
GRFPC0_OP1_0_SQMUXA_REP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.OP1_0_SQMUXA_REP1\,
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.RS1_3_X\(0));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_RNI6G9Q_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.G_53_REP1\,
dataa => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_RNI6G9Q: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.G_53_REP0\,
dataa => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\);
GRFPU0_GRFPU_X0_UN223_BCO_LSB_RNIRJ9T5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_REP1\(5),
dataa => \GRFPU0.GRFPU_X0.L3_2\(5),
datab => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPU0_GRFPU_X0_L4_4_REP3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_2\(3),
datad => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_2\(3),
datad => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L4_4_REP1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_2\(3),
datad => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_2_X\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_O2_3_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_3_X\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_O2_0_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_0_0_X\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I_X2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(5),
datab => \GRFPC0.RFA2.FID\(5),
cin => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.N_5\);
GRFPU0_GRFPU_X0_RDY_F0_I_X2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.RDY_F0_I_X2\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(5),
datab => \GRFPC0.RFA2.FID\(5),
cin => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.N_5\);
GRFPU0_GRFPU_X0_COMB_VITER_LOB2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.N_6\);
GRFPU0_GRFPU_X0_COMB_UN11_FLUSH: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN11_FLUSH\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD5\,
datab => \GRFPC0.RFA2.FID\(5),
cin => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.N_5\);
GRFPU0_GRFPU_X0_COMB_UN59_RNDOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101010001010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
cout => N_114503,
dataa => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datab => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.N_6\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(62));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_S_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_S\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(59));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(3),
dataa => N_3,
datab => \GRFPC0.WR2.RREG.RES\(8),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(3),
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(0),
dataa => N_3,
datab => \GRFPC0.WR2.RREG.RES\(5),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(0),
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(1),
dataa => N_3,
datab => \GRFPC0.WR2.RREG.RES\(6),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(1),
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(4),
dataa => N_3,
datab => \GRFPC0.WR2.RREG.RES\(9),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(4),
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_3\(2),
dataa => N_3,
datab => \GRFPC0.WR2.RREG.RES\(7),
datac => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(2),
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\);
\GRFPC0_VFIFO_INST_1_4_X_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101100")
port map (
combout => \GRFPC0.VFIFO.INST_1_4_X\(18),
dataa => N_96,
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(3),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\);
\GRFPU0_GRFPU_X0_L3_0_7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(4),
dataa => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_0\,
datab => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_9\(4));
GRFPU0_GRFPU_X0_COMB_RNDBIT_4_RNI3HEL: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111000011110")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M_299\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL3_RNI413VC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001110")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G2\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2_A\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL2\,
datad => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\);
\GRFPC0_OP1_I_A2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101110011")
port map (
combout => \GRFPC0.OP1_I_A2\(32),
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.RS1_3_X\(0));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_8_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_1\,
datab => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datac => \GRFPU0.MULO.MRES_BUF\(121),
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_A\);
GRFPU0_GRFPU_X0_VITER_STATE_23_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.STATE_23_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datab => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
\GRFPU0_DIVROM0_DATA_1_MUX_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100101010")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_2\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_2\);
\GRFPC0_OP1_0_IV_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(59),
dataa => \GRFPC0.DIV.RESULT\(59),
datab => \GRFPC0.OP1_0_IV_3_S\(59),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.OP1_0_IV_1\(59));
\GRFPC0_OP1_0_IV_3_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(36),
dataa => \GRFPC0.DIV.RESULT\(36),
datab => \GRFPC0.OP1_0_IV_3_S\(36),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.OP1_0_IV_1\(36));
\GRFPC0_OP1_0_IV_3_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(49),
dataa => \GRFPC0.DIV.RESULT\(49),
datab => \GRFPC0.OP1_0_IV_3_S\(49),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.OP1_0_IV_1\(49));
\GRFPC0_OP1_0_IV_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(44),
dataa => \GRFPC0.EX.RREG.RES\(44),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_3_S\(44),
datad => \GRFPC0.OP1_0_IV_0\(44));
\GRFPC0_OP1_0_IV_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(57),
dataa => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_3_S\(57),
datad => \GRFPC0.OP1_0_IV_0\(57));
\GRFPC0_OP1_0_IV_3_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(47),
dataa => \GRFPC0.DIV.RESULT\(47),
datab => \GRFPC0.OP1_0_IV_1\(47),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.OP1_0_IV_3_S\(47));
GRFPC0_D_FSTLCK_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_9\,
dataa => \GRFPC0.WR.CTRL.STDFQ\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.D.FLDLCK_0_0_G1_0\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_9_S\);
\GRFPU0_GRFPU_X0_L1_3_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datac => \GRFPU0.GRFPU_X0.L1_3_2_S\(1),
datad => \GRFPU0.GRFPU_X0.UN103_BCO_LSB\);
GRFPC0_D_FSTLCK_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_8\,
dataa => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.MEM.CTRL.STDFQ\,
datac => \GRFPC0.D.FSTLCK_0_0_G1_0\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_8_S\);
GRFPC0_FP_PIPELINE_FCC_1_M2S2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2S2_X\,
dataa => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.CCWR\,
datac => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.MEM.RREG.RESV\);
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101110011")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.N_18471_I_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\(59));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.DIVROM0.DATA_1_MUX_15\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(53));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(50));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(49));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011001000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(48));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(47));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(46));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(45));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(43));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(42));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(41),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_XX_MM\(41));
RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_40_M8_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001110000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_M4_0\);
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(39));
\RETGRFPU0_GRFPU_X0_COMB_VITER_R_I_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(37));
\RETGRFPC0_DIV_RESULT_0_0_31__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_31__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_31__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_29__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_29__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_29__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_27__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_27__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(27),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_27__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_25__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_25__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(25),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_25__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_16__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_16__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(16),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_16__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_14__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_14__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(14),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_14__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_10__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_10__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(10),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_10__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_8__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_8__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(8),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_8__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_4__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_4__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(4),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_4__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_1__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_1__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(1),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_1__G3_0\);
\RETGRFPC0_DIV_RESULT_0_0_0__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \RETGRFPC0.DIV.RESULT_0_0_0__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_0__G3_0\);
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(51),
dataa => \GRFPC0.OP2\(51),
datab => \GRFPC0.OP2\(54),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(50),
dataa => \GRFPC0.OP2\(50),
datab => \GRFPC0.OP2\(53),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(49),
dataa => \GRFPC0.OP2\(49),
datab => \GRFPC0.OP2\(52),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(48),
dataa => \GRFPC0.OP2\(48),
datab => \GRFPC0.OP2\(51),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(47),
dataa => \GRFPC0.OP2\(50),
datab => \GRFPC0.OP2\(47),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(46),
dataa => \GRFPC0.OP2\(49),
datab => \GRFPC0.OP2\(46),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(45),
dataa => \GRFPC0.OP2_I_M2\(45),
datab => \GRFPC0.OP2\(48),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(44),
dataa => \GRFPC0.OP2\(47),
datab => \GRFPC0.OP2\(44),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPC0_OP2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(31),
dataa => \GRFPC0.OP2_6\(31),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(31));
\RETGRFPC0_OP2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(29),
dataa => \GRFPC0.OP2_6\(29),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(29));
\RETGRFPC0_OP2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(27),
dataa => \GRFPC0.OP2_6\(27),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(27));
\RETGRFPC0_OP2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(25),
dataa => \GRFPC0.OP2_6\(25),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(25));
\RETGRFPC0_OP2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(16),
dataa => \GRFPC0.OP2_6\(16),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(16));
\RETGRFPC0_OP2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(14),
dataa => \GRFPC0.OP2_6\(14),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(14));
\RETGRFPC0_OP2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(10),
dataa => \GRFPC0.OP2_6\(10),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(10));
\RETGRFPC0_OP2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(8),
dataa => \GRFPC0.OP2_6\(8),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(8));
\RETGRFPC0_OP2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(4),
dataa => \GRFPC0.OP2_6\(4),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(4));
\RETGRFPC0_OP2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(1),
dataa => \GRFPC0.OP2_6\(1),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(1));
\RETGRFPC0_OP2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \RETGRFPC0.OP2\(0),
dataa => \GRFPC0.OP2_6\(0),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(0));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(43),
dataa => \GRFPC0.OP2\(46),
datab => \GRFPC0.OP2\(43),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(42),
dataa => \GRFPC0.OP2\(42),
datab => \GRFPC0.OP2_I_M2\(45),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(41),
dataa => \GRFPC0.OP2\(44),
datab => \GRFPC0.OP2\(41),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(40),
dataa => \GRFPC0.OP2\(40),
datab => \GRFPC0.OP2\(43),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(39),
dataa => \GRFPC0.OP2\(42),
datab => \GRFPC0.OP2\(39),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(38),
dataa => \GRFPC0.OP2\(38),
datab => \GRFPC0.OP2\(41),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(37),
dataa => \GRFPC0.OP2\(37),
datab => \GRFPC0.OP2\(40),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(36),
dataa => \GRFPC0.OP2\(36),
datab => \GRFPC0.OP2\(39),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(35),
dataa => \GRFPC0.OP2\(38),
datab => \GRFPC0.OP2\(35),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(34),
dataa => \GRFPC0.OP2\(37),
datab => \GRFPC0.OP2\(34),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(33),
dataa => \GRFPC0.OP2\(33),
datab => \GRFPC0.OP2\(36),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(32),
dataa => \GRFPC0.OP2\(32),
datab => \GRFPC0.OP2\(35),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(31),
dataa => \GRFPC0.OP2\(31),
datab => \GRFPC0.OP2\(34),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(30),
dataa => \GRFPC0.OP2\(30),
datab => \GRFPC0.OP2\(33),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
\RETGRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(29),
dataa => \GRFPC0.OP2\(29),
datab => \GRFPC0.OP2\(32),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2_REP1\(29));
RETGRFPU0_GRFPU_X0_COMB_ITER_OF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.ITER_OF\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
RETGRFPU0_GRFPU_X0_COMB_VST4_ADDOF_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \RETGRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC\);
\RETGRFPC0_FP_PIPELINE_RS1_6_0_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(4),
dataa => N_107,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(18));
\RETGRFPC0_FP_PIPELINE_RS1_6_0_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(3),
dataa => N_106,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(17));
\RETGRFPC0_FP_PIPELINE_RS1_6_0_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(2),
dataa => N_105,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(16));
\RETGRFPC0_FP_PIPELINE_RS1_6_0_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(1),
dataa => N_104,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(15));
\GRFPU0_GRFPU_X0_L1_3_2_S_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_2_S\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT27_4_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4_S\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD2\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD3\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datad => \GRFPU0.GRFPU_X0.UN8_C_ADD7\);
\GRFPC0_OP1_0_IV_2_S_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(50),
dataa => \GRFPC0.DIV.RESULT\(50),
datab => \GRFPC0.MEM.RREG.RES\(50),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_2_S_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(62),
dataa => \GRFPC0.DIV.RESULT\(62),
datab => \GRFPC0.MEM.RREG.RES\(62),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_2_S_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(40),
dataa => \GRFPC0.DIV.RESULT\(40),
datab => \GRFPC0.WR2.RREG.RES\(40),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(4));
\GRFPC0_OP1_0_IV_2_S_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(48),
dataa => \GRFPC0.DIV.RESULT\(48),
datab => \GRFPC0.MEM.RREG.RES\(48),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_2_S_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(46),
dataa => \GRFPC0.DIV.RESULT\(46),
datab => \GRFPC0.WR.RREG.RES\(46),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_2_S_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_2_S\(51),
dataa => \GRFPC0.DIV.RESULT\(51),
datab => \GRFPC0.MEM.RREG.RES\(51),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
GRFPC0_D_FSTLCK_RNO_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_9_S\,
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI2HR11_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_S\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI1RF21_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3_S\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_11_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11_S\,
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES\(86));
\GRFPC0_OP1_0_IV_3_S_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(44),
dataa => \GRFPC0.WR.RREG.RES\(44),
datab => \GRFPC0.WR2.RREG.RES\(44),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(4));
\GRFPC0_OP1_0_IV_3_S_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(47),
dataa => \GRFPC0.WR2.RREG.RES\(47),
datab => \GRFPC0.WR.RREG.RES\(47),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_3_S_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(59),
dataa => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.EX.RREG.RES\(59),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_3_S_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(36),
dataa => \GRFPC0.EX.RREG.RES\(36),
datab => \GRFPC0.MEM.RREG.RES\(36),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_3_S_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(49),
dataa => \GRFPC0.EX.RREG.RES\(49),
datab => \GRFPC0.MEM.RREG.RES\(49),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_3_S_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_3_S\(57),
dataa => \GRFPC0.WR.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RES\(57),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(4));
\GRFPC0_D_STLCK_RNO_8_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2_S\(0),
dataa => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25));
\GRFPC0_D_STLCK_RNO_11_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6_0_S\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.CPI_I_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\);
\GRFPC0_OP1_0_IV_5_A_S_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_5_A_S\(56),
dataa => \GRFPC0.WR.RREG.RES\(56),
datab => \GRFPC0.WR2.RREG.RES\(56),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_2_S_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2_S\(0),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2886_REGDEPX2_0_A3_0_A2\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2915_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_3_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_S\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\,
datad => \GRFPC0.RFA.LD\);
GRFPC0_D_FSTLCK_RNO_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_8_S\,
dataa => \GRFPC0.MEM.CTRL.LD\,
datab => \GRFPC0.MEM.CTRL.AFSR\,
datac => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.WR.CTRL.AFSR\);
GRFPU0_GRFPU_X0_ST3_EMAX_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_S\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_8_S_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8_S\(1),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(1));
\GRFPC0_D_STLCK_RNO_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5_S\,
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_568_3\(1));
GRFPC0_RFA2_RS1DEP_RNO_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110111")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_1_S\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_2\,
datab => \GRFPC0.UN1_REGDEP79\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_4\,
datad => \GRFPC0.REGDEP_1_SQMUXA_1\);
\GRFPC0_R_STATE_0_0_0__G0_0_X\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.R.STATE_0_0_0__G0_0_X\,
dataa => N_3,
datab => N_38);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN243_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1_X\,
dataa => N_174,
datab => N_173);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4841_DEP_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\,
dataa => N_173,
datab => N_176);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN243_DEP_2_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_2_0_A2_X\,
dataa => N_176,
datab => N_175);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4841_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_1_X\,
dataa => N_175,
datab => N_174);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3857_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3857_DEP_1_X\,
dataa => N_174,
datab => N_173);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4185_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4185_DEP_1_X\,
dataa => N_176,
datab => N_175);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(27),
dataa => N_144,
datab => \GRFPC0.EX.CTRL.PC\(29),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(23),
dataa => N_170,
datab => \GRFPC0.EX.CTRL.INST\(23),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(7),
dataa => N_124,
datab => \GRFPC0.EX.CTRL.PC\(9),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(19),
dataa => N_136,
datab => \GRFPC0.EX.CTRL.PC\(21),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(17),
dataa => N_134,
datab => \GRFPC0.EX.CTRL.PC\(19),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(11),
dataa => N_128,
datab => \GRFPC0.EX.CTRL.PC\(13),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(10),
dataa => N_127,
datab => \GRFPC0.EX.CTRL.PC\(12),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(6),
dataa => N_123,
datab => \GRFPC0.EX.CTRL.PC\(8),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(3),
dataa => N_120,
datab => \GRFPC0.EX.CTRL.PC\(5),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(2),
dataa => N_119,
datab => \GRFPC0.EX.CTRL.PC\(4),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(9),
dataa => N_126,
datab => \GRFPC0.EX.CTRL.PC\(11),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(19),
dataa => N_166,
datab => \GRFPC0.EX.CTRL.INST\(19),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(24),
dataa => N_171,
datab => \GRFPC0.EX.CTRL.INST\(24),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(0),
dataa => N_117,
datab => \GRFPC0.EX.CTRL.PC\(2),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(10),
dataa => N_157,
datab => \GRFPC0.EX.CTRL.INST\(10),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(22),
dataa => N_139,
datab => \GRFPC0.EX.CTRL.PC\(24),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(4),
dataa => N_121,
datab => \GRFPC0.EX.CTRL.PC\(6),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(28),
dataa => N_145,
datab => \GRFPC0.EX.CTRL.PC\(30),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(25),
dataa => N_172,
datab => \GRFPC0.EX.CTRL.INST\(25),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(3),
dataa => N_150,
datab => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(4),
dataa => N_151,
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(15),
dataa => N_162,
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(16),
dataa => N_163,
datab => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(17),
dataa => N_164,
datab => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(18),
dataa => N_165,
datab => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(1),
dataa => N_118,
datab => \GRFPC0.EX.CTRL.PC\(3),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(5),
dataa => N_122,
datab => \GRFPC0.EX.CTRL.PC\(7),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(8),
dataa => N_125,
datab => \GRFPC0.EX.CTRL.PC\(10),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(12),
dataa => N_129,
datab => \GRFPC0.EX.CTRL.PC\(14),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(13),
dataa => N_130,
datab => \GRFPC0.EX.CTRL.PC\(15),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(14),
dataa => N_131,
datab => \GRFPC0.EX.CTRL.PC\(16),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(15),
dataa => N_132,
datab => \GRFPC0.EX.CTRL.PC\(17),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(16),
dataa => N_133,
datab => \GRFPC0.EX.CTRL.PC\(18),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(18),
dataa => N_135,
datab => \GRFPC0.EX.CTRL.PC\(20),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(20),
dataa => N_137,
datab => \GRFPC0.EX.CTRL.PC\(22),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(21),
dataa => N_138,
datab => \GRFPC0.EX.CTRL.PC\(23),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(23),
dataa => N_140,
datab => \GRFPC0.EX.CTRL.PC\(25),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(24),
dataa => N_141,
datab => \GRFPC0.EX.CTRL.PC\(26),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(25),
dataa => N_142,
datab => \GRFPC0.EX.CTRL.PC\(27),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(26),
dataa => N_143,
datab => \GRFPC0.EX.CTRL.PC\(28),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(29),
dataa => N_146,
datab => \GRFPC0.EX.CTRL.PC\(31),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(30),
dataa => N_147,
datab => \GRFPC0.EX.CTRL.INST\(0),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_INST_1_0_I_M2_X_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(31),
dataa => N_148,
datab => \GRFPC0.EX.CTRL.INST\(1),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(2),
dataa => N_149,
datab => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(5),
dataa => N_152,
datab => \GRFPC0.EX.CTRL.INST\(5),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(6),
dataa => N_153,
datab => \GRFPC0.EX.CTRL.INST\(6),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(7),
dataa => N_154,
datab => \GRFPC0.EX.CTRL.INST\(7),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(8),
dataa => N_155,
datab => \GRFPC0.EX.CTRL.INST\(8),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(9),
dataa => N_156,
datab => \GRFPC0.EX.CTRL.INST\(9),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(11),
dataa => N_158,
datab => \GRFPC0.EX.CTRL.INST\(11),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(12),
dataa => N_159,
datab => \GRFPC0.EX.CTRL.INST\(12),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(13),
dataa => N_160,
datab => \GRFPC0.EX.CTRL.INST\(13),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(14),
dataa => N_161,
datab => \GRFPC0.EX.CTRL.INST\(14),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(21),
dataa => N_168,
datab => \GRFPC0.EX.CTRL.INST\(21),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(31),
dataa => N_178,
datab => \GRFPC0.EX.CTRL.INST\(31),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(26),
dataa => N_173,
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(27),
dataa => N_174,
datab => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(28),
dataa => N_175,
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_EX_CTRL_INST_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(29),
dataa => N_176,
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_OP2_4_X_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(35),
dataa => N_726,
datab => N_662,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_0_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_0_X\(9),
dataa => N_84,
datab => N_78);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
dataa => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_1_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8),
dataa => N_78,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(9),
dataa => N_92,
datab => N_84);
\GRFPC0_INST_I_A2_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.INST_I_A2_X\(14),
dataa => N_92,
datab => \GRFPC0.INST_I_M2\(1));
GRFPC0_FP_PIPELINE_LDLOCK27_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK27_X\,
dataa => N_108,
datab => N_109);
GRFPC0_EX_CTRL_LD_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_2_X\,
dataa => N_3,
datab => N_39);
GRFPC0_FP_PIPELINE_UN56_PENDEXC_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN56_PENDEXC_X\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_VDIV_EXEC_7_F0_RNILUQ3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.DIV.EXEC_0_0_G0_X\,
dataa => N_3,
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_27_I_O2_RNI2JMP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_132_I_0_O2_X\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1552_REGDEPX_2_0_A3_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX_2_0_A3_0_A2_X\,
dataa => N_96,
datab => N_94);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4360_REGDEPX_0_A4_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX_0_A4_1_X\,
dataa => N_95,
datab => N_93);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2800_REGDEPX_0_A2_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A2_0_A2_X\,
dataa => N_95,
datab => N_96);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN259_DEP_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\,
dataa => N_245,
datab => N_244);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4527_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4527_DEP_1_X\,
dataa => N_244,
datab => N_242);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1575_DEP_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_2_X\,
dataa => N_245,
datab => N_243);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4855_DEP_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP_1_X\,
dataa => N_244,
datab => N_243);
GRFPC0_EX_CTRL_LD_RNIGRHG7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110001011")
port map (
combout => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\,
dataa => N_39,
datab => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_OP2_4_X_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(43),
dataa => N_734,
datab => N_670,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(22),
dataa => N_426,
datab => N_713,
datac => N_649);
\GRFPC0_STDATA_1_X_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(22),
dataa => \GRFPC0.R.STDATA\(22),
datab => \GRFPC0.R.FSR.NONSTD\,
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(57),
dataa => N_748,
datab => N_684,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_STDATA_1_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(8),
dataa => \GRFPC0.R.STDATA\(8),
datab => \GRFPC0.R.FSR.AEXC\(3),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(2),
dataa => N_426,
datab => N_693,
datac => N_629);
\GRFPC0_INST_I_0_M2_0_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.INST_I_0_M2_0_X\(13),
dataa => N_91,
datab => \GRFPC0.FIFO.INST_0\(13),
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_FP_PIPELINE_UN1_CPI_3_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
dataa => N_249,
datab => N_248);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_10_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_10_X\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_I_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_X\,
dataa => N_39,
datab => \GRFPC0.WR.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_I_S_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X\,
dataa => N_38,
datab => \GRFPC0.WR.CTRL.LD\);
GRFPC0_FP_PIPELINE_LDLOCK23_3_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK23_3_X\,
dataa => N_102,
datab => N_97);
\GRFPC0_VFIFO_INST_0_4_X_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.VFIFO.INST_0_4_X\(18),
dataa => N_96,
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_FP_PIPELINE_0_UN1_OP_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
GRFPC0_FP_PIPELINE_UN1_CPI_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_X\,
dataa => N_111,
datab => N_110);
GRFPC0_VRFA_SEQERR_5_SQMUXA_1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.LDLOCK_1_M_4_X\,
dataa => N_97,
datab => N_102);
\GRFPC0_FP_PIPELINE_DBGDATA_4_I_M3_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_I_M3_X\(13),
dataa => N_426,
datab => N_704,
datac => N_640);
\GRFPC0_OP2_I_M3_3_X_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_I_M3_3_X\(45),
dataa => N_736,
datab => N_672,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(51),
dataa => N_742,
datab => N_678,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(38),
dataa => N_729,
datab => N_665,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(27),
dataa => \GRFPC0.R.STDATA\(27),
datab => \GRFPC0.R.FSR.TEM\(4),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(7),
dataa => N_426,
datab => N_698,
datac => N_634);
\GRFPC0_OP2_4_X_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(39),
dataa => N_730,
datab => N_666,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(7),
dataa => \GRFPC0.R.STDATA\(7),
datab => \GRFPC0.R.FSR.AEXC\(2),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(32),
dataa => N_723,
datab => N_659,
datac => \GRFPC0.OP2_SN_M4_REP1\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X_RNI1AT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => G_2026_X,
dataa => N_38,
datab => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\);
\GRFPC0_OP1_0_IV_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.RFO2_I_M_0_X\(18),
dataa => N_709,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\);
\GRFPC0_OP2_4_X_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(48),
dataa => N_739,
datab => N_675,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(53),
dataa => N_744,
datab => N_680,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_STDATA_1_X_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(23),
dataa => \GRFPC0.R.STDATA\(23),
datab => \GRFPC0.R.FSR.TEM\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(24),
dataa => N_426,
datab => N_715,
datac => N_651);
\GRFPC0_STDATA_1_X_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(24),
dataa => \GRFPC0.R.STDATA\(24),
datab => \GRFPC0.R.FSR.TEM\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_STDATA_1_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(25),
dataa => \GRFPC0.R.STDATA\(25),
datab => \GRFPC0.R.FSR.TEM\(2),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(26),
dataa => N_426,
datab => N_717,
datac => N_653);
\GRFPC0_STDATA_1_X_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(26),
dataa => \GRFPC0.R.STDATA\(26),
datab => \GRFPC0.R.FSR.TEM\(3),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_STDATA_1_X_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(30),
dataa => \GRFPC0.R.STDATA\(30),
datab => \GRFPC0.R.FSR.RD\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(14),
dataa => N_426,
datab => N_705,
datac => N_641);
\GRFPC0_STDATA_1_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(14),
dataa => \GRFPC0.R.STDATA\(14),
datab => \GRFPC0.R.FSR.FTT\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_STDATA_1_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(5),
dataa => \GRFPC0.R.STDATA\(5),
datab => \GRFPC0.R.FSR.AEXC\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
GRFPC0_VEX_RREG_RESV_0_SQMUXA_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.VEX.RREG.RESV_0_SQMUXA_0_A2_X\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(23),
dataa => N_426,
datab => N_714,
datac => N_650);
\GRFPC0_STDATA_1_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(6),
dataa => \GRFPC0.R.STDATA\(6),
datab => \GRFPC0.R.FSR.AEXC\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(6),
dataa => N_426,
datab => N_697,
datac => N_633);
\GRFPC0_OP2_4_X_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(46),
dataa => N_737,
datab => N_673,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(8),
dataa => N_426,
datab => N_699,
datac => N_635);
\GRFPC0_OP2_4_X_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(40),
dataa => N_731,
datab => N_667,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_4_X_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(33),
dataa => N_724,
datab => N_660,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(11),
dataa => N_426,
datab => N_702,
datac => N_638);
\GRFPC0_OP2_4_X_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(37),
dataa => N_728,
datab => N_664,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(3),
dataa => \GRFPC0.R.STDATA\(3),
datab => \GRFPC0.R.FSR.CEXC\(3),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(54),
dataa => N_745,
datab => N_681,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(42),
dataa => N_733,
datab => N_669,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(10),
dataa => \GRFPC0.R.STDATA\(10),
datab => \GRFPC0.R.FSR.FCC\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(10),
dataa => N_426,
datab => N_701,
datac => N_637);
\GRFPC0_OP2_4_X_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(61),
dataa => N_752,
datab => N_688,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(60),
dataa => N_751,
datab => N_687,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(49),
dataa => N_740,
datab => N_676,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_STDATA_1_X_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(16),
dataa => \GRFPC0.R.STDATA\(16),
datab => \GRFPC0.R.FSR.FTT\(2),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(16),
dataa => N_426,
datab => N_707,
datac => N_643);
\GRFPC0_STDATA_1_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(15),
dataa => \GRFPC0.R.STDATA\(15),
datab => \GRFPC0.R.FSR.FTT\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(9),
dataa => N_426,
datab => N_700,
datac => N_636);
\GRFPC0_STDATA_1_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(9),
dataa => \GRFPC0.R.STDATA\(9),
datab => \GRFPC0.R.FSR.AEXC\(4),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(36),
dataa => N_727,
datab => N_663,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(4),
dataa => \GRFPC0.R.STDATA\(4),
datab => \GRFPC0.R.FSR.CEXC\(4),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(31),
dataa => N_426,
datab => N_722,
datac => N_658);
GRFPC0_VMEM_RREG_RESV_0_SQMUXA_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
dataa => N_38,
datab => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X_REP2\);
GRFPC0_D_FSTLCK_M_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.D.FSTLCK_M_2_X\,
dataa => N_101,
datab => N_100);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_22_I_0_A2_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_I_0_I2_0_0_I4_0_I2_0_O2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP3\);
GRFPC0_FP_PIPELINE_UN33_DEBUG_UNIT_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
dataa => N_424,
datab => N_425);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0_RNIUGV1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.DIV.VALID_0_0_G0_X\,
dataa => N_3,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
GRFPC0_VEX_RREG_RES_0_SQMUXA_0_M2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110110001101")
port map (
combout => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
dataa => N_38,
datab => \GRFPC0.RFA.ST\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\);
GRFPC0_FP_PIPELINE_RS1D_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
dataa => N_167,
datab => \GRFPC0.RFA.ST\,
datac => \GRFPC0.RFA.RS1D\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(0),
dataa => N_426,
datab => N_691,
datac => N_627);
\GRFPC0_OP2_4_X_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(59),
dataa => N_750,
datab => N_686,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(58),
dataa => N_749,
datab => N_685,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(56),
dataa => N_747,
datab => N_683,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(55),
dataa => N_746,
datab => N_682,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(44),
dataa => N_735,
datab => N_671,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(4),
dataa => N_426,
datab => N_695,
datac => N_631);
\GRFPC0_STDATA_1_X_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(31),
dataa => \GRFPC0.R.STDATA\(31),
datab => \GRFPC0.R.FSR.RD\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(50),
dataa => N_741,
datab => N_677,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_STDATA_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(0),
dataa => \GRFPC0.R.STDATA\(0),
datab => \GRFPC0.R.FSR.CEXC\(0),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(27),
dataa => N_426,
datab => N_718,
datac => N_654);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(15),
dataa => N_426,
datab => N_706,
datac => N_642);
\GRFPC0_OP2_4_X_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(41),
dataa => N_732,
datab => N_668,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(2),
dataa => \GRFPC0.R.STDATA\(2),
datab => \GRFPC0.R.FSR.CEXC\(2),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(1),
dataa => N_426,
datab => N_692,
datac => N_628);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(25),
dataa => N_426,
datab => N_716,
datac => N_652);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(5),
dataa => N_426,
datab => N_696,
datac => N_632);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(3),
dataa => N_426,
datab => N_694,
datac => N_630);
\GRFPC0_STDATA_1_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(1),
dataa => \GRFPC0.R.STDATA\(1),
datab => \GRFPC0.R.FSR.CEXC\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_STDATA_1_X_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.STDATA_1_X\(11),
dataa => \GRFPC0.R.STDATA\(11),
datab => \GRFPC0.R.FSR.FCC\(1),
datac => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP2_4_X_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(63),
dataa => N_754,
datab => N_690,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_X_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(30),
dataa => N_426,
datab => N_721,
datac => N_657);
\GRFPC0_OP2_4_X_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(62),
dataa => N_753,
datab => N_689,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(52),
dataa => N_743,
datab => N_679,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP2_4_X_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(34),
dataa => N_725,
datab => N_661,
datac => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_4_X_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_4_X\(47),
dataa => N_738,
datab => N_674,
datac => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_OP1_0_IV_RNO_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.RFO2_I_M_0_X\(30),
dataa => N_721,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
dataa => N_107,
datab => N_106);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
dataa => N_106,
datab => N_107);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_1_0_A3_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
dataa => N_104,
datab => N_105);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_12_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
dataa => N_107,
datab => N_106);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\,
dataa => N_105,
datab => N_104);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13_1_I_O4_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\,
dataa => N_104,
datab => N_105);
GRFPC0_FP_PIPELINE_0_UN1_DEP_X_RNII47J: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_4_X\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.CPI_I_M_1_X\(64));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
dataa => N_107,
datab => N_106);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN3127_REGDEPX_0_A2_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX_0_A2_0_A2_X\,
dataa => N_81,
datab => N_82);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3751_REGDEPX_1_0_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\,
dataa => N_80,
datab => N_79);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4063_REGDEPX_1_I_O4_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\,
dataa => N_82,
datab => N_81);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1567_REGDEPX_2_0_A3_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX_2_0_A3_0_A2_X\,
dataa => N_82,
datab => N_80);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
dataa => N_105,
datab => N_104);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_X_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_X\(19),
dataa => N_80,
datab => N_79);
GRFPC0_FP_PIPELINE_VWR2_RREG_RES13_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
dataa => N_387,
datab => N_386);
\GRFPC0_FP_PIPELINE_11_REGDEPX_212_0_A2_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_212_0_A2_0_X\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_3_0_RNISCOI: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A2_0_0_X\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datab => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_RFA_ST_0_0_G1_0_1622_A3_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_1622_A3_0_X\,
dataa => N_39,
datab => N_112);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A2_1_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_1_0_X\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN943_REGDEPX_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_0_X\,
dataa => N_79,
datab => N_80);
GRFPC0_WR2_CTRL_AFSR_0_0_G1_0_1347_A2_0_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_0_0_X\,
dataa => N_389,
datab => N_39);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1561_DEP_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP_0_X\,
dataa => N_176,
datab => N_174);
\GRFPC0_D_STDLCK_0_0_9__G3_0_X\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G3_0_X\,
dataa => N_245,
datab => N_242);
GRFPC0_FP_PIPELINE_UN26_FPUSTART_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0_X\,
dataa => N_180,
datab => N_179);
GRFPC0_FP_PIPELINE_UN42_HOLDN_0_O2_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2_0_X\,
dataa => N_38,
datab => \GRFPC0.WR2.CNT\(1));
GRFPC0_FP_PIPELINE_UN25_HOLDN_A1_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_A1_0_X\,
dataa => N_38,
datab => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_MEM_RREG_RESV_RNIE8GF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_A2_0_0_X\,
dataa => N_38,
datab => \GRFPC0.MEM.RREG.RESV\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_0_X\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datab => N_103);
GRFPC0_FP_PIPELINE_FPUSTART_7_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_0_X\,
dataa => N_38,
datab => N_39);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0_1TT_B0_0_C_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C_0_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_VRFA_ST_1_SN_M1_0_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_0_X\,
dataa => N_102,
datab => N_99);
GRFPC0_FP_PIPELINE_UN29_WREN_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_0_X\,
dataa => N_38,
datab => \GRFPC0.DIV.VALID_REP1\);
\GRFPC0_FIFO_RD_RNI07LV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FIFO.RD_I_M_0_X\(0),
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FIFO.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_6_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_X\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datac => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011011110110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
dataa => N_89,
datab => N_90,
datac => N_97);
\GRFPC0_D_STLCK_RNO_5_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_5_X\(1),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.CPI_I_M_1_X\(64));
\GRFPC0_EX_CTRL_VCNT_RNIOM7B_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
dataa => N_39,
datab => \GRFPC0.EX.CTRL.VCNT\(0),
datac => \GRFPC0.EX.CTRL.VCNT\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4672_REGDEPX_0_A2_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX_0_A2_0_X\,
dataa => N_95,
datab => N_96,
datac => N_94);
\GRFPC0_EXSEL_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010001010")
port map (
combout => \GRFPC0.EXSEL_1_X\(2),
dataa => N_38,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(22),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(22),
datac => \GRFPC0.R.FSR.NONSTD\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(2),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(2),
datac => \GRFPC0.R.FSR.CEXC\(2));
GRFPC0_WR2_CTRL_LD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.WR2.CTRL.LD_0_0_G1_0_1395_A2_X\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.WR.CTRL.LD\);
GRFPC0_FP_PIPELINE_UN1_VRFA_ST_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
dataa => N_38,
datab => \GRFPC0.RFA.ST\,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_0_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0_X\(25),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.CPI_I_M_1_X\(64));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(7),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(7),
datac => \GRFPC0.R.FSR.AEXC\(2));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(24),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(24),
datac => \GRFPC0.R.FSR.TEM\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(26),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(26),
datac => \GRFPC0.R.FSR.TEM\(3));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(14),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(14),
datac => \GRFPC0.R.FSR.FTT\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(23),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(23),
datac => \GRFPC0.R.FSR.TEM\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(6),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(6),
datac => \GRFPC0.R.FSR.AEXC\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(8),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(8),
datac => \GRFPC0.R.FSR.AEXC\(3));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(11),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(11),
datac => \GRFPC0.R.FSR.FCC\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(10),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(10),
datac => \GRFPC0.R.FSR.FCC\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(16),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(16),
datac => \GRFPC0.R.FSR.FTT\(2));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(9),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(9),
datac => \GRFPC0.R.FSR.AEXC\(4));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(31),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(31),
datac => \GRFPC0.R.FSR.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010001100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_X\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datac => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_R_FSR_RD_0_0_0__G1_E_X\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
dataa => N_425,
datab => N_424,
datac => N_423);
\GRFPC0_RS1_3_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.RS1_3_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.ST\,
datac => \GRFPC0.V.STDATA_14\(14));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(0),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(0),
datac => \GRFPC0.R.FSR.CEXC\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(4),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(4),
datac => \GRFPC0.R.FSR.CEXC\(4));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(27),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(27),
datac => \GRFPC0.R.FSR.TEM\(4));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(15),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(15),
datac => \GRFPC0.R.FSR.FTT\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(1),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(1),
datac => \GRFPC0.R.FSR.CEXC\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(25),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(25),
datac => \GRFPC0.R.FSR.TEM\(2));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(5),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(5),
datac => \GRFPC0.R.FSR.AEXC\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(3),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(3),
datac => \GRFPC0.R.FSR.CEXC\(3));
\GRFPC0_FP_PIPELINE_DBGDATA_4_X_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => CPO_DBG_DATAZ(30),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_0_X\(30),
datac => \GRFPC0.R.FSR.RD\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1_X\(0),
dataa => N_84,
datab => N_78,
datac => N_79);
GRFPC0_FP_PIPELINE_VFIFO_RD10_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
dataa => N_39,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0));
GRFPC0_LDLOCK_1_M_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.LDLOCK_1_M_2_X\,
dataa => N_108,
datab => N_109,
datac => N_101);
\GRFPC0_D_STLCK_RNO_6_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_TZ_X\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.CPI_M_1_X\(64));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\,
dataa => N_113,
datab => N_112,
datac => \GRFPC0.FIFO.FULL\);
GRFPC0_MEM_CTRL_LD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.MEM.CTRL.LD_0_0_G1_0_1551_A2_X\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.EX.CTRL.LD\);
GRFPC0_WR_CTRL_LD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.WR.CTRL.LD_0_0_G1_0_1460_A2_X\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.MEM.CTRL.LD\);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A4_2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_2_X\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.CPI_M_1_X\(64));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_15_1_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_1_X\(1),
dataa => N_84,
datab => N_92,
datac => N_93);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_X\(27),
dataa => N_78,
datab => N_84,
datac => N_79);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_X\(0),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.CPI_M_1_X\(64));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_0_X_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_97);
GRFPC0_EX_RREG_RESV_RNIN7BH2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000101")
port map (
combout => \GRFPC0.EX.RREG.RESV_0_0_G0_0_X\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\);
\GRFPC0_FP_PIPELINE_1_0_STDEP_65_0_IV_I_A4_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_1_X\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_EX_CTRL_CCWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.EX.CTRL.CCWR_0_0_G1_X\,
dataa => N_3,
datab => \GRFPC0.RFA.WRITE_RD\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
GRFPC0_FP_PIPELINE_STDBL_1_1_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDBL_1_1_0_X\,
dataa => N_166,
datab => N_167,
datac => \GRFPC0.RFA.ST\);
GRFPC0_EX_CTRL_DIV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.EX.CTRL.DIV_0_0_G1_X\,
dataa => N_3,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_15_0_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_0_X\(1),
dataa => N_94,
datab => N_96,
datac => N_95);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_0_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0_X\(9),
dataa => N_78,
datab => N_84,
datac => N_79);
GRFPC0_FP_PIPELINE_UN6_OP3_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN6_OP3_0_X\,
dataa => N_102,
datab => N_98,
datac => N_100);
GRFPC0_CCWR_0_SQMUXA_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.CCWR_0_SQMUXA_0_X\,
dataa => N_97,
datab => N_99,
datac => N_102);
GRFPC0_CCWR_0_SQMUXA_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.CCWR_0_SQMUXA_1_X\,
dataa => N_98,
datab => N_100,
datac => N_101);
GRFPC0_STDDEP_0_SQMUXA_19_I_O4_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_19_I_O4_0_X\,
dataa => N_244,
datab => N_245,
datac => N_243);
GRFPC0_STDDEP_0_SQMUXA_6_I_O4_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_0_X\,
dataa => N_242,
datab => N_243,
datac => N_245);
GRFPC0_STDEP_0_SQMUXA_5_0_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_5_0_0_X\,
dataa => N_242,
datab => N_244,
datac => N_245);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_1_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_1_0_X\,
dataa => N_173,
datab => N_174,
datac => N_176);
GRFPC0_WR_CTRL_RDD_REP5_RNI0DDT: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_A2_0_0_X\,
dataa => N_386,
datab => N_387,
datac => \GRFPC0.WR.CTRL.RDD_REP5\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_1_X\(0),
dataa => N_108,
datab => N_109,
datac => N_97);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_1_X\,
dataa => N_108,
datab => N_109,
datac => N_97);
GRFPC0_RFA_RDD_RNIQE1J: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_1_X\,
dataa => N_39,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_RFA_AFSR_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_2_X\,
dataa => N_98,
datab => N_100,
datac => N_108);
GRFPC0_RFA_RDD_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_3_X\,
dataa => N_98,
datab => N_99,
datac => N_113);
GRFPC0_RFA_STDFQ_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_0_X\,
dataa => N_98,
datab => N_99,
datac => N_39);
GRFPC0_RFA_RDWR_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_0_X\,
dataa => N_102,
datab => N_109,
datac => N_99);
GRFPC0_VEX_CTRL_PEND_0_SQMUXA_1_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0_X\,
dataa => N_39,
datab => \GRFPC0.EX.CTRL.VCNT\(0),
datac => \GRFPC0.EX.CTRL.VCNT\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_X\(5),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\);
\GRFPC0_FP_PIPELINE_RS2_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(0),
datac => \GRFPC0.INST_I_M2\(0));
\GRFPC0_D_STLCK_RNO_8_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_4_I_I_A2_I_X\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3529_DEP\,
datab => \GRFPC0.RFA.LD_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX_36_0_A5_0_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_0_X\(1),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\);
\GRFPC0_D_STDLCK_RNO_5_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_12_I_I_A2_I_X\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_9_0_A2\(0),
datab => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_14_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_14_X\(0),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\);
\GRFPC0_FP_PIPELINE_WRDATA_6_X_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(22),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(22),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(54));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(8),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(8),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(40));
\GRFPC0_FP_PIPELINE_RS1_6_0_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(3),
dataa => N_106,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(17));
\GRFPC0_FP_PIPELINE_RS1_6_0_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(1),
dataa => N_104,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(15));
\GRFPC0_FP_PIPELINE_RS1_6_0_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(4),
dataa => N_107,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(18));
\GRFPC0_WRDATA_I_M3_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WRDATA_I_M3_X\(13),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.WRDATA_I_M3_0\(13),
datac => \GRFPC0.WRDATA_I_M3\(45));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(10),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(10),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(42));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(4),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(4),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(36));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(16),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(16),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(48));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(29),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(29),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(61));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(19),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(19),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(51));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(23),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(23),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(55));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(26),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(26),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(58));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(0),
dataa => N_436,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.AEXC\(0));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(1),
dataa => N_437,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.AEXC\(1));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(11),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(11),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(43));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(7),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(7),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(39));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(17),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(17),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(49));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(4),
dataa => N_440,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.AEXC\(4));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(25),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(25),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(57));
\GRFPC0_FP_PIPELINE_RS1_6_0_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(2),
dataa => N_105,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST\(16));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(6),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(6),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(38));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(14),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(14),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(46));
GRFPC0_LDLOCK_14_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.LDLOCK_14_X\,
dataa => N_104,
datab => \GRFPC0.LDLOCK_13\,
datac => \GRFPC0.LDLOCK_10\);
GRFPC0_LDLOCK_7_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.LDLOCK_7_X\,
dataa => N_104,
datab => \GRFPC0.LDLOCK_6\,
datac => \GRFPC0.LDLOCK_3\);
\GRFPC0_FP_PIPELINE_WRDATA_6_X_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(20),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(20),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(52));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(28),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(28),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(60));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3543_DEP_RNI2BLI: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3543_DEP\,
datab => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_X_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_X\(25),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(3),
dataa => N_439,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.AEXC\(3));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_1_X\(2),
dataa => N_438,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.AEXC\(2));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(0),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(0),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(32));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(9),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(9),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(41));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(5),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(5),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(37));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(3),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(3),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(35));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(2),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(2),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(34));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(1),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(1),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(33));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(31),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(31),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(63));
\GRFPC0_FP_PIPELINE_FCC_1_M2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2_X\(0),
dataa => \GRFPC0.FP_PIPELINE.FCC_1_M2S2_X\,
datab => \GRFPC0.FP_PIPELINE.FCC_1_M1\(0),
datac => \GRFPC0.FP_PIPELINE.FCC_1_M0\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M2_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2_X\(1),
dataa => \GRFPC0.FP_PIPELINE.FCC_1_M2S2_X\,
datab => \GRFPC0.FP_PIPELINE.FCC_1_M1\(1),
datac => \GRFPC0.FP_PIPELINE.FCC_1_M0\(1));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_5_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_5_X\(0),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A4_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_0_X\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\);
GRFPC0_RFA_RDD_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_1_X\,
dataa => N_100,
datab => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_7\);
GRFPC0_VWR2_RREG_RES_2_SQMUXA_1_I_O2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\,
dataa => N_38,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\);
\GRFPC0_D_STDLCK_RNO_4_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_X\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_0\,
datab => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_1_0_X_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_0_X\(20),
dataa => N_93,
datab => N_95,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15));
GRFPC0_RFA_LD_0_0_G1_0_A2_2_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_A2_2_0_X\,
dataa => N_113,
datab => N_99,
datac => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_7\);
GRFPC0_RFA_AFSR_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_5_X\,
dataa => N_113,
datab => N_101,
datac => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_2_X\);
GRFPC0_RFA_RDWR_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_3_X\,
dataa => N_108,
datab => N_112,
datac => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_0_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_6_X_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6_X\(21),
dataa => \GRFPC0.N_25443_2\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\);
GRFPC0_DIV_EXC_0_2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.DIV.EXC_0_2_X\,
dataa => N_3,
datab => \GRFPC0.DIV.PEND_1_0_G1_0_I_A5_0\);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_A2_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100001101")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A2_0_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_23_I_O2\);
GRFPC0_FP_PIPELINE_VRFA_RDD_1_0_A4_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST4_0_A3\);
\GRFPC0_FP_PIPELINE_RS1_6_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(3),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(3));
\GRFPC0_FP_PIPELINE_RS1_6_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_X\(1),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(1),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(1));
\GRFPC0_FP_PIPELINE_RS1_6_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(4),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(4));
\GRFPC0_FP_PIPELINE_RS1_6_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(2),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_X\(2));
\GRFPC0_D_STLCK_RNO_5_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_X\(1),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_0_0\(0));
GRFPC0_LDLOCK_15_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.LDLOCK_15_X\,
dataa => N_105,
datab => \GRFPC0.LDLOCK_14_X\,
datac => \GRFPC0.LDLOCK_7_X\);
\GRFPC0_R_FSR_CEXC_RNO_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.CPI_M_X\(393),
dataa => N_3,
datab => N_432,
datac => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\);
\GRFPC0_R_FSR_CEXC_RNO_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.CPI_M_X\(395),
dataa => N_3,
datab => N_434,
datac => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\);
\GRFPC0_R_FSR_CEXC_RNO_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.CPI_M_X\(394),
dataa => N_3,
datab => N_433,
datac => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\);
\GRFPC0_R_FSR_CEXC_RNO_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.CPI_M_X\(392),
dataa => N_3,
datab => N_431,
datac => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\);
\GRFPC0_R_FSR_CEXC_RNO_6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.CPI_M_X\(396),
dataa => N_3,
datab => N_435,
datac => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\);
GRFPC0_STDDEP_0_SQMUXA_21_0_A2_RNIJ5EJ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_X\(1),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_21_0_A2\);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A4_1_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_1_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_21_0_A2\);
\GRFPC0_D_STLCK_RNO_8_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_0\(0));
GRFPC0_V_FSR_CEXC_1_SQMUXA_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0_X\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.WR2.CTRL.SEQERR\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_18_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_18_X\(15),
dataa => N_103,
datab => N_108,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_I_O2_0_O3_0_O5\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_1_X_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_X\(20),
dataa => N_94,
datab => N_96,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_0_X\(20));
GRFPC0_STDDEP_0_SQMUXA_6_I_O4_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111011111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_X\,
dataa => N_244,
datab => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_0_X\,
datac => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_D_STLCK_RNO_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_3_0_X\(1),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3871_DEP_0_A3\,
datab => \GRFPC0.EX.CTRL.LD\);
GRFPC0_V_FSR_CEXC_6_SQMUXA_0_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_6_SQMUXA_0_X\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.DIV.VALID_REP1\);
GRFPC0_RFA_STDFQ_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_1_X\,
dataa => N_100,
datab => N_97,
datac => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_7\);
\GRFPC0_D_STLCK_RNO_8_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111010101")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I_0_X\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_1_0_X\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\);
\GRFPC0_D_STDLCK_RNO_2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011001110110011")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_0_X\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3529_DEP\,
datab => \GRFPC0.STDDEP_0_SQMUXA_80_I_I_A2_I\,
datac => \GRFPC0.RFA.LD\);
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_25_IV_I_A2_RNI0B862_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100011")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_6_X\(1),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_IV_I_A2\(1),
datab => \GRFPC0.STDDEP_0_SQMUXA_80_I_I_A2_I\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_I_I_0_A2\(0));
GRFPC0_EX_CTRL_RDD_REP2_RNI9D851: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_1_X\(1),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_7_I_I_A4_I_O2\);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A3_0_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100001101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_0_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\);
GRFPC0_FP_PIPELINE_LDLOCK19_A_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK19_A_X\,
dataa => N_100,
datab => N_101,
datac => N_102);
GRFPC0_VMEM_RREG_RESV_0_SQMUXA_0_A2_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_0_A2_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
GRFPC0_VMEM_RREG_RESV_1_SQMUXA_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
GRFPC0_VWR_RREG_RESV_1_SQMUXA_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.VWR.RREG.RESV_1_SQMUXA_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\);
GRFPC0_VWR_RREG_RESV_0_SQMUXA_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\);
\GRFPC0_FP_PIPELINE_8_STDEP_354_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_354_X\(1),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_28_I_0_O2\);
\GRFPC0_D_STLCK_RNO_12_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A4_X\(1),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP3\,
datac => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_X\);
\GRFPC0_D_STLCK_RNO_11_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_X\(1),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_9_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100001101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_X\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_9_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A4_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100001101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A4_X\(0),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_X\);
\GRFPC0_RS1_1_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => RFI2_RD1ADDRZ(3),
dataa => N_423,
datab => N_430,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
\GRFPC0_RS1_1_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => RFI2_RD1ADDRZ(2),
dataa => N_423,
datab => N_429,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3));
\GRFPC0_RS1_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => RFI2_RD1ADDRZ(1),
dataa => N_423,
datab => N_428,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
\GRFPC0_RS1_1_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => RFI2_RD1ADDRZ(0),
dataa => N_423,
datab => N_427,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_FP_PIPELINE_UN6_OP3_0_X_RNIV7EV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FIFO.FULL_M_0_2_1_X\,
dataa => N_109,
datab => N_108,
datac => \GRFPC0.FIFO.FULL_M_0_2_0\);
\GRFPC0_OP1_0_IV_4_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_4_X\(6),
dataa => N_633,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.OP1_0_IV_3\(6));
\GRFPC0_D_STDLCK_RNO_2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_0_X\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3871_DEP_0_A3\,
datab => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_23_I_O2\);
\GRFPC0_D_STDLCK_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_0_X\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_5_I_O2_1\,
datab => \GRFPC0.RFA.LD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2\);
\GRFPC0_FP_PIPELINE_RS2_1_X_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => RFI2_RD2ADDRZ(3),
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(4),
datac => \GRFPC0.INST_I\(4));
\GRFPC0_FP_PIPELINE_RS2_1_X_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => RFI2_RD2ADDRZ(0),
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(1),
datac => \GRFPC0.INST_I\(1));
\GRFPC0_FP_PIPELINE_RS2_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => RFI2_RD2ADDRZ(1),
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(2),
datac => \GRFPC0.INST_I\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX_234_0_A4_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_A4_X\(0),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_O2\(0));
GRFPC0_FP_PIPELINE_UN85_HOLDN_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN85_HOLDN_X_I\,
dataa => N_38,
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
GRFPC0_VWR2_RREG_RESV_0_SQMUXA_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111010101110")
port map (
combout => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
dataa => N_38,
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
GRFPC0_FP_PIPELINE_0_IS_LDF_UN5_OP_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP_X\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.LDLOCK19\);
\GRFPC0_STDATA_1_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110001011")
port map (
combout => \GRFPC0.STDATA_1_X\(13),
dataa => \GRFPC0.R.STDATA\(13),
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A3_2\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_I_M2_X_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111001001110")
port map (
combout => CPO_DBG_DATAZ(13),
dataa => N_425,
datab => \GRFPC0.FP_PIPELINE.DBGDATA_4_I_M3_X\(13),
datac => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A3_2\);
\GRFPC0_FP_PIPELINE_WRDATA_6_X_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(18),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(18),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(50));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(21),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(21),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(53));
\GRFPC0_MEMSEL_1_X_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000101")
port map (
combout => \GRFPC0.MEMSEL_1_X\(2),
dataa => N_38,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
\GRFPC0_FP_PIPELINE_RS2_1_X_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => RFI2_RD2ADDRZ(2),
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(3),
datac => \GRFPC0.INST_I\(3));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(27),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(27),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(59));
\GRFPC0_FP_PIPELINE_WRDATA_6_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(15),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(15),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(47));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_X_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_X\(8),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\(8));
GRFPC0_MEM_RREG_RESV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100010011")
port map (
combout => \GRFPC0.MEM.RREG.RESV_0_0_A4_0_G0_0_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VMEM.RREG.RESV_6_IV_I_I_O2_0_O2\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_13\);
GRFPC0_RFA2_RS2SEL_RET_6_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010001010")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G7_0_X\,
dataa => N_38,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\);
\GRFPC0_D_LDLCK_RNO_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1_1_X\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX_0_A5\,
datac => \GRFPC0.D.LDLCK_0_0_13__G1_0\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_I_O5_RNI6DE7_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.CPI_M_1_X\(64),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_0_I_O5_RNI6DE7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.CPI_I_M_1_X\(64),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\);
\GRFPC0_FP_PIPELINE_RS1_6_I_M2_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
GRFPC0_WR2_RREG_RESV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100010011")
port map (
combout => \GRFPC0.WR2.RREG.RESV_0_0_G0_0_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2\,
datac => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2\);
GRFPC0_WR_RREG_RESV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPC0.WR.RREG.RESV_0_0_G0_0_X\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_O2\,
datac => \GRFPC0.WR.RREG.RESV_0_0_G0_0_A\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.D.FLDLCK_M_X\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datab => \GRFPC0.D.FLDLCK_M_0\,
datac => \GRFPC0.D.FLDLCK\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_2_X\(0),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK19\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_2_X\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datab => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_1_X\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK19\);
\GRFPC0_FIFO_VCNT_1_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001111")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0_2__G2_X\,
dataa => N_3,
datab => \GRFPC0.VFIFO.INST_1_1_0\,
datac => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2\);
\GRFPC0_FIFO_VCNT_0_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001111")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0_2__G2_X\,
dataa => N_3,
datab => \GRFPC0.VFIFO.INST_0_1_0\,
datac => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA_2_SUM2\);
GRFPC0_FP_PIPELINE_0_UN1_DEP_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113,
datac => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP_X\);
GRFPC0_EX_CTRL_PEND_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G1_X\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.EX.CTRL.PEND_M_3\,
datac => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_X_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_X\(15),
dataa => N_84,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\(15),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15));
GRFPC0_FIFO_FULL_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1_X\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\(0),
datac => \GRFPC0.FIFO.FULL_0_0_G1_1\);
GRFPC0_FP_PIPELINE_VRFA_RDWR_1_X: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1_X\,
dataa => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP_X\,
datab => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datac => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\);
\GRFPC0_R_FSR_FCC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_0__G0_I_M4_X\,
dataa => N_441,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.FCC_0_0_0__G2\);
\GRFPC0_R_FSR_FCC_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_1__G0_I_M4_X\,
dataa => N_442,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.R.FSR.FCC_0_0_1__G2\);
GRFPC0_DIV_PEND_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_X\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_M5\,
datac => \GRFPC0.DIV.EXC_1_0_G3_0\);
\GRFPC0_R_FSR_FTT_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_2__G0_0_A3_X\,
dataa => N_38,
datab => \GRFPC0.R.FSR.FTT\(2),
datac => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\);
\GRFPC0_D_LDLCK_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1_X\,
dataa => \GRFPC0.D.LDLCK_0_0_13__G1_1_X\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX_120\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0\(1));
\GRFPC0_R_FSR_FTT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_0__G1_X\,
dataa => N_3,
datab => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.FTT_0_0_0__G3\);
\GRFPC0_INST_I_X_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPC0.INST_I_X\(6),
dataa => N_84,
datab => \GRFPC0.INST_I_1\(6),
datac => \GRFPC0.INST_I_M2\(1));
\GRFPC0_D_LDLCK_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_X\,
dataa => \GRFPC0.D.LDLCK_0_0_27__G1_0\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M4\(27),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX_250_X_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_250_X\(0),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_20\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX_248\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datac => \GRFPU0.GRFPU_X0.L4_4_REP1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.L4_4_REP2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
datac => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP1\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
datab => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03_C\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03_C\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03_C\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03_C\,
dataa => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03_C\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03_C\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03_C\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M17_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M17_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M19_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M19_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_34_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_34_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_35_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_35_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_36_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_36_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100110101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_25_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_25_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_26_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_26_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_29_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_29_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_31_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_31_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_34_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_34_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_35_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_35_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_36_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_36_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_0_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_2_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100101010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110110100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03_C\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_4_03_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03_C\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\);
\GRFPC0_D_LDLCK_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(0),
datac => \GRFPC0.D.LDLCK_0_0_26__G3\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX_251\(0));
GRFPC0_FP_PIPELINE_DEPMUX_RES_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES_U\,
dataa => \GRFPC0.INST\(25),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17\(1),
datad => \GRFPC0.FP_PIPELINE.IS_RDD.TMP\);
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN20_FLOP\,
datab => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I\,
datad => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_A3\);
\GRFPC0_D_LDLCK_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1),
datac => \GRFPC0.D.LDLCK_0_0_29__G1_0\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX_269\(1));
\GRFPC0_D_LDLCK_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3\(1),
datab => \GRFPC0.D.LDLCK_0_0_11__G3_0_11\,
datac => \GRFPC0.D.LDLCK_0_0_11__G1_0_M3\);
\GRFPC0_D_LDLCK_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101110011")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I\(1),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(1),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_161\(1));
GRFPC0_RFA2_RS2DEP_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111010101010")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G0\,
dataa => \GRFPC0.REGDEP_0_SQMUXA_2\,
datab => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_TZ\,
datac => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_2\,
datad => \GRFPC0.RFA2.RS2DEP_0_0_G1_2\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_17_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17\(1),
dataa => \GRFPC0.INST\(29),
datab => \GRFPC0.INST\(28),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17_D\(1));
\GRFPC0_D_LDLCK_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_0_M3\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_14\(1),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX_102\(1),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX_106\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX_251_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_251\(0),
dataa => N_82,
datab => N_80,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_19_1\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX_250_X\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_17_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17\(0),
dataa => \GRFPC0.INST\(29),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0\,
dataa => \GRFPU0.GRFPU_X0.UN2_FLOP_19\,
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6\,
datac => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_4\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0_1\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G0\,
dataa => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6\,
datab => \GRFPU0.GRFPU_X0.UN1_FLTYPE_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0_1\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_7__G0\,
dataa => \GRFPU0.GRFPU_X0.UN2_FLOP_19\,
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6\,
datac => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_4\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0_1\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_16_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16\(0),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.INST\(27),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I\,
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16_D\(0));
\GRFPC0_D_LDLCK_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(0),
datac => \GRFPC0.D.LDLCK_0_0_16__G1_0\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_161\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_17_D_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_17_D\(1),
dataa => \GRFPC0.INST\(29),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_15\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_161_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_161\(1),
dataa => N_78,
datab => N_84,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_160\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX_269_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_269\(1),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_18\(1),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_17\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX_266\(1));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP_RNIE7023: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29),
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPC0.V.STDATA_14_REP1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.UN1_SGNF_1_SQMUXA_5\(0));
GRFPC0_RFA2_RS2DEP_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_2\,
dataa => \GRFPC0.UN1_REGDEP161\,
datab => \GRFPC0.UN1_REGDEP173\,
datac => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_0\);
GRFPC0_RFA2_RS2DEP_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110101")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2\,
dataa => \GRFPC0.UN1_REGDEP173\,
datab => \GRFPC0.UN1_REGDEP147_0\,
datac => \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A1\,
datad => \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A0_0\);
\GRFPC0_R_FSR_CEXC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
dataa => \GRFPC0.R.FSR.CEXC\(4),
datab => \GRFPC0.WR2.RREG.RES_M\(4),
datac => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\);
\GRFPC0_R_FSR_CEXC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
dataa => \GRFPC0.R.FSR.CEXC\(3),
datab => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datac => \GRFPC0.R.FSR.CEXC_0_0_3__G1_5\);
\GRFPC0_R_FSR_CEXC_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
dataa => \GRFPC0.R.FSR.CEXC\(2),
datab => \GRFPC0.WR2.RREG.RES_M\(2),
datac => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\);
\GRFPC0_R_FSR_CEXC_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
dataa => \GRFPC0.R.FSR.CEXC\(1),
datab => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datac => \GRFPC0.R.FSR.CEXC_0_0_1__G1_5\);
\GRFPC0_R_FSR_CEXC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
dataa => \GRFPC0.R.FSR.CEXC\(0),
datab => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datac => \GRFPC0.R.FSR.CEXC_0_0_0__G1_5\);
\GRFPC0_D_STLCK_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_1_0_X\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O2_5_0\(0),
datac => \GRFPC0.D.STLCK_0_0_14__G1_4\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_M2\(0));
\GRFPC0_D_STLCK_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001101")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_3_1_M5_I\,
datab => D_M4_4,
datac => R_M2_2,
datad => \GRFPC0.D.STLCK_0_0_15__G1_5\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_4__G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_FLTYPE45\,
datab => \GRFPU0.GRFPU_X0.FLTYPE_5_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.UN1_FLTYPE_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\);
GRFPC0_D_FSTLCK_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1\,
dataa => \GRFPC0.D.FSTLCK_0_0_G1_15\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VD.FLDLCK_1_828\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_14\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20002_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_5\(0),
datac => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1\,
datad => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_A\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2\(0));
\GRFPC0_FPR_ALLOW_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPC0.FPRIN.ALLOW_0_0__G0_1\,
dataa => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
datab => \GRFPC0.DIV.EXEC_0_0_G0_X\,
datac => \GRFPC0.DIV.VALID_0_0_G0_X\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_16_D_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_16_D\(0),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_13\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX_106_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_106\(1),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_0_X\(1),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_1_X\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX_104\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_160_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_160\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A5\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(9),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_158\(1));
GRFPC0_RFA2_RS1DEP_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111010101010")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0\,
dataa => \GRFPC0.REGDEP_0_SQMUXA_1\,
datab => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_TZ\,
datac => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_1\,
datad => \GRFPC0.RFA2.RS1DEP_0_0_G1_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_A2_RNIU9AB4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_FLTYPE45\,
datac => \GRFPU0.GRFPU_X0.FLTYPE_5_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45_RNIFFM21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001110")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\,
datac => \GRFPU0.GRFPU_X0.FLTYPE_5_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_15\(1),
dataa => \GRFPC0.INST\(27),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_13\(1));
GRFPU0_GRFPU_X0_ST2_REG_RET_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_REST_9\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_RNIKE8V1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_A3\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\,
datac => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_7211_M\);
\GRFPC0_D_STLCK_RNO_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_5\,
dataa => D_M3_0_A2,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I\,
datac => \GRFPC0.D.STLCK_0_0_15__G1_4\,
datad => R_M2);
\GRFPC0_R_FSR_CEXC_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_5\,
dataa => \GRFPC0.DIV.EXCT\(0),
datab => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datac => \GRFPC0.R.FSR.CEXC_0_0_0__G1_5_A\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(0));
\GRFPC0_R_FSR_CEXC_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000011")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_5_A\,
dataa => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(0),
datac => \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_5\,
dataa => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\,
datad => \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\);
\GRFPC0_R_FSR_CEXC_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_5\,
dataa => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.R.FSR.CEXC_0_0_1__G1_2\,
datad => \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\);
\GRFPC0_D_LDLCK_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1\,
dataa => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_0\,
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4\(0),
datac => \GRFPC0.D.LDLCK_0_0_30__G3\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465\(0));
\GRFPC0_D_LDLCK_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(25),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0\(1));
\GRFPC0_D_LDLCK_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1\,
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5\(0),
datac => \GRFPC0.D.LDLCK_0_0_2__G3\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(0));
GRFPU0_GRFPU_X0_ST1_OP1NX_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datac => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0_A\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\);
GRFPU0_GRFPU_X0_ST1_OP1NX_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0_A\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(54),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_2\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4));
\GRFPC0_D_STLCK_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_2\(1),
datac => \GRFPC0.D.STLCK_0_0_3__G1_2\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_1\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19861_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datab => \GRFPU0.GRFPU_X0.N_19861_I_0_G0_1\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G3\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\);
\GRFPC0_D_STDLCK_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1\,
dataa => \GRFPC0.D.STDLCK_0_0_4__G1_3_0\,
datab => \GRFPC0.D.STDLCK_0_0_4__G1_3\,
datac => \GRFPC0.D.STDLCK_0_0_4__G1_4\,
datad => \GRFPC0.STDDEP_0_SQMUXA_182\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN28_DP_5_RNI44PE1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_5\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_6\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6_A\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_17_RNI5E1C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G6_A\,
dataa => \GRFPC0.OP2\(54),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_16\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\);
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2\,
dataa => \GRFPC0.OP2\(51),
datab => \GRFPU0.GRFPU_X0.EXP_1_SQMUXA_I\,
datac => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0\,
datad => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10\);
\GRFPC0_D_STLCK_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
datab => \GRFPC0.D.STLCK_0_0_21__G1_3\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5\(1),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_2\(1));
\GRFPC0_FPRIN_ALLOW_0_0__G5\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
datab => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76\,
datad => \GRFPC0.FPRIN.ALLOW_0_0__G5_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_A2_RNIEJEN4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I_O2_0_RNIF4EF2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4),
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_O2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_RNISS2E1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7211_M\,
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\,
datac => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_0_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV\(1),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1\(1),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW_1_SQMUXA_INV_0\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9\(1),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_3\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_4\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_9_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100100111011")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9_A\(1),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.INST\(27),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_7\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_161_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110110000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_161\(0),
dataa => N_84,
datab => N_78,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_160\(0));
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_SGNF_1_SQMUXA_5\(0),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_13_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_13\(1),
dataa => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I\,
dataa => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G3\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I_O3\);
\GRFPC0_D_LDLCK_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX_143\(0),
datad => \GRFPC0.D.LDLCK_0_0_14__G3_0\);
\GRFPC0_FP_PIPELINE_13_REGDEPX_248_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_248\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14\(1),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1),
datab => \GRFPC0.D.LDLCK_0_0_29__G1_0\,
datac => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_9_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9\(0),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_7\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_9_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001101100111")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_9_A\(0),
dataa => \GRFPC0.INST\(28),
datab => \GRFPC0.INST\(27),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_3\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_4\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G3\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(63),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(63));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_13_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_13\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I\(0),
datab => \GRFPC0.D.LDLCK_0_0_26__G3\,
datac => \GRFPC0.INST\(26));
GRFPC0_RFA2_RS1DEP_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_1\,
datab => \GRFPC0.REGDEP_1_SQMUXA_1\,
datac => \GRFPC0.RFA2.RS1DEP_0_0_G1_1_S\);
\GRFPC0_D_STLCK_RNO_6_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_4\,
dataa => \GRFPC0.D.STLCK_0_0_15__G1_1\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_1\(1),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_2\(0));
\GRFPC0_D_STLCK_RNO_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111100")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_4\,
dataa => N_103,
datab => \GRFPC0.D.STLCK_0_0_14__G1_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_X\);
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_0_IV_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1_A\(1),
datad => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_0_IV_1_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011111011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV_1_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_78\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_77\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datac => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_0\,
datad => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1_A\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101001111")
port map (
combout => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_1_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\,
datad => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O2_0\);
\GRFPC0_R_FSR_CEXC_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datab => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datac => \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\,
datad => \GRFPC0.DIV.EXCT_M\(4));
\GRFPC0_R_FSR_CEXC_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datab => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datac => \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\,
datad => \GRFPC0.DIV.EXCT_M\(2));
\GRFPC0_D_STLCK_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5\,
dataa => \GRFPC0.D.STLCK_0_0_29__G1_5_7\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_580_0\(1),
datac => \GRFPC0.D.STLCK_0_0_29__G1_5_S\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011011100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_7\(1),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_374\(1));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I_0\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4));
\GRFPC0_D_STLCK_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110111111100")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1\,
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
datab => \GRFPC0.D.STLCK_0_0_17__G1_4\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0\(1),
datad => \GRFPC0.D.STLCK_0_0_17__G1_A\);
\GRFPC0_D_STLCK_RNO_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000110011000")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_A\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19862_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_2\(4),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_A2\(8),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4),
datad => \GRFPU0.GRFPU_X0.N_19862_I_0_G0_0\);
\GRFPC0_D_STLCK_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1\,
dataa => \GRFPC0.D.STLCK_0_0_18__G1_5\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_390_0_IV_I_A5\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_3_RNI5KBH3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3\(1),
datac => \GRFPC0.D.LDLCK_0_0_29__G1_0_3\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_160_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_160\(0),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A5\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_158\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX_158_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_158\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(1));
GRFPC0_UN1_REGDEP173: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010011111111")
port map (
combout => \GRFPC0.UN1_REGDEP173\,
dataa => \GRFPC0.EX.CTRL.RDD_0_0_G1_0\,
datab => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD\,
datac => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP172\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_RNIF8PK3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110110101000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G3\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_3\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX_266_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_266\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_14\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX_104_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_104\(1),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.CPI_I_M_1_X\(64),
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX_102\(1));
GRFPU0_GRFPU_X0_UN1_FLTYPE_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_FLTYPE_0_SQMUXA\,
dataa => \GRFPC0.OP2\(54),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\,
datad => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_4\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPC0.V.STDATA_14_REP1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\);
GRFPU0_GRFPU_X0_COMB_UN5_FLOP_RNI6IQV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPU0.GRFPU_X0.COMB.UN5_FLOP\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000111010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_A\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011100100111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_A\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111101100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(5),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(5));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110010101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_4__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\,
datad => \GRFPU0.GRFPU_X0.N_58_I_I\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datab => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0_A4_0_1\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G1_1\);
GRFPC0_D_FSTLCK_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_14\,
dataa => \GRFPC0.FP_PIPELINE.FIFOV2\,
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.D.FSTLCK_0_0_G1_14_A\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_D_FSTLCK_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000001")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_14_A\,
dataa => \GRFPC0.VRFA.SEQERR_5_SQMUXA_1\,
datab => \GRFPC0.D.FSTLCK_0_0_G1_8\,
datac => \GRFPC0.D.FSTLCK_0_0_G1_9\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\);
\GRFPC0_R_FSR_CEXC_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(3),
datab => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(3));
\GRFPC0_R_FSR_CEXC_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
datab => \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\,
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(1));
\GRFPC0_R_FSR_CEXC_RNO_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\,
dataa => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\,
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_4__G1_1\);
\GRFPC0_R_FSR_CEXC_RNO_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\,
dataa => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\,
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPU0.GRFPU_X0.N_19862_I_0_G0_0\,
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.OP1_0_IV\(54),
datac => \GRFPC0.OP1_0_IV\(51),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_1\(4));
\GRFPC0_D_STLCK_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110001")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datac => \GRFPC0.D.STLCK_0_0_13__G1_3\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1\(1));
\GRFPC0_D_STLCK_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1\,
dataa => \GRFPC0.D.STLCK_0_0_5__G1_3\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_4\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\(1));
\GRFPC0_D_LDLCK_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_28__G3\,
datab => \GRFPC0.D.LDLCK_0_0_28__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(0));
\GRFPC0_D_LDLCK_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_20__G1_0\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(20),
datac => \GRFPC0.D.LDLCK_0_0_20__G3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I\(0));
\GRFPC0_FIFO_VCNT_0_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001010")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I\,
dataa => N_3,
datab => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\,
datac => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I_X2\,
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_A4_0\);
\GRFPC0_FIFO_VCNT_0_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100000")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I\,
dataa => N_3,
datab => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\,
datac => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_M4\,
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_A4_0\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\);
\GRFPC0_R_FSR_FTT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
dataa => N_3,
datab => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
datac => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datad => \GRFPC0.R.FSR.FTT_0_0_1__G1_0\);
GRFPC0_D_FLDLCK_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1\,
dataa => \GRFPC0.D.FLDLCK_0_0_G1_1_0\,
datab => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1_X\,
datac => \GRFPC0.FP_PIPELINE.VD.FLDLCK_1_828\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_D_STDLCK_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_0_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0\,
datad => \GRFPC0.D.STDLCK_0_0_9__G1_6\);
\GRFPC0_D_STDLCK_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1\,
dataa => \GRFPC0.N_19067_1_I_I_A2_I_O2\,
datab => \GRFPC0.D.STDLCK_0_0_0__G1_6\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111\);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010011")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1_M5_I_A3\,
datac => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_D_STLCK_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_5\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_4_1\(1),
datad => \GRFPC0.D.STLCK_0_0_23__G1_3\);
\GRFPC0_D_LDLCK_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1\,
dataa => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datab => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2\,
datac => \GRFPC0.D.LDLCK_0_0_5__G1_4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(1));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNI9HUN2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2\,
dataa => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_1\,
datab => \GRFPC0.RFA.LD_0_0_G1_0_A2_2_0_X\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\,
datad => CPO_EXCZ);
\GRFPC0_D_LDLCK_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4\(15),
datac => \GRFPC0.D.LDLCK_0_0_15__G1_4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I\(1));
\GRFPC0_D_STDLCK_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_4\,
datab => \GRFPC0.D.STDLCK_0_0_13__G1_7\,
datac => \GRFPC0.UN1_STDDEP_0_SQMUXA_107\,
datad => \GRFPC0.D.STDLCK_0_0_13__G1_A\);
\GRFPC0_D_STDLCK_RNO_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011101110111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.STDEP_2_SQMUXA_131_0_A2\);
\GRFPC0_FIFO_VCNT_1_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100000")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I\,
dataa => N_3,
datab => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\,
datac => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_M4\,
datad => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_A4_0\);
\GRFPC0_FIFO_VCNT_1_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001010")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I\,
dataa => N_3,
datab => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\,
datac => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_X2\,
datad => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_A4_0\);
GRFPU0_GRFPU_X0_UN1_VALLOW_2_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4_A\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datad => \GRFPU0.GRFPU_X0.N_4415_M\);
GRFPU0_GRFPU_X0_UN1_VALLOW_2_SQMUXA_4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_77\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_78\,
datad => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6_0\);
GRFPC0_WR2_CTRL_STDFQ_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2\,
dataa => \GRFPC0.WR.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2_0\,
datac => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A3\);
\GRFPC0_D_LDLCK_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0\(0),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX_53\(0),
datad => \GRFPC0.D.LDLCK_0_0_4__G1_0\);
\GRFPC0_INST_I_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111110001")
port map (
combout => \GRFPC0.INST_I_1\(6),
dataa => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.INST_I_0_6_M3\,
datad => R_M2_1);
GRFPC0_RFA2_RS2DEP_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011111")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_TZ\,
dataa => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_3\,
datab => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_A3\,
datac => \GRFPC0.UN1_REGDEP119\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_12_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2\,
datab => \GRFPC0.INST\(27),
datac => \GRFPC0.INST\(26),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_D\(1));
\GRFPC0_D_LDLCK_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_0\(12),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2\(12),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX_143_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_143\(0),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_5_X\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_16\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_140\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110001011")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_7\(0),
dataa => \GRFPC0.D.LDLCK_0_0_14__G3_0\,
datab => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I_O3\,
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPC0.OP1_0_IV\(52),
datac => \GRFPC0.OP1_0_IV\(53),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\);
\GRFPC0_D_LDLCK_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G3\,
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_35\(0));
\GRFPC0_D_LDLCK_RNO_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G3\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_10\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX_286\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(1),
datab => \GRFPC0.INST\(26),
datac => \GRFPC0.D.LDLCK_0_0_7__G3_0\);
GRFPC0_V_FSR_CEXC_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010001000")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2_A\);
GRFPC0_V_FSR_CEXC_0_SQMUXA_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001111")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2_A\,
dataa => \GRFPC0.WR2.CTRL.AFSR\,
datab => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
datad => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1\);
GRFPC0_REGDEP_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000001100000")
port map (
combout => \GRFPC0.REGDEP_0_SQMUXA_2\,
dataa => \GRFPC0.EX.CTRL.RDD_0_0_G1_0\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP172\);
\GRFPC0_R_FSR_FTT_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010100000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_0__G3\,
dataa => N_3,
datab => \GRFPC0.R.FSR.FTT\(0),
datac => \GRFPC0.R.FSR.FTT_0_0_0__G3_A\,
datad => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\);
\GRFPC0_R_FSR_FTT_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_0__G3_A\,
dataa => \GRFPC0.DIV.EXCT\(5),
datab => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110110000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_A\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_A\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\(0));
\GRFPC0_R_FSR_FTT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_2__G0_0\,
dataa => N_38,
datab => N_3,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.FSR.FTT_0_0_2__G0_0_A3_X\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_RNISFQL_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G3\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(51),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2\(4));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN28_DP_5_RNIM0RQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_5\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_6\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_M4_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M4\(27),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX_246_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(0),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(0),
datad => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(0));
GRFPC0_DIV_EXC_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPC0.DIV.EXC_1_0_G0_I\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.DIV.EXC_1_0_G0_I_O4\,
datad => \GRFPC0.DIV.EXC_1_0_G3\);
GRFPC0_REGDEP_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000001100000")
port map (
combout => \GRFPC0.REGDEP_0_SQMUXA_1\,
dataa => \GRFPC0.EX.CTRL.RDD_0_0_G1_0\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\,
datac => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(45));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001011001111")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12\(0),
dataa => \GRFPC0.D.LDLCK_0_0_16__G1_0\,
datab => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_12_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_A\(0),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5\(22),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1\,
datac => \GRFPC0.INST\(27),
datad => \GRFPC0.INST\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(34),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_53_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(4),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5));
\GRFPC0_D_STLCK_RNO_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_2\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_A2_1_I\(0),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_M2_0\(1));
\GRFPC0_FPRIN_ALLOW_0_0__G5_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPC0.FPRIN.ALLOW_0_0__G5_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.N_4415_M\,
datad => \GRFPU0.GRFPU_X0.N_4171_I_M\);
\GRFPC0_R_FSR_CEXC_RNO_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\,
dataa => \GRFPC0.R.FSR.TEM\(0),
datab => \GRFPC0.WR2.RREG.EXCT\(0),
datac => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
datad => \GRFPC0.V.FSR.CEXC_2_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_1\,
dataa => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.WR2.RREG.EXCT\(4),
datac => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
datad => \GRFPC0.V.FSR.CEXC_2_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\,
dataa => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.WR2.RREG.EXCT\(2),
datac => \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\,
datad => \GRFPC0.V.FSR.CEXC_2_SQMUXA\);
\GRFPC0_R_FSR_FTT_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110001011111")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_1__G1_0\,
dataa => N_3,
datab => \GRFPC0.R.FSR.FTT\(1),
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G1_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\,
datad => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O2_0\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_42\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_41\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_43\);
\GRFPC0_D_STDLCK_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1\,
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datac => \GRFPC0.D.STDLCK_0_0_7__G1_8\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_0\);
\GRFPC0_D_LDLCK_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3\(7),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\(1),
datac => \GRFPC0.D.LDLCK_0_0_7__G1_5\,
datad => \GRFPC0.D.LDLCK_0_0_7__G3_0\);
\GRFPC0_D_LDLCK_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_10__G1_1\,
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX_102\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_12\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_11\(0));
\GRFPC0_D_LDLCK_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(31),
datac => \GRFPC0.D.LDLCK_0_0_31__G1_2\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1));
\GRFPC0_D_STDLCK_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_8\,
datac => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\);
\GRFPC0_D_STLCK_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1\,
dataa => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1),
datab => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_2_1_0\(1),
datac => \GRFPC0.D.STLCK_0_0_9__G1_5\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A3_4\(1));
\GRFPC0_D_LDLCK_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1\,
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_0\(1),
datab => \GRFPC0.D.LDLCK_0_0_3__G1_3\,
datac => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_24\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0\(1));
\GRFPC0_D_STLCK_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1\,
dataa => \GRFPC0.D.STLCK_0_0_31__G1_4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_129_I_I_A2_I_O4\,
datad => \GRFPC0.D.STLCK_0_0_31__G1_A\);
\GRFPC0_D_STLCK_RNO_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011111011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_5\(1),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_3\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datab => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_D_STLCK_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1\,
dataa => \GRFPC0.D.STLCK_0_0_27__G1_2\,
datab => \GRFPC0.FP_PIPELINE.13.0.STDEP_545\(1),
datac => \GRFPC0.FP_PIPELINE.13.STDEP_540_0\(1),
datad => \GRFPC0.FP_PIPELINE.13.STDEP_536_3\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(54),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1_1\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_3\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\(42));
GRFPU0_GRFPU_X0_ST3_RDY_RNIA3IS2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101110011")
port map (
combout => \GRFPU0.GRFPU_X0.N_58_I_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\,
datac => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O2_0\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0_A4_0_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0\(53),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_2\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_O2\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_2\(53));
\GRFPC0_D_STLCK_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datab => \GRFPC0.D.STLCK_0_0_28__G1_4\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I\(0),
datad => \GRFPC0.D.STLCK_0_0_28__G1_A\);
\GRFPC0_D_STLCK_RNO_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_A\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_4\(0),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_O2_4_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_12\(0));
\GRFPC0_INST_I_1_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111001")
port map (
combout => R_M2_1,
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
GRFPC0_VFIFO_PC_0_1_SQMUXA_0_A2_M1_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\,
dataa => \GRFPC0.FIFO.FULL_M_0\,
datab => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_1\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
GRFPC0_VFIFO_INST_1_1_SQMUXA_M1_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
dataa => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
GRFPC0_RFA2_RS1DEP_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100000010")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_TZ\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datab => \GRFPC0.REGDEP_1_SQMUXA_3\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2\,
datad => \GRFPC0.RFA2.RS1DEP_0_0_G1_2594_TZ\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_12_D_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001001110010")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_12_D\(1),
dataa => \GRFPC0.INST\(27),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_10\(1));
\GRFPC0_D_STDLCK_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_4__G1_3_TZ\,
datab => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_35_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110110000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_35\(0),
dataa => N_84,
datab => N_78,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_34\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_374_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_374\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_373\(1));
\GRFPC0_D_STLCK_RNO_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101110111010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_1\(1),
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_X\(1),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0\(1),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\(1),
datac => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(1),
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.DEP\(1),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150\(1),
datad => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_154\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_158_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_158\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX_264_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001110010")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(0),
dataa => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX_264_A\(0),
datac => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(0),
datad => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX_264_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_264_A\(0),
dataa => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_1\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_463\(0));
\GRFPC0_FP_PIPELINE_WREN_1_F0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011011111")
port map (
combout => RFI2_WRENZ,
dataa => N_423,
datab => N_426,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_7\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0\(1),
datac => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_14_REGDEPX_264_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(1),
datad => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_263\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_102\(1),
dataa => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96\(1),
datad => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_100\(1));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_A2_1\,
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.OP1_0_IV\(31),
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_1\(4),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(31),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2\(4),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2\);
\GRFPC0_FP_PIPELINE_WREN_1_F0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001111111")
port map (
combout => RFI1_WRENZ,
dataa => N_423,
datab => N_426,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WREN_17_IV\(0));
GRFPU0_GRFPU_X0_UN2_FLOP_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_FLOP_19\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPC0.V.STDATA_14\(5),
datac => \GRFPC0.V.STDATA_14_REP2\(6),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\);
GRFPU0_GRFPU_X0_SGNF_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_1_SQMUXA_1\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPU0.GRFPU_X0.COMB.UN5_FLOP\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => CPO_LDLOCKZ,
dataa => \GRFPC0.FIFO.FULL_M_0_2_1_X\,
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(1),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_1\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_62_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110101110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
dataa => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
datab => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_37\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53\(18));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(0),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.DIVROM0.DATA_1_MUX_15\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(53));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110110011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G6\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2\(1));
\GRFPC0_FIFO_VCNT_1_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111111110001")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_X2\,
dataa => \GRFPC0.FIFO.VCNT_1\(1),
datab => \GRFPC0.FIFO.VCNT_1\(2),
datac => \GRFPC0.FIFO.VCNT_1\(0),
datad => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\);
\GRFPC0_FIFO_VCNT_1_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010100100")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_M4\,
dataa => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_1\(2),
datac => \GRFPC0.FIFO.VCNT_1\(1),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\);
\GRFPC0_FIFO_VCNT_0_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111111110001")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I_X2\,
dataa => \GRFPC0.FIFO.VCNT_0\(1),
datab => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.VCNT_0\(0),
datad => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\);
\GRFPC0_FIFO_VCNT_0_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010100100")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_M4\,
dataa => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.VCNT_0\(1),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(3),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(3));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_1_I_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010101110101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_O2\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(31),
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(63),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2\(63),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.L3_0\(5),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_13_C4\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(46));
\GRFPC0_D_STLCK_RNO_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_3\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datac => \GRFPC0.D.STLCK_0_0_21__G1_2\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11\(1));
\GRFPC0_D_STDLCK_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_6\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datab => \GRFPC0.D.STDLCK_0_0_9__G1_4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_6\);
\GRFPC0_D_STLCK_RNO_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_4\,
dataa => \GRFPC0.D.STLCK_0_0_28__G1_3\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_2586\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_580_0_O2\(1));
GRFPC0_RFA2_RS1DEP_RNO_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_4\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_2\,
datad => \GRFPC0.UN1_REGDEP63_D\);
\GRFPC0_D_STLCK_RNO_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5_7\,
dataa => \GRFPC0.D.STLCK_0_0_29__G1_5_7_A\,
datab => \GRFPC0.D.STLCK_0_0_29__G1_5_4\,
datac => \GRFPC0.D.STLCK_0_0_29__G1_A3\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1\(1));
\GRFPC0_D_STLCK_RNO_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5_7_A\,
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1));
\GRFPC0_D_STLCK_RNO_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100011")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_3\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6\(1));
\GRFPC0_D_STLCK_RNO_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_1\(12),
datac => \GRFPC0.D.STLCK_0_0_18__G1_2\,
datad => \GRFPC0.D.STLCK_0_0_18__G1_5_A\);
\GRFPC0_D_STLCK_RNO_2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011111001111")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_5_A\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A5_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_RFA2_RS1SEL_RET_17_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FPUSEL_6_0_6__G0_3_0\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.UN1_WRENX2_2_3\,
datac => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(42),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A2_0\(42));
\GRFPC0_D_STDLCK_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_8\,
dataa => \GRFPC0.D.STDLCK_0_0_7__G1_5\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_8\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_X\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_3\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(53));
\GRFPC0_D_LDLCK_RNO_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(15),
datab => \GRFPC0.D.LDLCK_0_0_15__G1_2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(15));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_7\(1),
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A0_1\(1));
\GRFPC0_D_STLCK_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0),
datac => \GRFPC0.D.STLCK_0_0_7__G1_6_6\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6\(1));
GRFPC0_FP_PIPELINE_2_REGDEPX2_85_1_M9_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_1\,
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_0\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A0\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_98_RNINMBG8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_0_8\,
datac => \GRFPC0.D.LDLCK_0_0_7__G3_A3\,
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_98\(1));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3\,
dataa => \GRFPC0.LDLOCK_1_M\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_1\,
datac => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0\(1),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_2_0\(1),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(1));
\GRFPC0_D_LDLCK_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1\,
dataa => \GRFPC0.N_23889\,
datab => \GRFPC0.D.LDLCK_0_0_22__G1_4\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5\(22),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5\(22));
\GRFPC0_D_STDLCK_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datab => \GRFPC0.D.STDLCK_0_0_1__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_10_X\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_M2\);
\GRFPC0_D_STDLCK_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1\,
dataa => \GRFPC0.D.STDLCK_0_0_2__G1_2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4\);
\GRFPC0_D_LDLCK_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_1\(0),
datab => \GRFPC0.D.LDLCK_0_0_6__G1_3\,
datac => \GRFPC0.N_25311\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0\(0));
\GRFPC0_D_LDLCK_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_9__G1_4\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A2_1\(1),
datac => \GRFPC0.D.LDLCK_0_0_9__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_5\(1),
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_0\(1),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_2\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1\(1));
\GRFPC0_D_STDLCK_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_2_0\,
datab => \GRFPC0.D.STDLCK_0_0_3__G1_6\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2\);
\GRFPC0_D_STLCK_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_1\(0),
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN1988_DEP\,
datac => \GRFPC0.D.STLCK_0_0_12__G1_6\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
\GRFPC0_D_STLCK_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1\,
dataa => \GRFPC0.D.STLCK_0_0_25__G1_2\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_0\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A2_0\(1),
datad => \GRFPC0.D.STLCK_0_0_25__G1_5\);
\GRFPC0_D_STDLCK_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1\,
dataa => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datab => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
datac => \GRFPC0.UN1_STDDEP_0_SQMUXA_108_I_M2\,
datad => \GRFPC0.D.STDLCK_0_0_15__G1_5\);
GRFPC0_EX_CTRL_SEQERR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2\,
dataa => \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2_0\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_0\(1),
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_1\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_8\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101100010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0\(1));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111000101110")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
\GRFPC0_D_LDLCK_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_O3_0\(1),
datac => \GRFPC0.D.LDLCK_0_0_1__G1_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_10\(1),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2\(1),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1\(1));
\GRFPC0_D_LDLCK_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_I_I_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_8__G1_5\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A2_0_0_I\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_12\(0));
\GRFPC0_D_STLCK_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110100")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datac => \GRFPC0.D.STLCK_0_0_19__G1_6\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_M2_0\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_6\);
\GRFPC0_D_STLCK_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1\,
dataa => \GRFPC0.D.STLCK_0_0_26__G1_2\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_550_0_IV_TZ\(0),
datac => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_0_IV_I_A2\(0),
datad => \GRFPC0.FP_PIPELINE.13.STDEP_536_3\(0));
\GRFPC0_D_STLCK_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.D.STLCK_0_0_8__G1_4\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_172_3\(0),
datad => \GRFPC0.D.STLCK_0_0_8__G1_A\);
\GRFPC0_D_STLCK_RNO_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101000111")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL1_I_0_A2_I_O4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_3\(0));
\GRFPC0_D_STLCK_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110100")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_6_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datac => \GRFPC0.D.STLCK_0_0_1__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7\(1));
\GRFPC0_D_STLCK_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1\,
dataa => \GRFPC0.D.STLCK_0_0_0__G1_3\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_137_I_I_A2_I_O2\,
datad => \GRFPC0.D.STLCK_0_0_0__G1_A\);
\GRFPC0_D_STLCK_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001111011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.N_19067_1_I_I_A2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3\(0));
GRFPC0_FP_PIPELINE_VDIV_EXEC_7_F0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000110000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F1\,
datad => \GRFPC0.VDIV.VALID_0_SQMUXA\);
GRFPC0_DIV_PEND_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010111111111")
port map (
combout => \GRFPC0.DIV.PEND_1_0_G0_I_O4\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\,
datac => \GRFPC0.VDIV.PEND_0_SQMUXA\,
datad => \GRFPC0.VDIV.EXC_2_SQMUXA\);
\GRFPC0_D_LDLCK_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_24__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_24__G1_1\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I\(0));
GRFPC0_WR2_CTRL_STDFQ_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A3\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\);
\GRFPC0_D_STLCK_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1\,
dataa => \GRFPC0.D.STLCK_0_0_22__G1_5_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_0\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2\(0));
GRFPC0_EX_CTRL_AFSR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_1698_A2\,
dataa => \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_A2_0_0\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\);
\GRFPC0_D_STLCK_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1\,
dataa => \GRFPC0.D.STLCK_0_0_4__G1_5\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_3\(0));
\GRFPC0_D_STLCK_RNO_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5\(1),
dataa => N_241,
datab => \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_7\(1),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5_A\(1));
\GRFPC0_D_STLCK_RNO_4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_5_A\(1),
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11\(1));
\GRFPC0_D_LDLCK_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1\,
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_7\(1),
datab => \GRFPC0.D.LDLCK_0_0_21__G1_4\,
datac => \GRFPC0.D.LDLCK_0_0_21__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\(1));
\GRFPC0_FP_PIPELINE_REN1_1_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110100010")
port map (
combout => RFI1_REN1Z,
dataa => N_423,
datab => N_424,
datac => N_425,
datad => \GRFPC0.FP_PIPELINE.REN1_1_IV_A\(1));
\GRFPC0_FP_PIPELINE_REN1_1_IV_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111000001100")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_1_IV_A\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datab => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
datac => \GRFPC0.FP_PIPELINE.REN1_2_I_M_0\(1),
datad => \GRFPC0.FP_PIPELINE.REN1_4\(1));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_4\(0),
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_3\(0),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_5\(0),
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2_1\(0));
\GRFPC0_FP_PIPELINE_REN1_1_IV_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000111")
port map (
combout => RFI2_REN1Z,
dataa => N_423,
datab => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datac => \GRFPC0.FP_PIPELINE.REN1_2_I_M\(2),
datad => \GRFPC0.FP_PIPELINE.REN1_1_IV_A\(2));
\GRFPC0_FP_PIPELINE_REN1_1_IV_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100110011")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_1_IV_A\(2),
dataa => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datab => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
datac => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP_0\,
datad => \GRFPC0.FP_PIPELINE.UN22_REN1\);
GRFPC0_RFA_SEQERR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A2\,
dataa => \GRFPC0.RFA.ST_0_0_G1_0_1622_A3_0_X\,
datab => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_O2\,
datac => CPO_LDLOCKZ,
datad => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_1\);
GRFPU0_GRFPU_X0_ITER_LOB_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1\,
dataa => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.LOB2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_1\,
datad => \GRFPU0.GRFPU_X0.VITER.LOB_1_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4\(15),
dataa => N_78,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2503_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4_1\(15));
\GRFPC0_D_STLCK_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.D.STLCK_0_0_10__G1_4\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_212_3\(0),
datad => \GRFPC0.D.STLCK_0_0_10__G1_A\);
\GRFPC0_D_STLCK_RNO_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000011101")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_212_3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_9\(0),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_1\(0));
\GRFPC0_D_STLCK_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1\,
dataa => \GRFPC0.FP_PIPELINE.8.0.STDEP_345_0_IV_TZ\(0),
datab => \GRFPC0.D.STLCK_0_0_16__G1_2\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_340_0_IV_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I\(0));
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_0_M6_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010100110011")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I\,
dataa => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I_A\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0\(0),
datad => \GRFPC0.INST\(26));
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_0_M6_I_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_0_M6_I_A\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14TT_0_M3_0_A2\,
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_0\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4\(0));
GRFPC0_RFA_RDD_RNIC67K8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0\,
dataa => N_38,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0\,
datad => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_A3\);
GRFPC0_FP_PIPELINE_VRFA_ST_1_SN_M1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_X\,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_1\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\);
\GRFPC0_D_STLCK_RNO_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101101001111")
port map (
combout => R_M2_2,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_288_1\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292_1\(1));
GRFPC0_DIV_EXC_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.DIV.EXC_1_0_G3\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.DIV.EXC_1_0_G3_0\,
datac => \GRFPC0.VDIV.VALID_0_SQMUXA\);
\GRFPC0_D_STDLCK_RNO_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000010100000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0\,
datab => \GRFPC0.STDEP_2_SQMUXA_133\,
datac => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_6\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_RNICRQQ3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_M4_E_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(54),
datac => D_M6_2,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_RNIL3RQ3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_M4_E_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(57),
datad => D_M6_1);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_RNIPVIA4_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_M4_E_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(58),
datad => D_M6_0);
\GRFPC0_D_STLCK_RNO_7_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101101001111")
port map (
combout => R_M2,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_288_3\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292_1\(1));
\GRFPC0_D_STDLCK_RNO_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_3_TZ\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_5\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_12_M_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(3),
dataa => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPC0.WR2.RREG.EXCT\(3),
datac => \GRFPC0.V.FSR.CEXC_2_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_12_M_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(1),
dataa => \GRFPC0.R.FSR.TEM\(1),
datab => \GRFPC0.WR2.RREG.EXCT\(1),
datac => \GRFPC0.V.FSR.CEXC_2_SQMUXA\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\(0),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_43\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100110101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_10\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I\(1),
datac => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111000101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_4\(0),
dataa => \GRFPC0.D.LDLCK_0_0_4__G1_0\,
datab => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_373_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_373\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_3\(1),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_2\(1),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I\);
\GRFPC0_FP_PIPELINE_15_REGDEPX_286_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX_286\(0),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX_284\(0));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_M_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(0),
dataa => \GRFPC0.DIV.EXCT_0_0_0__G3_1\,
datab => \GRFPC0.V.FSR.CEXC_2_SQMUXA_2_0_0\,
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA_0\,
datad => \GRFPC0.FP_PIPELINE.UN13_FPEXC\);
\GRFPC0_D_LDLCK_RNO_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G3\,
dataa => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_186\(0),
datad => \GRFPC0.FP_PIPELINE.10.1.REGDEPX_190\(0));
\GRFPC0_D_STDLCK_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111_A\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_6\);
\GRFPC0_D_STDLCK_RNO_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100010011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3_1111_A\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_RFA2_RS1SEL_RET_10_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100011")
port map (
combout => \GRFPC0.FPUSEL_6_0_7__G0_I_M4\,
dataa => \GRFPC0.RFA2.RS2SEL_0_0_7__G5\,
datab => \GRFPC0.UN1_WRENX2_2_3\,
datac => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_12\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_11\(0),
datad => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_14_1_REGDEPX_263_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_263\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_1\(1),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP\(1),
datad => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(1));
GRFPC0_FP_PIPELINE_V_STATE10_RNINRV37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_3\(4),
dataa => \GRFPC0.OP1_0_IV\(51),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2\(4));
GRFPC0_FP_PIPELINE_UN45_WREN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN45_WREN\,
dataa => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
datab => \GRFPC0.FP_PIPELINE.WREN_17_IV\(0));
\GRFPC0_D_STLCK_RNO_6_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100110101")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_M2_0\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_17_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX_246_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(1),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP\(1),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(1),
datad => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX_53_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_53\(0),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_13\(0),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_14_X\(0),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX_50\(0));
\GRFPC0_FP_PIPELINE_13_1_REGDEPX_244_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(0),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4256_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_242\(0));
GRFPC0_DIV_EXC_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.DIV.EXC_1_0_G0_I_O4\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.VDIV.EXC_0_SQMUXA\,
datac => \GRFPC0.VDIV.VALID_0_SQMUXA\);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0_1_M5_I_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1_M5_I_A3\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_D\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_34_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_34\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_32\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_0_0_O4_I_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_0_0_O4_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010111010101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\);
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110101100100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_536_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_532_3\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001110010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX_120\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX_120_A\(1),
datac => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_114\(1),
datad => \GRFPC0.FP_PIPELINE.6.1.REGDEPX_116\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX_120_A\(1),
dataa => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.DEP_1\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(62),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\(53));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.N_18471_I_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(2),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(2));
GRFPU0_GRFPU_X0_ITER_V_RNILKP34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4171_I_M\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(33));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6\(1),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\(1),
datac => \GRFPC0.D.LDLCK_0_0_11__G3_0_11\,
datad => \GRFPC0.INST\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.L3\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(40));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_1\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.L2_0_I_I_A2\(4),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_7_ANC3\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.L4_1\(4),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_13_ANC3\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.L2_0_I_I_A2\(4),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_7_ANC3\);
GRFPU0_GRFPU_X0_UN1_VALLOW_1_SQMUXA_INV_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW_1_SQMUXA_INV_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.N_4415_M\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8_S\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\);
GRFPC0_EX_CTRL_RDWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307\,
dataa => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datab => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_A3_0_2_1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\,
datad => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307_A3\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G1_0\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_3_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(61),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(61),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56));
\GRFPC0_D_STLCK_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_0_IV_TZ\(0),
datab => \GRFPC0.D.STLCK_0_0_10__G1_2\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_216_I_M_2\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_132_I_0_O2_X\);
\GRFPC0_D_STLCK_RNO_2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_23__G1_0\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1\(1));
GRFPC0_RFA2_RS1DEP_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_1\,
dataa => \GRFPC0.UN1_REGDEP79\,
datab => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_0\,
datac => \GRFPC0.REGDEP_1_SQMUXA_1\);
\GRFPC0_D_STLCK_RNO_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1\(0),
datab => \GRFPC0.STDDEP_0_SQMUXA_111\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1_0_0\(0),
datad => \GRFPC0.D.STLCK_0_0_28__G1_2\);
\GRFPC0_D_STLCK_RNO_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_4_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1\(1));
\GRFPC0_D_STLCK_RNO_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010111000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_5\(1),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0\(1));
\GRFPC0_D_STLCK_RNO_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1_6\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_M4\(0),
datab => \GRFPC0.D.STLCK_0_0_12__G1_4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_7_0\(1));
\GRFPC0_D_STDLCK_RNO_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_2_2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2\,
datad => \GRFPC0.D.STDLCK_0_0_15__G1_3\);
\GRFPC0_D_STDLCK_RNO_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111101111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_7\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
datab => \GRFPC0.D.STDLCK_0_0_13__G1_4\,
datac => \GRFPC0.D.STDLCK_0_0_13__G1_7_A\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_D_STDLCK_RNO_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_7_A\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O2_9\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001001100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_12\(0),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_6_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_10\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_5\(0));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44\,
dataa => \GRFPC0.OP2\(51),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_24\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_32\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44_A\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_44_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_44_A\,
dataa => \GRFPC0.OP2\(2),
datab => \GRFPC0.OP2\(11),
datac => \GRFPC0.OP2\(49),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\(1),
dataa => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_2\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_11\(1),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2_0\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_85_1_M9_I_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A0\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0\(1),
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_0_M6_I_0_A2_RNI6BSP7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0\,
dataa => \GRFPC0.D.LDLCK_0_0_14__G3_0_9\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_0\);
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2\,
dataa => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_15\,
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_22\,
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_25\,
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_27\);
\GRFPC0_D_STLCK_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1\,
dataa => \GRFPC0.D.STLCK_0_0_2__G1_5\,
datab => \GRFPC0.D.STLCK_0_0_2__G1_4\,
datac => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_1_X\(0),
datad => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2\(0));
\GRFPC0_D_LDLCK_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(19),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(19),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M2\(19),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I\(1));
\GRFPC0_D_LDLCK_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1\,
dataa => \GRFPC0.D.LDLCK_0_0_18__G1_1\,
datab => \GRFPC0.D.LDLCK_0_0_18__G1_A\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1\);
\GRFPC0_D_LDLCK_RNO_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0_A5\(0));
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_1_RNI75H41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4_0_0\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0\(1),
dataa => \GRFPC0.DIVI_0_SQMUXA_2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_881\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_A\(1),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_8\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_3\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_A\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_0_A3_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_21_0_A2\(1));
\GRFPC0_D_STDLCK_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_3_0\,
datab => \GRFPC0.D.STDLCK_0_0_6__G1_4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_4\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_1_RNI6RUM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111111")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I_O2\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001110")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
dataa => \GRFPC0.UN28_WREN_M8_I_A5\,
datab => \GRFPC0.UN28_WREN_M8_I_4\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\,
datad => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2\(4),
dataa => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_12\(4),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_13\(4),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_11\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14\(4));
GRFPC0_FP_PIPELINE_UN29_WREN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_4\,
datab => \GRFPC0.UN28_WREN_M8_I_4\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => \GRFPC0.UN28_WREN_M8_I_A5\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001110")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV\(0),
dataa => \GRFPC0.UN28_WREN_M8_I_A5\,
datab => \GRFPC0.UN28_WREN_M8_I_4\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\,
datad => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(0));
GRFPC0_V_FSR_CEXC_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.V.FSR.CEXC_2_SQMUXA_2_0_0\,
datac => \GRFPC0.FP_PIPELINE.V.STATE6\,
datad => \GRFPC0.FP_PIPELINE.UN13_FPEXC\);
GRFPC0_V_FSR_CEXC_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.V.FSR.CEXC_2_SQMUXA_2_0_0\,
datac => \GRFPC0.FP_PIPELINE.V.STATE6\,
datad => \GRFPC0.FP_PIPELINE.UN13_FPEXC\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_11\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_14\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_16\);
GRFPC0_V_FSR_FTT_1_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001000000000")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
dataa => N_3,
datab => \GRFPC0.WR2.CTRL.AFSR\,
datac => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1\);
\GRFPC0_D_STLCK_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101111111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1\,
dataa => \GRFPC0.D.STLCK_0_0_11__G1_4\,
datab => \GRFPC0.STDEP_0_SQMUXA_128\,
datac => \GRFPC0.STDDEP_0_SQMUXA_132_I_0_O2_X\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_M2\(1));
\GRFPC0_D_LDLCK_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1\,
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_0\(1),
datab => \GRFPC0.D.LDLCK_0_0_23__G1_4\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2\);
\GRFPC0_D_STDLCK_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_2\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datac => \GRFPC0.STDEP_2_SQMUXA_135_0_A2\,
datad => \GRFPC0.D.STDLCK_0_0_12__G1_A\);
\GRFPC0_D_STDLCK_RNO_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_0_0\(0),
datab => \GRFPC0.D.STDLCK_0_0_12__G1_5\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_4\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_3\);
\GRFPC0_D_STLCK_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1\,
dataa => \GRFPC0.D.STLCK_0_0_6__G1_5\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A2_0_0_X\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_1\(0));
\GRFPC0_D_STDLCK_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_2\,
datab => \GRFPC0.D.STDLCK_0_0_10__G1_5\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_A2_1_I\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2\);
\GRFPC0_D_STDLCK_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1\,
dataa => \GRFPC0.D.STDLCK_0_0_8__G3_2\,
datab => \GRFPC0.D.STDLCK_0_0_8__G1_5\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_12\(0));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_43\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\(18));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_4_2\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_5\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_6\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_7\(1));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_32\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_36\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_33\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_38\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_36\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_35\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_37\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_38\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXC\(0),
datab => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_4_1\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_2\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_3_1\);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_RNIBM8P3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(63),
datab => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I\(63),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M3\(63),
datab => \GRFPU0.GRFPU_X0.COMB.SIGN_1_I_M3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_A_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A\(63),
dataa => \GRFPU0.GRFPU_X0.G_53_REP1\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.G_51_REP1\);
GRFPU0_GRFPU_X0_VST4_EXC_0_SQMUXA_3_1_0_RNIR4JI: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O2_0\,
dataa => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_3_1_0\,
datab => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_0\,
datac => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_1\,
datad => \GRFPU0.GRFPU_X0.COMB.NXX_1_3\);
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_3\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\);
GRFPU0_GRFPU_X0_COMB_VST4_REG36_RNI8ANH1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111111111")
port map (
combout => \GRFPU0.GRFPU_X0.G_51\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datad => \GRFPU0.GRFPU_X0.G_51_A\);
GRFPU0_GRFPU_X0_COMB_VST4_REG30_RNINSES: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.G_51_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG30\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA_2\);
\GRFPC0_D_STDLCK_RNO_8_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datab => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_7\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1547_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_10\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I\(1),
dataa => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_10\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_1\(1));
GRFPC0_RFA2_RS1DEP_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100000")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_2594_TZ\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP14\,
datad => \GRFPC0.UN1_DIV.RDD\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_1_1_RNI9L7MF_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_1\(52));
GRFPC0_RFA2_RS2DEP_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000010010")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_A3\,
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M3_E\,
datac => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZTT_M3_0_TZ\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(53),
datab => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_YY\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_XX\(53));
\GRFPU0_DIVROM0_DATA_1_MUX_15_RNIOQSR2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => D_M6_2,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.DIVROM0.DATA_1_MUX_15\(2),
datac => D_M5_2);
\GRFPU0_DIVROM0_DATA_1_MUX_15_RNIRMSR2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => D_M6_1,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.DIVROM0.DATA_1_MUX_15\(5),
datac => D_M5_1);
\GRFPU0_DIVROM0_DATA_1_MUX_7_RNITEKB3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100100011")
port map (
combout => D_M6_0,
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.DIVROM0.DATA_1_MUX_7\(6),
datad => D_M5_0);
\GRFPC0_FP_PIPELINE_7_STDEP_292_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.7.STDEP_288_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_288_1\(1));
\GRFPC0_D_STLCK_RNO_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6_1\(1),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_3\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_4\(1),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1_A\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_1_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_1_A\(1),
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3\(1),
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A5_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5\(22),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_1\(22),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5\(22));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_M2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111111001100")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_3\(0),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_3\,
datad => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_8_1_REGDEPX_154_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_154\(1),
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_152\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110001011")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(0),
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.DEP\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150_I\(0),
datad => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_154\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX_140_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_140\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datab => \GRFPC0.CPI_M_1_X\(64),
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111110001011")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_102\(0),
dataa => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96_I\(0),
datad => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_100\(0));
GRFPC0_FP_PIPELINE_VRFA_LD_1_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.UN30_OP\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_463_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_463\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_4\(0),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_3\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0\(0));
GRFPC0_V_FSR_CEXC_4_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000101010001")
port map (
combout => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.STATE10_1\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE6\);
GRFPC0_VDIV_EXC_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.VDIV.EXC_2_SQMUXA\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.VDIV.VALID_0_SQMUXA\);
GRFPC0_PENDEXC_0_SQMUXA_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011011101")
port map (
combout => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\);
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2\(0));
\GRFPC0_FP_PIPELINE_5_1_REGDEPX_100_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_100\(1),
dataa => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_98\(1));
GRFPC0_UN1_V_FSR_FTT_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
dataa => \GRFPC0.DIV.EXCT\(5),
datab => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\,
datad => \GRFPC0.FP_PIPELINE.UN13_FPEXC\);
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_536_3\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_532_3\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_O2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_O2\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(53));
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_1_SQMUXA_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011101010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(1),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(55),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_A_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(55),
dataa => \GRFPU0.GRFPU_X0.G_53_REP1\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.G_51_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(62),
dataa => \GRFPU0.GRFPU_X0.G_52\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(62),
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(0),
datac => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(41),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_XX_MM\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(2),
dataa => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\,
datac => \GRFPU0.GRFPU_X0.VITER.DBUF_13_SUM2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_A\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_A\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\,
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_7_SUM2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.L4_1\(3),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_13_C2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.L3_0_3_I_S\(3),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_7_C2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(37));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_1_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_1\(63),
dataa => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV\(63),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_0\(63));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT_0_1\(0),
datab => \GRFPU0.GRFPU_X0.EXPT_CNST_0_A2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_0\(1),
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_SN_M1\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001010100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT_0_1\(0),
datab => \GRFPU0.GRFPU_X0.EXPT_CNST_I_A2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_0\(0),
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_SN_M1\);
GRFPU0_GRFPU_X0_VITER_DBUF_13_C4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13_C4\,
dataa => \GRFPU0.GRFPU_X0.L4_1\(4),
datab => \GRFPU0.GRFPU_X0.L4_1\(3),
datac => \GRFPU0.GRFPU_X0.L4_1\(2),
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_13_SUM2\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011010011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datab => \GRFPU0.MULO.MRES_BUF\(121),
datac => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(52),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(52));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_A_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101001001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(52),
dataa => \GRFPU0.GRFPU_X0.G_53_REP1\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(52),
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_RNI6G9Q_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.G_53\,
dataa => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(61),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2\(61),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(61),
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(35));
\GRFPC0_D_STLCK_RNO_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_5\,
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_0_A4_1_X\,
datac => \GRFPC0.D.STLCK_0_0_9__G1_3\,
datad => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\);
\GRFPC0_D_STLCK_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6_6\,
dataa => \GRFPC0.D.STLCK_0_0_7__G1_6_4\,
datab => \GRFPC0.D.STLCK_0_0_7__G1_A1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A2_0_0_X\(1));
GRFPC0_RFA2_RS1DEP_RNO_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010111")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_S_0\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\,
datac => \GRFPC0.REGDEP_1_SQMUXA_5\,
datad => \GRFPC0.REGDEP_1_SQMUXA_4\);
\GRFPC0_D_STLCK_RNO_6_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111111101")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_598_0_IV_TZ\(0),
datab => \GRFPC0.D.STLCK_0_0_28__G1_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_101\,
datad => \GRFPC0.FP_PIPELINE.14.0.STDEP_585_I_M_2\(0));
GRFPC0_RFA2_RS1DEP_RNO_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPC0_RFA2_RS1DEP_RNO_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_2\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\);
\GRFPC0_D_STLCK_RNO_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011101100")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_6\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\,
datab => \GRFPC0.D.STLCK_0_0_19__G1_5\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_D_STLCK_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_5\(0),
datad => \GRFPC0.D.STLCK_0_0_4__G1_4\);
\GRFPC0_D_STLCK_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_5_0\,
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_456_SEL0_0_I_O2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\(0),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_3_2\(0),
datad => \GRFPC0.D.STLCK_0_0_22__G1_4\);
\GRFPC0_D_STDLCK_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_6\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\(0),
datab => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.D.STDLCK_0_0_3__G1_6_A\);
\GRFPC0_D_STDLCK_RNO_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000111110101")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_6_A\,
dataa => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_0_1\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_11_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_11\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_8\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_7\(0),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_5\,
datad => \GRFPC0.D.LDLCK_0_0_11__G3_A4\);
\GRFPC0_D_LDLCK_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0\(8),
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_3_2\(0),
datac => \GRFPC0.D.LDLCK_0_0_8__G1_3\,
datad => \GRFPC0.D.LDLCK_0_0_8__G1_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1403_REGDEPX2_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10_A\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_10_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_10_A\(0),
dataa => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_7\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_6\(0),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_9_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_9\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_8\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_O2_1_RNIQFIC4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_11\,
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_1\(1),
datab => \GRFPC0.D.LDLCK_0_0_11__G3_0_9\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.D.LDLCK_0_0_11__G3_A4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_12\(0),
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_10\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000001100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_10\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_8\(0),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_0\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_1_0\(0));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_38\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_16\,
dataa => \GRFPC0.OP2\(36),
datab => \GRFPC0.OP2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_13\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_3\);
\GRFPC0_D_LDLCK_RNO_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(15),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_X\(15));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_27\,
dataa => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_18\,
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_19\,
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_16\,
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_17\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_48_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_37\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_36\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\(18));
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datab => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLTO4\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_2\,
dataa => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_3\(1),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M\(0));
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110000")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(1),
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.DIV.RD\(0),
datac => \GRFPC0.WR2.CTRL.RD_I_M\(0),
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(0),
datab => \GRFPC0.WREN_2_SQMUXA_4\,
datac => \GRFPC0.WREN_2_SQMUXA_3\,
datad => \GRFPC0.DIV.RD_M\(0));
GRFPC0_FP_PIPELINE_UN29_WREN_1_A1_D_RNIORGL4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0\,
dataa => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_3\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_1_D_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.7.STDEP_284_0_IV_I_0\(1),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_A\(1));
\GRFPC0_FP_PIPELINE_7_STDEP_292_1_D_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100101111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_A\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_15\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O2_0_RNIMJL05_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0_0\(1),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_O2_0\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0\(1));
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1\,
dataa => \GRFPC0.FP_PIPELINE.9.REGDEPX2_274\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_6\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_A\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_7\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_A\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5003_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_1_TZ\(1));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_40_M8_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_M4_0\);
GRFPC0_RFA2_RS1DEP_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2\,
dataa => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_10\(1),
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN348_DEP\,
datab => \GRFPC0.N_22435\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_2\);
GRFPC0_V_FSR_CEXC_6_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
dataa => \GRFPC0.V.FSR.CEXC_6_SQMUXA_0_X\,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_V_FSR_FTT_1_SQMUXA_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datac => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_V_FSR_CEXC_5_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_2\);
\GRFPC0_D_LDLCK_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_42_0_IV_I_A2_1\(0),
datab => \GRFPC0.D.LDLCK_0_0_0__G1_3\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_0_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_1_1\);
\GRFPC0_D_STLCK_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6\(1),
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6_0\(1),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5\(1),
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_M3_1\(1));
\GRFPC0_D_STLCK_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1\,
dataa => \GRFPC0.D.STLCK_0_0_20__G1_4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_5_0\(0),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_M2\(0));
\GRFPC0_D_STDLCK_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1\,
dataa => \GRFPC0.D.STDLCK_0_0_14__G1_3\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_580_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_M2\);
GRFPC0_FP_PIPELINE_0_EXEN2_3_0_0_RNIH58I3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_1__G0\,
dataa => \GRFPC0.EX.RREG.RESV_0_0_G0_0_X\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_3\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_1\);
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2\(0));
\GRFPC0_D_STLCK_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1\,
dataa => \GRFPC0.D.STLCK_0_0_30__G1_4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_129_I_I_A2_I_O4\,
datad => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_M2\(0));
\GRFPC0_D_STLCK_RNO_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_4_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_1\(1));
\GRFPC0_D_STLCK_RNO_6_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111101010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_3\(1),
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_7\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_612_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6\(1));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3300_DEP_RNIGVA7F: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_15\(1),
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_3\(1),
datac => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_16\(1),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_15\(1));
\GRFPC0_D_STDLCK_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1\,
dataa => \GRFPC0.D.STDLCK_0_0_11__G1_4\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2\);
\GRFPC0_D_STLCK_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111100")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1\,
dataa => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_O2_1_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5\(0),
datac => \GRFPC0.D.STLCK_0_0_24__G1_3\,
datad => \GRFPC0.D.STLCK_0_0_24__G1_A\);
\GRFPC0_D_STLCK_RNO_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_A\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_9\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_M2_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(15),
dataa => N_84,
datab => N_78,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_1\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(15),
dataa => N_89,
datab => N_90,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A2_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A2_0\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_0_RNIPHUG4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.N_67_I_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datab => \GRFPU0.GRFPU_X0.G_53_REP0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0\(57));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0\,
dataa => \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_0\(4),
datab => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(21),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\(21));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(40));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNIS9HF1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.V_2_M_0\,
datab => \GRFPU0.GRFPU_X0.N_4415_M\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_2\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_1\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL3_RNI413VC_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010111")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2_A\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL2\,
datad => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_RNIDBHGC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G2_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5\);
GRFPU0_GRFPU_X0_VITER_LOB_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000101010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.LOB_1_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datab => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_0_385\,
datac => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I\,
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2\,
datac => \GRFPU0.MULO.MRES_BUF\(121),
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_1\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_2_M4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0_A\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_2_M4_0_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datac => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datad => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U\);
\GRFPC0_FIFO_WR_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.UN1_PENDEXC_2\(0),
datad => \GRFPC0.FIFO.WR_0_0_0__G1_1\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG21\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_1_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXC\(1),
datab => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_4_1\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_3_1\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_7\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_8\(1),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I\(1),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_4\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_1_RNI01741_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A1_1\(44),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_1\(44),
datac => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(44));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_O2_1_0_RNI97HJ4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_1_0\(0),
datac => \GRFPC0.D.LDLCK_0_0_16__G1_0_7\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2\(0));
GRFPC0_FP_PIPELINE_UN205_HOLDN_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3\,
dataa => \GRFPC0.FP_PIPELINE.V.STATE10\,
datab => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_5\,
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
datad => CPO_LDLOCKZ);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_RNIH1BV_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_XX_MM\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_XX\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_YY\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(59),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0\,
dataa => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\);
GRFPC0_WR2_CTRL_SEQERR_RNI8D1D3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010101010101")
port map (
combout => \GRFPC0.DIV.EXC_1_0_G3_0\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.V.STATE6_0_0\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
datad => \GRFPC0.FPEXC_0_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M3_RNIBA681_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => D_M5_2,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M3\(54),
datac => D_M4_3);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_RNIB6681_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => D_M5_1,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(57),
datac => D_M4_2);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_RNIEA681_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => D_M5_0,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(58),
datac => D_M4_1);
\GRFPC0_D_STLCK_RNO_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_M2\(1),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1_A\(1));
\GRFPC0_D_STLCK_RNO_6_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010101000101")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_1_A\(1),
dataa => D_M4_I_A4_0_1,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_1_M8_I_0\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN1988_DEP\,
datad => R_M2_0);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_56_M6_I_A4_RNI0BP07: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(56),
dataa => D_M4,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_A4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_2\);
GRFPU0_GRFPU_X0_UN1_EXPOP_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0_0\,
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD55\,
datad => \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_2\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_5_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_7\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_13\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_43_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_43\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_41\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX_284_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX_284\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX_32_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_32\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_8\,
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_9\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_2_X\,
datad => \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0\);
\GRFPC0_FP_PIPELINE_10_1_REGDEPX_190_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.REGDEPX_190\(0),
dataa => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.10.1.REGDEPX_188\(0));
\GRFPC0_R_FSR_FCC_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_1__G2\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(1),
datab => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(1),
datac => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S2\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_98_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_98\(1),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_16_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_96\(1));
GRFPC0_UN1_WRENX2_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010111111")
port map (
combout => \GRFPC0.UN1_WRENX2_2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_0\,
datac => \GRFPC0.FP_PIPELINE.0.WR2EN2_1\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2\);
\GRFPC0_R_FSR_FCC_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_0__G2\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(0),
datab => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(0),
datac => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S2\);
GRFPC0_STDDEP_0_SQMUXA_182: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_182\,
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_169\);
GRFPC0_VDIV_VALID_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.VDIV.VALID_0_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.V.STATE10\,
datab => \GRFPC0.FP_PIPELINE.V.STATE6_0_0\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
datad => \GRFPC0.FPEXC_0_SQMUXA_1_0\);
GRFPC0_FP_PIPELINE_0_EXEN2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2\,
dataa => \GRFPC0.FP_PIPELINE.0.EXEN2_3\,
datab => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_0\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_1\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_1\,
dataa => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\,
datab => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\);
GRFPC0_RFA2_RS1SEL_RET_7_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_4__G5\,
dataa => N_38,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2\);
\GRFPC0_FP_PIPELINE_REN2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => RFI1_REN2Z,
dataa => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datab => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
\GRFPC0_FP_PIPELINE_REN2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => RFI2_REN2Z,
dataa => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datab => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
\GRFPC0_FP_PIPELINE_13_1_REGDEPX_244_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(1),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4256_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_242\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_6\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_5_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_13\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_11\);
\GRFPC0_D_STLCK_RNO_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_M2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0\(1));
\GRFPC0_FP_PIPELINE_13_1_REGDEPX_242_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_242\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(0));
\GRFPC0_D_STLCK_RNO_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A3_4\(1),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_1\(1),
datac => \GRFPC0.FP_PIPELINE.4.STDEP_172_2\(1),
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_1\(1));
\GRFPC0_D_STLCK_RNO_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_M2\(1),
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL0_0_I_O2\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_212_3\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_532_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_532_3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_532_3_A\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_528_3\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_532_3_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_532_3_A\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(49));
GRFPU0_GRFPU_X0_VITER_DBUF_7_ANC3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000101010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_ANC3\,
dataa => \GRFPU0.GRFPU_X0.L3_0_3_I_S\(3),
datab => \GRFPU0.GRFPU_X0.L3_0_3_0\(2),
datac => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datad => \GRFPU0.GRFPU_X0.L3_0_3_0\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111000101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(56));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(22),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(12),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(17),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(30));
GRFPU0_GRFPU_X0_VITER_DBUF_13_ANC3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010101")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13_ANC3\,
dataa => \GRFPU0.GRFPU_X0.L4_1\(3),
datab => \GRFPU0.GRFPU_X0.L4_1\(2),
datac => \GRFPU0.GRFPU_X0.L4_1\(1),
datad => \GRFPU0.GRFPU_X0.L4_1\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(55),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(55),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2_I_M2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_A2_0_RNIT2NH2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.N_4415_M\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(45));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110001001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_0\(63),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\(63),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_U\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(43));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(56),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(56));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(58),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(58));
GRFPU0_GRFPU_X0_COMB_VST4_REG37_RNIPKVM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111010101110")
port map (
combout => \GRFPU0.GRFPU_X0.G_52\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(59),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(60),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(60));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_I_O3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_I_O3\(56),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(43));
\GRFPC0_D_STLCK_RNO_2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101111111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_2\,
dataa => \GRFPC0.D.STLCK_0_0_10__G1_0\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_238_0_IV_TZ\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_123\,
datad => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2\(0));
\GRFPC0_D_STLCK_RNO_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011101100")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datab => \GRFPC0.D.STLCK_0_0_17__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_D_STLCK_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_4\,
dataa => \GRFPC0.D.STLCK_0_0_11__G1_2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_110\,
datac => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.DEP_2_IV\(1),
datad => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_0\(1));
\GRFPC0_D_STLCK_RNO_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5_4\,
dataa => \GRFPC0.D.STLCK_0_0_29__G1_5_2\,
datab => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_111\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_590\(1));
\GRFPC0_D_STLCK_RNO_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111100")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_4\(1),
datac => \GRFPC0.D.STLCK_0_0_31__G1_2\,
datad => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_1\(1));
\GRFPC0_D_STLCK_RNO_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\,
datac => \GRFPC0.D.STLCK_0_0_18__G1_1\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_1\(0));
\GRFPC0_D_STLCK_RNO_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_4\(1),
datab => \GRFPC0.D.STLCK_0_0_19__G1_2\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\(1),
datad => \GRFPC0.D.STLCK_0_0_19__G3\);
\GRFPC0_D_STDLCK_RNO_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_3_0\,
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\,
datac => \GRFPC0.N_201\,
datad => \GRFPC0.D.STDLCK_0_0_8__G1_3\);
\GRFPC0_D_STLCK_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\(0),
datab => \GRFPC0.D.STLCK_0_0_6__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_3\(0));
GRFPC0_UN1_WRENX2_2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.UN1_WRENX2_2_3\,
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
datac => \GRFPC0.UN1_WRENX2_2_0_0\,
datad => \GRFPC0.UN1_WRENX2_2_2\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_40_M8_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_4_RNIQ31J1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_1\(52),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD46\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_4\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_3_RNINKA2D_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_2\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0_A\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_5_1_RNITI744_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2_0_A\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_1\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPC0_D_STLCK_RNO_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.D.STLCK_0_0_4__G1_3\);
\GRFPC0_D_STLCK_RNO_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1_4\,
dataa => \GRFPC0.D.STLCK_0_0_12__G1_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_2\(12),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_2\(0));
\GRFPC0_D_STLCK_RNO_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_456_SEL0_0_I_O2\,
datac => \GRFPC0.D.STLCK_0_0_22__G1_3\,
datad => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_4\(0));
GRFPC0_UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2_RNI60ISB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_3\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_15\(1),
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_2\(1));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_RNILJEB8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_3\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_1\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_7\(1));
\GRFPC0_D_STDLCK_RNO_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_15__G1_0\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_0_0\,
datac => \GRFPC0.N_22435\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_D_STDLCK_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_0_1\,
datac => \GRFPC0.D.STDLCK_0_0_6__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\);
\GRFPC0_D_STDLCK_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110011")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_116_I\,
datac => \GRFPC0.D.STDLCK_0_0_7__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
\GRFPC0_D_STDLCK_RNO_6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_6\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_4\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_10\(0),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_6\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_4\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_7\(0));
\GRFPC0_D_LDLCK_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(1),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_5\(1),
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_TZ\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_8\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\(0),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O4\(0));
\GRFPC0_D_LDLCK_RNO_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_5\,
dataa => \GRFPC0.D.LDLCK_0_0_9__G1_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6\(9),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_7\(9),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(9));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_10\(1),
dataa => \GRFPC0.N_25113_2\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_5\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8_S\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_11_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_11\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_4\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_5\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_9\(1),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_1\);
GRFPC0_FIFO_FULL_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101100001011")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1_1\,
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.UN1_PENDEXC_3\(0),
datac => \GRFPC0.VFIFO.FULL_3_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6_F0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_M6_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_3\,
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_3\(0));
\GRFPC0_FIFO_WR_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011001100")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datab => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\,
datad => \GRFPC0.FIFO.WR_0_0_0__G3_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_2\(0),
dataa => \GRFPU0.GRFPU_X0.CCV_5_SQMUXA_S6_2\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LESS2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_38\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_4_03\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_23\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_37\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_36\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_4_03\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_35\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M21_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_28\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_36\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_20\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_0\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_4_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_4_03\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34_A\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_34_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_4_TZ\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_1_TZ\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_14_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14\(4),
dataa => \GRFPC0.OP1_0_IV\(36),
datab => \GRFPC0.OP1_0_IV\(47),
datac => \GRFPC0.OP1_0_IV\(44),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14_A\(4));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_14_A_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_14_A\(4),
dataa => \GRFPC0.OP1_0_IV\(39),
datab => \GRFPC0.OP1_0_IV\(32),
datac => \GRFPC0.OP1_0_IV\(41),
datad => \GRFPC0.OP1_0_IV\(46));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_10\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_7\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_8\(1));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_25\,
dataa => \GRFPC0.OP1_0_IV\(29),
datab => \GRFPC0.OP1_0_IV\(21),
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_12\,
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_20\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_9_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_5\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(4),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
datac => \GRFPU0.GRFPU_X0.L4_7\(3),
datad => \GRFPU0.GRFPU_X0.L4_7\(0));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_3\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
datab => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_1\(0),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_X2\(0),
datad => \GRFPU0.GRFPU_X0.L4_7\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_46_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_4_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_30\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_40\(18));
GRFPU0_GRFPU_X0_ITER_SIGN_RNI1KOK2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A4\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5_A\,
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_5_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_5_A\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A0\,
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M6_E\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_E\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_4_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4_1\(15),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datab => \GRFPC0.CPI_I_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(15));
GRFPC0_V_FSR_CEXC_3_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001010100")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA_0\,
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2\,
dataa => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\,
datab => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2_A\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_2_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_4_1\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1_0\(4),
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\);
GRFPU0_GRFPU_X0_ST2_EMINM1_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_1183_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_11\,
datad => \GRFPU0.GRFPU_X0.EXPT_CNST_0_A2\(1));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_2\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_S_0\,
datab => \GRFPU0.GRFPU_X0.NXX_1_I_A2_I_O2\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S\);
GRFPC0_V_FSR_CEXC_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011100000")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000010100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_11\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110100011")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_1\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_O2_0\,
datab => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.MULO.MRES_BUF\(121),
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2\);
GRFPC0_FP_PIPELINE_UN29_WREN_1_A0_RNIUVOK2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_6\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2\,
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(3),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A0\,
datad => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2\(1),
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_0\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_3\(1),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_1\(1));
GRFPC0_RFA2_RS2DEP_RNO_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\,
dataa => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2_0\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M\(0),
dataa => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_1_X\(0),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_2_X\(0),
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPC0_D_STLCK_RNO_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9\(1),
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9_0\(1),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_11_2\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_10\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_6\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_5\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_0_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_881\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1),
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_13\(1),
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5\(22),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_7\(22),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_8\(22),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_M6_I_A3_I_0\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_0_WRENX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2\,
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datac => \GRFPC0.FP_PIPELINE.0.WRENX2_0\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2_2\);
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_0\(1),
datab => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_M2\(1),
datad => \GRFPC0.N_24899_1\);
\GRFPC0_FPUSEL_6_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E\,
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E_2\);
GRFPC0_UN1_REGDEP79: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110100")
port map (
combout => \GRFPC0.UN1_REGDEP79\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.RD\,
datac => \GRFPC0.UN1_REGDEP79_2\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0\(0),
dataa => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3\(0));
GRFPC0_FP_PIPELINE_0_WR2EN2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
dataa => \GRFPC0.WR2.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datac => \GRFPC0.FP_PIPELINE.0.WR2EN2_0\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2_1\);
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1\(1),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0\(1),
datad => \GRFPC0.N_24899_1\);
\GRFPC0_D_STLCK_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_5\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_3_0_X\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_1\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110100001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1_1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(33),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O3_0\(24));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A\(24));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110100001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1_1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(24),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O3_0\(24));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_7\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O2_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_6\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1175_0_O3\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O2_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(51),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_A2\(50));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(31),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(34),
datac => \GRFPC0.OP1_0_IV\(31),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(48),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(46),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
GRFPU0_GRFPU_X0_ITER_NX_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4_I_M\,
datac => \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\,
datad => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\);
GRFPU0_GRFPU_X0_ST3_RDY_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_1\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_2_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1\);
GRFPU0_GRFPU_X0_VST3_REG_0_SQMUXA_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_0_O2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.MULO.MRES\(68),
datac => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7\);
GRFPC0_RFA_WRITE_RD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.RDWR_5_SQMUXA_0\,
datac => \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ\,
datad => \GRFPC0.RFA.WRITE_RD_0_0_G1_1\);
GRFPC0_VFIFO_FULL_3_SQMUXA_RNIVBMC3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FIFO.RD_0_0_0__G1\,
dataa => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datab => \GRFPC0.FIFO.RD_I_M\(0),
datac => \GRFPC0.FIFO.RD_M\(0),
datad => \GRFPC0.VFIFO.FULL_3_SQMUXA\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_ADDOF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMIN\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPINC_SP\,
datac => \GRFPU0.GRFPU_X0.COMB.CCUF_1_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A4_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2\(12),
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2_0\(12),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2\(12),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_0\(12));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_5\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_6\(0),
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M6_I_A3_0\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_1_RNI59741_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A1_1\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(38));
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0_1TT_B0_0_D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_D\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.FPRDY4\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F0_1TT_B0_0_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101010111")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0_1TT_B0_0_C_0_X\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_RNIUMD85_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0\,
dataa => \GRFPC0.D.LDLCK_0_0_4__G1_0_7\,
datab => \GRFPC0.D.LDLCK_0_0_4__G1_0_5\,
datac => \GRFPC0.D.LDLCK_0_0_4__G1_0_6\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2\(0));
GRFPC0_RFA2_RS2DEP_RNO_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000010000000")
port map (
combout => \GRFPC0.UN1_REGDEP147_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\,
datac => \GRFPC0.UN1_REGDEP147_0_1\,
datad => \GRFPC0.UN1_REGDEP147_0_A\);
GRFPC0_RFA2_RS2DEP_RNO_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101001010101")
port map (
combout => \GRFPC0.UN1_REGDEP147_0_A\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP146\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_RNI24F552_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(55),
dataa => D_M1_E_2,
datab => R_M3_0_A2_2_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4\(55));
GRFPC0_UN1_RDWR_3_SQMUXA_RNIGFTO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datac => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_4_RNI3SP0T_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(51),
dataa => D_M1_E_0,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_M4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_A2_3_XX_RNIF2R9_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_XX_MM\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_XX\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_YY\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4\(41),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_RNI7SEK_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_YY\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_XX\(46),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_RNID4FK_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_XX_MM\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_YY\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_XX\(48),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_D\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_S\(37));
GRFPC0_INST_I_0_6_M3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010000")
port map (
combout => \GRFPC0.INST_I_0_6_M3\,
dataa => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_YY_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_YY\(53),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_2\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_XX_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_XX\(53),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(16),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_2\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\(53));
GRFPC0_FP_PIPELINE_UN29_WREN_1_A0_RNIRL685: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_3\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2\,
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(3),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A0\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_RNI6RIG_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011101000111")
port map (
combout => D_M4_3,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(54),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_RNIC7JG_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010001110100")
port map (
combout => D_M4_2,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(57),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_RNIEBJG_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010001110100")
port map (
combout => D_M4_1,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(58),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58));
\GRFPC0_D_STLCK_RNO_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3_TZ\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_11_1\(1));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
dataa => \GRFPU0.GRFPU_X0.RNDOP_14_IV_2372_TZ\,
datab => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\,
datac => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
datad => \GRFPU0.GRFPU_X0.COMB.STICKY_1\);
\GRFPC0_FP_PIPELINE_14_1_REGDEPX_260_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(1));
\GRFPC0_FP_PIPELINE_8_1_REGDEPX_152_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_152\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150\(1));
\GRFPC0_FP_PIPELINE_8_1_REGDEPX_154_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_154\(0),
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_152\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A4_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A4_2\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_O3_6\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3\);
\GRFPC0_FP_PIPELINE_5_1_REGDEPX_100_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_100\(0),
dataa => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_98\(0));
\GRFPC0_D_STLCK_RNO_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A2_0\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0\(1));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(1),
dataa => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.R.FSR.FCC\(1),
datac => \GRFPC0.V.FSR.FCC_2_SQMUXA_1\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_FP_PIPELINE_12_REGDEPX2_370_1_M6_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M5_E\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I_A3_0\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_M2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_2\);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(0),
dataa => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.R.FSR.FCC\(0),
datac => \GRFPC0.V.FSR.FCC_2_SQMUXA_1\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_M2\(0),
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1\(0));
GRFPC0_FP_PIPELINE_UN1_V_STATE10_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.STATE10_1\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.WR2.CTRL.RD_I_M\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(0),
datab => \GRFPC0.WREN_2_SQMUXA_4\,
datac => \GRFPC0.WREN_2_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_5_1_REGDEPX_98_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_98\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96\(1));
GRFPC0_FP_PIPELINE_UN13_FPEXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN13_FPEXC\,
dataa => \GRFPC0.WR2.RREG.EXCT\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S2\,
dataa => \GRFPC0.V.FSR.FCC_3_SQMUXA_0\,
datab => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datac => \GRFPC0.V.FSR.CEXC_0_SQMUXA_1\);
GRFPC0_UN1_WRENX10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPC0.UN1_WRENX10_I\,
dataa => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3\,
datac => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_M2\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX_50_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_50\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_0_0_A3\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_20_0_IV_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0\(0));
\GRFPC0_FP_PIPELINE_14_1_REGDEPX_260_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(0));
GRFPC0_REGDEP_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000010010000")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_1\,
dataa => \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1_I_M2\(0),
datab => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datac => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0\);
\GRFPC0_D_STLCK_RNO_5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_5\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_172_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_3\(0),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_168_3\(0),
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\(15),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datab => N_84,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_18_X\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_A\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_A\,
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL1_I_0_A2_0_A2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_122_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3\,
datad => \GRFPC0.STDDEP_0_SQMUXA_166_I\);
\GRFPC0_FP_PIPELINE_13_STDEP_532_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101100010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_532_3\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_532_3_A\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0\(0));
\GRFPC0_FP_PIPELINE_13_STDEP_532_3_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101000011010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_532_3_A\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(19),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(20),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(28),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(34),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datad => \GRFPU0.GRFPU_X0.L3_0_3_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111101010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(53),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\,
datac => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(32));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(32));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(36));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(36));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(29),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(29));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(29),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(29));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(46));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(37),
datac => NN_1,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(23),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001101010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(55),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\,
datac => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(0),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(0));
GRFPU0_GRFPU_X0_VITER_DBUF_7_SUM2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100110101001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_SUM2\,
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datac => \GRFPU0.GRFPU_X0.L3_0_3_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(55),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(44),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
GRFPU0_GRFPU_X0_VITER_DBUF_7_C2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010111")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_C2\,
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datac => \GRFPU0.GRFPU_X0.L3_0_3_0\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(26),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(27),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(30),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(30));
GRFPC0_RFA_SEQERR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_O2\,
dataa => \GRFPC0.VRFA.SEQERR_5_SQMUXA_1\,
datab => \GRFPC0.FP_PIPELINE.UN26_OP\,
datac => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datad => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A3_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(25),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_47_U_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111000010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_U\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_1\(63));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_SN_M1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_SN_M1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_11\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\);
GRFPU0_GRFPU_X0_VITER_DBUF_13_C2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010111")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13_C2\,
dataa => \GRFPU0.GRFPU_X0.L4_1\(2),
datab => \GRFPU0.GRFPU_X0.L4_1\(1),
datac => \GRFPU0.GRFPU_X0.L4_1\(0));
GRFPU0_GRFPU_X0_COMB_UN63_BLSB_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLTO4\);
GRFPU0_GRFPU_X0_VST4_EXC_0_SQMUXA_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN7_G_SP_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7));
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA_1_RNIEH843: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_3_1\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_9\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_2_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(56),
dataa => \GRFPU0.GRFPU_X0.G_52\,
datab => \GRFPU0.GRFPU_X0.G_51_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(56));
GRFPU0_GRFPU_X0_COMB_NXX_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.NXX_1_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datab => \GRFPU0.GRFPU_X0.NXX\,
datac => \GRFPU0.GRFPU_X0.NXX_1_I_A2_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.NXX_1_3_A\);
GRFPU0_GRFPU_X0_COMB_NXX_1_3_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.NXX_1_3_A\,
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datad => \GRFPU0.MULO.MRES_BUF\(121));
GRFPU0_GRFPU_X0_COMB_UN1_ADDI3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5\,
datab => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ST3.EMINM1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011110001010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1\(52),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\,
datac => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(58),
dataa => \GRFPU0.GRFPU_X0.G_52\,
datab => \GRFPU0.GRFPU_X0.G_51_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(58));
GRFPU0_GRFPU_X0_VST4_REG_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.G_51_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_5_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_5\(60),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datab => \GRFPU0.GRFPU_X0.G_51_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(34),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(34),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(49));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(49));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(26),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(26));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(26),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(26),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(26));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(22),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(22),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(22));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(22),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(22),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(22));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(42));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(42));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(30),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(30));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010111010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_A\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(30),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10));
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_0_RNI2I7U1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_10\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA_1\);
\GRFPC0_D_STLCK_RNO_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL1_I_0_A2_I_O4\,
datac => \GRFPC0.D.STLCK_0_0_9__G1_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
\GRFPC0_D_STLCK_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_X\(1),
datac => \GRFPC0.D.STLCK_0_0_3__G1_1\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2\(1));
\GRFPC0_D_STLCK_RNO_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_2\,
dataa => \GRFPC0.D.STLCK_0_0_21__G1_0\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(21),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_A2_1_I\(0));
\GRFPC0_D_STLCK_RNO_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110101")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.13.STDEP_554_0_IV_TZ\(0),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.D.STLCK_0_0_26__G1_0\,
datad => \GRFPC0.STDEP_0_SQMUXA_84_1\);
\GRFPC0_D_STLCK_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_4\,
dataa => \GRFPC0.D.STLCK_0_0_8__G1_2\,
datab => \GRFPC0.FP_PIPELINE.4.0.STDEP_185_0_IV_TZ\(0),
datac => \GRFPC0.FP_PIPELINE.4.STDEP_176_I_M_1\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\);
\GRFPC0_D_STLCK_RNO_2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_358\(1),
datab => \GRFPC0.D.STLCK_0_0_17__G1_0\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_350\(1),
datad => \GRFPC0.FP_PIPELINE.8.0.STDEP_345\(1));
\GRFPC0_D_STLCK_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_2\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_0\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_0\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2\(1));
\GRFPC0_D_STLCK_RNO_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6_4\,
dataa => \GRFPC0.D.STLCK_0_0_7__G1_6_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_0\(7),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\(1),
datad => \GRFPC0.D.STLCK_0_0_7__G1_A0\);
GRFPC0_RFA2_RS1DEP_RNO_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_0_A4\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0));
GRFPC0_RFA2_RS1DEP_RNO_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\,
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0));
\GRFPC0_D_STLCK_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_5__G1_0\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_1\(1),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_0\(1));
\GRFPC0_D_STDLCK_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_6\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_108_I_0_0_O3\,
datab => \GRFPC0.D.STDLCK_0_0_0__G1_2\,
datac => \GRFPC0.D.STDLCK_0_0_0__G1_5\,
datad => \GRFPC0.STDDEP_0_SQMUXA_137_I_I_A2_I_O2\);
GRFPC0_RFA2_RS2DEP_RNO_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100000111")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A0_0\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_0\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2\,
datad => \GRFPC0.UN1_EX.CTRL.RDD_1\);
\GRFPC0_D_STLCK_RNO_4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_6_0\(1),
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1\(1));
\GRFPC0_D_STLCK_RNO_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_1\,
dataa => \GRFPC0.D.STLCK_0_0_18__G1_TZ\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datac => \GRFPC0.D.STDLCK_0_0_9__G3\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_394_0_IV_I_A2\(0));
\GRFPC0_D_STLCK_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\(0),
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0),
datad => \GRFPC0.D.STLCK_0_0_20__G1_3\);
\GRFPC0_D_STLCK_RNO_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_2\,
dataa => \GRFPC0.D.STLCK_0_0_16__G1_1\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_350_0_IV_TZ\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2\(44));
\GRFPC0_D_STDLCK_RNO_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_1_2\,
datab => \GRFPC0.D.STDLCK_0_0_12__G1_2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\,
datad => \GRFPC0.D.STDLCK_0_0_12__G1_5_A\);
\GRFPC0_D_STDLCK_RNO_3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_5_A\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_2\);
\GRFPC0_D_STLCK_RNO_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_2_0\(1),
datab => \GRFPC0.D.STLCK_0_0_13__G1_2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_7_0\(1));
\GRFPC0_D_STDLCK_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_5__G1_0\,
datab => \GRFPC0.STDDEP_0_SQMUXA_123\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3\);
GRFPC0_UN1_WRENX2_2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000100")
port map (
combout => \GRFPC0.UN1_WRENX2_2_2\,
dataa => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_56_M6_I_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_2\,
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD50\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(52));
\GRFPC0_D_STDLCK_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datac => \GRFPC0.D.STDLCK_0_0_10__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_0\);
\GRFPC0_D_STLCK_RNO_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datac => \GRFPC0.FIFO.INST_0_M_9\(25),
datad => \GRFPC0.D.STLCK_0_0_4__G1_2\);
\GRFPC0_D_STLCK_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_4\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_113_0_A2\,
datab => \GRFPC0.FIFO.INST_0_M_9\(25),
datac => \GRFPC0.D.STLCK_0_0_2__G1_2\,
datad => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_4\(0));
\GRFPC0_D_STLCK_RNO_3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A2_0_X\(0),
datab => \GRFPC0.D.STLCK_0_0_22__G1_0\,
datac => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0\(0),
datad => \GRFPC0.N_23889\);
\GRFPC0_D_STLCK_RNO_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
datac => \GRFPC0.D.STLCK_0_0_30__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_3_0_RNIN73O7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111010")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_2\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_0\(1),
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\(1),
datac => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_7\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_D_STLCK_RNO_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_1_1_REP1_RNIJT4S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100011011")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1\(1),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_8\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1_A\(1));
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_O2_0_RNIDVV72_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_1_1_A\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
GRFPC0_RFA2_RS1DEP_RNO_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_2_0\,
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\);
\GRFPC0_D_STDLCK_RNO_2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_4\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.D.STDLCK_0_0_13__G1_3\);
\GRFPC0_D_STDLCK_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datab => \GRFPC0.D.STDLCK_0_0_11__G1_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0_1078\);
GRFPC0_FP_PIPELINE_3_REGDEPX2_115TT_1_M3_0_A2_RNICON77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_8\,
dataa => \GRFPC0.D.LDLCK_0_0_7__G3_0_2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_0_1_0\,
datac => \GRFPC0.D.LDLCK_0_0_7__G3_0_5\,
datad => \GRFPC0.D.LDLCK_0_0_7__G3_0_6\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_2_RNID2RV3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0_7\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(0),
datab => \GRFPC0.D.LDLCK_0_0_16__G1_0_4\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_2\(0));
\GRFPC0_D_STDLCK_RNO_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_6__G1_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_118_I\,
datad => \GRFPC0.STDDEP_0_SQMUXA_107_I_O4\);
GRFPC0_RFA_WRITE_RD_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1_1\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_3\,
datab => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2\);
GRFPC0_FP_PIPELINE_0_EXEN2_3_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_1\,
dataa => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1),
datad => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O3_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_3_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_4\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_8\(1),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\(1));
\GRFPC0_D_LDLCK_RNO_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1_2\,
dataa => \GRFPC0.D.LDLCK_0_0_8__G1_1\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_A3\(0));
\GRFPC0_D_LDLCK_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(5),
datac => \GRFPC0.D.LDLCK_0_0_5__G1_2\,
datad => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_0_RNIIJ4H3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_9\,
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_1\(1),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4\,
datad => \GRFPC0.D.LDLCK_0_0_11__G3_0_7\);
\GRFPC0_D_LDLCK_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_3_1\(1),
datab => \GRFPC0.D.LDLCK_0_0_23__G1_3\,
datac => \GRFPC0.D.LDLCK_0_0_23__G1_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\(5));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\(1),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(1),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_3\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_5\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_6\(1));
GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_M10_I_A5_0_RNI5MDK6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0_9\,
dataa => \GRFPC0.D.LDLCK_0_0_14__G3_0_4\,
datab => \GRFPC0.D.LDLCK_0_0_14__G3_A2\,
datac => \GRFPC0.D.LDLCK_0_0_14__G3_0_5\,
datad => \GRFPC0.D.LDLCK_0_0_14__G3_0_6\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_10\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_4\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_8\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_4_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_4_2\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_8\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_7\(0));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_2\,
dataa => \GRFPC0.OP2\(50),
datab => \GRFPC0.OP2\(47),
datac => \GRFPC0.OP2\(44),
datad => \GRFPC0.OP2\(31));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_1\(0),
dataa => \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2\,
datab => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0_A2_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_4_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_4_03\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_26\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_0\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_1\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_28\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_0\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_1\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_33\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_4_03\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_4_03\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_3\,
dataa => \GRFPC0.OP2\(44),
datab => \GRFPC0.OP2\(53),
datac => \GRFPC0.OP2\(39),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(61),
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(61),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(62),
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(62),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_13_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_13\(4),
dataa => \GRFPC0.OP1_0_IV\(34),
datab => \GRFPC0.OP1_0_IV\(42),
datac => \GRFPC0.OP1_0_IV\(50),
datad => \GRFPC0.OP1_0_IV\(43));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_12_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_12\(4),
dataa => \GRFPC0.OP1_0_IV\(37),
datab => \GRFPC0.OP1_0_IV\(49),
datac => \GRFPC0.OP1_0_IV_I_A2\(45),
datad => \GRFPC0.OP1_0_IV\(35));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_2_11_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_2_11\(4),
dataa => \GRFPC0.OP1_0_IV\(38),
datab => \GRFPC0.OP1_0_IV\(33),
datac => \GRFPC0.OP1_0_IV\(40),
datad => \GRFPC0.OP1_0_IV\(48));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_22\,
dataa => \GRFPC0.OP1_0_IV\(27),
datab => \GRFPC0.OP1_0_IV\(8),
datac => \GRFPC0.OP1_0_IV\(14),
datad => \GRFPC0.OP1_0_IV\(26));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_20\,
dataa => \GRFPC0.OP1_0_IV\(0),
datab => \GRFPC0.OP1_0_IV\(19),
datac => \GRFPC0.OP1_0_IV\(22),
datad => \GRFPC0.OP1_0_IV\(6));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_19\,
dataa => \GRFPC0.OP1_0_IV\(4),
datab => \GRFPC0.OP1_0_IV\(10),
datac => \GRFPC0.OP1_0_IV\(30),
datad => \GRFPC0.OP1_0_IV\(20));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_18\,
dataa => \GRFPC0.OP1_0_IV\(16),
datab => \GRFPC0.OP1_0_IV\(17),
datac => \GRFPC0.OP1_0_IV\(9),
datad => \GRFPC0.OP1_0_IV\(11));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_17\,
dataa => \GRFPC0.OP1_0_IV\(2),
datab => \GRFPC0.OP1_0_IV\(12),
datac => \GRFPC0.OP1_0_IV\(18),
datad => \GRFPC0.OP1_0_IV\(28));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_16\,
dataa => \GRFPC0.OP1_0_IV\(25),
datab => \GRFPC0.OP1_0_IV\(1),
datac => \GRFPC0.OP1_0_IV\(24),
datad => \GRFPC0.OP1_0_IV\(3));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_15\,
dataa => \GRFPC0.OP1_0_IV\(5),
datab => \GRFPC0.OP1_0_IV\(7),
datac => \GRFPC0.OP1_0_IV\(23));
\GRFPC0_D_STDLCK_RNO_12_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_7\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_6\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_40_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_40\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_28\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_39_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_38_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_36_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_36\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1\(18));
GRFPC0_FP_PIPELINE_UN29_WREN_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_4\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_3\,
datab => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\(1),
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3491_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_6\(1));
\GRFPC0_D_LDLCK_RNO_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_2\,
dataa => \GRFPC0.D.LDLCK_0_0_31__G1_0\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(31),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\(5),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(31));
\GRFPC0_D_STDLCK_RNO_7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_5\,
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_2\,
datad => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_7\(1),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0\(1),
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_5\(1),
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_4\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\(21),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_5\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_2\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_M2\(21));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_O2_0_I_A2\(0),
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_2403\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2\);
GRFPC0_UN28_WREN_M8_I_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPC0.UN28_WREN_M8_I_4\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.UN28_WREN_M8_I_3\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_3_1\,
dataa => \GRFPC0.LDLOCK_M_4\,
datab => \GRFPC0.D.FLDLCK_M_X\,
datac => \GRFPC0.D.FSTLCK_M\,
datad => \GRFPC0.LDLOCK_15_X\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_2_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_3\(1),
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_M_0_X\(1),
datac => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP_X\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPC0_UN1_VDIV_EXEC7_RNIUE0U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0\,
dataa => \GRFPC0.RFA.WRITE_RD\,
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datac => \GRFPC0.UN1_VDIV.EXEC7\,
datad => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_3\);
GRFPC0_RDWR_5_SQMUXA_RNI5KPT: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.RDWR_3_SQMUXA\,
datac => \GRFPC0.RDWR_5_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
GRFPC0_VFIFO_INST_1_1_SQMUXA_M1_E_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_38,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(56),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_1\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_2\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(54),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(58));
\GRFPC0_D_STDLCK_RNO_5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\,
datab => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_3\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M\,
dataa => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_M_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4_1\(0),
datac => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_1\(0));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3\(1),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_A\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010111001111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_A\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_I_M_6\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datab => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_I_A4\(0),
datac => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_0\(0));
GRFPC0_RFA2_RS2SEL_RET_5_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G1\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.0.WRSEL4\,
datac => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7\);
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001101")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_3\(0),
datab => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_A\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_A\(0),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_3\(0),
datab => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_19_1\);
GRFPC0_FP_PIPELINE_UN68_HOLDN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
dataa => \GRFPC0.WR2.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.UN68_HOLDN_A\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.UN28_WREN_M8_I_A5_2\);
GRFPC0_FP_PIPELINE_UN68_HOLDN_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN_A\,
dataa => N_38,
datab => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.DIV.VALID_REP1\,
datad => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I\(0),
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datac => \GRFPC0.N_21857\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001001100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A\(0),
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_0_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_5\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_19_1\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0_A4\(0),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A4_0\(0),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_2\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_O2_1_RNI1T4H4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6\(1),
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6_1\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_10_0\(1),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_1\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\);
\GRFPC0_D_STLCK_RNO_5_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2\(1),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2_0\(1),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_O2_0\(1),
datad => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_653\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_1_0\(1),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_2\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5\,
dataa => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_0\,
datab => \GRFPU0.GRFPU_X0.CCV_3_SQMUXA_S4_2_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_5\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_12\(1),
datad => \GRFPU0.GRFPU_X0.COMB.UN6_LESS_0_A3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(50),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1\(41),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(41));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3\,
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0_2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_1\);
GRFPU0_GRFPU_X0_ST3_ZERO_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\,
datab => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_1\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\(0),
datad => \GRFPU0.GRFPU_X0.VST3.RDY_0_SQMUXA_0\);
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_REST_4\,
datad => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5_0\);
GRFPU0_GRFPU_X0_VST3_REG_4_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1_0\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(52));
GRFPU0_GRFPU_X0_ITER_SQRT_REP1_RNILNATD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_3\,
datad => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\);
GRFPU0_GRFPU_X0_COMB_VST1_V4_RNIVNAN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4415_M\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.V4\);
GRFPU0_GRFPU_X0_COMB_UN55_BLSBLTO4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLTO4\,
dataa => \GRFPU0.GRFPU_X0.L3_0\(2),
datab => \GRFPU0.GRFPU_X0.L4_3\(4),
datac => \GRFPU0.GRFPU_X0.L4_3\(3),
datad => \GRFPU0.GRFPU_X0.L4_3\(1));
\GRFPC0_FP_PIPELINE_REN1_1_IV_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_2_I_M\(2),
dataa => N_423,
datab => \GRFPC0.FP_PIPELINE.STDBL_1_1_U\,
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST_X\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0));
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_A2_0_RNI9P0ED: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111011111")
port map (
combout => \GRFPU0.GRFPU_X0.ALLOW_0_2__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61\);
GRFPU0_GRFPU_X0_VITER_V_0_SQMUXA_2_RNIVAFS4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011010000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
dataa => \GRFPC0.RFA2.FLUSH\,
datab => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_1\,
datad => \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_2\);
GRFPU0_GRFPU_X0_UN1_VALLOW_1_SQMUXA_INV_0_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G0\,
dataa => N_3,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G6\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2),
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_A2\(11));
GRFPC0_RFA_READ_RS1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100010")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1\,
dataa => \GRFPC0.RFA.READ_RS1_0_0_G1_1\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_0\);
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG21\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1_1\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\);
GRFPU0_GRFPU_X0_ST3_INF_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datab => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\,
datac => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL6\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1\);
\GRFPC0_D_STLCK_RNO_8_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.STDEP_585_I_M_2\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2_0\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.FPRDY4\);
GRFPC0_RFA2_RS2DEP_RNO_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101111111")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZTT_M3_0_TZ\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.RDWR_5_SQMUXA_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\,
datad => \GRFPC0.RDWR_3_SQMUXA\);
\GRFPC0_D_STLCK_RNO_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111101000111")
port map (
combout => D_M4_4,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL0_0\,
datab => D_M3_1,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_288_2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIDF4BP_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(39),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNII957T_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(43),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIND74S_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(42),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIF11DV_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIFPSI11_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(47),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNITLOO31_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIRDLR41_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_XX_MM\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(50),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(50),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_D_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_D\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(37),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(59),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_2\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_A\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_A\(59),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(59));
GRFPC0_UN1_REGDEP63_D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110111101101")
port map (
combout => \GRFPC0.UN1_REGDEP63_D\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\,
datac => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPU0_GRFPU_X0_ST2_DIFFN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\);
GRFPC0_RFA2_RS2SEL_RET_6_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000101010")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G7\,
dataa => \GRFPC0.FPUSEL_1_0_3__G7_0_X\,
datab => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
datac => \GRFPC0.FP_PIPELINE.1.EXEN7_4\);
GRFPC0_RFA2_RS2DEP_RNO_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000010000")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_1_A1\,
dataa => \GRFPC0.FP_PIPELINE.1.UN1_EX.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datad => \GRFPC0.UN1_EX.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_4_STDEP_172_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_168_1\(1),
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_1_D\(1));
GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_M6_I_A3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2_1\,
datac => \GRFPC0.FP_PIPELINE.UN15_OP_2\,
datad => \GRFPC0.FP_PIPELINE.UN15_OP_1_TZ\);
\GRFPC0_D_STLCK_RNO_4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010001010")
port map (
combout => D_M3_0_A2,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_1_0_X\(0),
datab => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\,
datac => D_M2_E_2_0,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_1\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_93_RNIP4IQ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000100000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_A3\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_23_IV\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_93\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_D_STLCK_RNO_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_7_3_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_9\(1),
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP11_0_A2_0_A3\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
GRFPU0_GRFPU_X0_EXPOP_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110001000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(96),
datad => \GRFPU0.GRFPU_X0.RNDOP_32_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(0),
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\(0));
GRFPC0_UN1_STDDEP_0_SQMUXA_99_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2_0\,
datac => \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0_A2_0_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_41_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_41\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN726_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
dataa => \GRFPC0.OP1_0_IV\(32),
datab => \GRFPC0.OP1_0_IV\(29),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
dataa => \GRFPC0.OP1_0_IV\(33),
datab => \GRFPC0.OP1_0_IV\(30),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
dataa => \GRFPC0.OP1_0_IV\(35),
datab => \GRFPC0.OP1_0_IV\(32),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
dataa => \GRFPC0.OP1_0_IV\(33),
datab => \GRFPC0.OP1_0_IV\(36),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
dataa => \GRFPC0.OP1_0_IV\(38),
datab => \GRFPC0.OP1_0_IV\(35),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
dataa => \GRFPC0.OP1_0_IV\(38),
datab => \GRFPC0.OP1_0_IV\(41),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
dataa => \GRFPC0.OP1_0_IV\(39),
datab => \GRFPC0.OP1_0_IV\(42),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
dataa => \GRFPC0.OP1_0_IV\(41),
datab => \GRFPC0.OP1_0_IV\(44),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
dataa => \GRFPC0.OP1_0_IV_I_A2\(45),
datab => \GRFPC0.OP1_0_IV\(42),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
dataa => \GRFPC0.OP1_0_IV_I_A2\(45),
datab => \GRFPC0.OP1_0_IV\(48),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_M2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_M2\(19),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0\(1));
\GRFPC0_FP_PIPELINE_10_1_REGDEPX_188_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.REGDEPX_188\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\(0),
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_186\(0));
\GRFPC0_D_STLCK_RNO_5_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100011101")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_M3_1\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1\(1),
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5\(1));
GRFPC0_FP_PIPELINE_FPUSTART_7_RNI8J4NB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
dataa => \GRFPC0.RFA.RDD\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_A3\,
datad => \GRFPC0.N_17807_I_0_G1\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111100000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_M2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292\(0));
GRFPC0_RFA2_RS2SEL_RET_4_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100011")
port map (
combout => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3\,
dataa => \GRFPC0.RFA2.RS2SEL_0_0_7__G5\,
datab => \GRFPC0.FP_PIPELINE.1.DIVEN10\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_96_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101110101010")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_96\(1),
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_21\(1),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_23_IV\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_93\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
dataa => \GRFPC0.OP1_0_IV\(39),
datab => \GRFPC0.OP1_0_IV\(36),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
dataa => \GRFPC0.OP1_0_IV\(50),
datab => \GRFPC0.OP1_0_IV\(53),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
dataa => \GRFPC0.OP1_0_IV\(50),
datab => \GRFPC0.OP1_0_IV\(47),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
dataa => \GRFPC0.OP1_0_IV\(47),
datab => \GRFPC0.OP1_0_IV\(44),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\,
datad => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_A\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_1_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_A\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_155\);
GRFPC0_STDDEP_0_SQMUXA_169: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_169\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\,
datad => \GRFPC0.STDDEP_0_SQMUXA_145\);
GRFPC0_REGDEP_1_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010100000010100")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_4\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPC0_REGDEP_1_SQMUXA_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010100000010100")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_5\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPC0_REGDEP_1_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100100000010010")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_3\,
dataa => \GRFPC0.WR2.CTRL.RD\(0),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_I_M2_X\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPC0_FP_PIPELINE_V_STATE6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE6\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.FPRDY4\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.FPRDY4\);
GRFPC0_UN28_WREN_M8_I_A5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.UN28_WREN_M8_I_A5\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.FPRDY4\,
datac => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_RNI7VEN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPC0.FPEXC_0_SQMUXA_1_0\,
dataa => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datab => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\);
GRFPC0_RFA2_RS2SEL_RET_9_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPC0.FPUSEL_1_0_4__G4\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.0.WRSEL4\,
datac => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FPUSEL_1_0_4__G5\);
\GRFPC0_FPUSEL_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101100001111")
port map (
combout => \GRFPC0.FPUSEL_1\(2),
dataa => \GRFPC0.EXSEL_1_X\(2),
datab => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
datac => \GRFPC0.FPUSEL_1_A\(2),
datad => \GRFPC0.FP_PIPELINE.1.EXEN7_4\);
\GRFPC0_FPUSEL_1_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPC0.FPUSEL_1_A\(2),
dataa => \GRFPC0.MEMSEL_1_X\(2),
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
datac => \GRFPC0.FPUSEL_1_0_3__G0_E_3\);
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_3\(0),
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.5.STDEP_212_1\(0));
\GRFPC0_FP_PIPELINE_13_1_REGDEPX_242_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_242\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(1));
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_3\(1),
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(1),
datad => \GRFPC0.FP_PIPELINE.5.STDEP_212_1\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_172_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_1\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_168_3\(0));
\GRFPC0_FP_PIPELINE_4_STDEP_172_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111010101")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_2\(1),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_168_1\(1),
datad => \GRFPC0.FP_PIPELINE.4.STDEP_168_2\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111101")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_3\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL1_I_0_A2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_A\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_A\(1),
dataa => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL1_I_0_A2_I_O2\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_46\,
datad => \GRFPC0.STDEP_2_SQMUXA_131_0_A2\);
GRFPC0_UN1_STDDEP_0_SQMUXA_107: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100110011")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_107\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL1_I_0_A2_I_O2\,
datac => \GRFPC0.UN1_STDEP2194\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_6_1_REGDEPX_116_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.REGDEPX_116\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_114\(1));
\GRFPC0_FP_PIPELINE_REN1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_4\(1),
dataa => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP_0\,
datab => \GRFPC0.FP_PIPELINE.UN14_REN1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.L4_4\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP4\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_A3_0_0_A2\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(15),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001011001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(24),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(27),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001011001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(29),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(36),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.L4_1\(1),
datad => \GRFPU0.GRFPU_X0.L4_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(16),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(16));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_M3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M3\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(11),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_I_M3\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(14),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(56));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(13),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(13));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(10),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(19),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(28),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(36),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(27),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(35),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(26),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(34),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(25),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(33),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(32),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(22),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(30),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(29),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(20),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(28),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(19),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(27),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(26),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(25),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(16),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(24),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(15),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(23),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV_I_A2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(21),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(12),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(20),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(19),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(17),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(16),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(15),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(14),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(13),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(12),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(11),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(10),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(9),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(8),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O2_0\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.SIGN1_2_I_0_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2\);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_3_RNIJV8P: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(63),
datad => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I\(17),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_1\(16),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(35),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35));
GRFPU0_GRFPU_X0_COMB_UN138_RNDOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\,
datad => \GRFPU0.GRFPU_X0.RNDOP_32_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_A\(0),
datad => \GRFPU0.GRFPU_X0.L4_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\,
datad => \GRFPU0.GRFPU_X0.L3_0_3\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(17),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(18),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPC0.OP1_0_IV\(14),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(22),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP1\,
datab => \GRFPC0.OP1_0_IV\(23),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(31),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(15),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPC0.OP2_I_M2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP3\,
datab => \GRFPC0.OP2\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(22),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.L4_4\(1),
datac => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.L4_4\(1),
datac => \GRFPU0.GRFPU_X0.L4_4\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(16),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(33),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001011001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\(8),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_M3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M3\(15),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(15),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_I_M3\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_47_1_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47_1\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.SIGN1_0_A3\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV\(63));
\GRFPU0_GRFPU_X0_ITADDI2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110010101101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITADDI2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.L3_1_2\(0),
datac => \GRFPU0.GRFPU_X0.L3_0_4\(5),
datad => \GRFPU0.GRFPU_X0.L3_0_6\(0));
GRFPU0_GRFPU_X0_VITER_DBUF_13_SUM2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100110101001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13_SUM2\,
dataa => \GRFPU0.GRFPU_X0.L4_1\(2),
datab => \GRFPU0.GRFPU_X0.L4_1\(1),
datac => \GRFPU0.GRFPU_X0.L4_1\(0));
\GRFPU0_GRFPU_X0_ITADDI2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110010101101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITADDI2_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.L3_1_2\(1),
datac => \GRFPU0.GRFPU_X0.L3_0_4\(5),
datad => \GRFPU0.GRFPU_X0.L3_0_6\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2\,
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(7));
GRFPU0_GRFPU_X0_COMB_UN7_G_SP_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN7_G_SP_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(28),
datad => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U\);
\GRFPC0_RFA2_FOP_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0\,
dataa => \GRFPC0.RFA2.FOP_0_0_X2\(1),
datab => \GRFPC0.INST_I\(8),
datac => \GRFPC0.RDWR_5_SQMUXA_0\,
datad => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A\);
\GRFPC0_RFA2_FOP_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010010000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST\(31),
datac => \GRFPC0.INST_I\(10),
datad => \GRFPC0.INST_I\(11));
GRFPC0_FP_PIPELINE_UN1_VFIFO_FULL10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.UN1_VFIFO.RD_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\);
GRFPU0_GRFPU_X0_UN1_ST3_FARRES_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_ADDOF_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC\);
GRFPU0_GRFPU_X0_ITER_FLUSH0_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G0_E_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA_1\);
GRFPU0_GRFPU_X0_COMB_VST4_REG36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG36\,
dataa => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2));
GRFPU0_GRFPU_X0_COMB_VST4_REG38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG38\,
dataa => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPC0_D_STLCK_RNO_5_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_2\,
dataa => \GRFPC0.D.STLCK_0_0_9__G1_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1\(1),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
\GRFPC0_D_STLCK_RNO_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_1\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_113_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_0\(1));
\GRFPC0_D_STLCK_RNO_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.D.STLCK_0_0_27__G1_1\,
datac => \GRFPC0.STDEP_0_SQMUXA_108_0\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_4_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101011101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_0\,
dataa => \GRFPC0.D.STLCK_0_0_10__G1_TZ_X\,
datab => \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_0_0\(0));
\GRFPC0_D_STLCK_RNO_2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_2\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\,
datac => \GRFPC0.D.STLCK_0_0_11__G1_1\);
\GRFPC0_D_STDLCK_RNO_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_1\,
datac => \GRFPC0.D.STDLCK_0_0_9__G1_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_10_X\);
\GRFPC0_D_STLCK_RNO_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_24__G1_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_2_0\(0));
\GRFPC0_D_STLCK_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111011")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_0__G1_1\,
datab => \GRFPC0.STDDEP_0_SQMUXA_108_I_0_0_O3\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_42_0_IV_I_A2_1\(0),
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_D_STLCK_RNO_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_1\(12),
datac => \GRFPC0.D.STLCK_0_0_14__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_4\(0));
\GRFPC0_D_STLCK_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_1\(1),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_X\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1\(1),
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_3\(1));
\GRFPC0_D_STLCK_RNO_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_5\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_3\(1),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_2\(1),
datad => \GRFPC0.D.STLCK_0_0_31__G3\);
\GRFPC0_D_STDLCK_RNO_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datab => \GRFPC0.STDDEP_0_SQMUXA_84\,
datac => \GRFPC0.D.STDLCK_0_0_8__G1_1\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_D_STLCK_RNO_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001110")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datab => \GRFPC0.D.STLCK_0_0_20__G1_2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_D_STLCK_RNO_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111010")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_1\,
dataa => \GRFPC0.D.STLCK_0_0_16__G1_TZ\,
datab => \GRFPC0.STDDEP_0_SQMUXA_28_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0),
datad => \GRFPC0.FP_PIPELINE.8.STDEP_358_0_IV_I_A2\(0));
\GRFPC0_D_STLCK_RNO_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_2\(0),
datab => \GRFPC0.D.STLCK_0_0_6__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A3\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_0\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(38));
\GRFPC0_D_STLCK_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111010")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_1__G1_1\,
datab => \GRFPC0.STDDEP_0_SQMUXA_108_I_0_0_O3\,
datac => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_3\(1));
\GRFPC0_D_STLCK_RNO_2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datac => \GRFPC0.D.STLCK_0_0_13__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPC0_UN1_REGDEP79_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011011111111")
port map (
combout => \GRFPC0.UN1_REGDEP79_2\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
datac => \GRFPC0.UN1_REGDEP79_0\,
datad => \GRFPC0.FP_PIPELINE.0.EXEN2_3\);
\GRFPC0_D_STLCK_RNO_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datab => \GRFPC0.STDDEP_0_SQMUXA_7_I_I_A4_I_O2\,
datac => \GRFPC0.D.STLCK_0_0_4__G1_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_0\(0));
\GRFPC0_D_STDLCK_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_3_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\,
datab => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datac => \GRFPC0.D.STDLCK_0_0_4__G1_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\);
\GRFPC0_D_STLCK_RNO_6_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1\(1));
GRFPC0_RFA2_RS2DEP_RNO_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2_0\,
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\);
\GRFPC0_D_STLCK_RNO_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111010")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_3\,
dataa => \GRFPC0.D.STLCK_0_0_30__G1_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datac => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2\(0));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_51_M3_0_A2_RNIIRM8C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111110111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_A4_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3_A\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M1_E\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_2_RNIM0HQ_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_3_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(51),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_1_0\(52));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_3_RNI3M3E2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110110010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_6_1\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_3\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_8_0\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_1\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_1\,
dataa => \GRFPC0.N_201\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0\);
\GRFPC0_D_STDLCK_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_1__G1_0\,
datab => \GRFPC0.STDDEP_0_SQMUXA_113_0_A2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_106_I_0_0_O4_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0\);
\GRFPC0_D_STDLCK_RNO_4_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.D.STDLCK_0_0_13__G1_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STDLCK_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.D.STDLCK_0_0_3__G1_2\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_LDLCK_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_5\,
dataa => \GRFPC0.D.LDLCK_0_0_7__G1_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4\(7),
datac => \GRFPC0.D.LDLCK_0_0_7__G1_3\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_0\(7));
\GRFPC0_D_STLCK_RNO_7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_11_2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN348_DEP\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_10\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_11\(1));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_0_RNIQPPK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_3\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_1\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\,
datad => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_2\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_5\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4\);
\GRFPC0_D_LDLCK_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(25),
datab => \GRFPC0.D.LDLCK_0_0_25__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.D.LDLCK_0_0_25__G1_3_A\);
\GRFPC0_D_LDLCK_RNO_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_3_A\,
dataa => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3944_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0_2\(1));
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_A2_3_RNI4J523_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_6_1\(1),
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_7\(1),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_12\(1),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_8\(1),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_3\(0));
\GRFPC0_D_STLCK_RNO_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_4_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_9\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_0_A2_0_A2_I\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_11_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_7\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_5\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_5\(1));
\GRFPC0_D_STDLCK_RNO_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_3\,
dataa => \GRFPC0.UN1_STDEP1222\,
datab => \GRFPC0.D.STDLCK_0_0_7__G1_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_119_0_A2\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2_2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_2_2\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_9\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_D_STDLCK_RNO_10_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_4\,
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0_1\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000001100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_7\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2\(0),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3\(0),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_3\(0),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0));
\GRFPC0_D_LDLCK_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.D.LDLCK_0_0_6__G1_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_2\(53),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_0\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(53));
\GRFPC0_D_LDLCK_RNO_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_4\,
dataa => \GRFPC0.D.LDLCK_0_0_21__G1_1\,
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_4\(21),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\(5));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_8\(0),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1\(0),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_D_LDLCK_RNO_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1_X\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_X\(8));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_2\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6108_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\(1));
\GRFPC0_D_LDLCK_RNO_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_24__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(28),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_A4_X\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_7\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_TZ\(0),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_5\(0),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_4\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O2_RNIV5PU2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1_0_3\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.D.LDLCK_0_0_29__G1_0_1\,
datad => \GRFPC0.D.LDLCK_0_0_29__G1_0_0\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A3_0_RNIU3KD3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_7\,
dataa => \GRFPC0.D.LDLCK_0_0_11__G3_0_3\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_0_2\,
datac => \GRFPC0.D.LDLCK_0_0_11__G3_0_0\,
datad => \GRFPC0.D.LDLCK_0_0_11__G3_0_1\);
\GRFPC0_D_LDLCK_RNO_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_1\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_4_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21),
datad => \GRFPC0.D.LDLCK_0_0_9__G1_1_A\);
\GRFPC0_D_LDLCK_RNO_4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_1_A\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0_X\(9),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(9),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\(8));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_9\(1),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_7\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_8\(0),
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1_2\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1\(51),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(51),
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_2\(53),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1_1\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(53));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_7\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_TZ_TZ\(0));
\GRFPC0_D_LDLCK_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_3\,
dataa => \GRFPC0.D.LDLCK_0_0_0__G1_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_0\(0),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_7\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_4\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1_M9_I_A4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_10\(1),
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4\(1),
datab => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_4\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_8\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4313_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_2\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_6\(1));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_43\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_39\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_38\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_42\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_25\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_26\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_13\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_6\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_5\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_TZ\(0));
\GRFPC0_D_LDLCK_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1_4\,
dataa => \GRFPC0.D.LDLCK_0_0_22__G1_0\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1\(0),
datac => \GRFPC0.D.LDLCK_0_0_22__G1_1\,
datad => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0\(0));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_0\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M17_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M16_4_03_0_G2\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_5_TZ\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_4_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_0\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_20\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8_TZ\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_0\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18_A\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_TZ\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001011110011111")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_18_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M16_4_03_0_G2\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_5_TZ\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G0\);
\GRFPC0_FIFO_WR_RNO_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000010100000")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3_1\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(61),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1_A\(61),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD9\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_1_1\(61));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_1_A_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1_A\(61),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datab => \GRFPU0.GRFPU_X0.UN23_EXP\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_1_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(62),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD10\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_2\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_0\(62),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_1_1\(61));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_2\,
dataa => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\,
datab => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_10\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_8\(1),
dataa => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_4_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_6\(1));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_2_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_2_12\,
dataa => \GRFPC0.OP1_0_IV\(15),
datab => \GRFPC0.OP1_0_IV_I_A2\(13));
\GRFPC0_D_LDLCK_RNO_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_1\,
dataa => \GRFPC0.D.LDLCK_0_0_18__G1_0\,
datab => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(7));
\GRFPC0_D_STDLCK_RNO_15_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_6\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datab => D_M2_E_4_0,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_2\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_28_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_28\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_25_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25_A\(18),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M16_4_03_0_G2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_25_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111001111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_25_A\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_24_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_4_03_0_G0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G0\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_3\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_2\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_8_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_8\(22),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_4\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_2\(22),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_6\(22));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_7_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_7\(22),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(22),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_1\(22));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_6\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_TZ\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_6\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_TZ\(1),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0\(1));
GRFPC0_V_FSR_FCC_2_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101000000000")
port map (
combout => \GRFPC0.V.FSR.FCC_2_SQMUXA_1\,
dataa => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.UN25_HOLDN_0\);
GRFPC0_V_FSR_FCC_3_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.V.FSR.FCC_3_SQMUXA_0\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR2.CTRL.CCWR\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.FPRDY4\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8\(0),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0_A\(0),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_0_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2_0_A\(0),
dataa => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN962_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11\(1));
GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_M6_I_A3_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101110000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_M6_I_A3_I_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5003_REGDEPX2_I_I_A2\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_333_0_A3_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\);
GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_M6_I_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M6_I_A3_0\,
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6398_REGDEPX2_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\);
GRFPC0_FP_PIPELINE_12_REGDEPX2_370_1_M6_I_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M6_I_A3_0\,
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5516_REGDEPX2_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(52),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(52));
GRFPC0_UN28_WREN_M8_I_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011111111")
port map (
combout => \GRFPC0.UN28_WREN_M8_I_3\,
dataa => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.UN28_WREN_M8_I_1\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.FP_PIPELINE.UN25_HOLDN_0\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_1\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA_1_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_0\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_1\,
dataa => \GRFPU0.GRFPU_X0.C_ADD10\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_0\);
GRFPU0_GRFPU_X0_COMB_ADDI3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_6\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_4\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_1\);
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datad => \GRFPU0.GRFPU_X0.UN1_VST2.REG108\);
GRFPC0_VFIFO_INST_1_1_SQMUXA_M1_E_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_2_1\,
dataa => \GRFPC0.FIFO.FULL_M_0_2_1_X\,
datab => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.FULL\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
\GRFPC0_FP_PIPELINE_REN1_1_IV_A_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_2_I_M_0\(1),
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.FP_PIPELINE.STDBL_1_1_U\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
GRFPC0_WREN_2_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.WREN_2_SQMUXA_4\,
dataa => \GRFPC0.WR2.CTRL.RDD_REP1\,
datab => \GRFPC0.WR2.CTRL.CCWR\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN25_HOLDN_0\);
GRFPU0_GRFPU_X0_COMB_UN57_RNDOP_0_RNISEPV41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_8_RNILCONO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A\,
dataa => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A5_0_1\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_A2_2_0_RNIEFUA1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0\(1),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_0\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2\,
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\(2));
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST2.QSNAN12\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datac => \GRFPU0.GRFPU_X0.VST2.EXC_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\);
GRFPC0_FP_PIPELINE_UN1_WR2_CTRL_CCWR_RNITBJ81: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.UN28_WREN_M8_I_A5_2\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\);
GRFPC0_RFA2_RS2DEP_RNO_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2_0\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
GRFPC0_VFIFO_PC_0_1_SQMUXA_0_A2_M1_E_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2\,
dataa => \GRFPC0.FIFO.FULL_M_0_2_1_X\,
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_1\);
\GRFPC0_D_STLCK_RNO_5_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I\,
dataa => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_2_1_M6_I_0_X\,
datac => D_M3_1,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_1\(1));
GRFPC0_FP_PIPELINE_0_REGDEP62_I_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0\(0),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1\(0),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_3\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_2_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O2_9\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_5\);
\GRFPC0_D_STLCK_RNO_7_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6_1\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_1\(0),
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\(0),
datad => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_1_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_0\(12),
dataa => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_5\(12),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1_0\(12));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4\(0),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_0\(0),
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_1\(0),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_0\(0),
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2\(0));
GRFPC0_FP_PIPELINE_0_REGDEP14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP14\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP14_0\,
datad => \GRFPC0.UN1_WRENX2_2_0\);
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_1\);
GRFPC0_RFA_STDFQ_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2\,
dataa => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_4\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\,
datad => CPO_LDLOCKZ);
GRFPC0_FP_PIPELINE_0_EXSEL4_I_A2_RNIU8SJ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FPUSEL_1_0_1__G0\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.0.EXSEL4_I_A2\,
datac => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7_4\);
GRFPC0_FP_PIPELINE_UN29_WREN_1_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
datad => \GRFPC0.UN28_WREN_M8_I_A5_2\);
GRFPU0_GRFPU_X0_FLTYPE_5_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000001100")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_5_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_5\,
datab => \GRFPU0.GRFPU_X0.EXP_1_SQMUXA_I\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_6\);
GRFPC0_FP_PIPELINE_0_REGDEP30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP30_0\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2_0\);
\GRFPC0_FP_PIPELINE_2_REGDEPX_48_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_0\(0));
\GRFPC0_D_STLCK_RNO_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_11_1\(1));
GRFPC0_FP_PIPELINE_1_REGDEP172: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP172\,
dataa => \GRFPC0.RFA.RDWR\,
datab => \GRFPC0.RFA.WRITE_RD_M\,
datac => \GRFPC0.UN1_VDIV.EXEC7\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP172_2\);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_A2_2\(0),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_3\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_REP0_RNIQ85M3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000000000")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_A3\,
dataa => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_O3_1\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_3\(0),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_M2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_4\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_4\(0));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3300_DEP_RNI9MJ51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_16\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3300_DEP_RNIEUVM1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_15\(1),
dataa => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1_0\);
\GRFPC0_FP_PIPELINE_1_0_STDEP_65_0_IV_I_A4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2\(0),
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\,
datab => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN348_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011011100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_6\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDEP10_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_27_0_A2_0_A2_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPC0_RFA_RDD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2\,
dataa => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_3_X\,
datab => \GRFPC0.RFA.RDD_0_0_G1_0_A2_4_0\,
datac => CPO_LDLOCKZ,
datad => CPO_EXCZ);
GRFPU0_GRFPU_X0_ITER_NX_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
datad => \GRFPU0.GRFPU_X0.COMB.STICKY_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_3\(1));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_46\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(49));
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNIA7151_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG21\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(45));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2_0\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_A\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_0\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_A\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD0\,
datac => \GRFPU0.GRFPU_X0.C_ADD10\,
datad => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_3\(0));
GRFPU0_GRFPU_X0_ST3_EMIN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_5\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3\);
GRFPU0_GRFPU_X0_ST3_EMAX_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_S\);
GRFPU0_GRFPU_X0_ST2_ZERO_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2\,
dataa => \GRFPU0.GRFPU_X0.VST2.REG_3_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datad => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_3\);
GRFPU0_GRFPU_X0_UN1_VST3_REG22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100111111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFN\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG21\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_1\,
datab => \GRFPU0.GRFPU_X0.G_53_REP0\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_O3\(10));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_2\,
datab => \GRFPU0.GRFPU_X0.G_53_REP0\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I_A4_0\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(45));
\GRFPU0_GRFPU_X0_EXPT_CNST_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_CNST_0_A2\(1),
dataa => \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_7\(21));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_0\,
datab => \GRFPU0.GRFPU_X0.G_53_REP0\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_O3\(6));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(40),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_5\(21));
GRFPU0_GRFPU_X0_COMB_VST1_V4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V4\,
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_5\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_15_5\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V4_A\);
GRFPU0_GRFPU_X0_COMB_VST1_V4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V4_A\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(5),
datac => \GRFPC0.FP_PIPELINE.UN8_OP_7_1\,
datad => \GRFPC0.FP_PIPELINE.UN11_OP_7_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_IV_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.UN1_VST2.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV_0\(63),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M\(63));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIAS8KC_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61_1\,
datac => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_A5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000101010")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_0\,
dataa => \GRFPC0.INST_I_M5\(19),
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_2\,
datac => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_7_0_A2\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2\);
GRFPC0_VFIFO_FULL_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.VFIFO.FULL_3_SQMUXA\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datac => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
datad => CPO_EXCZ);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_5\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2\,
datad => \GRFPU0.GRFPU_X0.N_58_I_I_O2\);
GRFPU0_GRFPU_X0_COMB_VST4_REG37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
dataa => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I_M2\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES_1_IV\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\,
datad => \GRFPU0.GRFPU_X0.N_16368_M_2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_2\(48),
datab => \GRFPU0.GRFPU_X0.G_53_REP0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(48));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_7_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5\(0),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_0\(0),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_3\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(44),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_4\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4\(44));
GRFPC0_FP_PIPELINE_UN1_WR2_RREG_RESV_RNI5LGJ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_HOLDN_1\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datad => \GRFPC0.UN28_WREN_M8_I_A5_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_4_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_M2\(41),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_4\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_1_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1_0\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_0\(52),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
GRFPC0_FP_PIPELINE_UN205_HOLDN_3_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datac => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_5\,
datad => CPO_LDLOCKZ);
GRFPC0_RFA2_RS2DEP_RNO_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0_0\,
dataa => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_5_2_RNI0HUI6_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110100011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(111),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_2\(52));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101001100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_2_A2_1\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_TZ\,
datac => \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_YY_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_YY\(46),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_XX_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_XX\(46),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_YY_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_YY\(48),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_XX_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_XX\(48),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(48));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0_RNIF6LL: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1_U\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2\);
\GRFPC0_FP_PIPELINE_4_STDEP_172_1_D_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_1_D\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_168_2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0\(40),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3\(40),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(40));
\GRFPU0_GRFPU_X0_L4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(0),
dataa => \GRFPU0.GRFPU_X0.L4_D\(0),
datab => \GRFPU0.GRFPU_X0.L4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M6_0\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
datac => D_M7,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_O2_0_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3_TZ_0\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPU0_GRFPU_X0_L3_0_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0\(1),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_3_0_0\(1),
datac => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0\(1),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(41),
dataa => \GRFPC0.OP2\(44),
datab => \GRFPC0.OP2\(41),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(44),
dataa => \GRFPC0.OP2\(47),
datab => \GRFPC0.OP2\(44),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(47),
dataa => \GRFPC0.OP2\(50),
datab => \GRFPC0.OP2\(47),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(50),
dataa => \GRFPC0.OP2\(50),
datab => \GRFPC0.OP2\(53),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => NN_1,
dataa => \GRFPC0.OP1_0_IV\(32),
datab => \GRFPC0.OP1_0_IV\(29),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(34),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(34),
datac => \GRFPC0.OP1_0_IV\(37));
\GRFPC0_FP_PIPELINE_5_1_REGDEPX_98_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.REGDEPX_98\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96_I\(0));
GRFPC0_WR_CTRL_PEND_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010101010")
port map (
combout => \GRFPC0.WR.CTRL.PEND_0_0_G1_0\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.WR.CTRL.PEND\,
datac => \GRFPC0.FIFO_INC_2_SQMUXA\,
datad => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S\);
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0\(0),
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_2\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_590_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_590\(1),
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
GRFPC0_FP_PIPELINE_1_DIVEN10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10\,
dataa => \GRFPC0.DIV.RD\(3),
datab => RFI2_RD2ADDRZ(2),
datac => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_1_1\,
datad => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\);
\GRFPC0_FP_PIPELINE_8_1_REGDEPX_152_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.REGDEPX_152\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150_I\(0));
\GRFPC0_R_STATE_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011101000100")
port map (
combout => \GRFPC0.R.STATE_0_0_1__G2\,
dataa => \GRFPC0.DIV.PEND_1_0_G1_0_I_A5_0\,
datab => \GRFPC0.RFAREG.R.STATE_4_M2S2\,
datac => \GRFPC0.R.STATE_0_0_1__G2_A\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_R_STATE_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010111")
port map (
combout => \GRFPC0.R.STATE_0_0_1__G2_A\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\);
GRFPC0_FP_PIPELINE_1_EXEN7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7\,
dataa => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
datab => \GRFPC0.FP_PIPELINE.1.EXEN7_4\);
GRFPC0_FP_PIPELINE_0_UN1_DIV_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.DIV.RD\(0),
datad => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_96_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96\(1),
dataa => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_94\(1));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPC0.V.STDATA_14_REP1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3\);
GRFPC0_RFA2_RS2SEL_RET_9_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPC0.FPUSEL_1_0_4__G5\,
dataa => N_38,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.1.WR2EN10\);
\GRFPC0_FPUSEL_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010100000")
port map (
combout => \GRFPC0.FPUSEL_6\(2),
dataa => \GRFPC0.EXSEL_1_X\(2),
datab => \GRFPC0.MEMSEL_1_X\(2),
datac => \GRFPC0.FP_PIPELINE.0.EXEN2\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E\);
\GRFPC0_FP_PIPELINE_5_STDEP_212_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_1\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_13\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datad => \GRFPC0.UN1_STDDEP_0_SQMUXA_104_0_A5\);
\GRFPC0_FP_PIPELINE_0_STDEP_8_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDEP10_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_M2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
GRFPC0_WR2_CTRL_PEND_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010101100")
port map (
combout => \GRFPC0.WR2.CTRL.PEND_0_0_G1_0\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.WR2.CTRL.PEND_0_0_G1_0_A3_1\,
datac => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
datad => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\);
GRFPC0_WR2_EXC_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPC0.WR2.EXC_0_0_G0_0\,
dataa => \GRFPC0.WR2.EXC_0_0_G0_0_A3_2\,
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.WR2.EXC_0_0_G0_0_M3\);
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_24_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_24\(1),
dataa => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_22\(1));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_258_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(0),
dataa => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_212_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_1\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(1));
GRFPC0_UN1_VDIV_EXEC7_RNIDJ7S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.FLDLCK_1_828\,
dataa => \GRFPC0.RFA.RDWR\,
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\,
datac => \GRFPC0.RFA.WRITE_RD_M\,
datad => \GRFPC0.UN1_VDIV.EXEC7\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2\(12),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1_0\(12));
\GRFPC0_FP_PIPELINE_4_STDEP_168_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101101010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_3\(0),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_164_0_IV\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A3_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.D.LDLCK_0_0_23__G1_3\);
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_150_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150\(1),
dataa => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\(1));
\GRFPC0_FP_PIPELINE_13_0_STDEP_545_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110101")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.STDEP_545\(1),
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
datab => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datad => \GRFPC0.STDEP_0_SQMUXA_84_1_0\);
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0_O2\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(15),
dataa => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1\(15),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\(0));
GRFPC0_FP_PIPELINE_UN14_REN1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100011011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN14_REN1\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_RNDOP_32_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_32_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.GRFPU_X0.RNDOP_32_0_A3_0\(0));
GRFPU0_GRFPU_X0_COMB_UN6_LESS_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_LESS_0_A3\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4\(55),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD49\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I\(12),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3_0\(12),
datac => \GRFPU0.GRFPU_X0.N_20664\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(12));
GRFPU0_GRFPU_X0_ST3_ZERO_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.RDY_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_28\,
dataa => \GRFPC0.OP1_0_IV\(28),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_27\,
dataa => \GRFPC0.OP1_0_IV\(27),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_26\,
dataa => \GRFPC0.OP1_0_IV\(26),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_25\,
dataa => \GRFPC0.OP1_0_IV\(25),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_24\,
dataa => \GRFPC0.OP1_0_IV\(24),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_22\,
dataa => \GRFPC0.OP1_0_IV\(22),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_21\,
dataa => \GRFPC0.OP1_0_IV\(21),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_20\,
dataa => \GRFPC0.OP1_0_IV\(20),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_19\,
dataa => \GRFPC0.OP1_0_IV\(19),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_18\,
dataa => \GRFPC0.OP1_0_IV\(18),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_17\,
dataa => \GRFPC0.OP1_0_IV\(17),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_16\,
dataa => \GRFPC0.OP1_0_IV\(16),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_15\,
dataa => \GRFPC0.OP1_0_IV\(15),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_13\,
dataa => \GRFPC0.OP1_0_IV_I_A2\(13),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_12\,
dataa => \GRFPC0.OP1_0_IV\(12),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_11\,
dataa => \GRFPC0.OP1_0_IV\(11),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_9\,
dataa => \GRFPC0.OP1_0_IV\(9),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_8\,
dataa => \GRFPC0.OP1_0_IV\(8),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_7\,
dataa => \GRFPC0.OP1_0_IV\(7),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_6\,
dataa => \GRFPC0.OP1_0_IV\(6),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_5\,
dataa => \GRFPC0.OP1_0_IV\(5),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_4\,
dataa => \GRFPC0.OP1_0_IV\(4),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_3\,
dataa => \GRFPC0.OP1_0_IV\(3),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_2\,
dataa => \GRFPC0.OP1_0_IV\(2),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_1\,
dataa => \GRFPC0.OP1_0_IV\(1),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_0\,
dataa => \GRFPC0.OP1_0_IV\(0),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(13),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(32),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(60),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV\(60));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(49),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(49),
datac => \GRFPC0.OP1_0_IV\(52));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(48),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(51),
datac => \GRFPC0.OP1_0_IV\(48));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(46),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(49),
datac => \GRFPC0.OP1_0_IV\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(43),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(43),
datac => \GRFPC0.OP1_0_IV\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(40),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(43),
datac => \GRFPC0.OP1_0_IV\(40));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_M2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_M2\(37),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(37),
datac => \GRFPC0.OP1_0_IV\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(19),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(19),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(34),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(11),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(14),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(28),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_A\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_A_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_A\(28),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(28),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(28),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(28));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(59),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(59));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(16),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(16));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(14),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_I_M3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_I_M3\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(11),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_I_M3\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(56),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(56));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(21),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(21),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_A\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_A_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_A\(21),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(20),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(20),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(20));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(13),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(13));
GRFPU0_GRFPU_X0_COMB_S_SP_1_1_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U\,
dataa => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U_A\,
datab => \GRFPU0.GRFPU_X0.S_SP_23\,
datac => \GRFPU0.GRFPU_X0.S_SP_22\,
datad => \GRFPU0.GRFPU_X0.S_SP_24\);
GRFPU0_GRFPU_X0_COMB_S_SP_1_1_U_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1_U_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(10),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(19),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(19));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNIITB32_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(55),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD3\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(55));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1\(17),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(17),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(17));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN41_DP_RNIH4CE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010100011")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_11\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN22_DP\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_10\,
dataa => \GRFPC0.OP1_0_IV\(10),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_14\,
dataa => \GRFPC0.OP1_0_IV\(14),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_23\,
dataa => \GRFPC0.OP1_0_IV\(23),
datab => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(26),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(26),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(26));
\GRFPU0_GRFPU_X0_VST3_REG_47_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(38));
\GRFPU0_GRFPU_X0_VST3_REG_47_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(46));
\GRFPU0_GRFPU_X0_L4_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(0),
dataa => \GRFPU0.GRFPU_X0.L4_2_1\(0),
datab => \GRFPU0.GRFPU_X0.L3_0\(0),
datac => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(30),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(23),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_0_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(0));
GRFPC0_FP_PIPELINE_UN22_REN1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN22_REN1\,
dataa => N_38,
datab => \GRFPC0.RFA.RS1\(0),
datac => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
GRFPC0_FP_PIPELINE_UN26_OP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_OP\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.FP_PIPELINE.UN30_OP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(25),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_I_M3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_I_M3\(15),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(15),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(15));
GRFPU0_GRFPU_X0_UN1_VST4_SEL2_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101111111111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_2\);
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\,
datad => \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(62),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(62));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_A2\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datac => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\);
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100110011")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0\,
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4_A\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2\);
GRFPC0_UN1_RDWR_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_A\);
GRFPC0_UN1_RDWR_3_SQMUXA_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111001100")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_A\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST_I\(10),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.INST_I\(11));
GRFPC0_FP_PIPELINE_VFIFO_FULL_6_F0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100001000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6_F0\,
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.UN1_VFIFO.RD_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\);
\GRFPC0_UN1_VFIFO_FULL_0_SQMUXA_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001001110010")
port map (
combout => \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\(0),
dataa => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datab => \GRFPC0.VFIFO.FULL_1_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
datad => CPO_EXCZ);
\GRFPU0_GRFPU_X0_VST3_REG_47_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(41));
GRFPU0_GRFPU_X0_ST3_DIFFV_RNI5OM92: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPINC\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_0\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(56));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_0\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(58));
\GRFPU0_GRFPU_X0_L4_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(1),
dataa => \GRFPU0.GRFPU_X0.L3_1_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_5\(1),
datac => \GRFPU0.GRFPU_X0.L3_0_3\(5));
\GRFPU0_GRFPU_X0_L4_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(0),
dataa => \GRFPU0.GRFPU_X0.L3_1_1\(0),
datab => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datac => \GRFPU0.GRFPU_X0.L3_0_5\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(60),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_1\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_A\(60),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(60));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_A_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_A\(60),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_O2\(59),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD8\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_1\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_A\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_A\(59),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_O2\(59),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD7\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(10),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(10));
\GRFPC0_D_STLCK_RNO_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_1\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_82_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.13.STDEP_550_I_M_2\(0),
datad => \GRFPC0.FP_PIPELINE.13.STDEP_558\(1));
\GRFPC0_D_STLCK_RNO_7_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_0\,
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_6_X\(1),
datac => \GRFPC0.EX.CTRL.RDD\,
datad => \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\);
\GRFPC0_D_STLCK_RNO_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_TZ\(0),
datab => \GRFPC0.D.STLCK_0_0_8__G1_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\,
datad => \GRFPC0.FP_PIPELINE.4.0.STDEP_185_I_M_2\(0));
\GRFPC0_D_STLCK_RNO_9_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_X\(1),
datab => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A4_X\(1),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.STDDEP_0_SQMUXA_119_0_A2\);
GRFPC0_RFA2_RS2DEP_RNO_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_S_0\,
dataa => \GRFPC0.FP_PIPELINE.1.REGDEP146_0\,
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3\,
datac => \GRFPC0.REGDEP_1_SQMUXA_11\,
datad => \GRFPC0.UN1_REGDEP133\);
\GRFPC0_D_STLCK_RNO_4_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_5_X\(1),
datab => \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datad => \GRFPC0.D.STLCK_0_0_11__G3_0\);
\GRFPC0_D_STLCK_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_2_1_0\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4\,
datad => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\);
\GRFPC0_D_STLCK_RNO_5_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_7_0\(1),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_6_X\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_4_I_I_A2_I_X\,
datad => \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\);
\GRFPC0_D_STLCK_RNO_7_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_0\,
dataa => \GRFPC0.D.STLCK_0_0_28__G1_TZ\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_10\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1));
\GRFPC0_D_STLCK_RNO_2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_X\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A4_X\(0),
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.STDDEP_0_SQMUXA_119_0_A2\);
\GRFPC0_D_STLCK_RNO_5_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5_2\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_2\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_594_I_M_2\(0),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_X\(0),
datad => \GRFPC0.D.STLCK_0_0_29__G1_A5\);
\GRFPC0_D_STDLCK_RNO_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000110000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_5\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.N_19067_1_I_I_A2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_2_X\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_2\);
\GRFPC0_D_STLCK_RNO_4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_2\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2\(1),
datac => \GRFPC0.D.STLCK_0_0_19__G1_0\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2\(0));
\GRFPC0_D_STLCK_RNO_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3543_DEP\,
datab => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datad => \GRFPC0.D.STLCK_0_0_20__G1_1\);
GRFPC0_RFA2_RS2DEP_RNO_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100000000")
port map (
combout => \GRFPC0.UN1_REGDEP147_0_1\,
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEP132\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O2_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O2_5_0\(0),
dataa => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\,
datab => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_1\(12),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_4\(0));
\GRFPC0_D_STLCK_RNO_7_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datab => \GRFPC0.D.STLCK_0_0_13__G1_0\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STDLCK_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G3_2\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_0_A2_0_A2_I\(1),
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_D_STDLCK_RNO_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_10__G1_0_X\,
datab => \GRFPC0.STDDEP_0_SQMUXA_8_I_I_A2_I_X\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_122_I_I_A2_0_A2\);
GRFPC0_RFA2_RS2DEP_RNO_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1_A\,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7_3\);
GRFPC0_RFA2_RS2DEP_RNO_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_1_A\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => RFI2_RD2ADDRZ(3),
datad => RFI2_RD2ADDRZ(0));
\GRFPC0_D_STLCK_RNO_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101110101111")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_2\,
dataa => \GRFPC0.D.STLCK_0_0_2__G1_1\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.STDDEP_0_SQMUXA_106_I_0_0_O4_I_O2\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_3\(0),
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_278_0_O2_I_A3\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_0_X\(0));
GRFPC0_RFA2_RS1DEP_RNO_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_1\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP66_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.EXEN2\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111110100011")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3_0\,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL1_I_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_3_0_RNI7HAS: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_11_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3_0\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL1_I_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0_A\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_1_0_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_1_0_A\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_D_STDLCK_RNO_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_3\,
dataa => \GRFPC0.D.STDLCK_0_0_14__G1_0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_101\,
datad => \GRFPC0.STDDEP_0_SQMUXA_111\);
\GRFPC0_D_STDLCK_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datac => \GRFPC0.D.STDLCK_0_0_2__G1_0_X\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_3_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_1\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_0\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2_0\(56),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.N_19572_1_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_9\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_3\(1),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_488_3_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNIUOATO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000001100")
port map (
combout => R_M3_0_A2_2_1,
dataa => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datab => R_M3_0_A2_2_0,
datac => R_M3_0_A2_2_1_A,
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_8_RNIUE159_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000000100")
port map (
combout => R_M3_0_A2_2_1_A,
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD49\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPC0_RFA2_RS1SEL_RET_13_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G1_0\,
dataa => N_38,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2\);
\GRFPC0_D_STDLCK_RNO_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001101")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_2\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.D.STDLCK_0_0_3__G1_0\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_RNIER081_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_6_1\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_0_WR2EN2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000010010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2_1\,
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP30_0\);
\GRFPC0_D_STDLCK_RNO_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0_4\(0),
datab => \GRFPC0.D.STDLCK_0_0_11__G1_0_X\,
datac => \GRFPC0.STDDEP_0_SQMUXA_96_0_A3\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1667_REGDEPX2_0_A2_0_A2_RNIU2OT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_6\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1667_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\,
datac => \GRFPC0.D.LDLCK_0_0_7__G3_0_0\,
datad => \GRFPC0.D.LDLCK_0_0_7__G3_0_1\);
GRFPC0_FP_PIPELINE_3_REGDEPX2_115TT_1_M3_0_A2_RNI3RBS: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_5\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_A2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_O2_0\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datad => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0_A\(1));
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_A2_1_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001010011")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_1_0_A\(1),
dataa => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1_A\(1));
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_A2_1_1_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_1_1_A\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A4_1_RNIOTA83_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0_4\,
dataa => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_1\(0),
datab => \GRFPC0.D.LDLCK_0_0_16__G1_0_0\,
datac => \GRFPC0.D.LDLCK_0_0_16__G1_0_1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1\(0));
GRFPC0_FP_PIPELINE_0_WRENX2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100100001001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_2\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
datac => \GRFPC0.FP_PIPELINE.0.WRENX2_2_A\);
GRFPC0_FP_PIPELINE_0_WRENX2_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_2_A\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
\GRFPC0_FP_PIPELINE_RS1_6_X_RNIJQUB_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000010010000")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_2\,
dataa => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.RS1_6_X\(4),
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_1\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_A2_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_2\(0),
dataa => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_5\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_4\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_6\(0),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_4\(0),
dataa => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_TZ\(0));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(54),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_1_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0_1078\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_10_X\);
\GRFPC0_D_LDLCK_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_19_1\(0),
datab => \GRFPC0.D.LDLCK_0_0_10__G3_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(10),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(10));
\GRFPC0_D_LDLCK_RNO_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3\(6),
datab => \GRFPC0.D.LDLCK_0_0_6__G1_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_0\(6),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(7));
\GRFPC0_D_LDLCK_RNO_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0\,
dataa => N_94,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15_1_X\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\(27),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(27));
\GRFPC0_D_LDLCK_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1_3\,
dataa => \GRFPC0.D.LDLCK_0_0_3__G1_1\,
datab => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_7\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_3\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_2\(0));
GRFPC0_UN1_STDDEP_0_SQMUXA_99_0_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000010100000")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_99_0_A2_0_0\,
dataa => \GRFPC0.N_19572_1_I_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\(1),
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3\(1),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_TZ\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(50));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_4\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_6\(0),
dataa => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_7\(0),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1\(0));
\GRFPC0_R_FSR_CEXC_RNO_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
dataa => \GRFPC0.CPI_M_X\(392),
datab => \GRFPC0.DIV.EXCT\(0),
datac => \GRFPC0.R.FSR.TEM\(0),
datad => \GRFPC0.V.FSR.CEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
dataa => \GRFPC0.CPI_M_X\(395),
datab => \GRFPC0.DIV.EXCT\(3),
datac => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.V.FSR.CEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\,
dataa => \GRFPC0.CPI_M_X\(393),
datab => \GRFPC0.DIV.EXCT\(1),
datac => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.V.FSR.CEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
dataa => \GRFPC0.CPI_M_X\(396),
datab => \GRFPC0.DIV.EXCT\(4),
datac => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.V.FSR.CEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_5_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\,
dataa => \GRFPC0.CPI_M_X\(394),
datab => \GRFPC0.DIV.EXCT\(2),
datac => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.V.FSR.CEXC_1_SQMUXA\);
\GRFPC0_D_LDLCK_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(5),
datab => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\(5),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\(5));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_O2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_1_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3858_REGDEPX2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(0));
\GRFPC0_D_LDLCK_RNO_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_2\,
dataa => \GRFPC0.D.LDLCK_0_0_23__G1_1\,
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.D.LDLCK_0_0_23__G1_2_A\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_D_LDLCK_RNO_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_2_A\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_6\(1),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_O2_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_5\(1),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(1),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_1\(1),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_5\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_2\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O3_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110001010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_3_0\,
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_1\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_M10_I_A5_0_RNIKC2H1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0_6\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A3\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5_0\,
datac => \GRFPC0.D.LDLCK_0_0_14__G3_A0\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(51),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0_A\(51),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
datad => \GRFPU0.GRFPU_X0.G_53_REP0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_A_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0_A\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2_0\(21),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_I_O2_4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_O2_4_1\(0),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_10\(0),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_6_0\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_5\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(57),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(54),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M3\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(58),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(53),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_9\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1_A\(54),
datac => \GRFPU0.GRFPU_X0.G_53_REP0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_1_A_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_1_A\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.UN23_EXP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(54),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_9\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(53));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datab => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0_A\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_2_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2_0_A\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.COMB.UN8_SIGN1\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_4_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(17),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M2\(17),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0\(17));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_O2_0\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_A2_3\(46));
GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_M6_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111100010011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M6_0\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_6\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9\(1),
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_7\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_6\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_13_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_3\(1));
\GRFPC0_FIFO_WR_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datad => \GRFPC0.FIFO.WR_0_0_0__G1_0_A\);
\GRFPC0_FIFO_WR_RNO_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1_0_A\,
dataa => \GRFPC0.FIFO.RD\(0),
datab => \GRFPC0.VFIFO.WR_0_SQMUXA_1_0\,
datac => \GRFPC0.FP_PIPELINE.CNTX14\,
datad => \GRFPC0.VFIFO.WR_1_SQMUXA_0\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_41\,
dataa => \GRFPC0.OP2\(24),
datab => \GRFPC0.OP2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_33\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_23\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_39\,
dataa => \GRFPC0.OP2\(12),
datab => \GRFPC0.OP2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_13\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_30\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_38\,
dataa => \GRFPC0.OP2\(26),
datab => \GRFPC0.OP2\(30),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_9\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_28\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10_A\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M20_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_11\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_14\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_0\,
dataa => \GRFPC0.OP2_6\(50),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(50),
datad => \GRFPC0.OP2\(47));
\GRFPC0_FIFO_WR_RNO_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001001100")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
dataa => N_39,
datab => \GRFPC0.DIV.EXC_0_2_X\,
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FP_PIPELINE.UN4_FIFO_CLR\);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_3_RNIPIBL2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_3\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\(0),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_7\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111100010011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_6\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1_2\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A4_1\(1));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110011001100")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G1_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datad => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_4\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
datac => \GRFPU0.GRFPU_X0.L4_7\(4),
datad => \GRFPU0.GRFPU_X0.L4_7\(2));
\GRFPC0_D_LDLCK_RNO_2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_1\(0),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_2\(19),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_37_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_37\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_4_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_9_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G1\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M8_4_03_0_G2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9_A\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_9_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001001010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_9_A\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_7_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7_A\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M7_4_03_0_G2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M8_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_7_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_7_A\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1_A\(18),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_1_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100100111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_1_A\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110100010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2_A\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_9\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_2_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_2_A\(0),
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3_0\(1),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6032_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_5\(0),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_A4\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_1\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_I_A2_1_1_RNIB7HU_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000010111010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_7\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_O2_2_RNI191O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_6\,
dataa => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_2\(0),
datad => \GRFPC0.D.LDLCK_0_0_4__G1_0_6_A\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1181_REGDEPX2_RNI6GVQ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_6_A\,
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0_1\(0),
datad => \GRFPC0.D.LDLCK_0_0_4__G1_0_4\);
\GRFPC0_D_LDLCK_RNO_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(19),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\(31));
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_RNIF1FG4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_1\,
dataa => N_3,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\);
GRFPU0_GRFPU_X0_ST3_RDY_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datad => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I\);
\GRFPC0_D_STDLCK_RNO_9_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_3\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4\,
datad => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_5\(1),
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4_0_0_A4\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6_TZ\(1),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(39));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(43));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(37));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(42));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(47));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(45));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_3_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP\,
datad => \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD11\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_TZ\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_7_5_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_3\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_2_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A3\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4\(0));
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST1.FLTYPE2_65\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.REST_2_IV\(2));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_3\,
dataa => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\,
datab => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.VST2.RDY_0_SQMUXA_0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_5_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3\(0),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4313_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_A0\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_2\(0));
\GRFPC0_FP_PIPELINE_4_STDEP_168_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_2\(1),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP683\,
datac => \GRFPC0.STDEP_2_SQMUXA_133\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1167_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2\(1));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A2_1_RNII0JL: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_A4\,
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2285_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(37));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0\(1),
dataa => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datab => \GRFPC0.STDDEP_0_SQMUXA_88_I_I_A2_I\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_2\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_2\(1));
\GRFPC0_OP1_0_IV_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(52),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(52),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(52),
datad => \GRFPC0.OP1_0_IV_A\(52));
\GRFPC0_OP1_0_IV_A_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(52),
dataa => N_711,
datab => N_647,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2_A\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_6\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O3_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_2_A\,
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_8\);
\GRFPC0_OP1_0_IV_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(21),
dataa => N_712,
datab => \GRFPC0.OP1_0_IV_3\(21),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(21));
\GRFPC0_OP1_0_IV_A_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(21),
dataa => N_648,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_21__G3\);
\GRFPC0_OP1_0_IV_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(2),
dataa => N_693,
datab => \GRFPC0.OP1_0_IV_3\(2),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(2));
\GRFPC0_OP1_0_IV_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(2),
dataa => N_629,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_2__G3\);
\GRFPC0_OP1_0_IV_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(32),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(32),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
datad => \GRFPC0.OP1_0_IV_A\(32));
\GRFPC0_OP1_0_IV_A_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(32),
dataa => N_691,
datab => N_627,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(48),
dataa => N_643,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_4\(48),
datad => \GRFPC0.FPO_I_M\(48));
\GRFPC0_OP1_0_IV_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(42),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(42),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datad => \GRFPC0.OP1_0_IV_A\(42));
\GRFPC0_OP1_0_IV_A_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(42),
dataa => N_701,
datab => N_637,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(51),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datac => \GRFPC0.RFO1_I_M_0\(19),
datad => \GRFPC0.OP1_0_IV_4\(51));
\GRFPC0_OP1_0_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(0),
dataa => N_691,
datab => \GRFPC0.OP1_0_IV_3\(0),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(0));
\GRFPC0_OP1_0_IV_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(0),
dataa => N_627,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_0__G3\);
\GRFPC0_OP1_0_IV_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(59),
dataa => N_654,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_3\(59),
datad => \GRFPC0.OP1_0_IV_A\(59));
\GRFPC0_OP1_0_IV_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(59),
dataa => N_718,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\,
datac => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
datad => \GRFPC0.RFA2.RS1SEL_REP2\(0));
\GRFPC0_OP1_0_IV_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(56),
dataa => N_651,
datab => \GRFPC0.OP1_2_SQMUXA\,
datac => \GRFPC0.OP1_0_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_5\(56));
\GRFPC0_OP1_0_IV_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(55),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(55),
datac => \GRFPC0.DIV.RESULT_0_0_55__G3\,
datad => \GRFPC0.OP1_0_IV_A\(55));
\GRFPC0_OP1_0_IV_A_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(55),
dataa => N_714,
datab => N_650,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(1),
dataa => N_692,
datab => \GRFPC0.OP1_0_IV_3\(1),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(1));
\GRFPC0_OP1_0_IV_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(1),
dataa => N_628,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_1__G3\);
\GRFPC0_OP1_0_IV_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(31),
dataa => N_722,
datab => \GRFPC0.OP1_2_SQMUXA\,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_5\(31));
\GRFPC0_OP1_0_IV_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(35),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(35),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
datad => \GRFPC0.OP1_0_IV_A\(35));
\GRFPC0_OP1_0_IV_A_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(35),
dataa => N_694,
datab => N_630,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(30),
dataa => N_721,
datab => \GRFPC0.OP1_0_IV_3\(30),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(30));
\GRFPC0_OP1_0_IV_A_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(30),
dataa => N_657,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_30__G3\);
\GRFPC0_OP1_0_IV_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(29),
dataa => N_720,
datab => \GRFPC0.OP1_0_IV_3\(29),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(29));
\GRFPC0_OP1_0_IV_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(29),
dataa => N_656,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_29__G3\);
\GRFPC0_OP1_0_IV_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(58),
dataa => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datab => \GRFPC0.OP1_0_IV_3\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
datad => \GRFPC0.OP1_0_IV_A\(58));
\GRFPC0_OP1_0_IV_A_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(58),
dataa => N_717,
datab => N_653,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0\(1),
dataa => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11\(1),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\(0));
\GRFPC0_OP1_0_IV_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPC0.OP1_0_IV\(62),
dataa => N_657,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.RFO2_I_M_0_X\(30),
datad => \GRFPC0.OP1_0_IV_4\(62));
\GRFPC0_OP1_0_IV_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(61),
dataa => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datab => \GRFPC0.OP1_0_IV_3\(61),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(61),
datad => \GRFPC0.OP1_0_IV_A\(61));
\GRFPC0_OP1_0_IV_A_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(61),
dataa => N_720,
datab => N_656,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(60),
dataa => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datab => \GRFPC0.OP1_0_IV_3\(60),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(60),
datad => \GRFPC0.OP1_0_IV_A\(60));
\GRFPC0_OP1_0_IV_A_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(60),
dataa => N_719,
datab => N_655,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(53),
dataa => N_648,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_3\(53),
datad => \GRFPC0.OP1_0_IV_A\(53));
\GRFPC0_OP1_0_IV_A_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(53),
dataa => N_712,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\,
datac => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
datad => \GRFPC0.RFA2.RS1SEL_REP2\(0));
\GRFPC0_OP1_0_IV_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(44),
dataa => N_639,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_3\(44),
datad => \GRFPC0.OP1_0_IV_A\(44));
\GRFPC0_OP1_0_IV_A_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(44),
dataa => N_703,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\,
datac => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
datad => \GRFPC0.RFA2.RS1SEL_REP2\(0));
\GRFPC0_OP1_0_IV_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(41),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(41),
datac => \GRFPC0.OP1_0_IV_A\(41),
datad => \GRFPC0.OP1_0_IV_3\(41));
\GRFPC0_OP1_0_IV_A_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(41),
dataa => N_700,
datab => N_636,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0\,
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_3_0_O2\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.N_22435\,
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_1\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_RNIFEHQ3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_7\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_1_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1_0\(12),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\(12),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_2\(12),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_2\(0));
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_0_0_X\,
datad => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1\);
GRFPC0_FP_PIPELINE_1_DIVEN10_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
dataa => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datac => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_A\,
datad => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_DIVEN10_4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_A\,
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datad => RFI2_RD2ADDRZ(3));
GRFPC0_FP_PIPELINE_8_REGDEPX2_250_1_M6_I_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_243_0_A3_0\(1),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2_A\);
GRFPC0_FP_PIPELINE_8_REGDEPX2_250_1_M6_I_0_O2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_O2_A\,
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3608_REGDEPX2_I_I_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3752_REGDEPX2_I_I_A2_0_A2_0_A2\);
\GRFPC0_DIV_RESULT_0_0_55__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111111")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_55__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(55),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_55__G3_0\,
datad => \GRFPC0.DIV.RESULT_0_0_55__G3_A\);
\GRFPC0_DIV_RESULT_0_0_55__G3_A\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_55__G3_A\,
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(58),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(58),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_A_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_A\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(46),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(46));
\GRFPU0_GRFPU_X0_RES_1_6_I_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(34),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(36),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(36),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_A\(36));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_A_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_A\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(57),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A\(57));
\GRFPU0_GRFPU_X0_RES_1_6_I_A_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_A\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(32),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(32),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(32));
\GRFPC0_OP1_0_IV_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(9),
dataa => N_700,
datab => \GRFPC0.OP1_0_IV_3\(9),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(9));
\GRFPC0_OP1_0_IV_A_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(9),
dataa => N_636,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.WR.RREG.RES_0_0_9__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(52),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(52),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52));
\GRFPC0_OP1_0_IV_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(49),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(49),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
datad => \GRFPC0.OP1_0_IV_A\(49));
\GRFPC0_OP1_0_IV_A_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(49),
dataa => N_708,
datab => N_644,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(60),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(60),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(60),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60));
\GRFPU0_GRFPU_X0_RES_1_6_I_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(61),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(61),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(61),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(61));
\GRFPC0_OP1_0_IV_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(10),
dataa => N_701,
datab => \GRFPC0.OP1_0_IV_3\(10),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(10));
\GRFPC0_OP1_0_IV_A_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(10),
dataa => N_637,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_10__G3\);
\GRFPC0_OP1_0_IV_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(19),
dataa => N_710,
datab => \GRFPC0.OP1_0_IV_3\(19),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(19));
\GRFPC0_OP1_0_IV_A_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(19),
dataa => N_646,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_19__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(35),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(35),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(35));
\GRFPU0_GRFPU_X0_RES_1_6_I_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(37),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(40),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(40));
\GRFPC0_OP1_0_IV_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(37),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(37),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
datad => \GRFPC0.OP1_0_IV_A\(37));
\GRFPC0_OP1_0_IV_A_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(37),
dataa => N_696,
datab => N_632,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(39),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(39),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(39));
\GRFPC0_OP1_0_IV_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(39),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(39),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
datad => \GRFPC0.OP1_0_IV_A\(39));
\GRFPC0_OP1_0_IV_A_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(39),
dataa => N_698,
datab => N_634,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(43),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.RFO1_I_M_0\(11),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(43),
datad => \GRFPC0.OP1_0_IV_4\(43));
\GRFPC0_OP1_0_IV_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(11),
dataa => N_702,
datab => \GRFPC0.OP1_0_IV_3\(11),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(11));
\GRFPC0_OP1_0_IV_A_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(11),
dataa => N_638,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_11__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(33),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(33));
\GRFPC0_OP1_0_IV_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(33),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(33),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
datad => \GRFPC0.OP1_0_IV_A\(33));
\GRFPC0_OP1_0_IV_A_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(33),
dataa => N_692,
datab => N_628,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(36),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(36),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
datad => \GRFPC0.OP1_0_IV_A\(36));
\GRFPC0_OP1_0_IV_A_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(36),
dataa => N_695,
datab => N_631,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(14),
dataa => N_705,
datab => \GRFPC0.OP1_0_IV_3\(14),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(14));
\GRFPC0_OP1_0_IV_A_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(14),
dataa => N_641,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_14__G3\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2_0\(0));
\GRFPC0_OP1_0_IV_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(6),
dataa => N_697,
datab => \GRFPC0.OP1_I_A2\(0),
datac => \GRFPC0.OP1_0_IV_4_X\(6),
datad => \GRFPC0.FPO_I_M\(6));
\GRFPC0_OP1_0_IV_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(23),
dataa => N_714,
datab => \GRFPC0.OP1_0_IV_3\(23),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(23));
\GRFPC0_OP1_0_IV_A_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(23),
dataa => N_650,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_23__G3\);
\GRFPC0_OP1_0_IV_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(20),
dataa => N_711,
datab => \GRFPC0.OP1_0_IV_3\(20),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(20));
\GRFPC0_OP1_0_IV_A_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(20),
dataa => N_647,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_20__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(43),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(43),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43));
\GRFPU0_GRFPU_X0_RES_1_6_I_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(45),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(45),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(49),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(49));
\GRFPC0_OP1_0_IV_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(26),
dataa => N_717,
datab => \GRFPC0.OP1_0_IV_3\(26),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(26));
\GRFPC0_OP1_0_IV_A_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(26),
dataa => N_653,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_26__G3\);
\GRFPC0_OP1_0_IV_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(57),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(57),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
datad => \GRFPC0.OP1_0_IV_A\(57));
\GRFPC0_OP1_0_IV_A_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(57),
dataa => N_716,
datab => N_652,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(51),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(51),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(51));
\GRFPC0_OP1_0_IV_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(17),
dataa => N_708,
datab => \GRFPC0.OP1_0_IV_3\(17),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(17));
\GRFPC0_OP1_0_IV_A_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(17),
dataa => N_644,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_17__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(48),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(48));
\GRFPC0_OP1_0_IV_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(47),
dataa => N_642,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_3\(47),
datad => \GRFPC0.OP1_0_IV_A\(47));
\GRFPC0_OP1_0_IV_A_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(47),
dataa => N_706,
datab => \GRFPC0.OP1_1_SQMUXA_REP1\,
datac => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
datad => \GRFPC0.RFA2.RS1SEL_REP2\(0));
\GRFPC0_OP1_0_IV_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPC0.OP1_0_IV\(50),
dataa => N_645,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.RFO2_I_M_0_X\(18),
datad => \GRFPC0.OP1_0_IV_4\(50));
\GRFPC0_OP1_0_IV_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(7),
dataa => N_698,
datab => \GRFPC0.OP1_0_IV_3\(7),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(7));
\GRFPC0_OP1_0_IV_A_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(7),
dataa => N_634,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_7__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(42),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(42),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(42));
\GRFPU0_GRFPU_X0_RES_1_6_I_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(41),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(41),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41));
\GRFPU0_GRFPU_X0_RES_1_6_I_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(38),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(38));
\GRFPC0_OP1_0_IV_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(38),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(38),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
datad => \GRFPC0.OP1_0_IV_A\(38));
\GRFPC0_OP1_0_IV_A_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(38),
dataa => N_697,
datab => N_633,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_I_A2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2\(45),
dataa => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datab => \GRFPC0.OP1_0_IV_I_A2_3\(45),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
datad => \GRFPC0.OP1_0_IV_I_A2_A\(45));
\GRFPC0_OP1_0_IV_I_A2_A_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_A\(45),
dataa => N_704,
datab => N_640,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.N_201\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_0\,
datad => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_3_X\);
\GRFPC0_D_STLCK_RNO_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O2_2\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_X3\(1),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_2\(0),
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_O3_0\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
GRFPC0_STDDEP_0_SQMUXA_145: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_145\,
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0_1\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP683\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP682\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_OP1_0_IV_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.OP1_0_IV\(40),
dataa => N_635,
datab => \GRFPC0.OP1_I_A2\(32),
datac => \GRFPC0.OP1_0_IV_4\(40),
datad => \GRFPC0.FPO_I_M\(40));
\GRFPC0_OP1_0_IV_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(34),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(34),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
datad => \GRFPC0.OP1_0_IV_A\(34));
\GRFPC0_OP1_0_IV_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(34),
dataa => N_693,
datab => N_629,
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPC0_OP1_0_IV_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(8),
dataa => N_699,
datab => \GRFPC0.OP1_0_IV_3\(8),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(8));
\GRFPC0_OP1_0_IV_A_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(8),
dataa => N_635,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_8__G3\);
\GRFPC0_OP1_0_IV_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.OP1_0_IV\(54),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.OP1_0_IV_3\(54),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(54),
datad => \GRFPC0.OP1_0_IV_A\(54));
\GRFPC0_OP1_0_IV_A_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPC0.OP1_0_IV_A\(54),
dataa => N_713,
datab => N_649,
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_I_A2\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(54),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP2\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(54),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54));
\GRFPC0_OP1_0_IV_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(22),
dataa => N_713,
datab => \GRFPC0.OP1_0_IV_3\(22),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(22));
\GRFPC0_OP1_0_IV_A_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(22),
dataa => N_649,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_22__G3\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(9),
datac => \GRFPC0.V.STDATA_14\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_0\);
GRFPC0_FP_PIPELINE_1_EXEN7_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7_4\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(3),
datad => \GRFPC0.FP_PIPELINE.1.EXEN7_4_A\);
GRFPC0_FP_PIPELINE_1_EXEN7_4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111110110111110")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7_4_A\,
dataa => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datad => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_WR2EN10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
dataa => \GRFPC0.WR2.CTRL.RD\(3),
datab => RFI2_RD2ADDRZ(2),
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10_1\,
datad => \GRFPC0.FP_PIPELINE.1.WR2EN10_2\);
GRFPC0_FP_PIPELINE_1_WRENX10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
datac => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.FP_PIPELINE.1.WRENX10_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_5\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_5\(1),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\);
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\(1),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_S\,
datab => \GRFPC0.STDDEP_0_SQMUXA_110\,
datac => \GRFPC0.STDDEP_0_SQMUXA_132_I_0_O2_X\);
\GRFPC0_FP_PIPELINE_5_STDEP_208_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2_0\(1),
datab => \GRFPC0.FP_PIPELINE.5.STDEP851_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
GRFPC0_FP_PIPELINE_FCC_VALID_1_U_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100000000000")
port map (
combout => CPO_CCVZ,
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_I_M2\,
datad => \GRFPC0.FP_PIPELINE.FCC_VALID_1_U_I_A\);
GRFPC0_FP_PIPELINE_FCC_VALID_1_U_I_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_VALID_1_U_I_A\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_DEP_1_SQMUXA_88_0_A3_I_O2_0_0_RNIEME83: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001110")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\(1),
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1_0\(1));
\GRFPC0_FP_PIPELINE_1_0_STDEP_65_0_IV_I_A4_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_4\(0),
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\,
datab => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O3_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5_0\(0),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\(1),
datac => \GRFPC0.FIFO.INST_0_M_9\(25),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
dataa => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\,
datad => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPC0_OP1_0_IV_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(24),
dataa => N_715,
datab => \GRFPC0.OP1_0_IV_3\(24),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(24));
\GRFPC0_OP1_0_IV_A_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(24),
dataa => N_651,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_24__G3\);
\GRFPC0_OP1_0_IV_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(4),
dataa => N_695,
datab => \GRFPC0.OP1_0_IV_3\(4),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(4));
\GRFPC0_OP1_0_IV_A_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(4),
dataa => N_631,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_4__G3\);
\GRFPC0_OP1_0_IV_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(18),
dataa => N_709,
datab => \GRFPC0.OP1_0_IV_3\(18),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(18));
\GRFPC0_OP1_0_IV_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(18),
dataa => N_645,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_18__G3\);
\GRFPC0_OP1_0_IV_I_A2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2\(13),
dataa => N_704,
datab => \GRFPC0.OP1_0_IV_I_A2_3\(13),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_I_A2_A\(13));
\GRFPC0_OP1_0_IV_I_A2_A_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_A\(13),
dataa => N_640,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_13__G3\);
\GRFPC0_OP1_0_IV_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(5),
dataa => N_696,
datab => \GRFPC0.OP1_0_IV_3\(5),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(5));
\GRFPC0_OP1_0_IV_A_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(5),
dataa => N_632,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_5__G3\);
\GRFPC0_OP1_0_IV_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(28),
dataa => N_719,
datab => \GRFPC0.OP1_0_IV_3\(28),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(28));
\GRFPC0_OP1_0_IV_A_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(28),
dataa => N_655,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_28__G3\);
\GRFPC0_OP1_0_IV_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(27),
dataa => N_718,
datab => \GRFPC0.OP1_0_IV_3\(27),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(27));
\GRFPC0_OP1_0_IV_A_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(27),
dataa => N_654,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_27__G3\);
\GRFPC0_OP1_0_IV_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(25),
dataa => N_716,
datab => \GRFPC0.OP1_0_IV_3\(25),
datac => \GRFPC0.OP1_I_A2_REP1\(0),
datad => \GRFPC0.OP1_0_IV_A\(25));
\GRFPC0_OP1_0_IV_A_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(25),
dataa => N_652,
datab => \GRFPC0.OP1_0_SQMUXA_REP1\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_25__G3\);
\GRFPC0_OP1_0_IV_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(3),
dataa => N_694,
datab => \GRFPC0.OP1_0_IV_3\(3),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(3));
\GRFPC0_OP1_0_IV_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(3),
dataa => N_630,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_3__G3\);
\GRFPC0_OP1_0_IV_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(16),
dataa => N_707,
datab => \GRFPC0.OP1_0_IV_3\(16),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(16));
\GRFPC0_OP1_0_IV_A_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(16),
dataa => N_643,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP2\(0),
datad => \GRFPC0.DIV.RESULT_0_0_16__G3\);
\GRFPC0_OP1_0_IV_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(15),
dataa => N_706,
datab => \GRFPC0.OP1_0_IV_3\(15),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(15));
\GRFPC0_OP1_0_IV_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(15),
dataa => N_642,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_15__G3\);
\GRFPC0_OP1_0_IV_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(12),
dataa => N_703,
datab => \GRFPC0.OP1_0_IV_3\(12),
datac => \GRFPC0.OP1_I_A2\(0),
datad => \GRFPC0.OP1_0_IV_A\(12));
\GRFPC0_OP1_0_IV_A_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.OP1_0_IV_A\(12),
dataa => N_639,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.DIV.RESULT_0_0_12__G3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_53\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_57\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_54\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_59\);
GRFPU0_GRFPU_X0_COMB_MULBP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(11),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
datab => \GRFPU0.GRFPU_X0.MULO_M\(71),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(11),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(34),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(34),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
datab => \GRFPU0.GRFPU_X0.MULO_M\(94),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(34),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFN\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(9),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(29),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(29),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(24),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(24),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_3\(0),
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.C_ADD10\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_O2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0\,
dataa => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_A\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111110111011")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
GRFPU0_GRFPU_X0_VST3_REG_1_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_5_0\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_0\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_6\);
\GRFPC0_FIFO_VCNT_0_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100011110")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA_2_SUM2\,
dataa => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.VCNT_0\(2),
datad => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\);
\GRFPC0_FIFO_VCNT_1_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110110000110011")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2\,
dataa => N_3,
datab => \GRFPC0.FIFO.VCNT_1\(2),
datac => CPO_EXCZ,
datad => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2_A\);
\GRFPC0_FIFO_VCNT_1_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010100010000")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_SUM2_A\,
dataa => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_C1_1_TZ\,
datab => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_A2_1_3_RNITLR24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001001110111")
port map (
combout => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.V\,
datab => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2\,
datad => \GRFPU0.GRFPU_X0.N_13472_I_0_G0_A\);
GRFPU0_GRFPU_X0_ST2_V_RNI2HT11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100010101")
port map (
combout => \GRFPU0.GRFPU_X0.N_13472_I_0_G0_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.V\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(18));
\GRFPC0_OP1_0_IV_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.OP1_0_IV\(46),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
datac => \GRFPC0.RFO1_I_M_0\(14),
datad => \GRFPC0.OP1_0_IV_4\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(26),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(26),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(26),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(30),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(30),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(30),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(22),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(22),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(22),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(22));
GRFPC0_RDWR_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.RDWR_3_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(16),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(16),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1\(8),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(8),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(25),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(25),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(25),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(25),
datab => \GRFPU0.GRFPU_X0.MULO_M\(85),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(25),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_5_0_RNIL8IA4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_A\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_RNIU6622_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST4_SEL5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_6\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_2\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL2\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_2\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_RNII57T3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_6\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_0\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_9_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S\,
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S_0\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2\,
datad => \GRFPU0.MULO.MRES_BUF\(121));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(7),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_33_IV_TZ\(7),
datac => \GRFPU0.GRFPU_X0.MULO_M_299\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7));
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_0_A2_1_0_RNI1ODD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M_2\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2_1_0\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\);
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.INST_I\(12),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2_3\);
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_0\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_O3\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_1_1\);
GRFPC0_FIFO_INC_5_SQMUXA_RNIMUGQ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FIFO.RD_I_M\(0),
dataa => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datab => \GRFPC0.FIFO.RD_I_M_0_X\(0),
datac => \GRFPC0.FIFO_INC_5_SQMUXA\,
datad => CPO_EXCZ);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datac => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO10\);
\GRFPU0_GRFPU_X0_UN6_SGNFX_RNI8ETH1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1_A\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNII84V_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV\(10),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_A\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
datab => \GRFPU0.GRFPU_X0.MULO_M\(70),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(10),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPC0_D_STLCK_RNO_4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_TZ\,
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A0_1_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_2403\,
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_2\(1),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_1\(1));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_A\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000110101011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\);
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
dataa => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(3),
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\(2));
GRFPU0_GRFPU_X0_ST3_V_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.N_56_I_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.V\,
datab => \GRFPU0.GRFPU_X0.ST3.V_0_I_A2\,
datac => \GRFPU0.GRFPU_X0.ST3.V_0_I_A2_0\);
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_7_RNIPU288_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(45),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(47),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(50),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(50),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(42),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(43));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_55_M4_0_A2_1_RNIFUQV6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110100000000")
port map (
combout => D_M1_E_2,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_55_M4_0_A2_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(55),
datad => D_M4_0);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_O2_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_RNIVN0T9_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101110")
port map (
combout => D_M1_E_0,
dataa => D_M4_I_0,
datab => D_M4_I_A4_0_0,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A3_RNICCSN_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_1\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A3\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_4_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(51),
dataa => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_1_0\(52),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_5_2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_2\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_1\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_239_A1_RNIP4CL2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_A2\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_239_A1\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_2\(0));
GRFPC0_WR_RREG_RESV_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001010111")
port map (
combout => \GRFPC0.WR.RREG.RESV_0_0_G0_0_A\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => CPO_EXCZ);
GRFPU0_GRFPU_X0_ST2_INF_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.QSNAN12\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
GRFPU0_GRFPU_X0_VITER_ND_I_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83\);
GRFPU0_GRFPU_X0_VITER_ND_I_0_SQMUXA_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_RNDOP_32_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_32_0_A3_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_20\);
\GRFPC0_RFA2_FOP_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
datad => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4\);
GRFPU0_GRFPU_X0_ST1_SIGN1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SIGN1_0_0_G0\,
dataa => \GRFPC0.OP1_0_IV\(63),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPU0_GRFPU_X0_L4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(1),
dataa => \GRFPU0.GRFPU_X0.L4_D\(1),
datab => \GRFPU0.GRFPU_X0.L4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(1));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110001011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datab => \GRFPU0.GRFPU_X0.L1_4_4\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2_A\(0));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2_A\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(14),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_0\(0));
GRFPU0_GRFPU_X0_ST2_RDY_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST2.RDY_0_I_M3\,
datac => \GRFPU0.GRFPU_X0.VST2.RDY_0_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I_A3_2\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101000111")
port map (
combout => D_M7,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datac => D_M3_0,
datad => D_M5);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_4_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_4\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_52_M3_0_A2_1\,
datab => D_M1_E,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
GRFPC0_FP_PIPELINE_UN29_WREN_1_A1_D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_D\,
dataa => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2_1\,
datab => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\(2));
\GRFPC0_D_STLCK_RNO_5_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_5\(1),
datab => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_7_0\(1));
GRFPC0_FP_PIPELINE_2_REGDEPX2_85_1_M9_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A4_0_0\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_VFIFO_PC_0_1_SQMUXA_0_A2_M1_E_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FIFO.FULL_M_0\,
dataa => \GRFPC0.FIFO.FULL_M_0_2_1_X\,
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_I_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6077_REGDEPX2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_A2_1_0_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_0_A3_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_A4_0_1_0\(0));
\GRFPC0_FP_PIPELINE_13_STDEP_554_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_554_0_IV_TZ\(0),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_12_0_A2_0\(0),
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.RFA.RDD\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2049_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A3_1_0\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_0\(0),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0_0_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_2\(1),
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0\(1),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_2\(0),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_O2_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(25),
dataa => \GRFPC0.UN1_FIFO.INST_0_16_I_I2_I_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\(0),
dataa => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2919_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\(0));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(1),
dataa => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX_0_A3\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257_A\(1));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257_A\(1),
dataa => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datac => \GRFPC0.UN1_FIFO.INST_0_9\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_3\(1),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_24_IV_I_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_273_0_A3\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\(1));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_2_RNI2CHU2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2\);
\GRFPC0_WRDATA_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(15),
dataa => N_423,
datab => N_424,
datac => N_446,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(15));
\GRFPC0_WRDATA_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(24),
dataa => N_423,
datab => N_424,
datac => N_455,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6\(24));
\GRFPC0_WRDATA_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(27),
dataa => N_423,
datab => N_424,
datac => N_458,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(27));
\GRFPC0_WRDATA_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(12),
dataa => N_423,
datab => N_424,
datac => N_443,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6\(12));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_238_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\(0),
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.STDEP_0_SQMUXA_84_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000000")
port map (
combout => \GRFPC0.N_25311\,
dataa => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\,
datab => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_58\(0));
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_4\(0),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1004_DEP\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_288_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_288_3\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.N_19292_1_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_288_2\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_288_1\(1));
GRFPC0_MEM_CTRL_PEND_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0\,
dataa => \GRFPC0.FP_PIPELINE.UN54_HOLDN\,
datab => \GRFPC0.MEM.CTRL.PEND_0_0_G2_1\,
datac => \GRFPC0.VDIV.EXC_1_SQMUXA_0_O2\,
datad => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3\);
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3_1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I\(1));
\GRFPC0_FPUSEL_6_M1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPC0.FPUSEL_6_M1\(0),
dataa => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.WRSEL4\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.0.WRENX2\);
GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_M6_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M6_E\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A3\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_274_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_274\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4121_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_274_A\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_274_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_274_A\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_24_IV_I_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2_I_I_A2\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_175_1_M9_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175TT_1_M3_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_UN15_OP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_2\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPC0.V.STDATA_14_REP0\(6),
datac => \GRFPC0.FP_PIPELINE.UN17_OP_7_3\,
datad => \GRFPC0.FP_PIPELINE.UN15_OP_2_A\);
GRFPC0_FP_PIPELINE_UN15_OP_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_2_A\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14\(8),
datac => \GRFPC0.V.STDATA_14\(10),
datad => \GRFPC0.V.STDATA_14_REP1\(11));
\GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_DEP_2_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100011111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\(1),
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\,
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_A4\);
\GRFPC0_WRDATA_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(30),
dataa => N_423,
datab => N_424,
datac => N_461,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6\(30));
\GRFPC0_WRDATA_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(21),
dataa => N_423,
datab => N_424,
datac => N_452,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(21));
\GRFPC0_WRDATA_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(18),
dataa => N_423,
datab => N_424,
datac => N_449,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(18));
\GRFPC0_STDATA_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(13),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(13),
datad => \GRFPC0.STDATA_1_X\(13));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_2_RNIASFP1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_O2\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2_0\(0));
\GRFPC0_D_STLCK_RNO_4_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000110000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_M2\(1),
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A3_0_1\(1),
datab => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(1),
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_14_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(1));
GRFPC0_STDDEP_0_SQMUXA_19_I_O4_RNIEETM1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O4_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datab => \GRFPC0.STDDEP_0_SQMUXA_19_I_O4\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_8\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000110001")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_0_A2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_3\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011011111")
port map (
combout => \GRFPU0.GRFPU_X0.N_19857_I_0_G0_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_O2\(31),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_A2\(8));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI5FRQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010101000")
port map (
combout => \GRFPC0.RFA2.RS2SEL_0_0_7__G5\,
dataa => N_38,
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
\GRFPC0_FP_PIPELINE_5_STDEP_208_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100001010000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_240\(1),
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_3\(0));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_186_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_186\(0),
dataa => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3231_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(31),
dataa => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_M2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_M2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_M2\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_8_3_0_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_M2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_27_0_A2_0_A2_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\);
GRFPC0_FP_PIPELINE_0_STDEP_12_SEL1_I_0_A2_1_RNIDB2T5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_11_1\(1),
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_3\(1));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_O3_3_0\(0),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_4\(0));
GRFPC0_RFA2_FLUSH_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.N_17807_I_0_G0_I\,
dataa => N_39,
datab => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.N_17807_I_0_G0_I_A3_0\,
datad => CPO_EXCZ);
\GRFPC0_D_STLCK_RNO_2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_4\(1),
dataa => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datac => \GRFPC0.STDEP_0_SQMUXA_109_0\,
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_4_STDEP_168_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_1\(1),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0\,
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datac => \GRFPC0.STDEP_2_SQMUXA_133\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_26\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_3\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_6_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_170_0_A2_2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(15),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5\(15),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_10\(15),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_9\(15));
\GRFPC0_FP_PIPELINE_12_0_STDEP_505_0_IV_I_M2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_M2_0\(0),
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_484_0_IV\(0));
GRFPC0_STDDEP_0_SQMUXA_166_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100101111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_166_I\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\,
datad => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_0\);
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_114_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_114\(1),
dataa => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\(1));
\GRFPU0_GRFPU_X0_L4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100111011")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(2),
dataa => \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datad => \GRFPU0.GRFPU_X0.L4_A\(2));
\GRFPU0_GRFPU_X0_L4_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000100010")
port map (
combout => \GRFPU0.GRFPU_X0.L4_A\(2),
dataa => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.L1_5_4_2\(3),
datac => \GRFPU0.GRFPU_X0.L1_6_1_3_I_1\(1),
datad => \GRFPU0.GRFPU_X0.L1_6_1_3_I_A4\(1));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3_0\);
GRFPU0_GRFPU_X0_COMB_STICKY_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.STICKY_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_20\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(36),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(59),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(59));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(16),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(16),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(16));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(16),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(14),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_I_M3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_I_M3\(11),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2_I_M2\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2_0\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(7),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(3),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(56),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(56));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(56),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(2),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(13),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(13),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(13));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(41),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(41),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(41));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(32),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(32),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(32));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(36),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(36),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(47),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(47),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(29),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(29),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(29));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(10),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(46),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(46));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(34),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(34),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0\(34));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(19),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(19),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(19));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(19),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G1\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_1\);
GRFPU0_GRFPU_X0_UN1_VST2_EXC_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110011")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA_I\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_2\,
datab => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VST2.QSNAN12\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
GRFPU0_GRFPU_X0_UN1_VST2_REG108: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG108\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.REST_2_IV\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001111110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I_A4_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0\(18),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_53_REP0\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(34),
dataa => \GRFPU0.GRFPU_X0.G_53_REP0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34),
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001111110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_A\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_53_REP1\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_O2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_O2_0\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M2\(45),
datac => \GRFPU0.GRFPU_X0.G_51_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_A2_3\(46));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(35),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(35));
\GRFPU0_GRFPU_X0_INTI2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001011100001")
port map (
combout => \GRFPU0.GRFPU_X0.INTI2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63),
datad => \GRFPU0.GRFPU_X0.INTI2_1_A\(0));
\GRFPU0_GRFPU_X0_INTI2_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001110011011")
port map (
combout => \GRFPU0.GRFPU_X0.INTI2_1_A\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.UN1_RND_INC\(0),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_8_I_A2\);
\GRFPU0_GRFPU_X0_L4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(0),
dataa => \GRFPU0.GRFPU_X0.L4_2\(0),
datab => \GRFPU0.GRFPU_X0.L3_0_1\(0),
datac => \GRFPU0.GRFPU_X0.L3_0\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(55),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(55));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(55),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(17),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(17),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(17));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_VST3_REG_47_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(38));
\GRFPU0_GRFPU_X0_VST3_REG_47_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(46));
\GRFPU0_GRFPU_X0_L3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(0),
dataa => \GRFPU0.GRFPU_X0.L2_0_2\(0),
datab => \GRFPU0.GRFPU_X0.L2_1_1\(0),
datac => \GRFPU0.GRFPU_X0.L2_0_10\(4));
\GRFPU0_GRFPU_X0_L4_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(1),
dataa => \GRFPU0.GRFPU_X0.L4_2_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0\(1),
datac => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPU0_GRFPU_X0_L4_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(0),
dataa => \GRFPU0.GRFPU_X0.L3_1\(0),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(0),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
GRFPC0_FP_PIPELINE_IS_RDD_TMP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010111")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.TMP\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\,
datac => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\);
\GRFPU0_GRFPU_X0_L3_0_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(0),
datab => \GRFPU0.GRFPU_X0.L2_0_6\(0),
datac => \GRFPU0.GRFPU_X0.L2_0_9\(4));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_REP3_RNIJ8526_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O3_0\(24),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(43));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_O2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_A2_1_0_A2\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(15),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(15),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_L3_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datab => \GRFPU0.GRFPU_X0.L1_6_1_5_0_I_0\(0),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4));
\GRFPU0_GRFPU_X0_L3_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(0),
dataa => \GRFPU0.GRFPU_X0.L2_0_4\(4),
datab => \GRFPU0.GRFPU_X0.L2_1_3\(0),
datac => \GRFPU0.GRFPU_X0.L2_0_4\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(62),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(62),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(62));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_EXPT_CNST_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_CNST_I_A2\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_0_SQMUXA\);
\GRFPU0_GRFPU_X0_L3_0_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(1),
dataa => \GRFPU0.GRFPU_X0.L2_0_4\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_4\(1),
datac => \GRFPU0.GRFPU_X0.L2_1_3\(1));
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011001100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G0_I_O4\,
dataa => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
datab => \GRFPU0.GRFPU_X0.ST3.V_0_I_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF\);
GRFPU0_GRFPU_X0_ITER_EMIN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMIN\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G5\,
datac => \GRFPU0.GRFPU_X0.UN1_VST3.REG40\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\);
GRFPU0_GRFPU_X0_NXX_1_I_A2_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_I_O2\,
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7\);
\GRFPC0_UN1_PENDEXC_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111001011111")
port map (
combout => \GRFPC0.UN1_PENDEXC_2\(0),
dataa => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.UN1_VFIFO.WR_1_SQMUXA\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPU0_GRFPU_X0_VST3_REG_47_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(41));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_0_RNI41101: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011001100")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0\);
GRFPU0_GRFPU_X0_ST3_INF_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC18LTO10_RNI94Q21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_2_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC18LTO10\,
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0\);
GRFPU0_GRFPU_X0_COMB_EXPDEC_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPINC_SP\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2\,
datac => \GRFPU0.GRFPU_X0.EXPDEC_SP_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(52));
GRFPU0_GRFPU_X0_EXPDEC_SP_1_SQMUXA_RNIH8PT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPINC\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPINC_SP\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2\,
datac => \GRFPU0.GRFPU_X0.EXPDEC_SP_1_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1\(1));
GRFPU0_GRFPU_X0_COMB_CCUF_1_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011110111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCUF_1_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2\);
GRFPU0_GRFPU_X0_UN1_VITER_FLUSH0_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\);
\GRFPU0_GRFPU_X0_L3_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(1),
dataa => \GRFPU0.GRFPU_X0.L2_1_4\(1),
datab => \GRFPU0.GRFPU_X0.L2_0_5\(1),
datac => \GRFPU0.GRFPU_X0.L2_0_7\(4));
\GRFPU0_GRFPU_X0_L3_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.L3_1_1_A\(0),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(0));
\GRFPU0_GRFPU_X0_L3_1_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101111111111")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_L3_0_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(0),
dataa => \GRFPU0.GRFPU_X0.L2_1_4\(0),
datab => \GRFPU0.GRFPU_X0.L2_0_7\(4),
datac => \GRFPU0.GRFPU_X0.L2_0_5\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(49),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(26),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(26),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(26));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(22),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(22),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(22));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(42),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(42),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(30),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(30),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(30));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_A_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_A\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38));
\GRFPC0_D_STLCK_RNO_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_IV\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_562_0_IV_I_A2\(0));
\GRFPC0_D_STLCK_RNO_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_0\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_354_X\(1));
\GRFPC0_D_STDLCK_RNO_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2\,
datac => \GRFPC0.D.STDLCK_0_0_9__G1_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
\GRFPC0_D_STLCK_RNO_6_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6_1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0),
datac => \GRFPC0.D.STLCK_0_0_7__G1_6_0\);
\GRFPC0_D_STLCK_RNO_2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_9_0_A2\(0),
datab => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datad => \GRFPC0.D.STLCK_0_0_24__G1_1_A\);
\GRFPC0_D_STLCK_RNO_3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010001")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_1_A\,
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_98_I_I_A2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0));
\GRFPC0_D_STLCK_RNO_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111010000")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_1\,
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_38_0_O2_I_A3\(1),
datad => \GRFPC0.D.STLCK_0_0_0__G1_0\);
\GRFPC0_D_STLCK_RNO_4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_5_I_O2_1\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_1\(1),
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1));
\GRFPC0_D_STDLCK_RNO_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_2\,
dataa => \GRFPC0.D.STDLCK_0_0_0__G1_0\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_38_0_O2_I_A3\(1),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_12_0_STDEP_505_0_IV_I_O2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_O2_1_1\(0),
dataa => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_A2_0\(0),
datab => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_5\(1),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\(1),
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_D_STDLCK_RNO_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111101011111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_1\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_28_I_0_O2\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datac => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_X\,
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011111110")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_3\(0),
datab => \GRFPC0.EX.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\);
\GRFPC0_D_STLCK_RNO_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.N_19067_1_I_I_A2_I_O2\,
datac => \GRFPC0.D.STLCK_0_0_1__G1_0\);
\GRFPC0_D_STDLCK_RNO_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_2\,
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0),
datad => \GRFPC0.D.STDLCK_0_0_12__G1_1\);
\GRFPC0_D_STLCK_RNO_12_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_0_O2_I_A3\(1));
\GRFPC0_D_STDLCK_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101110101010")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_0\,
dataa => \GRFPC0.D.STLCK_0_0_11__G3_0\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_18_I\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_0\);
GRFPC0_UN1_WRENX2_2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPC0.UN1_WRENX2_2_0_0\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
GRFPC0_UN1_REGDEP79_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101101111011")
port map (
combout => \GRFPC0.UN1_REGDEP79_0\,
dataa => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.5.STDEP851_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_D_STLCK_RNO_5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_5_I_O2_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_2\(0),
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0));
\GRFPC0_D_STDLCK_RNO_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datad => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
GRFPC0_FP_PIPELINE_0_REGDEP66_0_A2_RNIKM77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2_0\,
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP66_0_A2\,
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0));
GRFPC0_RFA2_RS2DEP_RNO_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_2_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_0_A4\,
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0));
\GRFPC0_D_STLCK_RNO_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101110")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_0_X\(0),
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_19_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A4_1_X\(0));
\GRFPC0_D_STLCK_RNO_4_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3871_DEP_0_A3\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_I_A2\(0),
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_A2_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_336_3_I_A2_0_1\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL0_0_I_O2\);
\GRFPC0_D_STLCK_RNO_2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2_1_1\(0),
datac => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_0\(0),
datad => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_0_2\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_4\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_3_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3_0\(56),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(56));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A4_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_1\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
\GRFPC0_D_STLCK_RNO_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101100001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_9_0\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_FP_PIPELINE_5_STDEP_208_3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_19572_1_I_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_RNIFPN1C_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011100000111")
port map (
combout => R_M3_0_A2_2_0,
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55));
\GRFPC0_D_STDLCK_RNO_5_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_1\,
dataa => N_243,
datab => \GRFPC0.STDEP_0_SQMUXA_5_0_0_X\,
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.D.STDLCK_0_0_13__G1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_RNIGJTK8_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_0\,
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_55_M4_0_A2_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2\(55));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_A2_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_1\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_0\(0));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_2_RNI1QPJ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011101100")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G2_0_0\,
dataa => \GRFPC0.RFA.WRITE_RD\,
datab => \GRFPC0.RFA.RDWR\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_A2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_0_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\);
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_A2_0_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010101")
port map (
combout => \GRFPU0.GRFPU_X0.N_19861_I_0_G0_1\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPC0.V.STDATA_14_REP0\(6),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3));
GRFPC0_FP_PIPELINE_0_WRENX2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_0\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3));
\GRFPC0_FP_PIPELINE_RS1_6_X_RNI07V7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
\GRFPC0_FP_PIPELINE_RS1_6_X_RNIEHVH_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_FP_PIPELINE_0_REGDEP62_I_S_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111110110111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
GRFPC0_FP_PIPELINE_0_REGDEP62_I_S_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101101111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62_I_S_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_0_0\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A3_1\);
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_1\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(2),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101101111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP46_I_S_0\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_1_1_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_1_0\(52),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_I_0\,
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPC0.V.STDATA_14_REP1\(6),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\);
\GRFPC0_D_STDLCK_RNO_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111101111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.STDDEP_0_SQMUXA_9_I_O4\,
datac => \GRFPC0.STDDEP_0_SQMUXA_6_I_O4_X\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\);
\GRFPC0_D_STLCK_RNO_10_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001100110011111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_3_1_M8_I_0\,
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
datad => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\);
\GRFPC0_D_STDLCK_RNO_14_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_3_7_1\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2\(0),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2_0_A2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_2_S\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_4_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\,
dataa => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\);
GRFPC0_FP_PIPELINE_1_WR2EN10_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10_1\,
dataa => \GRFPC0.WR2.CTRL.RDWR\,
datab => \GRFPC0.WR2.CTRL.RD\(2),
datac => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datad => RFI2_RD2ADDRZ(1));
GRFPC0_FP_PIPELINE_1_WRENX10_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
datad => RFI2_RD2ADDRZ(2));
GRFPC0_FP_PIPELINE_0_REGDEP30_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP30_0\,
dataa => \GRFPC0.WR2.CTRL.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(2),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
GRFPC0_FP_PIPELINE_0_REGDEP14_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP14_0\,
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
GRFPC0_FP_PIPELINE_0_EXEN2_3_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2_3_0_0\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD_RNI3OTK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000100")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
datad => RFI2_RD2ADDRZ(1));
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_A5_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_0\,
dataa => \GRFPC0.INST\(21),
datab => \GRFPC0.INST_I_M5\(19),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011100000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_0\(53),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53));
\GRFPC0_D_LDLCK_RNO_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3231_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_1\(7),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5\(21),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(21));
\GRFPC0_D_LDLCK_RNO_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1_0\(23),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6_X\(21),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(21),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_X\(20));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_12\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_0\,
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_3\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_7\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_0_A2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_0\(48),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
datad => \GRFPU0.GRFPU_X0.G_53_REP0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_4\(0),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_4_0_TZ_RNICOM31_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1_0_1\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_1_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_4_0_TZ\(1));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_A2_2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_2_3\,
dataa => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(7),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_3\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_3_1\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_7_I_I_A4_I_O2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_16_RNIHUPS_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_3\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_16\(1),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(1),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4_0\);
\GRFPC0_D_LDLCK_RNO_2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(23),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(23));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_2_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(1),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0_1\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_0\(1),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001010111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_8\(1),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_6\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_0_2_RNI69T41_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0_5\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_3_I\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_2\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1\(0));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_20_RNIIR191_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0_4\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\(0),
datad => \GRFPC0.D.LDLCK_0_0_14__G3_0_4_A\);
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3356_REGDEPX2_0_A2_RNIF7PP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_0_4_A\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M3_E_I_1\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_6\(0),
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1_1\(0),
datab => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_3\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_4\(0),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_I\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_1\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_4_2\(0),
datab => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_4_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_1\(46),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_0\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_4_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_4\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_2\(48),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_0\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(19),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(19),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(19),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(14),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_4_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_4\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(44),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_3_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3_0\(12),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M2\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0_0\(12),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2\(12),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(20),
datab => \GRFPU0.GRFPU_X0.MULO_I_M\(81),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(20),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(27),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(27),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(15),
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_3\(33),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_2\(59),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_3\(59));
\GRFPC0_D_LDLCK_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_3\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(0),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_4\,
dataa => \GRFPC0.D.LDLCK_0_0_14__G3_A0_0\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A2_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_4\(1),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A3_2\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_3\(1),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2049_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_30\,
dataa => \GRFPC0.OP2\(1),
datab => \GRFPC0.OP2\(25),
datac => \GRFPC0.OP2\(0),
datad => \GRFPC0.OP2\(27));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_28\,
dataa => \GRFPC0.OP2\(10),
datab => \GRFPC0.OP2\(16),
datac => \GRFPC0.OP2\(8),
datad => \GRFPC0.OP2\(29));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_26\,
dataa => \GRFPC0.OP2\(6),
datab => \GRFPC0.OP2\(15),
datac => \GRFPC0.OP2_I_M2\(5),
datad => \GRFPC0.OP2\(21));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_25\,
dataa => \GRFPC0.OP2\(18),
datab => \GRFPC0.OP2\(19),
datac => \GRFPC0.OP2_I_M2\(13),
datad => \GRFPC0.OP2\(20));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_24\,
dataa => \GRFPC0.OP2\(17),
datab => \GRFPC0.OP2\(22),
datac => \GRFPC0.OP2\(3),
datad => \GRFPC0.OP2\(7));
\GRFPC0_D_LDLCK_RNO_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_0\,
dataa => N_93,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX_0_A2_0_X\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(28),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(28));
\GRFPC0_D_LDLCK_RNO_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(28),
datac => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_3\(1),
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A1\(1),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_1\(1),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_2\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_2_0\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O3\(1),
datac => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0_A\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101011101")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_0_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0\(1));
GRFPC0_RFA_STDFQ_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_4\,
dataa => N_113,
datab => N_101,
datac => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_0_X\,
datad => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2_1_X\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(18));
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_7_RNIOURS4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_O3_11_1_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_419_A0_RNIHQDP1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6165_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_0\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_419_A0\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_A3_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_0_0\(0),
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_3\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_3\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_0\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_O3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6443_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_0\(1));
\GRFPC0_D_STDLCK_RNO_16_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_3_9_2\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_105_I_0_O4\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.STDDEP_0_SQMUXA_14_I_0\,
datad => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_3_0\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3_1\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_2\(22),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1\(0),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2\(0),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A4_0_RNIDP7C1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_5\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1167_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A4_0\(0),
datad => \GRFPC0.D.LDLCK_0_0_4__G1_0_1\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_6_RNIJEOU_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_4\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_I\(0),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6\(0),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2_A\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_2_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2_A\(1),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\(1));
\GRFPC0_D_STDLCK_RNO_11_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_7_2\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datab => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\);
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F1_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datab => \GRFPU0.GRFPU_X0.ITER.LOB\,
datac => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_0_385\,
datad => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_2\(1),
dataa => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2919_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_1\(7),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\(1));
GRFPC0_FP_PIPELINE_UN205_HOLDN_3_7_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_5\,
dataa => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_2\,
datab => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0\);
\GRFPC0_OP1_0_IV_5_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_5\(56),
dataa => N_715,
datab => \GRFPC0.OP1_1_SQMUXA\,
datac => \GRFPC0.OP1_0_IV_2\(56),
datad => \GRFPC0.OP1_0_IV_5_A\(56));
\GRFPC0_OP1_0_IV_5_A_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010001010")
port map (
combout => \GRFPC0.OP1_0_IV_5_A\(56),
dataa => \GRFPC0.OP1_0_IV_5_A_S\(56),
datab => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0));
\GRFPC0_OP1_0_IV_5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_5\(31),
dataa => N_658,
datab => \GRFPC0.OP1_0_SQMUXA\,
datac => \GRFPC0.OP1_0_IV_3\(31),
datad => \GRFPC0.FPO_I_M\(31));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M9_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_21_TZ_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_21_TZ_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M12_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M11_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_22_TZ_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M12_4_03_0_G2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(7),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2\(58),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_O2\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2_A\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_2_A_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2_A\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_2\(56),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_0\(56));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_IV_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_IV_0\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_I_M\,
datad => \GRFPU0.GRFPU_X0.COMB.UN6_SWAP\);
\GRFPU0_GRFPU_X0_VST2_EXC_13_I_M_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100000011")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_0\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datab => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
datac => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\,
datad => \GRFPU0.GRFPU_X0.UN1_CCV12\);
GRFPU0_GRFPU_X0_ST3_INF_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ST2.INF\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_I_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_I_A3_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN4931_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_0_2\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_O2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_2_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datab => \GRFPC0.V.STDATA_14_M_0\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5957_REGDEPX2_I_0_O3_I_A2\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0_A3_0\(1));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_39\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_35\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_36\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_42\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_3_TZ_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_3_TZ_0\(0),
dataa => \GRFPC0.V.STDATA_14_I_M2\(0),
datab => \GRFPC0.V.STDATA_14\(14),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_3\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_5_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1\(15),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_1\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1_A\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_5_1_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5_1_A\(15),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_4_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_5\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\(0),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_0\(0));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16368_M_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.N_16368_M_1\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\);
\GRFPC0_OP1_0_IV_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.OP1_0_IV\(63),
dataa => N_658,
datab => \GRFPC0.OP1_0_IV_2\(63),
datac => \GRFPC0.OP1_I_A2\(32),
datad => \GRFPC0.OP1_0_IV_A\(63));
\GRFPC0_OP1_0_IV_A_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.OP1_0_IV_A\(63),
dataa => N_722,
datab => \GRFPC0.OP1_0_IV_1\(63),
datac => \GRFPC0.OP1_1_SQMUXA_REP1\,
datad => \GRFPC0.OP1_0_IV_0\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_4_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4\(40),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD34\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_1\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_2\(40));
GRFPC0_UN1_RDWR_3_SQMUXA_4_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C_1\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_RNI2BU64_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0\(2),
dataa => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
datac => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0_0\(2));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPC0.LDLOCK_1_M\,
dataa => N_106,
datab => \GRFPC0.LDLOCK_1_M_3\,
datac => \GRFPC0.LDLOCK_1_15\,
datad => \GRFPC0.LDLOCK_1_30\);
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_1\,
dataa => \GRFPC0.V.STDATA_14_I_M_4\(14),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_1_0_A2_0_A2_0_A2\,
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2_2_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_7\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_6\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1004_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_3\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_O4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O4\(0),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_0\(0));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_5\,
dataa => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_4_0_S_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0\(0),
dataa => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4_0\(0));
\GRFPC0_RFA2_FID_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_4__G0\,
dataa => \GRFPC0.MEM.CTRL.ID\(4),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0),
datac => \GRFPC0.FID_1_IV_0_0_4__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2\(4));
\GRFPC0_RFA2_FID_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_0__G0\,
dataa => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0),
datac => \GRFPC0.FID_1_IV_0_0_0__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2_1\(0));
\GRFPC0_D_STLCK_RNO_8_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_10\(1),
dataa => D_M2_E_4_0,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_12\(1));
\GRFPC0_D_STLCK_RNO_10_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_11\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(1),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_11\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.STDEP_2_SQMUXA_143_0_A2_I\);
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_I_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_I_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4791_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_274_0_A4\(0),
datad => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_272_IV_0\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_564_0_IV_I_M2_RNIKRUR1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5_0\(1),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_2\);
\GRFPC0_RFA2_FID_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_1__G0\,
dataa => \GRFPC0.MEM.CTRL.ID\(1),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0),
datac => \GRFPC0.FID_1_IV_0_0_1__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2\(1));
GRFPC0_RFA_AFSR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2\,
dataa => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_4\,
datab => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_5_X\,
datac => CPO_LDLOCKZ,
datad => CPO_EXCZ);
GRFPC0_FP_PIPELINE_V_STDATA_1S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1S2\,
dataa => \GRFPC0.UN1_DIV.EXC\,
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.UN1_WR2.EXC\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_1\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_O3_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5516_REGDEPX2_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_RFA2_FID_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_5__G0\,
dataa => \GRFPC0.MEM.CTRL.ID\(5),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0),
datac => \GRFPC0.FID_1_IV_0_0_5__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2\(5));
GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_M5_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E\,
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.RDD_REP4\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2_0_A3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E_0\);
\GRFPC0_RFA2_FID_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_2__G0\,
dataa => \GRFPC0.MEM.CTRL.ID\(2),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0),
datac => \GRFPC0.FID_1_IV_0_0_2__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_5\,
dataa => D_M2_E_4_0,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_RFA2_FID_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FID_1_IV_0_0_3__G0\,
dataa => \GRFPC0.EX.CTRL.ID\(3),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0),
datac => \GRFPC0.FID_1_IV_0_0_3__G0_1\,
datad => \GRFPC0.FID_1_IV_0_A2_1\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.N_19572_1_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_9\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_STDDEP_0_SQMUXA_155: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_155\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_X2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_RFA_ST_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_1622_A2\,
dataa => N_108,
datab => N_100,
datac => \GRFPC0.RFA.ST_0_0_G1_0_1622_A2_2\,
datad => \GRFPC0.RFA.ST_0_0_G1_0_1622_O2\);
GRFPC0_RFA_RDWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2\,
dataa => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_2\,
datab => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_3_X\,
datac => CPO_LDLOCKZ,
datad => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_1\);
\GRFPC0_D_STLCK_RNO_8_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_5\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_O3_0\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL1_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_0\(1),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14_I_M_6\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2_0_0_A3\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1\(1),
dataa => \GRFPC0.V.STDATA_14\(15),
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2\,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(60),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_4\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_5\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_I_A2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_5\(0),
dataa => \GRFPC0.V.STDATA_14\(15),
datab => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A4_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
GRFPC0_UN1_STDDEP_0_SQMUXA_104_0_A5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_104_0_A5\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_X2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_STDDEP_0_SQMUXA_124_I_O2_RNID4BC5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_3\(1),
datab => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datac => \GRFPC0.STDDEP_0_SQMUXA_124_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_1\(1));
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_0\(0),
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_O3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_3\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_4\(0),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_M2\(0));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_0_A2_RNIKQQL: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_2\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_O3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_4\(0),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_2\(1),
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0\(1),
dataa => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_0_I_O5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5\,
dataa => N_108,
datab => N_90,
datac => N_86,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5_A\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_0_I_O5_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_0_I_O5_A\,
dataa => N_89,
datab => N_88,
datac => N_84,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_I_O3_0_O2_0\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_35\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_36\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_45\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_48\);
GRFPU0_GRFPU_X0_COMB_SHV2LTO10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_1\,
datab => \GRFPU0.GRFPU_X0.COMB.SHV2LTO5_0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHV2LTO3\);
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD11\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0\(0),
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0_2\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_10\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_5\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_12\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_13\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_17\,
datad => \GRFPU0.GRFPU_X0.L3\(5));
GRFPU0_GRFPU_X0_NXX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX\,
dataa => \GRFPU0.GRFPU_X0.NXX_9\,
datab => \GRFPU0.GRFPU_X0.NXX_11\,
datac => \GRFPU0.GRFPU_X0.NXX_8\,
datad => \GRFPU0.GRFPU_X0.NXX_10_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(48));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(12));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(28),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(54));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(45),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_1\(45));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(61),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(61),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(61));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(60),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(60),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV\(60),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.MULO_I_M\(120),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
datad => \GRFPU0.GRFPU_X0.MULO_M_299\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_10\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_18\);
GRFPU0_GRFPU_X0_ITER_EMIN_RNIRSSBA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMIN\,
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.MULO_M_299\);
GRFPU0_GRFPU_X0_VITER_ND_I_1_SQMUXA_1_RNIUK5N2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83\,
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_3\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.C_ADD10\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\);
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2\,
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.C_ADD10\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(62),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0_A\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111111011101")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD10\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_O2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41),
dataa => \GRFPU0.GRFPU_X0.G_52\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M2\(45),
datac => \GRFPU0.GRFPU_X0.G_51_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2_1\(41));
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST3.REG40\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_5\);
GRFPC0_EX_CTRL_PEND_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000000010")
port map (
combout => \GRFPC0.EX.CTRL.PEND_M_3\,
dataa => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.EX.CTRL.PEND_M_3_A\,
datad => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\);
GRFPC0_EX_CTRL_PEND_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.EX.CTRL.PEND_M_3_A\,
dataa => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.MEM.CTRL.PEND\,
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.FP_PIPELINE.UN54_HOLDN\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3\(53),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(53));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(58),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(57));
\GRFPU0_GRFPU_X0_L3_0_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(5),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
datab => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_7\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_IV_RNO_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M_0\(63));
GRFPU0_GRFPU_X0_COMB_VST4_SEL3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\,
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_RNIU8344_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_22__G0\,
dataa => N_3,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_M2\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(22),
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0\,
dataa => N_3,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_M2\(23),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(22),
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
GRFPU0_GRFPU_X0_EXPT_5_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4\,
datad => \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_L3_0_4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_4\(5),
dataa => \GRFPU0.GRFPU_X0.L3_0_4_2\(5),
datab => \GRFPU0.GRFPU_X0.UN18_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_4\(4));
GRFPC0_RFA_READ_RS1_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST_I_X\(6),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0_0\);
GRFPC0_UN1_VFIFO_WR_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011101100")
port map (
combout => \GRFPC0.UN1_VFIFO.WR_1_SQMUXA\,
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.UN1_VFIFO.WR_1_SQMUXA_0\,
datac => \GRFPC0.FP_PIPELINE.CNTX14\,
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\);
GRFPC0_FP_PIPELINE_FPUSTART_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
dataa => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
datab => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_5\,
datad => \GRFPC0.FP_PIPELINE.FPUSTART_7_6\);
\GRFPC0_EX_CTRL_ID_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3\,
dataa => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_4\,
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_6\,
datac => \GRFPC0.FP_PIPELINE.FIFOV2\);
\GRFPU0_GRFPU_X0_BIAS_4_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100111011")
port map (
combout => \GRFPU0.GRFPU_X0.BIAS_4_0\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.BIAS_4_0_A\(7));
\GRFPU0_GRFPU_X0_BIAS_4_0_A_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BIAS_4_0_A\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_2\);
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_4_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datad => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\);
GRFPU0_GRFPU_X0_UN1_ST2_FLTYPE2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8_0\,
datad => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_A3_3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0),
datad => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_2\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_174_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3\(0),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(38),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\(38));
\GRFPC0_D_STLCK_RNO_7_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1_0\(1));
\GRFPC0_D_STLCK_RNO_7_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100001101")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_A0\,
dataa => \GRFPC0.D.STLCK_0_0_7__G1_A0_A\,
datab => \GRFPC0.EX.CTRL.RDD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_27_I_I_A3_I\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\(1));
\GRFPC0_D_STLCK_RNO_9_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010111111")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_A0_A\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => N_241);
GRFPC0_RFA2_RS2DEP_RNO_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M3_E\,
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP2\,
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0));
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A2\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_5\(1));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_1_0_TZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011011111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_TZ\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPC0.V.STDATA_14\(11),
datac => \GRFPC0.V.STDATA_14_REP0\(6),
datad => \GRFPC0.FP_PIPELINE.UN8_OP_7_6\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2\(0),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7004_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2_TZ_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_2_1_RNI7UUK_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_1\(0),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_2_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\);
GRFPC0_UN1_WRENX2_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000001110")
port map (
combout => \GRFPC0.UN1_WRENX2_2_0\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_FP_PIPELINE_0_WR2EN2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2_0\,
dataa => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
GRFPC0_RFA_WRITE_RD_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_0\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\);
\GRFPU0_GRFPU_X0_REST_1_2_RNID3SE1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001110101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G2_0\,
datac => \GRFPU0.GRFPU_X0.REST_1_2\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\);
GRFPC0_RDWR_5_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.RDWR_5_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_8_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1\(0),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_16\(0));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A3\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.DIVROM0.DATA_1_MUX_15\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_RNIR86A6_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011011000")
port map (
combout => D_M4_0,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datab => D_M3_E_0_0,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_D\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_RNIJPCH6_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010110001101")
port map (
combout => D_M4,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datab => D_M3_0_0,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_D\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(56));
GRFPC0_FP_PIPELINE_UN25_HOLDN_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011001110100000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_0\,
dataa => \GRFPC0.FP_PIPELINE.UN23_HOLDN\,
datab => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datac => \GRFPC0.FP_PIPELINE.UN25_HOLDN_A1_0_X\,
datad => \GRFPC0.FP_PIPELINE.UN25_HOLDN_A0_2\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A4\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300TT_0_M1_E\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_12\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_E\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2\(0));
GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_M10_I_A5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3491_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M3_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_TZ_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_TZ_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5681_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A4_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6165_REGDEPX2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0_TZ_0\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_3\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_I_I_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_5_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M7_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M8_4_03_0_G2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_5_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A2_0_0\(1),
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A4_1_0\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_1_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_1_TZ\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN4931_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_0_2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101110101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2_0\(0));
\GRFPC0_D_STLCK_RNO_2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_TZ\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.CPI_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ_A\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_TZ_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_TZ_A\(0),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_350_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_350_0_IV_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6606_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ_A\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_TZ_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_TZ_A\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_O2\(0));
\GRFPC0_D_STLCK_RNO_9_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_TZ\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.CPI_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_14\);
\GRFPC0_FP_PIPELINE_14_STDEP_598_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_598_0_IV_TZ\(0),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_5_STDEP_238_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_0_IV_TZ\(0),
dataa => N_241,
datab => \GRFPC0.EX.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_4\(0),
datad => \GRFPC0.D.STLCK_0_0_11__G3_0\);
\GRFPC0_FP_PIPELINE_13_STDEP_550_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_550_0_IV_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_7_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_0_0\(0),
dataa => N_172,
datab => \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.RDD\);
\GRFPU0_GRFPU_X0_COMB_RMND_7_I_M3_RNIRF9N4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.COMB.RMND_7_I_M3\(1),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ\,
datad => \GRFPU0.GRFPU_X0.G_16_0_A3_1\);
\GRFPC0_D_STLCK_RNO_6_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_123_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_4\(14),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_393_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_4\(14),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0_A3_0\(1));
GRFPC0_FP_PIPELINE_0_UN1_FPO_15_RNIDMBD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_15\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(22),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_0\(22));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8\(1));
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_3\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2_0\);
GRFPC0_WR_CTRL_LD_RNILGL42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2\,
dataa => N_38,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_A2_0_0_X\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2_0\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_355_1_M9_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1_M9_I_A4\,
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M1_E_0\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M3_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_3\(1),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_I_I_A2_1_A2_1_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_O2_4_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3\(1),
dataa => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_1_1\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_5_1\(0),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_0_0\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(29),
dataa => \GRFPC0.OP2\(29),
datab => \GRFPC0.OP2\(32),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(31),
dataa => \GRFPC0.OP2\(31),
datab => \GRFPC0.OP2\(34),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_O2_3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_3_1\(1),
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6326_REGDEPX2_I_I_A2_1_A2\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_10\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(30),
dataa => \GRFPC0.DIV.PC\(30),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(29),
dataa => \GRFPC0.DIV.PC\(29),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(28),
dataa => \GRFPC0.DIV.PC\(28),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(27),
dataa => \GRFPC0.DIV.PC\(27),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(26),
dataa => \GRFPC0.DIV.PC\(26),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(25),
dataa => \GRFPC0.DIV.PC\(25),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
dataa => \GRFPC0.DIV.PC\(24),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(23),
dataa => \GRFPC0.DIV.PC\(23),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(22),
dataa => \GRFPC0.DIV.PC\(22),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(21),
dataa => \GRFPC0.DIV.PC\(21),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(20),
dataa => \GRFPC0.DIV.PC\(20),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(19),
dataa => \GRFPC0.DIV.PC\(19),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(16),
dataa => \GRFPC0.DIV.PC\(16),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(14),
dataa => \GRFPC0.DIV.PC\(14),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(13),
dataa => \GRFPC0.DIV.PC\(13),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(11),
dataa => \GRFPC0.DIV.PC\(11),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(9),
dataa => \GRFPC0.DIV.PC\(9),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(4),
dataa => \GRFPC0.DIV.PC\(4),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(4));
\GRFPC0_WRDATA_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(15),
dataa => N_423,
datab => N_424,
datac => N_446,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(47));
\GRFPC0_FP_PIPELINE_WRDATA_6_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6\(24),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(24),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(24),
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(24));
\GRFPC0_FP_PIPELINE_WRDATA_6_A_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001001011111")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(24),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(56),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(56),
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_WRDATA_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(24),
dataa => N_423,
datab => N_424,
datac => N_455,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(56));
\GRFPC0_WRDATA_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(27),
dataa => N_423,
datab => N_424,
datac => N_458,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(59));
\GRFPC0_OP2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(44),
dataa => \GRFPC0.OP2_6\(44),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(44));
\GRFPC0_OP2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(47),
dataa => \GRFPC0.OP2_6\(47),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(47));
\GRFPC0_OP2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(56),
dataa => \GRFPC0.OP2_6\(56),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(56));
\GRFPC0_OP2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(62),
dataa => \GRFPC0.OP2_6\(62),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(62));
\GRFPC0_FP_PIPELINE_WRDATA_6_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6\(12),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(12),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(12),
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(12));
\GRFPC0_FP_PIPELINE_WRDATA_6_A_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001001011111")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(12),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(44),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(44),
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_WRDATA_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(12),
dataa => N_423,
datab => N_424,
datac => N_443,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(44));
\GRFPC0_OP2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(50),
dataa => \GRFPC0.OP2_6\(50),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(50));
\GRFPC0_OP2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(59),
dataa => \GRFPC0.OP2_6\(59),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(59));
\GRFPC0_R_STDATA_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.R.STDATA_0_0_0__G3\,
dataa => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0));
\GRFPC0_R_STDATA_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.R.STDATA_0_0_1__G3\,
dataa => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_96_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001110110011")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_96_I\(0),
dataa => \GRFPC0.UN1_FIFO.INST_0_12\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95_I_A2_0\(0),
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_FP_PIPELINE_7_STDEP_288_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_288_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_284_0_IV_I_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
\GRFPC0_FP_PIPELINE_7_STDEP_288_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_288_2\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.N_19292_1_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_284_0_IV_I_0\(1),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
\GRFPC0_FP_PIPELINE_8_0_STDEP_345_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011001100110011")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.STDEP_345\(1),
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datab => \GRFPC0.STDDEP_0_SQMUXA_84\,
datac => \GRFPC0.STDEP_0_SQMUXA_92_1\,
datad => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_2_IV\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(6),
dataa => \GRFPC0.DIV.PC\(6),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(12),
dataa => \GRFPC0.DIV.PC\(12),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(12));
GRFPC0_STDEP_0_SQMUXA_84_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_84_1_0\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_9_1\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_1_0\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_O3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_0_A2_0\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_1\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_93_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_93\(1),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1403_REGDEPX2_I_I_A2\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_22_IV\(1));
GRFPC0_FP_PIPELINE_UN15_OP_1_TZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_1_TZ\,
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPC0.FP_PIPELINE.UN8_OP_7_6\,
datac => \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN11_OP_7\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_5\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10\(0),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_5\(0),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_11\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(30),
dataa => \GRFPC0.OP2\(30),
datab => \GRFPC0.OP2\(33),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_363_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011101010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\(1),
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_22_IV_0\(1));
GRFPC0_FP_PIPELINE_UN15_OP_2_TZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPC0.V.STDATA_14_REP0\(6),
datac => \GRFPC0.FP_PIPELINE.UN17_OP_7_3\,
datad => \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ_A\);
GRFPC0_FP_PIPELINE_UN15_OP_2_TZ_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_2_TZ_A\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14\(8),
datac => \GRFPC0.V.STDATA_14_REP1\(11));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_423_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\(0),
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6326_REGDEPX2_I_I_A2_1_A2\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_23_IV_I_A3\(0));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_RNIQ0KV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011010101")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_O2\,
dataa => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.VWR.RREG.RESV_6_IV_I_I_A2_0_0_X\,
datac => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\,
datad => G_2026_X);
GRFPC0_FP_PIPELINE_0_EXEN2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2_3\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.FP_PIPELINE.RS1_6_X\(3),
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
\GRFPC0_WRDATA_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(30),
dataa => N_423,
datab => N_424,
datac => N_461,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(62));
\GRFPC0_FP_PIPELINE_WRDATA_6_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6\(30),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(30),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(30),
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(30));
\GRFPC0_FP_PIPELINE_WRDATA_6_A_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001001011111")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_6_A\(30),
dataa => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datab => \GRFPC0.DIV.RESULT\(62),
datac => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(62),
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_WRDATA_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(21),
dataa => N_423,
datab => N_424,
datac => N_452,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(53));
\GRFPC0_OP2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(53),
dataa => \GRFPC0.OP2_6\(53),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(53));
\GRFPC0_WRDATA_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(18),
dataa => N_423,
datab => N_424,
datac => N_449,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(50));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(2),
dataa => \GRFPC0.DIV.PC\(2),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(17),
dataa => \GRFPC0.DIV.PC\(17),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(17));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_4_RNIE55C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0_1078\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4\);
GRFPC0_FP_PIPELINE_UN30_OP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN30_OP\,
dataa => N_97,
datab => N_102,
datac => \GRFPC0.FP_PIPELINE.LDLOCK23_4\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK19\);
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_M2\(1),
dataa => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_O2_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\,
datac => \GRFPC0.STDEP_2_SQMUXA_141_0_A2\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_M2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_M2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_O2_1\(0),
datad => \GRFPC0.STDEP_2_SQMUXA_141_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100110101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
GRFPC0_UN1_REGDEP133: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111101001111")
port map (
combout => \GRFPC0.UN1_REGDEP133\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(7),
dataa => \GRFPC0.DIV.PC\(7),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(15),
dataa => \GRFPC0.DIV.PC\(15),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(15));
\GRFPC0_FIFO_INST_1_RNIU9A93_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPC0.FIFO.INST_1_M_2\(25),
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\,
datac => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_A4\);
\GRFPC0_FIFO_INST_1_RNIU9A93_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FIFO.INST_1_I_M_2\(25),
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\,
datac => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_A4\);
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_94_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_94\(1),
dataa => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1656_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_92_IV\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_A2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_A2\(8),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_0\(4),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
GRFPC0_UN28_WREN_M8_I_A5_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.UN28_WREN_M8_I_A5_2\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_A2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31),
dataa => \GRFPC0.R.FSR.NONSTD\,
datab => \GRFPC0.V.STDATA_14_REP1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_O2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000110000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_1\(1),
dataa => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.V.STDATA_14_I_M_6\(0),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_0\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_1\);
GRFPC0_UN1_REGDEP161: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111101001111")
port map (
combout => \GRFPC0.UN1_REGDEP161\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.1.UN1_EX.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
GRFPC0_UN1_REGDEP119: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111101001111")
port map (
combout => \GRFPC0.UN1_REGDEP119\,
dataa => \GRFPC0.WR2.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\(0),
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN962_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(3),
dataa => \GRFPC0.DIV.PC\(3),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(5),
dataa => \GRFPC0.DIV.PC\(5),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
dataa => \GRFPC0.DIV.PC\(10),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
dataa => \GRFPC0.DIV.PC\(31),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4\,
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7004_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475TT_1_M3_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100001011")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_0_A4\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(8),
dataa => \GRFPC0.DIV.PC\(8),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(18),
dataa => \GRFPC0.DIV.PC\(18),
datab => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_3_1\(0),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_18\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_4\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_5\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_368_3_0_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_3_0_M2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datad => \GRFPC0.STDEP_2_SQMUXA_143_0_A2_I\);
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_22_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_22\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP\(1),
datad => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_20_IV\(1));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3\(0),
dataa => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_256_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\(0),
dataa => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX_0_A3\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\(0));
\GRFPC0_D_STLCK_RNO_9_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_2\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_0_0_RNIKGOF1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_1_X\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
GRFPC0_UN1_STDDEP_0_SQMUXA_108_I_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100011101")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_108_I_M2\,
dataa => \GRFPC0.WR.CTRL.RDD_REP5\,
datab => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_O3_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_O3_5\(0),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_3\(1),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_164_0_IV\(0),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP682\,
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.STDEP_2_SQMUXA_133\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_RS1_6_0_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001011")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6_0_I_M2\(0),
dataa => N_103,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0\,
datac => \GRFPC0.INST_I_0\(14),
datad => \GRFPC0.INST_I_A2_X\(14));
\GRFPC0_FP_PIPELINE_12_STDEP_484_0_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_484_0_IV\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
GRFPC0_FP_PIPELINE_0_STDEP11_0_A2_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP11_0_A2_0_A3\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_148_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011110101")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP\(1),
datad => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_2_IV\(1));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_150_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_150_I\(0),
dataa => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148_0_A2\(0),
datad => \GRFPC0.STDEP_0_SQMUXA_92_1\);
\GRFPC0_FP_PIPELINE_13_STDEP_558_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_558\(1),
dataa => N_243,
datab => \GRFPC0.STDEP_0_SQMUXA_5_0_0_X\,
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1));
GRFPC0_UN1_STDEP2194: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPC0.UN1_STDEP2194\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_3_0_O2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_A_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_46\,
dataa => \GRFPC0.FP_PIPELINE.13.STDEP2195\,
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_123_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_1_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_4\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\);
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LTO10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_5_0\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_6\);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datad => \GRFPU0.GRFPU_X0.MULO_M_299\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G0\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_0_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_0\(62),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(10),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\);
\GRFPU0_GRFPU_X0_VST3_REG_47_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(49));
\GRFPU0_GRFPU_X0_VST3_REG_37_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_16\);
\GRFPU0_GRFPU_X0_VST3_REG_37_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_15\);
\GRFPU0_GRFPU_X0_VST3_REG_37_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(29),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_14\);
\GRFPU0_GRFPU_X0_VST3_REG_37_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_8\);
\GRFPU0_GRFPU_X0_VST3_REG_37_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_7\);
\GRFPU0_GRFPU_X0_VST3_REG_37_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(21),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_6\);
\GRFPU0_GRFPU_X0_VST3_REG_37_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_12\);
\GRFPU0_GRFPU_X0_VST3_REG_37_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_11\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(32),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(32));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_I_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2_I_M2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5),
datad => \GRFPU0.GRFPU_X0.VST2.REG_5_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(13),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(13),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(18),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(18));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M5_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M1_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M3_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M10_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M9_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M6_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G1\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_4_03_0_G1\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\,
dataa => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(52));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\,
dataa => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(54));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\,
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(55));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\,
dataa => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G1\);
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_3_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.REST_1_2_IV\(2));
GRFPU0_GRFPU_X0_UN1_REST_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_REST_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.REST_1_2_IV\(2));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\,
dataa => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_O3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_O3\(10),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0_0\(10),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_4_03_0_G1\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_4_03_0_G1\);
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_4_0\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_A\);
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100101110")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.COMB.ITCIN\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_75_2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_7\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_O3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_O3\(6),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0\(6),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\,
dataa => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(53));
\GRFPU0_GRFPU_X0_L3_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(0),
dataa => \GRFPU0.GRFPU_X0.L1_2_6\(0),
datab => \GRFPU0.GRFPU_X0.L2_0_I_I_A2\(4),
datac => \GRFPU0.GRFPU_X0.L2_0\(0));
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datad => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0_A\(1));
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100001110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_3\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\,
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(58));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_L3_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(0),
dataa => \GRFPU0.GRFPU_X0.L2_1\(0),
datab => \GRFPU0.GRFPU_X0.L2_0_1\(0),
datac => \GRFPU0.GRFPU_X0.L2\(4));
\GRFPU0_GRFPU_X0_L4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_6_I\(0),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4));
\GRFPU0_GRFPU_X0_L4_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(2),
dataa => \GRFPU0.GRFPU_X0.L3_1_2\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_4\(5),
datac => \GRFPU0.GRFPU_X0.L3_0_6\(2));
\GRFPU0_GRFPU_X0_L4_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_0\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_6\(3),
datad => \GRFPU0.GRFPU_X0.L3_0_4\(5));
\GRFPU0_GRFPU_X0_REST_2_RNIBT1F2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_5\(21),
dataa => \GRFPU0.GRFPU_X0.REST_2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21));
GRFPU0_GRFPU_X0_EXPT_4_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C\);
GRFPU0_GRFPU_X0_EXPT_4_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_4_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN22_DP\);
\GRFPU0_GRFPU_X0_L4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010101010101")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(4),
dataa => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datab => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_5_4_2\(3),
datad => \GRFPU0.GRFPU_X0.L1_4_3\(3));
\GRFPU0_GRFPU_X0_L4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101010101")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(3),
dataa => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datab => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_5_4_2\(3),
datad => \GRFPU0.GRFPU_X0.L1_4_3\(3));
\GRFPU0_GRFPU_X0_VST3_REG_37_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_10\);
\GRFPU0_GRFPU_X0_VST3_REG_37_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_23\);
\GRFPU0_GRFPU_X0_VST3_REG_37_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_31\);
\GRFPU0_GRFPU_X0_VST3_REG_47_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(51));
\GRFPU0_GRFPU_X0_L4_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.L1_6_1_4_0_I_A2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_L2_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(0),
dataa => \GRFPU0.GRFPU_X0.L1_1_0_0\(0),
datab => \GRFPU0.GRFPU_X0.L1_1_0_A3_1\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_2_0\(0),
datad => \GRFPU0.GRFPU_X0.L1_0_1\(3));
\GRFPU0_GRFPU_X0_L3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(1),
dataa => \GRFPU0.GRFPU_X0.L2_0_2\(1),
datab => \GRFPU0.GRFPU_X0.L2_1_1\(1),
datac => \GRFPU0.GRFPU_X0.L2_0_10\(4));
\GRFPU0_GRFPU_X0_L4_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(2),
dataa => \GRFPU0.GRFPU_X0.L4_2_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0\(2),
datac => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(23),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(23));
\GRFPU0_GRFPU_X0_L4_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(1),
dataa => \GRFPU0.GRFPU_X0.L3_1\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L3_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(0),
dataa => \GRFPU0.GRFPU_X0.L2_0_3\(0),
datab => \GRFPU0.GRFPU_X0.L2_1_2\(0),
datac => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPU0_GRFPU_X0_L3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.L3_1_A\(0),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_L3_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000001010001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_A\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datad => \GRFPU0.GRFPU_X0.UN1_ST2.DIFF_1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0_2\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_O3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_0\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14_REP1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_3\);
\GRFPU0_GRFPU_X0_L3_0_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(1),
datab => \GRFPU0.GRFPU_X0.L2_0_6\(1),
datac => \GRFPU0.GRFPU_X0.L2_0_9\(4));
\GRFPU0_GRFPU_X0_L3_0_7_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(2),
datab => \GRFPU0.GRFPU_X0.L2_0_6\(2),
datac => \GRFPU0.GRFPU_X0.L2_0_9\(4));
\GRFPU0_GRFPU_X0_L3_0_7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(3),
dataa => \GRFPU0.GRFPU_X0.L1_0_0\(3),
datab => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_9\(4));
\GRFPU0_GRFPU_X0_L2_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(0),
dataa => \GRFPU0.GRFPU_X0.L1_1_7\(0),
datab => \GRFPU0.GRFPU_X0.L1_0_7\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_0\(3));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_7\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_5\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101010101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_2\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5),
datad => \GRFPU0.GRFPU_X0.VST2.REG_5_SQMUXA\);
GRFPU0_GRFPU_X0_UN1_REST_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_REST_9\,
dataa => \GRFPU0.GRFPU_X0.REST_1_2\(6),
datab => \GRFPU0.GRFPU_X0.REST_1_2\(7),
datac => \GRFPU0.GRFPU_X0.REST_2\(5));
\GRFPU0_GRFPU_X0_L2_0_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(0),
dataa => \GRFPU0.GRFPU_X0.L1_0_10\(3),
datab => \GRFPU0.GRFPU_X0.L1_0_6\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_5\(0));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
dataa => \GRFPU0.GRFPU_X0.L1_5_6\(0),
datab => \GRFPU0.GRFPU_X0.L1_4_5\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_4\(3));
\GRFPU0_GRFPU_X0_L2_1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_3\(0),
dataa => \GRFPU0.GRFPU_X0.L1_3_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_5\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_3\(3));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\);
GRFPU0_GRFPU_X0_EXPT_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C\);
GRFPU0_GRFPU_X0_UN1_EXPT_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP\);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_0\(1),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO10\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN11_DP\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\);
\GRFPU0_GRFPU_X0_L4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(1),
dataa => \GRFPU0.GRFPU_X0.L4_2\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_1\(1),
datac => \GRFPU0.GRFPU_X0.L3_0\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M32_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M28_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M24_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M33_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M23_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M27_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M29_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M31_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(59));
\GRFPU0_GRFPU_X0_L2_0_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(1),
dataa => \GRFPU0.GRFPU_X0.L1_0_6_0\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_10\(3),
datac => \GRFPU0.GRFPU_X0.L1_1_5\(1));
\GRFPU0_GRFPU_X0_L3_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datab => \GRFPU0.GRFPU_X0.L1_6_1_5_I_0_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(1),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4));
GRFPU0_GRFPU_X0_VITER_V_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110100100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_2\,
dataa => \GRFPC0.RFA2.FID\(5),
datab => \GRFPU0.GRFPU_X0.ST1.IDCST\(5),
datac => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0_2\);
GRFPU0_GRFPU_X0_COMB_VST3_REG46_0_A2_RNIJPIG1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.V_0_I_A2_0\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST3.REG40\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\);
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST3.REG40\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_A\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U\,
datac => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U\,
datad => \GRFPU0.GRFPU_X0.S3ADDI\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M24_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M25_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M23_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M27_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M29_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M31_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M17_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M17_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\);
GRFPC0_FP_PIPELINE_UN3_FIFO_CLR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
dataa => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datab => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datad => \GRFPC0.FIFO_INC_5_SQMUXA\);
GRFPC0_FP_PIPELINE_UN4_FIFO_CLR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_FIFO_CLR\,
dataa => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datab => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datad => \GRFPC0.FIFO_INC_5_SQMUXA\);
\GRFPU0_GRFPU_X0_VST3_REG_37_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_26\);
\GRFPU0_GRFPU_X0_UN1_ST2_FLTYPE2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(59),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0_M4\);
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_1_RNIH7A01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(57),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0_M4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(57),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0_M4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110001")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0\,
dataa => CARRY_PATCH0,
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0_M4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110001")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0\,
dataa => CARRY_PATCH0,
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0_M4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0_M4\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(55),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0_M4\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_I_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000111111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1\(2));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M32_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M28_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0\(53),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
\GRFPU0_GRFPU_X0_L2_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_6\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_5\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3));
\GRFPU0_GRFPU_X0_L3_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010001110100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_6_1_4_I\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(1));
\GRFPU0_GRFPU_X0_L2_0_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(0),
dataa => \GRFPU0.GRFPU_X0.L1_1_6\(0),
datab => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3),
datac => \GRFPU0.GRFPU_X0.L1_0_5\(0));
\GRFPU0_GRFPU_X0_L2_1_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_4\(0),
dataa => \GRFPU0.GRFPU_X0.L1_3_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_4\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(0),
dataa => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_6\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_5\(0));
\GRFPU0_GRFPU_X0_L4_7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_5\(3),
datad => \GRFPU0.GRFPU_X0.L3_0_3\(5));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_REST_2_RNIGL8K2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datab => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6));
\GRFPC0_D_STLCK_RNO_6_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100011111")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_0\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_105_I_0_O4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datad => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\);
\GRFPC0_D_STLCK_RNO_4_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110001")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_0\,
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_105_I_0_O4\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\);
\GRFPC0_D_STLCK_RNO_6_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_23_I_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.STDDEP_0_SQMUXA_96_0_A3\);
\GRFPC0_D_STLCK_RNO_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001110101011")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_6_0\(1),
dataa => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datac => \GRFPC0.STDDEP_0_SQMUXA_106_I_0_0_O4_I_O2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
\GRFPC0_D_STLCK_RNO_8_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010111010")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_6_0\,
dataa => \GRFPC0.D.STLCK_0_0_7__G1_6_0_S\,
datab => \GRFPC0.STDDEP_0_SQMUXA_26_I_I_A3_I\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1));
\GRFPC0_D_STLCK_RNO_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010001")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_0\,
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_85_I_I_A2_I_O2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_20_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_0_0\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_D_STLCK_RNO_7_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011001100")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_0\,
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\(0),
datac => \GRFPC0.EX.CTRL.RDD\,
datad => \GRFPC0.D.STDLCK_0_0_9__G3\);
\GRFPC0_D_STLCK_RNO_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101010101010")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_2_X\(0),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0));
\GRFPC0_D_STLCK_RNO_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_0\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_20_I_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_22_I_0_A2_X\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_38_0_O2_I_A3\(1));
\GRFPC0_D_STDLCK_RNO_4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011111111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.STDDEP_0_SQMUXA_12_I_I_A2_I_X\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\(1));
\GRFPC0_D_STLCK_RNO_9_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_17_1_0\(1),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3543_DEP\,
datac => \GRFPC0.EX.CTRL.RDD_REP3\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_D_STDLCK_RNO_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_0\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.STDDEP_0_SQMUXA_94_I_O4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_1\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_1\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A1_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A1_1\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A1_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A1_1\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(38));
\GRFPC0_FP_PIPELINE_1_0_STDEP_65_0_IV_I_A4_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_A4_2_0\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0));
\GRFPC0_D_STDLCK_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_0\,
dataa => N_242,
datab => \GRFPC0.STDDEP_0_SQMUXA_19_I_O4_0_X\,
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.STDDEP_0_SQMUXA_21_0_A2\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1004_DEP_RNIPI5B1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_5_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1004_DEP\);
GRFPC0_D_FSTLCK_RNO_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_0\,
dataa => \GRFPC0.CCWR_0_SQMUXA_0_X\,
datab => \GRFPC0.CCWR_0_SQMUXA_1_X\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK27_X\,
datad => \GRFPC0.MEM.CTRL.CCWR\);
\GRFPC0_D_STDLCK_RNO_6_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_12_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
datad => \GRFPC0.RFA.LD\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_2_0\(0),
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\);
GRFPC0_FP_PIPELINE_1_REGDEP172_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP172_2\,
dataa => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_2\,
datab => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_3\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_0\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_1\);
\GRFPC0_D_LDLCK_RNO_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_0\(7),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(7),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\(5));
\GRFPC0_D_LDLCK_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1240_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(7),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(7));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_3_RNILN9M: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_M3_A0_0\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_8\(1));
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A2_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_0_0\(1),
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_9\);
\GRFPC0_D_LDLCK_RNO_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_0\,
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0_X\(25),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_X\(25));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1592_REGDEPX2_RNI16QQ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1592_REGDEPX2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.D.LDLCK_0_0_7__G3_A1_0\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3946_REGDEPX2_0_A2_0_O2_RNIPEG31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0_1\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2_0_A2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_3_0_RNI2LT41_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0_0\,
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1\(0));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNI71BCH_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_B0_0_A5_0_1\,
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
\GRFPC0_D_STDLCK_RNO_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_278_0_O2_I_A3\(1));
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_A2_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_1_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_1\(0),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_10_0\(1),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0_1\(0),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_2_0\(1));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001111110")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\,
dataa => \GRFPC0.INST_I\(10),
datab => \GRFPC0.INST_I\(8),
datac => \GRFPC0.INST_I\(11),
datad => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4_A\);
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_4_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010111")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4_A\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I\(12),
datac => \GRFPC0.INST_I\(11));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN1988_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_0\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_5\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_X\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_4_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1\(41),
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1_A\(41),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_4_1_A_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_4_1_A\(41),
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(41),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPC0_D_LDLCK_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(20));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_4_1\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\);
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_0\,
dataa => \GRFPC0.INST_I_0_M3\(13),
datab => \GRFPC0.INST\(9),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_4_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_2\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_1\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(39));
GRFPC0_FP_PIPELINE_RSDEC_RS1V18_1_RNIOG96: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M_2\,
dataa => \GRFPC0.INST\(24),
datab => \GRFPC0.INST\(23),
datac => \GRFPC0.INST\(31),
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18_1\);
\GRFPC0_D_LDLCK_RNO_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1_0\,
dataa => \GRFPC0.N_25443_2\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(5),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_6\);
\GRFPC0_D_LDLCK_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1_1\,
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_0_X\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_3\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_2\(0),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_1_0\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0_A0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_1\(0),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0\(0),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2564_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_4\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2\(1));
\GRFPC0_D_LDLCK_RNO_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_1\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_2\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNIHIBU7_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_2\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_0\(52),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(52));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_0_0\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_6\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_2\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_1\(0),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_6_0\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_4\(0),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_3_2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A3_0_RNII43B1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1_0_0\,
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_1_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0_1\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0\(1));
\GRFPC0_D_LDLCK_RNO_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(5),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_X\(5));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A3_0_RNIC4501_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_2\,
dataa => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_0\(1));
GRFPC0_FP_PIPELINE_5_REGDEPX2_175_1_M9_I_A0_RNIL7I41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_1\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2637_REGDEPX2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A0\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_2_RNICP2C_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_0_0\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_2\(1));
\GRFPC0_D_LDLCK_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_0\(9),
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_4\(9),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_1\(7));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2915_REGDEPX2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_7\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_0\(1),
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_2\(1),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_3_I\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_6_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_6_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_4\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_3_2\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V12_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_2\,
dataa => \GRFPC0.INST_I_0_M3\(13),
datab => \GRFPC0.INST\(9),
datac => \GRFPC0.INST_I_X\(6),
datad => \GRFPC0.INST_I\(10));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_6_RNI4MGR1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100011111000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_O3_2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_4_X\(1),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_6\,
datac => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_0\(1),
datad => \GRFPC0.STDDEP_0_SQMUXA_107_I_O4\);
GRFPC0_RFA_READ_RS1_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_0_0\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I\(11),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_2\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
datab => \GRFPC0.D.LDLCK_0_0_14__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_0_A4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_0\(0),
dataa => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(26),
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(26),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(24),
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(36),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(35),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(35),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(35),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(16),
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(22),
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(22),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(27),
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(9),
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(15),
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(33),
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(31),
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(30),
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(30),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0_A\(17),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_0_A_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001110101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2_0_A\(17),
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD11\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(29),
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_2\(8),
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_9_0\(1),
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_1\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2_A\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_0_A3_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_2_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_2_A\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A4_0_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_2\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4299_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4328_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_1\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4238_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_1\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A3_0_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_0\(1),
dataa => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1\(1));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_33\,
dataa => \GRFPC0.OP2_I_M2\(45),
datab => \GRFPC0.OP2\(35),
datac => \GRFPC0.OP2\(40),
datad => \GRFPC0.OP2\(43));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_32\,
dataa => \GRFPC0.OP2\(34),
datab => \GRFPC0.OP2\(42),
datac => \GRFPC0.OP2\(46),
datad => \GRFPC0.OP2\(39));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_13\,
dataa => \GRFPC0.OP2_6\(23),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(23),
datad => \GRFPC0.OP2\(14));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_9\,
dataa => \GRFPC0.OP2_6\(9),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(9),
datad => \GRFPC0.OP2\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_O2_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2_1\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_53_REP1\,
datad => \GRFPU0.GRFPU_X0.N_233\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI38N53_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2\(0));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_0_52_M3_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_52_M3_0_A2_1\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
\GRFPC0_D_LDLCK_RNO_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1_1\,
dataa => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_1\(0),
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_89_A0_RNISF79_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_2\(1),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1212_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A0\(1));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_9\(0),
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_7\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_2\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_1\(12));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_32\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2370\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_4_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_4_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_4_03\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0_A\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O3_0_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_O3_0_A\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_O2_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_O2_0\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG37\,
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_14\,
dataa => \GRFPC0.OP2\(49),
datab => \GRFPC0.OP2\(51),
datac => \GRFPC0.OP2\(52),
datad => \GRFPC0.OP2\(54));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_13\,
dataa => \GRFPC0.OP2\(37),
datab => \GRFPC0.OP2\(38),
datac => \GRFPC0.OP2\(33),
datad => \GRFPC0.OP2\(32));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_11\,
dataa => \GRFPC0.OP2\(40),
datab => \GRFPC0.OP2\(46),
datac => \GRFPC0.OP2_I_M2\(45),
datad => \GRFPC0.OP2\(41));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\,
dataa => \GRFPC0.OP2\(34),
datab => \GRFPC0.OP2\(35),
datac => \GRFPC0.OP2\(48),
datad => \GRFPC0.OP2\(43));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_0\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0\);
GRFPC0_RFA_RDD_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_A2_4_0\,
dataa => N_101,
datab => N_39,
datac => N_97,
datad => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2_1_X\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\(6));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN28_DP_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_6\,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(55),
datac => \GRFPC0.OP2\(60),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_2\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_0\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_O3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2_0_A3_0_A2\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_13\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7),
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_2_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_5_SQMUXA_S6_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.COMB.SIGN1_2_I_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\,
datad => \GRFPU0.GRFPU_X0.CCV_3_SQMUXA_S4_2_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_43_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_43\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_4_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_15\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_35\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_42_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_4_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_4_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_33\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010010101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0_A\(18));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_0_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100100111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0_A\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A3_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A3_0_1\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_A5_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_A5_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A4_2_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A4_2_0\(12),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX_0_A5\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_1\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_1_1\,
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6063_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_1\(0),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A4_0_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_1\(22),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_3_0\(0),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_2\(0),
dataa => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_1_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_1\(0),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6473_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A4\(0));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1300_REGDEPX2_RNI5EIN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_0_1\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_4\(1),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1_0\(1),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(0));
GRFPC0_WR2_CTRL_PEND_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.WR2.CTRL.PEND_0_0_G1_0_A3_1\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.WR2.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_5\,
datad => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A3_1_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_2\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41),
datad => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_1\(1),
dataa => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A0_0\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_9_0_A2_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0_1\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A1\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A2_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A1\(1));
GRFPU0_GRFPU_X0_VST4_EXC_0_SQMUXA_3_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_3_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_33\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_29\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_25\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\(32));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\(5),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_3\(1));
GRFPC0_V_FSR_CEXC_2_SQMUXA_2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_2_SQMUXA_2_0_0\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.FP_PIPELINE.UN26_HOLDN_0\);
\GRFPC0_OP1_0_IV_4_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(51),
dataa => N_710,
datab => \GRFPC0.OP1_0_IV_1\(51),
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_2\(51));
\GRFPC0_OP1_0_IV_4_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(46),
dataa => N_705,
datab => \GRFPC0.OP1_0_IV_1\(46),
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_2\(46));
\GRFPC0_OP1_0_IV_4_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(48),
dataa => N_707,
datab => \GRFPC0.OP1_0_IV_1\(48),
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_2\(48));
\GRFPC0_OP1_0_IV_4_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(40),
dataa => N_699,
datab => \GRFPC0.OP1_0_IV_1\(40),
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_2\(40));
\GRFPC0_OP1_0_IV_4_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(43),
dataa => N_702,
datab => \GRFPC0.OP1_0_IV_1\(43),
datac => \GRFPC0.OP1_1_SQMUXA\,
datad => \GRFPC0.OP1_0_IV_2\(43));
\GRFPC0_FP_PIPELINE_2_REGDEPX_48_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_48_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\(5),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_2\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6));
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(31),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_A4_1\(0));
\GRFPC0_OP1_0_IV_4_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(62),
dataa => \GRFPC0.OP1_0_IV_1\(62),
datab => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.OP1_0_IV_2\(62));
\GRFPC0_OP1_0_IV_4_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101000000000")
port map (
combout => \GRFPC0.OP1_0_IV_4\(50),
dataa => \GRFPC0.OP1_0_IV_1\(50),
datab => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
datac => \GRFPC0.RFA2.RS1SEL_REP1\(0),
datad => \GRFPC0.OP1_0_IV_2\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_1\(60),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_1\(60),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\,
dataa => \GRFPU0.GRFPU_X0.REST_2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_1_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000010")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0_A2_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.COMB.SIGN1_2_I_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\,
datad => \GRFPU0.GRFPU_X0.CCV_3_SQMUXA_S4_2_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_1\(59),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_1\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD11\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G5_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(0));
GRFPC0_EX_CTRL_RDD_REP4_RNIEO582: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_4_1_0\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.STDDEP_0_SQMUXA_98_I_I_A2_I_O2\,
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_5\(1));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101011101")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
dataa => \GRFPU0.GRFPU_X0.REST_2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_14\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_15\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\,
datad => \GRFPU0.GRFPU_X0.N_18308_12\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_20\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\,
datab => \GRFPU0.MULO.MRES\(93),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12_0\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_16\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_53\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_20\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_21\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_26\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_43\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_7_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_7_5_0\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_2\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_O2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M2\(0),
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN962_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_0_A2\);
\GRFPU0_GRFPU_X0_RES_1_6_I_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(37),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(35));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(38));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(45),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(45),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(51));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_A_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(32),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(32),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(42));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_A_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(61),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(61));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(33));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(39));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_1_A_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1_A\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(48));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(49));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(49),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001111111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(46));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_A_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1_A\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_O2_0\(0),
dataa => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_0_A2_1_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1\(0));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_4\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\,
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1));
GRFPC0_STDEP_0_SQMUXA_109_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001110000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_109_0\,
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000010111010")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_1\(0),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_1\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_I\(0));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_46\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_21\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_22\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_41\);
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3_0\(0),
datac => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3\(1));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_239_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3855_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3840_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4791_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4776_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1));
\GRFPC0_V_STDATA_14_RNI781G1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001111")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0\,
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPC0.V.STDATA_14\(11),
datac => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0_A\);
\GRFPC0_V_STDATA_14_RNI224V_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110000111111")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_1287_O3_1_0_A\,
dataa => \GRFPC0.V.STDATA_14\(7),
datab => \GRFPC0.V.STDATA_14\(12),
datac => \GRFPC0.V.STDATA_14\(8),
datad => \GRFPC0.V.STDATA_14_REP0\(6));
GRFPU0_GRFPU_X0_EXPT_5_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_5_SQMUXA_1_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_6\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_2\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_1_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4299_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4328_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_A3_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_2\,
dataa => \GRFPC0.V.STDATA_14\(8),
datab => \GRFPC0.V.STDATA_14\(10),
datac => \GRFPC0.V.STDATA_14_REP1\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_IV_RNO_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M_0\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_O3_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_O3_3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3855_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3840_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(15),
datab => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(0),
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0),
datad => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_A2_0\(0));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010101")
port map (
combout => \GRFPU0.GRFPU_X0.N_16368_M_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP\);
\GRFPC0_R_FSR_TEM_RNIL7FC2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_0_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datab => \GRFPC0.R.FSR.TEM\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\,
datad => \GRFPC0.DIV.EXCT_0_0_0__G3_1\);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_20_RNIJBMA1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_2\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\(0),
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_X_RNI6S892_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_S_2_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.4.STDEP_190_I_M_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.LDLOCK_1_M_3\,
dataa => N_99,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datac => \GRFPC0.LDLOCK_1_M_1\,
datad => \GRFPC0.LDLOCK_1_M_2_X\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_2_RNIKFMI_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3_8_0\(1),
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\(1),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\);
GRFPC0_UN1_VFIFO_WR_1_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110010000100000")
port map (
combout => \GRFPC0.UN1_VFIFO.WR_1_SQMUXA_0\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.VFIFO.WR_0_SQMUXA_0\,
datad => \GRFPC0.VFIFO.WR_0_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_0\(9),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_I_A2_1_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_I_A2_1_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6063_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1));
GRFPC0_FP_PIPELINE_5_REGDEPX2_175TT_1_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175TT_1_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_5_1\(1),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2609_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_0_A4_0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_0_A4_0_1_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_0\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_A3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010111111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A3_1_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2\(0));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.LDLOCK_M_4\,
dataa => N_98,
datab => N_99,
datac => N_102,
datad => \GRFPC0.LDLOCK_M_3\);
GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_M5_E_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_430_0_M5_E_0\,
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6443_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_13\(1));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_48\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_25\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_26\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_37\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_46\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.D.FLDLCK_M_0\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.LDLOCK23_3_X\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK23_4\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\(27),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_96,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_0\(8));
GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_M9_I_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_M9_I_A0\,
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1_0\(1),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_9_RNIUPOT_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_A0\,
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_419_A0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_419_A0\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_UN205_HOLDN_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_0\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_2\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0_0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360TT_1_M3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2\,
dataa => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2_0_A2_1_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2_0\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_51_M3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(51));
GRFPC0_FP_PIPELINE_UN29_WREN_1_A1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
datac => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
GRFPU0_GRFPU_X0_ST2_RDY_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I_A3_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.D.FSTLCK_M\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datab => \GRFPC0.D.FSTLCK_M_A\,
datac => \GRFPC0.D.FSTLCK_M_1\,
datad => \GRFPC0.D.FSTLCK\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.D.FSTLCK_M_A\,
dataa => N_102,
datab => N_98,
datac => N_97,
datad => N_99);
GRFPC0_FP_PIPELINE_12_REGDEPX2_370_1_M5_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M5_E\,
dataa => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_4\(1),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M3_E\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M5_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E\,
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M3_E_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E_0\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_273_0_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_273_0_A3\(1),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_I_M_4\(14),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4121_REGDEPX2_I_I_A2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_3\(1),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_1\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.N_25113_2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_5\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
\GRFPC0_INST_I_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000011")
port map (
combout => \GRFPC0.INST_I\(3),
dataa => N_81,
datab => \GRFPC0.INST_I_A2_1\(3),
datac => \GRFPC0.INST_I_A2_0\(3),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPC0_INST_I_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.INST_I\(8),
dataa => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_A\(8));
\GRFPC0_INST_I_A_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPC0.INST_I_A\(8),
dataa => N_86,
datab => \GRFPC0.FIFO.INST_0\(8),
datac => \GRFPC0.INST_I_A2_2\(1),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_0_I_M2_0_RNI3S2A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.N_19845_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2_0\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2\(1));
\GRFPC0_INST_I_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.INST_I\(11),
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\,
datad => \GRFPC0.INST_I_A\(11));
\GRFPC0_INST_I_A_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110100001100")
port map (
combout => \GRFPC0.INST_I_A\(11),
dataa => N_89,
datab => \GRFPC0.INST_I_A2_0_0\(11),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_M2\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_3_REGDEPX2_115TT_1_M3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M1_E_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_0\(7),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1\(10),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX_0_A4_1_X\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX_2_0_A3_0_A2_X\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(20),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_1_X\(20));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3_0\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0));
GRFPC0_WR2_CTRL_DIV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.WR2.CTRL.DIV_0_0_G1_0_1405_A2\,
dataa => N_3,
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_A2\);
GRFPC0_FIFO_INC_5_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FIFO_INC_5_SQMUXA\,
dataa => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.UN54_HOLDN\,
datad => \GRFPC0.VDIV.EXC_1_SQMUXA_0_O2\);
\GRFPC0_DIV_RESULT_0_0_1__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_1__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(1),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_1__G3_0\);
GRFPC0_STDEP_0_SQMUXA_84_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_84_1\,
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_0_M6_I_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_0\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
GRFPC0_FP_PIPELINE_UN11_OP_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_OP_7\,
dataa => \GRFPC0.V.STDATA_14\(5),
datab => \GRFPC0.V.STDATA_14\(10),
datac => \GRFPC0.FP_PIPELINE.UN11_OP_7_1\,
datad => \GRFPC0.FP_PIPELINE.UN8_OP_7_6\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_O2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6473_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_0\(1),
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_8\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_9\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_5_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_6\(1));
\GRFPC0_DIV_RESULT_0_0_31__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_31__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_31__G3_0\);
\GRFPC0_WR_RREG_RES_0_0_9__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(9),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.WR.RREG.RES_0_0_9__G3_0\);
\GRFPC0_DIV_RESULT_0_0_15__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_15__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(15),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_15__G3_0\);
\GRFPC0_DIV_RESULT_0_0_16__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_16__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(16),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_16__G3_0\);
\GRFPC0_DIV_RESULT_0_0_10__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_10__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(10),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_10__G3_0\);
\GRFPC0_DIV_RESULT_0_0_19__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_19__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(19),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_19__G3_0\);
\GRFPC0_DIV_RESULT_0_0_11__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_11__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(11),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_11__G3_0\);
\GRFPC0_DIV_RESULT_0_0_28__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_28__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(28),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_28__G3_0\);
\GRFPC0_DIV_RESULT_0_0_18__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_18__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(18),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_18__G3_0\);
\GRFPC0_DIV_RESULT_0_0_4__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_4__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(4),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_4__G3_0\);
\GRFPC0_DIV_RESULT_0_0_14__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_14__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(14),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_14__G3_0\);
\GRFPC0_DIV_RESULT_0_0_2__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_2__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_2__G3_0\);
\GRFPC0_DIV_RESULT_0_0_6__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_6__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(6),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_6__G3_0\);
\GRFPC0_DIV_RESULT_0_0_20__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_20__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(20),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_20__G3_0\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_1\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2_0\);
\GRFPC0_DIV_RESULT_0_0_5__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_5__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(5),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_5__G3_0\);
\GRFPC0_DIV_RESULT_0_0_30__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_30__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_30__G3_0\);
\GRFPC0_DIV_RESULT_0_0_29__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_29__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_29__G3_0\);
\GRFPC0_DIV_RESULT_0_0_26__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_26__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(26),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_26__G3_0\);
\GRFPC0_DIV_RESULT_0_0_25__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_25__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(25),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_25__G3_0\);
\GRFPC0_DIV_RESULT_0_0_24__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_24__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(24),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_24__G3_0\);
\GRFPC0_DIV_RESULT_0_0_23__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_23__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(23),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_23__G3_0\);
\GRFPC0_DIV_RESULT_0_0_21__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_21__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(21),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_21__G3_0\);
\GRFPC0_DIV_RESULT_0_0_17__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_17__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(17),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_17__G3_0\);
\GRFPC0_DIV_RESULT_0_0_12__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_12__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(12),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_12__G3_0\);
\GRFPC0_DIV_RESULT_0_0_0__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_0__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_0__G3_0\);
\GRFPC0_DIV_RESULT_0_0_7__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_7__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(7),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_7__G3_0\);
\GRFPC0_DIV_RESULT_0_0_3__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_3__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(3),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_3__G3_0\);
\GRFPC0_DIV_RESULT_0_0_27__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_27__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(27),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2_REP1\(2),
datac => \GRFPC0.DIV.RESULT_0_0_27__G3_0\);
\GRFPC0_DIV_RESULT_0_0_13__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_13__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(13),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_13__G3_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_3_0_A2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_WR2_CTRL_CCWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.WR2.CTRL.CCWR_0_0_G1_0_1418_A2\,
dataa => N_3,
datab => \GRFPC0.WR.CTRL.CCWR\,
datac => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_A2\);
GRFPC0_WR2_CTRL_RDWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.WR2.CTRL.RDWR_0_0_G1_0_1385_A2\,
dataa => N_3,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_A2\);
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_I_S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S\,
dataa => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_X\,
datab => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_0\,
datac => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_6\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_MEM_CTRL_AFSR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I\,
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
datac => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
datad => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\);
GRFPC0_MEM_CTRL_DIV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.MEM.CTRL.DIV_0_0_G1_0_1562_I\,
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
datac => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
datad => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\);
GRFPC0_MEM_CTRL_RDWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.MEM.CTRL.RDWR_0_0_G1_0_1534_I\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
datac => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
datad => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\);
GRFPC0_MEM_CTRL_SEQERR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.MEM.CTRL.SEQERR_0_0_G1_0_1516_I\,
dataa => \GRFPC0.EX.CTRL.SEQERR\,
datab => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
datac => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
datad => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2\(1),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_14_STDEP_590_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0\,
dataa => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_M2\,
datad => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\);
\GRFPC0_DIV_RESULT_0_0_22__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_22__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(22),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_22__G3_0\);
\GRFPC0_DIV_RESULT_0_0_8__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_8__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(8),
datab => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
datac => \GRFPC0.DIV.RESULT_0_0_8__G3_0\);
GRFPC0_STDEP_2_SQMUXA_133: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_133\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
datab => \GRFPC0.STDEP_2_SQMUXA_133_0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
dataa => \GRFPC0.WR2.CTRL.INST\(22),
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\,
datac => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_A\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_A\,
dataa => \GRFPC0.WR2.CTRL.INST\(20),
datab => \GRFPC0.WR2.CTRL.INST\(30),
datac => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_A3\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0\(0),
dataa => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2\(0),
datac => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A3\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1_0\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(1),
dataa => N_93,
datab => N_95,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX_2_0_A3_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(19));
\GRFPC0_FID_1_IV_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FID_1_IV_0_A3_1\(0),
dataa => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datab => \GRFPC0.FP_PIPELINE.UN5_SHARE_I_O2\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datad => \GRFPC0.FID_1_IV_0_A3_3\(0));
GRFPC0_MEM_CTRL_CCWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.MEM.CTRL.CCWR_0_0_G1_0_1580_I\,
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_I_A6_0_X\,
datac => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
datad => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_M6_X\);
GRFPC0_WR_CTRL_CCWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.WR.CTRL.CCWR_0_0_G1_0_1485_I\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.CCWR\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\);
GRFPC0_WR_CTRL_DIV_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.WR.CTRL.DIV_0_0_G1_0_1470_I\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\);
GRFPC0_WR_CTRL_RDWR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.WR.CTRL.RDWR_0_0_G1_0_1446_I\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\);
GRFPC0_WR_CTRL_SEQERR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.WR.CTRL.SEQERR_0_0_G1_0_1431_I\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.SEQERR\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\);
GRFPC0_WR_CTRL_AFSR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110000000000")
port map (
combout => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.AFSR\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_1\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_85TT_1_M3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2\,
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_1\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2_A\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_85TT_1_M3_0_A2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M3_0_A2_A\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4_0_O2\(1),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_INST_I_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.INST_I\(2),
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_A\(2));
\GRFPC0_INST_I_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPC0.INST_I_A\(2),
dataa => N_80,
datab => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.INST_I_A2_2\(1),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPC0_INST_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.INST_I\(1),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_I_A\(1));
\GRFPC0_INST_I_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPC0.INST_I_A\(1),
dataa => N_79,
datab => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.INST_I_A2_2\(1),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(15),
dataa => N_92,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
GRFPC0_UN1_STDDEP_0_SQMUXA_110_I_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111111")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\,
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPU0_GRFPU_X0_RDY_F0_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.RDY_F0_I\,
dataa => \GRFPU0.GRFPU_X0.ST3.V\,
datab => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\,
datac => \GRFPU0.GRFPU_X0.RDY_F0_I_A\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48));
GRFPU0_GRFPU_X0_RDY_F0_I_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001110011011")
port map (
combout => \GRFPU0.GRFPU_X0.RDY_F0_I_A\,
dataa => \GRFPC0.RFA2.FLUSH\,
datab => \GRFPU0.GRFPU_X0.ST3.V\,
datac => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datad => \GRFPU0.GRFPU_X0.RDY_F0_I_X2\);
GRFPU0_GRFPU_X0_COMB_UN2_FLOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP\,
dataa => \GRFPC0.V.STDATA_14\(8),
datab => \GRFPC0.V.STDATA_14_REP1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_6\);
GRFPU0_GRFPU_X0_COMB_UN2_FLOP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0\,
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.V.STDATA_14_REP0\(6),
datac => \GRFPC0.FP_PIPELINE.UN17_OP_7_3\,
datad => \GRFPC0.FP_PIPELINE.UN14_OP_7_2_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(17),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(43),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(36),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(37),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2\,
dataa => \GRFPU0.GRFPU_X0.C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_1_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datac => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datad => \GRFPU0.GRFPU_X0.COMB.UN8_SIGN1\);
\GRFPU0_GRFPU_X0_REST_2_IV_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_IV\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(11),
datac => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4));
\GRFPU0_GRFPU_X0_REST_1_2_IV_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_IV\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(20),
datac => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4));
GRFPU0_GRFPU_X0_UN223_BCO_LSB_RNIRJ9T5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3\(5),
dataa => \GRFPU0.GRFPU_X0.L3_2\(5),
datab => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(39),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(21),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(20),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(40),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(14),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(8),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_0\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(23),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(32),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.RMND_7_I_M3\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(55),
dataa => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(55),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(44),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(26),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(13),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(52),
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(52),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(28),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(11),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(12),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(54),
dataa => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(54),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(51),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(48),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(45),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(53),
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(53),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(57),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(57),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(57),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(56),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(56),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(33),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(49),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(47),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(34),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(58),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(58),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(15),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(46),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(10),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(27),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_A\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(16),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(19),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST2.RDY\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_74_7\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(29),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(38),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datab => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1_2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(25),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_13\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_19\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(18),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(9),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(35),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(30),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD11\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_4\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(41),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_ST3_REG_RNIBGC63_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0\);
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1\);
\GRFPU0_GRFPU_X0_L1_0_5_0_A2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3),
dataa => \GRFPU0.GRFPU_X0.TZI2_I_0_M3\(7),
datab => \GRFPU0.GRFPU_X0.TZI2\(5),
datac => \GRFPU0.GRFPU_X0.L1_0_5_0_O3\(3),
datad => \GRFPU0.GRFPU_X0.UN38_BCO_LSB\);
\GRFPU0_GRFPU_X0_L3_0_1_RNIR9Q63_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(5),
dataa => \GRFPU0.GRFPU_X0.L3_0_1\(5),
datab => \GRFPU0.GRFPU_X0.UN103_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_0\(3),
datad => \GRFPU0.GRFPU_X0.L2\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(50),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(33),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_O2\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(59),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(59),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(31),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7_REP1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_L2_0_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(4),
dataa => \GRFPU0.GRFPU_X0.L2_0_4_2\(4),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN8_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_0_10\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(22),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
GRFPU0_GRFPU_X0_UN153_BCO_LSB_0_A2_RNIPD753: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5),
dataa => \GRFPU0.GRFPU_X0.L3_2_0_A2_0_0\(5),
datab => \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\,
datac => \GRFPU0.GRFPU_X0.L1_0_A2\(3),
datad => \GRFPU0.GRFPU_X0.L2_0_10\(4));
\GRFPC0_INST_I_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111100")
port map (
combout => \GRFPC0.INST_I\(10),
dataa => N_88,
datab => \GRFPC0.INST_I_A2_1\(10),
datac => \GRFPC0.INST_I_A2_0\(10),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_I_1_RNIHME34_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_9\(4),
dataa => \GRFPU0.GRFPU_X0.L2_0_9_0\(4),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_0_0\(3));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN41_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_3\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN11_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN11_DP\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ\);
GRFPU0_GRFPU_X0_ITER_V_REP3_RNILEOD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2_0\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI03G53_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_3\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_1\);
GRFPC0_WR2_CTRL_AFSR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2\,
dataa => N_388,
datab => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_0_0_X\,
datac => \GRFPC0.WR.CTRL.AFSR\,
datad => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_3\);
GRFPC0_WR2_CTRL_SEQERR_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.WR2.CTRL.SEQERR_0_0_G1_0_1326_A2\,
dataa => N_388,
datab => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_0_0_X\,
datac => \GRFPC0.WR.CTRL.SEQERR\,
datad => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_3\);
\GRFPC0_INST_I_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000011")
port map (
combout => \GRFPC0.INST_I\(4),
dataa => N_82,
datab => \GRFPC0.INST_I_A2_1\(4),
datac => \GRFPC0.INST_I_A2_0\(4),
datad => \GRFPC0.INST_I_M2\(1));
\GRFPC0_INST_I_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPC0.INST_I\(12),
dataa => \GRFPC0.FIFO.INST_0\(12),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\,
datad => \GRFPC0.INST_I_A\(12));
\GRFPC0_INST_I_A_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110100001100")
port map (
combout => \GRFPC0.INST_I_A\(12),
dataa => N_90,
datab => \GRFPC0.INST_I_A2_0_0\(12),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_M2\(1));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_0\,
datad => \GRFPU0.GRFPU_X0.COMB.BIAS15\);
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\);
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_1_RNI1F9O1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_7\(4),
dataa => \GRFPU0.GRFPU_X0.L2_0_7_0\(4),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN43_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(24),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_A_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_A\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP1\);
\GRFPU0_GRFPU_X0_L2_0_10_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_10\(4),
dataa => \GRFPU0.GRFPU_X0.L2_0_10_0_0\(4),
datab => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0_A2\,
datac => \GRFPU0.GRFPU_X0.L1_0_1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_0\(41),
datac => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_1_SQMUXA_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_A\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_A_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_A\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_I_A2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1\(0),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_1_0_A2_0_A4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1_A\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_I_A2_1_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000111111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_1_A\(0),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1212_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1226_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_A4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A4_1\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_0_A2_1_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A2_0\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_85_I_A2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1\(0),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1_A\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_85_I_A2_1_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_I_A2_1_1_A\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_A4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1\(1),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1_0\(1));
\GRFPC0_D_STLCK_RNO_5_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.STDEP_185_I_M_2\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_1_M_2\(25));
\GRFPC0_D_STLCK_RNO_5_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_I_M_2_S\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_0_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ_A\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_0_TZ_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_TZ_A\(1),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_1_0\(0),
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_14_STDEP_564_0_IV_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\(1),
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1_0\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_M4_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E\,
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\(8),
dataa => N_93,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_0\(8),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX_2_0_A3_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
GRFPU0_GRFPU_X0_ST2_V_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.V_0_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.VST2.V_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_54_M4_E_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3_1\(52),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(52));
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14TT_0_M3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000011")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14TT_0_M3_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_4\(0),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_3\(0));
\GRFPC0_D_STLCK_RNO_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_3_1_M5_I\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_288_SEL1_I_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL0_0\,
datad => D_M3_1);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6900_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A4_0\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1755_REGDEPX2_0_A2_RNI51UE1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_1\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.D.LDLCK_0_0_7__G3_A2_0\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_0\(0),
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0\(0),
datab => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_0_1_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_0_1_0\(52),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD45\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38));
GRFPC0_RDWR_5_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.RDWR_5_SQMUXA_0\,
dataa => \GRFPC0.INST_I_0_M3\(13),
datab => \GRFPC0.INST\(9),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
datad => \GRFPC0.INST_I\(12));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_2\(1));
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2\,
dataa => \GRFPC0.INST_I_0_M3\(13),
datab => \GRFPC0.INST_I\(8),
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2_1_0\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_STATE_45_0_M2_0_RNIGV595_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.STATE_45_0_M2_0\(24),
datac => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\);
GRFPU0_GRFPU_X0_COMB_SWAP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_TZ_TZ\,
datab => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\,
datad => \GRFPU0.GRFPU_X0.C_ADD11\);
GRFPU0_GRFPU_X0_COMB_VST2_REG36_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_TZ_TZ\,
datab => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPC0_D_STLCK_RNO_6_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_230_I_M_2\(0),
dataa => N_172,
datab => \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.RDD\);
\GRFPC0_D_STLCK_RNO_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_550_I_M_2\(0),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_12_0_A2_0\(0),
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.RFA.RDD\);
GRFPC0_V_FSR_CEXC_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
dataa => \GRFPC0.DIV.EXCT\(5),
datab => \GRFPC0.DIV.VALID_REP1\,
datac => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0_X\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A3_1\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1\(0),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPU0_GRFPU_X0_L4_D_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.L4_D\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
datac => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datad => \GRFPU0.GRFPU_X0.L1_6_1_3_0\(0));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001101")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3_0_TZ\,
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\(1));
\GRFPC0_FP_PIPELINE_7_STDEP_292_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => D_M5,
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\,
datac => D_M3_0);
\GRFPC0_D_STLCK_RNO_9_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => D_M4_I_A4_0_1,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\,
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_D\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(56),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_15\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_D\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.DIVROM0.DATA_1_MUX_15\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55));
GRFPC0_D_FSTLCK_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010011111100")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_15\,
dataa => N_38,
datab => \GRFPC0.RFA.STDFQ\,
datac => \GRFPC0.FP_PIPELINE.UN1_VEX.CTRL.LD_0\,
datad => \GRFPC0.N_17807_I_0_G1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0\(0),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_TZ\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_O2_0_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0_0_TZ\(0),
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3608_REGDEPX2_I_I_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3752_REGDEPX2_I_I_A2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_8_STDEP_340_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101110101")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_340_0_IV_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_4_0_STDEP_185_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011001100110011")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.STDEP_185_0_IV_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\,
datab => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1\(0),
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_194_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_TZ\(0),
dataa => N_172,
datab => \GRFPC0.RFA.RDD\,
datac => \GRFPC0.FP_PIPELINE.4.STDEP_190_I_M_1_0\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_14_I_0\);
\GRFPC0_FP_PIPELINE_5_0_STDEP_225_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100111011")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.STDEP_225_0_IV_TZ\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
\GRFPC0_FP_PIPELINE_8_0_STDEP_345_0_IV_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100111011")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.STDEP_345_0_IV_TZ\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100001111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_0_0\(1),
dataa => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.V.STDATA_14_REP0\(6),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_1\(1));
GRFPC0_FP_PIPELINE_0_REGDEP2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP2\,
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\);
GRFPC0_FP_PIPELINE_0_REGDEP34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
dataa => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M_6\(0),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5957_REGDEPX2_I_0_O3_I_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_15\,
dataa => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\);
GRFPC0_VWR2_RREG_RES_2_SQMUXA_1_I_O2_X_REP2_RNIK4P01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010111")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RESV_9_IV_I_I_O2_0\,
dataa => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
datad => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_14\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4\(1),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_A4_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_15\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_O3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_2\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2\(18),
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_X\(19),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX_0_A2_0_A2_X\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(19),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_2\(19));
GRFPC0_FIFO_INC_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FIFO_INC_2_SQMUXA\,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.WR2.CTRL.PEND\,
datac => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.VDIV.EXC_1_SQMUXA_0_O2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A3\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_5_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_2_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_6_0_A4\(0));
\GRFPC0_R_FSR_CEXC_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.WR2.RREG.RES_M\(4),
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.WR2.RREG.RES\(4),
datad => \GRFPC0.V.FSR.CEXC_0_SQMUXA_1\);
GRFPC0_FP_PIPELINE_UN1_WR2_RREG_RESV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
dataa => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_0\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_2\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_R_FSR_CEXC_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.WR2.RREG.RES_M\(2),
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datad => \GRFPC0.V.FSR.CEXC_0_SQMUXA_1\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_0_M6_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2_1\,
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_26\,
dataa => \GRFPC0.OP2_6\(26),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(26),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_23\,
dataa => \GRFPC0.OP2_6\(23),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(23),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_22\,
dataa => \GRFPC0.OP2_6\(22),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(22),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_19\,
dataa => \GRFPC0.OP2_6\(19),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(19),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_18\,
dataa => \GRFPC0.OP2_6\(18),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(18),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_15\,
dataa => \GRFPC0.OP2_6\(15),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(15),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_14\,
dataa => \GRFPC0.OP2_6\(14),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(14),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_12\,
dataa => \GRFPC0.OP2_6\(12),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(12),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_11\,
dataa => \GRFPC0.OP2_6\(11),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(11),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_9\,
dataa => \GRFPC0.OP2_6\(9),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(9),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_7\,
dataa => \GRFPC0.OP2_6\(7),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(7),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_4\,
dataa => \GRFPC0.OP2_6\(4),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(4),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_3\,
dataa => \GRFPC0.OP2_6\(3),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(3),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_1\,
dataa => \GRFPC0.OP2_6\(1),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(1),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(34),
dataa => \GRFPC0.OP2\(37),
datab => \GRFPC0.OP2\(34),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(36),
dataa => \GRFPC0.OP2\(36),
datab => \GRFPC0.OP2\(39),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(37),
dataa => \GRFPC0.OP2\(37),
datab => \GRFPC0.OP2\(40),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(38),
dataa => \GRFPC0.OP2\(38),
datab => \GRFPC0.OP2\(41),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(39),
dataa => \GRFPC0.OP2\(42),
datab => \GRFPC0.OP2\(39),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(42),
dataa => \GRFPC0.OP2\(42),
datab => \GRFPC0.OP2_I_M2\(45),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(45),
dataa => \GRFPC0.OP2_I_M2\(45),
datab => \GRFPC0.OP2\(48),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(48),
dataa => \GRFPC0.OP2\(48),
datab => \GRFPC0.OP2\(51),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(49),
dataa => \GRFPC0.OP2\(49),
datab => \GRFPC0.OP2\(52),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(30),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(29),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(28),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(27),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(26),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(25),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(24),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(24),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(23),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(22),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(21),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(20),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(19),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(16),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(14),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(13),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(11),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(9),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(4),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.UN1_DIV.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.UN1_DIV.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
dataa => \GRFPC0.DIV.RESULT\(47),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(47),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
dataa => \GRFPC0.DIV.RESULT\(59),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(59),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(47),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(47),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(47));
\GRFPC0_OP2_5_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(62),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(62),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(62));
\GRFPC0_OP2_5_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(44),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(44),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(44));
\GRFPC0_FP_PIPELINE_WRDATA_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
dataa => \GRFPC0.DIV.RESULT\(44),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(44),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
dataa => \GRFPC0.DIV.RESULT\(50),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(50),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(50),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(50),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(50));
\GRFPC0_OP2_5_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(59),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(59),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(59));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_166_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\(0),
dataa => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
\GRFPC0_OP2_5_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(56),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(56),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(56));
\GRFPC0_FP_PIPELINE_WRDATA_3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
dataa => \GRFPC0.DIV.RESULT\(56),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(56),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A5_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_2\(1),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_0\(7));
GRFPC0_FP_PIPELINE_VWR2_CTRL_RDD_1_I_O2_1_RNIBRHQ7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001000")
port map (
combout => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
dataa => \GRFPC0.WR.CTRL.LD\,
datab => \GRFPC0.WR.CTRL.RDD_REP5\,
datac => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_UN1_VFIFO_VCNT_0_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101100000011")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\,
dataa => N_3,
datab => \GRFPC0.VFIFO.VCNT_0_0_SQMUXA\,
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\,
datad => CPO_EXCZ);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(0),
dataa => \GRFPC0.DIV.EXCT\(0),
datab => \GRFPC0.R.FSR.AEXC\(0),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_D_STLCK_RNO_9_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_10\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_58_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_58\(0),
dataa => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3\(7),
dataa => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3528_REGDEPX_1_0_I\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_1\(7));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3\(6),
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1240_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_5_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_5\(12),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_1\(0));
GRFPC0_V_STDATA_0_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.V.STDATA_0_SQMUXA_4\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.MEM.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.UN54_HOLDN\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(6),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(12),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(12));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_8\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_1\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0));
GRFPC0_FP_PIPELINE_0_REGDEP66_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_0_A2\,
dataa => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_4\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_4\,
datad => \GRFPC0.FP_PIPELINE.VMEM.RREG.RESV_6_IV_I_I_O2_0_O2\);
GRFPC0_FP_PIPELINE_0_WRSEL4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRSEL4\,
dataa => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.RDD_REP2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2\(1),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1196_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\(31),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(51),
dataa => \GRFPC0.OP2\(51),
datab => \GRFPC0.OP2\(54),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(33),
dataa => \GRFPC0.OP2\(33),
datab => \GRFPC0.OP2\(36),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_1\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3858_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_1_0\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(32),
dataa => \GRFPC0.OP2\(32),
datab => \GRFPC0.OP2\(35),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_8\,
dataa => \GRFPC0.OP2_6\(8),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(8),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_2\,
dataa => \GRFPC0.OP2_6\(2),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(2),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_17\,
dataa => \GRFPC0.OP2_6\(17),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(17),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_20\,
dataa => \GRFPC0.OP2_6\(20),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(20),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_24\,
dataa => \GRFPC0.OP2_6\(24),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(24),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
\GRFPC0_DIV_EXCT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100010")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_2__G0_0\,
dataa => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
datac => \GRFPC0.DIV.EXCT_0_0_2__G4\,
datad => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_3\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN271_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(62),
dataa => \GRFPC0.DIV.RESULT\(62),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(62),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_FP_PIPELINE_WRDATA_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
dataa => \GRFPC0.DIV.RESULT\(53),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(53),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(53),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(53),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(53));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_0\,
dataa => \GRFPC0.OP2_6\(0),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(0),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_5\,
dataa => \GRFPC0.OP2_6_I_M2\(5),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5_I_M2\(5),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_13\,
dataa => \GRFPC0.OP2_I_M3\(13),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_I_M3_0\(13),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_16\,
dataa => \GRFPC0.OP2_6\(16),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(16),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_28\,
dataa => \GRFPC0.OP2_6\(28),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(28),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_10\,
dataa => \GRFPC0.OP2_6\(10),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(10),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_27\,
dataa => \GRFPC0.OP2_6\(27),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(27),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(2),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(17),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(17));
GRFPC0_RFA_ST_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001100")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_1622_O2\,
dataa => \GRFPC0.RFA.ST_0_0_G1_0_1622_A3_0_X\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_X\,
datac => CPO_LDLOCKZ,
datad => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_1\);
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_2_0_RNICO7E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011011111")
port map (
combout => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A3_2\,
dataa => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datab => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
datac => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\);
GRFPC0_FP_PIPELINE_LDLOCK19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK19\,
dataa => N_99,
datab => N_97,
datac => N_98,
datad => \GRFPC0.FP_PIPELINE.LDLOCK19_A_X\);
GRFPC0_FP_PIPELINE_0_REGDEP50_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_0_A4\,
dataa => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\);
GRFPC0_FP_PIPELINE_UN1_CPI_12_RNIJDAC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_12\);
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_A2_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\);
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_3_0_O2_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_O2_1\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2_REP1\);
GRFPC0_WR_CTRL_STDFQ_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
dataa => \GRFPC0.MEM.CTRL.STDFQ\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_12\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O3_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_2\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\,
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_X3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000111100001")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_X3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\,
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0));
\GRFPC0_R_STATE_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001100100011")
port map (
combout => \GRFPC0.R.STATE_0_0_0__G2\,
dataa => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.RFAREG.R.STATE_4_M2S2\,
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_STDEP_2_SQMUXA_141_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_141_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_0_A2_0_A2_I\(1),
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_3\(1),
dataa => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.RDD_REP2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(7),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(15),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(15));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(40),
dataa => \GRFPC0.OP2\(40),
datab => \GRFPC0.OP2\(43),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_6\,
dataa => \GRFPC0.OP2_6\(6),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(6),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_21\,
dataa => \GRFPC0.OP2_6\(21),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(21),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_25\,
dataa => \GRFPC0.OP2_6\(25),
datab => \GRFPC0.OP2_SN_M8_REP3\,
datac => \GRFPC0.OP2_5\(25),
datad => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_REP1\);
GRFPC0_FP_PIPELINE_0_UN1_HOLDN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_HOLDN\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
GRFPC0_FP_PIPELINE_FPRDY4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.FPRDY4\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_FLTYPE45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_FLTYPE45\,
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(46),
dataa => \GRFPC0.OP2\(49),
datab => \GRFPC0.OP2\(46),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(43),
dataa => \GRFPC0.OP2\(46),
datab => \GRFPC0.OP2\(43),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\(0),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3\(1),
dataa => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2285_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_3\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2285_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2\(0),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14\(2),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\(0));
GRFPC0_REGDEP_1_SQMUXA_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010100000010100")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_11\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.RS2_1_X\(0),
datad => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
GRFPC0_FP_PIPELINE_13_STDEP2195: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP2195\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\(1));
GRFPC0_STDEP_2_SQMUXA_131_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_131_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(3),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(5),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(10),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(10),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(31),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(31),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(31));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_184_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\(0),
dataa => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(8),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(18),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(18));
GRFPC0_STDEP_2_SQMUXA_143_0_A2_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111111111")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_143_0_A2_I\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
\GRFPC0_FP_PIPELINE_0_STDEP_562_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_562_0_IV_I_A2\(0),
dataa => N_243,
datab => \GRFPC0.STDEP_0_SQMUXA_5_0_0_X\,
datac => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_I_0_I2_0_0_I4_0_I2_0_O2_X\(0));
GRFPC0_FP_PIPELINE_0_STDEP_8_SEL1_I_0_A2_1_0_A2_RNIBGT01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_9\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX_234_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_234_0_O2\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX_212_0_A2_0_X\(0),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\,
dataa => \GRFPC0.RFA.RD\(4),
datab => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(4));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_1\,
dataa => \GRFPC0.RFA.RD\(2),
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(2));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
dataa => \GRFPC0.RFA.RD\(3),
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(3));
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\,
dataa => \GRFPC0.RFA.RD\(1),
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6_X\(1));
\GRFPC0_FID_1_IV_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FID_1_IV_0_A3_0\(0),
dataa => N_39,
datab => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datad => CPO_EXCZ);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_O3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_O3_4\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
GRFPC0_MEM_CTRL_STDFQ_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_13\);
GRFPC0_FP_PIPELINE_UN1_CPI_13_RNIN655: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_13\);
GRFPC0_UN1_VDIV_EXEC7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100110111")
port map (
combout => \GRFPC0.UN1_VDIV.EXEC7\,
dataa => N_39,
datab => N_38,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datad => CPO_EXCZ);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_M2\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0));
\GRFPC0_D_STLCK_RNO_4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_1\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_9\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\);
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_2_RNIQ1ON_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_13\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0));
\GRFPC0_FP_PIPELINE_4_STDEP_168_1_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_26\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
datac => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPC0_STDEP_2_SQMUXA_135_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_135_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL0_0_I_A2_RNIAB3Q: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_8\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_27_0_A2_0_A2_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_27_0_A2_0_A2_0_A2\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_UN2263_REGDEPX_RNIJDJB2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datab => D_M2_E_2_0,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_3_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_4\(21),
dataa => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5\(21),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_0\(7));
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_112_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\(1),
dataa => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(35),
dataa => \GRFPC0.OP2\(38),
datab => \GRFPC0.OP2\(35),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I_O2\(29));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_1\(14),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\(0));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M11_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M84_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\);
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_O2\,
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51_A\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2\(62),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1_0_O3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_O3_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP_1_SN_M2_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.INF_0_SQMUXA_43_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datab => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1_2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_11\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_12\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_6\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_7\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_14\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_15\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_16\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(0),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(1),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(5),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(48),
dataa => \GRFPU0.GRFPU_X0.G_53_REP1\,
datab => \GRFPU0.GRFPU_X0.G_52\,
datac => \GRFPU0.GRFPU_X0.G_51_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_O3\(50));
\GRFPU0_GRFPU_X0_VST3_REG_47_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(49));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(0),
dataa => \GRFPU0.GRFPU_X0.L1_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(0),
datac => \GRFPU0.GRFPU_X0.L1_4\(3));
\GRFPU0_GRFPU_X0_L1_4_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(0),
dataa => \GRFPU0.GRFPU_X0.L1_4_1_3_0\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_4_0\(0),
datac => \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(21),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(30),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(29),
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(55),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(33),
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(48),
dataa => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(47),
dataa => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(11),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(31),
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(27),
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(26),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(24),
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(23),
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(13),
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(25),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(22),
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(51),
dataa => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(44),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(43),
dataa => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(14),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(12),
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M4\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(32),
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(34),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(35),
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(20),
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(19),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(38),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(37),
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M3\(40),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(40));
\GRFPU0_GRFPU_X0_L2_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(0),
dataa => \GRFPU0.GRFPU_X0.L1_1_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_0_4\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_4\(3));
\GRFPU0_GRFPU_X0_L2_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_2\(0),
dataa => \GRFPU0.GRFPU_X0.L1_2_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_3\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(36),
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(42),
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(41),
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(18),
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(18));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0_A\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_4_03_0_G0_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101100111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0_A\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_31\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_23\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_4_03_0_G1\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
GRFPU0_GRFPU_X0_ITER_NX_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_A\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\);
GRFPU0_GRFPU_X0_ITER_NX_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011101000111")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_ITER_NORM_REP1_RNI0HC0B: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(54),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(54));
GRFPU0_GRFPU_X0_COMB_UN1_ST2_FLOP_4_5_RNIKNMP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_5\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(3),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_5\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_2\,
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(15),
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(28),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(28));
\GRFPU0_GRFPU_X0_L2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0\(0),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0_O2\(2),
datab => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\,
datac => \GRFPU0.GRFPU_X0.L1_1_2\(0),
datad => \GRFPU0.GRFPU_X0.L1_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(49),
dataa => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(50),
dataa => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(50));
\GRFPU0_GRFPU_X0_L2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_1\(0),
dataa => \GRFPU0.GRFPU_X0.L1_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_2\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_A2\(3));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(2),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2\(16),
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_0\(16));
\GRFPU0_GRFPU_X0_L2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1\(0),
dataa => \GRFPU0.GRFPU_X0.L1_3_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_2\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_0\(3));
\GRFPU0_GRFPU_X0_L2_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(0),
dataa => \GRFPU0.GRFPU_X0.L1_1_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_0_3\(0),
datac => \GRFPU0.GRFPU_X0.L1_0\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2\(17),
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M2\(17));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(1),
dataa => \GRFPU0.GRFPU_X0.L1_4_4\(1),
datab => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datac => \GRFPU0.GRFPU_X0.L1_5_4\(1));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
dataa => \GRFPU0.GRFPU_X0.L1_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_5_2\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_1\(3));
\GRFPU0_GRFPU_X0_L4_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_1\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_1\(3),
datad => \GRFPU0.GRFPU_X0.L3_0\(5));
GRFPU0_GRFPU_X0_COMB_VST3_REG21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG21\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\);
\GRFPU0_GRFPU_X0_L3_0_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(2),
dataa => \GRFPU0.GRFPU_X0.L2_0_4\(2),
datab => \GRFPU0.GRFPU_X0.L2_0_4\(4),
datac => \GRFPU0.GRFPU_X0.L2_1_3\(2));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
dataa => \GRFPU0.GRFPU_X0.L1_5_0\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_4\(3));
GRFPU0_GRFPU_X0_EXPT_2_SQMUXA_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPT_2_SQMUXA_1_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN22_DP\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(45),
dataa => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(46),
dataa => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(46));
\GRFPU0_GRFPU_X0_L3_0_3_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0\(2),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0_O2\(2),
datab => \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\,
datac => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\,
datad => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0\(2));
\GRFPU0_GRFPU_X0_VST3_REG_47_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_0\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(51));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.ODDEXP_0_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.VITER.ODDEXP_1_SQMUXA_1\);
\GRFPU0_GRFPU_X0_L4_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(3),
dataa => \GRFPU0.GRFPU_X0.L1_1\(3),
datab => \GRFPU0.GRFPU_X0.L1_4\(3),
datac => \GRFPU0.GRFPU_X0.L3_0\(3),
datad => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPU0_GRFPU_X0_L3_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(2),
dataa => \GRFPU0.GRFPU_X0.L2_0_2\(2),
datab => \GRFPU0.GRFPU_X0.L2_1_1\(2),
datac => \GRFPU0.GRFPU_X0.L2_0_10\(4));
\GRFPU0_GRFPU_X0_L1_0_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.L1_0_2_0_O2\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_2_0_A2_0_0\(0),
datad => \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\);
\GRFPU0_GRFPU_X0_L2_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_2\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_1\(3));
\GRFPU0_GRFPU_X0_L4_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_6_1_1_I\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_L3_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(1),
dataa => \GRFPU0.GRFPU_X0.L2_0_3\(1),
datab => \GRFPU0.GRFPU_X0.L2_1_2\(1),
datac => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPU0_GRFPU_X0_L3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_6\(1),
datab => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_L4_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_2\(3),
datad => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(0),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_4_3\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(10),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(9),
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(8),
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(8));
\GRFPU0_GRFPU_X0_L1_1_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_7\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(19),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_1_6_0\(0),
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_0_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_7\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(27),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_1_6_0\(0),
datad => \GRFPU0.GRFPU_X0.UN243_BCO_LSB\);
\GRFPU0_GRFPU_X0_L2_0_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_7\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_7\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_0\(3));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(1),
datab => \GRFPU0.GRFPU_X0.L1_2_7\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_5\(3));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_0\,
datab => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(3),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_3_1_5_0\(0),
datad => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_2_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_7\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(11),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_6_0_I\(0),
datad => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(3),
dataa => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_0\,
datab => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L1_2_5\(3));
GRFPU0_GRFPU_X0_COMB_VST2_ADD_1_1_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110100100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1_U\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_40_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011001011101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_38\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\);
GRFPU0_GRFPU_X0_UN1_VST2_QSNAN12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.QSNAN12\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datac => \GRFPU0.GRFPU_X0.REST_1_1_U\(2),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.SIGN1_0_A3\);
GRFPU0_GRFPU_X0_UN1_VST2_REG_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011111100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_I_O3\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\,
datad => \GRFPU0.GRFPU_X0.C_ADD11\);
GRFPU0_GRFPU_X0_ST2_REG_RET_4_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_REST\,
dataa => \GRFPU0.GRFPU_X0.REST_1_2\(7),
datab => \GRFPU0.GRFPU_X0.REST_1_2\(6));
\GRFPU0_GRFPU_X0_L1_4_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datab => \GRFPU0.GRFPU_X0.L1_4_5_A\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_1_4_0\(0),
datad => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_5_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110111111111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_5_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_6\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.L1_5_6_A\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_1_5_0\(0),
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_5_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110111111111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_6_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_3_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_5\(0),
dataa => \GRFPU0.GRFPU_X0.L1_3_1_3_0_A4\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_1_3_A4_0\(0),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0\(0),
datad => \GRFPU0.GRFPU_X0.UN18_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110001010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(0),
dataa => \GRFPU0.GRFPU_X0.TZI\(16),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_4_0_TZ\(0),
datad => \GRFPU0.GRFPU_X0.UN13_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_1_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_5\(0),
dataa => \GRFPU0.GRFPU_X0.TZI_I_M2\(12),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.UN8_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_1_1_4_0\(0));
\GRFPU0_GRFPU_X0_L1_0_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6\(0),
dataa => \GRFPU0.GRFPU_X0.TZI\(1),
datab => \GRFPU0.GRFPU_X0.TZI\(0),
datac => \GRFPU0.GRFPU_X0.TZI\(2),
datad => \GRFPU0.GRFPU_X0.L1_0_6_A\(0));
\GRFPU0_GRFPU_X0_L1_0_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6_A\(0),
dataa => \GRFPU0.GRFPU_X0.TZI_I_M2\(4),
datab => \GRFPU0.GRFPU_X0.TZI\(3),
datac => \GRFPU0.GRFPU_X0.TZI\(5),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M3_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M3\(39),
dataa => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(39));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_6\,
dataa => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_1_RNILVU21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\);
\GRFPU0_GRFPU_X0_L4_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2\(1),
dataa => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_0_1_I\,
datab => \GRFPU0.GRFPU_X0.L1_6_1_I_A4\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4));
\GRFPU0_GRFPU_X0_L3_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(1),
dataa => \GRFPU0.GRFPU_X0.L2_1\(1),
datab => \GRFPU0.GRFPU_X0.L2_0_1\(1),
datac => \GRFPU0.GRFPU_X0.L2\(4));
\GRFPU0_GRFPU_X0_ITER_EXPOP_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPOP_0_0_1__G2\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.GRFPU_X0.EXPOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(7),
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M16_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M16_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M12_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M12_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M7_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\);
\GRFPU0_GRFPU_X0_L1_0_6_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6_0\(1),
dataa => \GRFPU0.GRFPU_X0.TZI\(3),
datab => \GRFPU0.GRFPU_X0.TZI\(2),
datac => \GRFPU0.GRFPU_X0.L1_0_6_0_A2_0_1\(1),
datad => \GRFPU0.GRFPU_X0.L1_0_1_5_I_1\(1));
\GRFPU0_GRFPU_X0_L2_1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_3\(1),
dataa => \GRFPU0.GRFPU_X0.L1_3_5\(1),
datab => \GRFPU0.GRFPU_X0.L1_2_5\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_3\(3));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(1),
dataa => \GRFPU0.GRFPU_X0.L1_5_6\(1),
datab => \GRFPU0.GRFPU_X0.L1_4_5\(1),
datac => \GRFPU0.GRFPU_X0.L1_4_4\(3));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG40\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EMAXP112\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNII8B31_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011110000011100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG40\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M8_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M8_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M16_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M16_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M12_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M12_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M9_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M9_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M7_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M7_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M11_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M11_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_26\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\);
GRFPU0_GRFPU_X0_VST3_INF_1_SQMUXA_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_I_M2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1_0_IV_I_M2\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.INF\,
datab => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datad => \GRFPU0.GRFPU_X0.COMB.ITER_OF\);
GRFPU0_GRFPU_X0_COMB_UN13_ITER_OF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.COMB.ITER_OF\);
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011101000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_A\);
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD7\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD8\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD9\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_2\);
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_1_0\);
GRFPU0_GRFPU_X0_EXPDEC_SP_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDEC_SP_1_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\,
datad => N_35978);
GRFPU0_GRFPU_X0_EXPDEC_SP_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDEC_SP_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\,
datad => N_35977);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111010101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.ZERO\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\);
GRFPU0_GRFPU_X0_COMB_INCX16_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_5\);
GRFPU0_GRFPU_X0_VST4_EXC_0_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_0_SQMUXA_1_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2\,
datab => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U\,
datac => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U\);
GRFPU0_GRFPU_X0_ST4_RDY_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.RDY_0_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\);
GRFPU0_GRFPU_X0_UN1_VITER_FLUSH0_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMIN\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.EXPOP\(1));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010011000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4_A\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101010001")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(52));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_1_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1_1\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_1_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_1_1\(61),
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\);
\GRFPU0_GRFPU_X0_L1_0_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5\(1),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I\(1),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_1_4_I_I\(1),
datad => \GRFPU0.GRFPU_X0.UN38_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6\(0),
dataa => \GRFPU0.GRFPU_X0.L1_4_1_5_0_TZ\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.L1_4_6_A\(0));
\GRFPU0_GRFPU_X0_L1_4_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111100111111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L4_7_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(2),
dataa => \GRFPU0.GRFPU_X0.L3_1_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_5\(2),
datac => \GRFPU0.GRFPU_X0.L3_0_3\(5));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(1),
dataa => \GRFPU0.GRFPU_X0.L1_4_6\(1),
datab => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datac => \GRFPU0.GRFPU_X0.L1_5_5\(1));
\GRFPU0_GRFPU_X0_L2_1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_4\(1),
dataa => \GRFPU0.GRFPU_X0.L1_3_4\(1),
datab => \GRFPU0.GRFPU_X0.L1_2_4\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3));
\GRFPU0_GRFPU_X0_L1_0_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5\(0),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0\(0),
datab => \GRFPU0.GRFPU_X0.UN38_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_1_4_0\(0));
\GRFPU0_GRFPU_X0_L1_1_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_6\(0),
dataa => \GRFPU0.GRFPU_X0.TZI2\(8),
datab => \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0\(0),
datad => \GRFPU0.GRFPU_X0.UN43_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_4\(0),
dataa => \GRFPU0.GRFPU_X0.TZI2\(20),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_5_0\(0),
datad => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_5_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5\(0),
dataa => \GRFPU0.GRFPU_X0.L1_5_1_4_0_TZ\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_4_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_5_5_A\(0));
\GRFPU0_GRFPU_X0_L1_5_5_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111100111111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
dataa => \GRFPU0.GRFPU_X0.L1_5\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_5\(3));
GRFPU0_GRFPU_X0_COMB_VST4_RDY4_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_4\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_5\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_A2_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datac => \GRFPU0.GRFPU_X0.G_53_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_9\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2\(61),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G1\,
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_A2_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_A2_1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41),
datac => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datad => \GRFPU0.GRFPU_X0.G_53_REP0\);
\GRFPU0_GRFPU_X0_REST_2_RNIAHAH1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_REST_2_RNI74U21_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O3_0_0_A2_1\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datab => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(6),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPC0_D_STDLCK_RNO_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_0\,
dataa => N_175,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_1_0_X\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.D.STDLCK_0_0_9__G3\);
\GRFPC0_D_STDLCK_RNO_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111100001111")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1_X\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_2_0_A2_X\,
datac => \GRFPC0.STDDEP_0_SQMUXA_85_I_I_A2_I_O2\,
datad => \GRFPC0.RFA.LD\);
GRFPC0_RFA2_RS2DEP_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011110")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_3\,
dataa => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_0\,
datac => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_1\);
\GRFPC0_D_STLCK_RNO_7_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_2_0\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\,
dataa => \GRFPC0.V.STDATA_14\(9),
datab => \GRFPC0.V.STDATA_14\(12),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\);
\GRFPC0_D_STDLCK_RNO_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_1_X\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_0\,
datad => \GRFPC0.RFA.LD\);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_IV_I_A3_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_474_0_IV_I_A3_2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\);
\GRFPC0_D_STDLCK_RNO_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1247_DEP\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_5_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1682_REGDEPX2_RNI03RE1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_2\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1));
GRFPC0_FP_PIPELINE_3_REGDEPX2_115_1_M9_I_M4_0_A4_RNIBNOU: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_0_1_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1608_REGDEPX2_0_A2_1_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4\);
\GRFPC0_RFA2_FID_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_1__G0_1\,
dataa => \GRFPC0.DIV.ID\(1),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_1__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_1__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(1),
datab => \GRFPC0.WR.CTRL.ID\(1),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
\GRFPC0_RFA2_FID_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_3__G0_1\,
dataa => \GRFPC0.DIV.ID\(3),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_3__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_3__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(3),
datab => \GRFPC0.WR.CTRL.ID\(3),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
\GRFPC0_RFA2_FID_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_2__G0_1\,
dataa => \GRFPC0.DIV.ID\(2),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_2__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_2__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(2),
datab => \GRFPC0.WR.CTRL.ID\(2),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
\GRFPC0_RFA2_FID_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_0__G0_1\,
dataa => \GRFPC0.DIV.ID\(0),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_0__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_0__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(0),
datab => \GRFPC0.WR.CTRL.ID\(0),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
\GRFPC0_RFA2_FID_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_4__G0_1\,
dataa => \GRFPC0.DIV.ID\(4),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_4__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_4__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(4),
datab => \GRFPC0.WR.CTRL.ID\(4),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
\GRFPC0_RFA2_FID_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_5__G0_1\,
dataa => \GRFPC0.DIV.ID\(5),
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
datad => \GRFPC0.FID_1_IV_0_0_5__G0_1_A\);
\GRFPC0_RFA2_FID_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FID_1_IV_0_0_5__G0_1_A\,
dataa => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.WR.CTRL.ID\(5),
datac => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\,
datad => \GRFPC0.FID_1_IV_0_A3\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\);
GRFPC0_RFA_READ_RS1_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1_1\,
dataa => \GRFPC0.INST\(24),
datab => \GRFPC0.INST\(23),
datac => \GRFPC0.INST\(21),
datad => \GRFPC0.INST\(31));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST\(5),
datac => \GRFPC0.INST_I\(11),
datad => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_O2_6_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_6_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datad => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.N_20002_I_0_G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datad => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPC0_D_LDLCK_RNO_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1_0\,
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_X\(0),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1\(6));
GRFPC0_STDDEP_0_SQMUXA_170_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_170_0_A2_2\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_4_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_4_1\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O3\(40),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(40),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_1\(38),
dataa => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4\(38),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_1_D_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_1_D_0_0\(1),
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
datab => \GRFPC0.N_19292_1_I_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_R_FSR_CEXC_RNO_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\,
dataa => \GRFPC0.DIV.EXCT\(1),
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
datac => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_O2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_O2_1_0\,
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP_0_A2\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_0\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(47),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(49),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(42),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(37),
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2_A\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_A_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000001110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2_A\(37),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(39),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(50),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(43),
dataa => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
dataa => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(45),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(45));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_1\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(23),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(23),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(23),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(19),
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M_0\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(82));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(32),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(32),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(24),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD18\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(25),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M_0\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(95));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(16),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD10\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M_0\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(22),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD16\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(22),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(13),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(13),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(13),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(28),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(27),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD21\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(9),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD3\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(9),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(15),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD9\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(33),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD27\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_2\(59),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(31),
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(29),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD23\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_1\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010111000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(18),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_2_2\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN30_DP_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN30_DP_23\,
dataa => \GRFPC0.OP2_6\(36),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(36),
datad => \GRFPC0.OP2\(41));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(53));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0_1\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_0\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11_0\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_2_0\(1),
dataa => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.V.STDATA_14\(15),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_1_0_A2_0_A2_0_A2\,
datad => \GRFPC0.V.STDATA_14_I_M_4\(14));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_0\(0),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_1\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_26\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_TZ\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_4_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_4_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M22_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_4_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_4_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_4_03\);
GRFPC0_RFA2_FLUSH_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.N_17807_I_0_G0_I_A3_0\,
dataa => \GRFPC0.EX.CTRL.VCNT\(0),
datab => \GRFPC0.EX.CTRL.VCNT\(1),
datac => \GRFPC0.FP_PIPELINE.UN5_SHARE_I_O2\,
datad => \GRFPC0.FP_PIPELINE.UN11_SHARE\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_0\,
dataa => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_I_A2_6_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_6_0\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2_0\(1));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6151_REGDEPX2_RNI3E051: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_4\,
dataa => \GRFPC0.OP2\(56),
datab => \GRFPC0.OP2\(55),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_0\,
datad => \GRFPC0.OP2\(61));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_0\(1),
dataa => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_2_0\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0_1\(1),
datad => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_1\(22),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX_212_0_A2_0_X\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_35_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_35\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_4_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_4_03\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_33_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_33\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_4_03\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datac => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1175_0_O3\,
datad => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\);
GRFPC0_FP_PIPELINE_UN29_WREN_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_3\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.FP_PIPELINE.UN29_WREN_0_X\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(57),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(57));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(61),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(61));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(60),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(60));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(58),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(58));
\GRFPC0_INST_I_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000100")
port map (
combout => \GRFPC0.INST_I_0\(14),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_A2_1\(14));
GRFPC0_WR2_EXC_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.WR2.EXC_0_0_G0_0_A3_2\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_2_0\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_0\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\,
datac => \GRFPC0.N_19067_1_I_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O5_6_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O5_6\(22),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5226_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8_1\(1),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_0\(0),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6459_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6488_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\(1),
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3372_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3401_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(28),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_M2\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2\(45));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(48));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_A2_0_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0_0\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_A2_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_A2_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_1_0_A2_0\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(60),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__G0_I_A4_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_0_0\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_3_SQMUXA_1_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
GRFPU0_GRFPU_X0_ST3_ZERO_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.ZERO\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_10\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(15),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_1\(15),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
GRFPC0_EX_CTRL_RDWR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_A3_0_2_1\,
dataa => N_3,
datab => \GRFPC0.RFA.WRITE_RD\,
datac => N_45794_2,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\);
\GRFPC0_OP1_0_IV_3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(55),
dataa => \GRFPC0.EX.RREG.RES\(55),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(55),
datad => \GRFPC0.OP1_0_IV_1\(55));
\GRFPC0_OP1_0_IV_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(52),
dataa => \GRFPC0.EX.RREG.RES\(52),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(52),
datad => \GRFPC0.OP1_0_IV_1\(52));
\GRFPC0_OP1_0_IV_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(54),
dataa => \GRFPC0.WR.RREG.RES\(54),
datab => \GRFPC0.OP1_0_IV_1\(54),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.OP1_0_IV_0\(54));
\GRFPC0_OP1_0_IV_3_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(61),
dataa => \GRFPC0.EX.RREG.RES\(61),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(61),
datad => \GRFPC0.OP1_0_IV_1\(61));
\GRFPC0_OP1_0_IV_3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(58),
dataa => \GRFPC0.EX.RREG.RES\(58),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(58),
datad => \GRFPC0.OP1_0_IV_1\(58));
\GRFPC0_OP1_0_IV_3_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(60),
dataa => \GRFPC0.EX.RREG.RES\(60),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(60),
datad => \GRFPC0.OP1_0_IV_1\(60));
\GRFPC0_OP1_0_IV_3_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(37),
dataa => \GRFPC0.MEM.RREG.RES\(37),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(37),
datad => \GRFPC0.OP1_0_IV_1\(37));
\GRFPC0_OP1_0_IV_3_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(39),
dataa => \GRFPC0.MEM.RREG.RES\(39),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(39),
datad => \GRFPC0.OP1_0_IV_1\(39));
\GRFPC0_OP1_0_IV_3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(35),
dataa => \GRFPC0.EX.RREG.RES\(35),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(35),
datad => \GRFPC0.OP1_0_IV_1\(35));
\GRFPC0_OP1_0_IV_3_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(41),
dataa => \GRFPC0.WR.RREG.RES\(41),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datac => \GRFPC0.WR2.RREG.RES_I_M\(41),
datad => \GRFPC0.OP1_0_IV_2\(41));
\GRFPC0_OP1_0_IV_3_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(32),
dataa => \GRFPC0.EX.RREG.RES\(32),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(32),
datad => \GRFPC0.OP1_0_IV_1\(32));
\GRFPC0_OP1_0_IV_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(33),
dataa => \GRFPC0.MEM.RREG.RES\(33),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(33),
datad => \GRFPC0.OP1_0_IV_1\(33));
\GRFPC0_OP1_0_IV_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(38),
dataa => \GRFPC0.MEM.RREG.RES\(38),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(38),
datad => \GRFPC0.OP1_0_IV_1\(38));
\GRFPC0_OP1_0_IV_I_A2_3_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_3\(45),
dataa => \GRFPC0.EX.RREG.RES\(45),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_I_A2_0\(45),
datad => \GRFPC0.OP1_0_IV_I_A2_1\(45));
\GRFPC0_OP1_0_IV_3_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(42),
dataa => \GRFPC0.EX.RREG.RES\(42),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(42),
datad => \GRFPC0.OP1_0_IV_1\(42));
\GRFPC0_OP1_0_IV_3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(34),
dataa => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(34),
datad => \GRFPC0.OP1_0_IV_1\(34));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_2_0\(15),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\);
\GRFPC0_OP1_0_IV_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(53),
dataa => \GRFPC0.EX.RREG.RES\(53),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(53),
datad => \GRFPC0.OP1_0_IV_1\(53));
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I_X2_RNI8MGA2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2_0\(2),
dataa => \GRFPC0.RFA2.FLUSH\,
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\,
datad => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\);
\GRFPC0_OP1_0_IV_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(26),
dataa => \GRFPC0.MEM.RREG.RES\(26),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(26),
datad => \GRFPC0.OP1_0_IV_1\(26));
\GRFPC0_OP1_0_IV_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(2),
dataa => \GRFPC0.EX.RREG.RES\(2),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(2),
datad => \GRFPC0.OP1_0_IV_1\(2));
\GRFPC0_OP1_0_IV_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(31),
dataa => \GRFPC0.EX.RREG.RES\(31),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(31),
datad => \GRFPC0.OP1_0_IV_1\(31));
\GRFPC0_OP1_0_IV_3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(24),
dataa => \GRFPC0.EX.RREG.RES\(24),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(24),
datad => \GRFPC0.OP1_0_IV_1\(24));
\GRFPC0_OP1_0_IV_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(3),
dataa => \GRFPC0.WR.RREG.RES\(3),
datab => \GRFPC0.OP1_0_IV_1\(3),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.OP1_0_IV_0\(3));
\GRFPC0_OP1_0_IV_3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(22),
dataa => \GRFPC0.MEM.RREG.RES\(22),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(22),
datad => \GRFPC0.OP1_0_IV_1\(22));
\GRFPC0_OP1_0_IV_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(0),
dataa => \GRFPC0.EX.RREG.RES\(0),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(0),
datad => \GRFPC0.OP1_0_IV_1\(0));
\GRFPC0_OP1_0_IV_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(20),
dataa => \GRFPC0.MEM.RREG.RES\(20),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(20),
datad => \GRFPC0.OP1_0_IV_1\(20));
\GRFPC0_OP1_0_IV_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(19),
dataa => \GRFPC0.MEM.RREG.RES\(19),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(19),
datad => \GRFPC0.OP1_0_IV_1\(19));
\GRFPC0_OP1_0_IV_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(9),
dataa => \GRFPC0.MEM.RREG.RES\(9),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(9),
datad => \GRFPC0.OP1_0_IV_1\(9));
\GRFPC0_OP1_0_IV_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(16),
dataa => \GRFPC0.WR.RREG.RES\(16),
datab => \GRFPC0.OP1_0_IV_0\(16),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.OP1_0_IV_1\(16));
\GRFPC0_OP1_0_IV_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(4),
dataa => \GRFPC0.EX.RREG.RES\(4),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(4),
datad => \GRFPC0.OP1_0_IV_1\(4));
\GRFPC0_OP1_0_IV_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(15),
dataa => \GRFPC0.EX.RREG.RES\(15),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(15),
datad => \GRFPC0.OP1_0_IV_1\(15));
\GRFPC0_OP1_0_IV_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(25),
dataa => \GRFPC0.EX.RREG.RES\(25),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(25),
datad => \GRFPC0.OP1_0_IV_1\(25));
\GRFPC0_OP1_0_IV_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(10),
dataa => \GRFPC0.MEM.RREG.RES\(10),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(10),
datad => \GRFPC0.OP1_0_IV_1\(10));
\GRFPC0_OP1_0_IV_3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(30),
dataa => \GRFPC0.EX.RREG.RES\(30),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(30),
datad => \GRFPC0.OP1_0_IV_1\(30));
\GRFPC0_OP1_0_IV_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(6),
dataa => \GRFPC0.MEM.RREG.RES\(6),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(6),
datad => \GRFPC0.OP1_0_IV_1\(6));
\GRFPC0_OP1_0_IV_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(7),
dataa => \GRFPC0.MEM.RREG.RES\(7),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(7),
datad => \GRFPC0.OP1_0_IV_1\(7));
\GRFPC0_OP1_0_IV_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(23),
dataa => \GRFPC0.MEM.RREG.RES\(23),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(23),
datad => \GRFPC0.OP1_0_IV_1\(23));
\GRFPC0_OP1_0_IV_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(17),
dataa => \GRFPC0.MEM.RREG.RES\(17),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(17),
datad => \GRFPC0.OP1_0_IV_1\(17));
\GRFPC0_OP1_0_IV_3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(14),
dataa => \GRFPC0.MEM.RREG.RES\(14),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(14),
datad => \GRFPC0.OP1_0_IV_1\(14));
\GRFPC0_OP1_0_IV_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(11),
dataa => \GRFPC0.MEM.RREG.RES\(11),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(11),
datad => \GRFPC0.OP1_0_IV_1\(11));
\GRFPC0_OP1_0_IV_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(1),
dataa => \GRFPC0.EX.RREG.RES\(1),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(1),
datad => \GRFPC0.OP1_0_IV_1\(1));
\GRFPC0_OP1_0_IV_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(8),
dataa => \GRFPC0.MEM.RREG.RES\(8),
datab => \GRFPC0.RFA2.RS1SEL\(2),
datac => \GRFPC0.OP1_0_IV_0\(8),
datad => \GRFPC0.OP1_0_IV_1\(8));
\GRFPC0_OP1_0_IV_I_A2_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_3\(13),
dataa => \GRFPC0.WR2.RREG.RES\(13),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datac => \GRFPC0.OP1_0_IV_I_A2_0\(13),
datad => \GRFPC0.OP1_0_IV_I_A2_1\(13));
\GRFPC0_OP1_0_IV_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(28),
dataa => \GRFPC0.EX.RREG.RES\(28),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(28),
datad => \GRFPC0.OP1_0_IV_1\(28));
\GRFPC0_OP1_0_IV_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(5),
dataa => \GRFPC0.EX.RREG.RES\(5),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(5),
datad => \GRFPC0.OP1_0_IV_1\(5));
\GRFPC0_OP1_0_IV_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(27),
dataa => \GRFPC0.WR.RREG.RES\(27),
datab => \GRFPC0.OP1_0_IV_1\(27),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.OP1_0_IV_0\(27));
\GRFPC0_OP1_0_IV_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(18),
dataa => \GRFPC0.WR.RREG.RES\(18),
datab => \GRFPC0.OP1_0_IV_1\(18),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datad => \GRFPC0.OP1_0_IV_0\(18));
\GRFPC0_OP1_0_IV_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(21),
dataa => \GRFPC0.EX.RREG.RES\(21),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(21),
datad => \GRFPC0.OP1_0_IV_1\(21));
\GRFPC0_OP1_0_IV_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(29),
dataa => \GRFPC0.EX.RREG.RES\(29),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datac => \GRFPC0.OP1_0_IV_0\(29),
datad => \GRFPC0.OP1_0_IV_1\(29));
\GRFPC0_OP1_0_IV_3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.OP1_0_IV_3\(12),
dataa => \GRFPC0.EX.RREG.RES\(12),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(12),
datad => \GRFPC0.OP1_0_IV_1\(12));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1_0\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_RNIG5DJ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000000100")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_3\,
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G2_A0_1_X\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_17\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_9\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_0\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.COMB.EXP57_0_O2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\(59));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_2_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_2_A2_1\,
dataa => \GRFPC0.V.STDATA_14\(21),
datab => \GRFPC0.V.STDATA_14\(10),
datac => \GRFPC0.V.STDATA_14_I_M2\(19),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2_1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_O2_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_1_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_59\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_49\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_50\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_47\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_48\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_43\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_18\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_19\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_16\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_17\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_12\,
dataa => \GRFPU0.GRFPU_X0.NXX_10\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_4\,
datac => \GRFPU0.GRFPU_X0.NXX_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_11_S\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_3\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_10\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_18\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\,
datab => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_14\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_1\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_6\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_10\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_8\);
GRFPU0_GRFPU_X0_NXX_10_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_10_0\,
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.NXX_0\,
datac => \GRFPU0.MULO.MRES\(96),
datad => \GRFPU0.GRFPU_X0.N_18308_12\);
GRFPC0_STDEP_0_SQMUXA_108_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_108_0\,
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25),
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_O2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_2_3\(0),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M_0\(64));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(37),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPC0_DIV_RESULT_0_0_55__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_55__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(55),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datab => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(45),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(32),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(61),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(9),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(61),
dataa => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(60),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(8),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(8),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60),
dataa => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_4_I_M2\(57),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_2\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(49),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_2\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datab => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(36),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI087Q2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M6_I_A3_I_1_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_0_2\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14\(10),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2_1\,
datad => \GRFPC0.DIVI_0_SQMUXA_2\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_39\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_19\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_17\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_13\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_11\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_9\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_36\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_4\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_35\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_2\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\);
\GRFPC0_DIV_RESULT_0_0_0__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_0__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(0),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_4__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_4__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_WR_RREG_RES_0_0_9__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_9__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(9),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPC0_DIV_RESULT_0_0_3__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_3__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(3),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_1__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_1__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_14__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_14__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(14),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_18__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_18__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(18),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_17__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_17__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(17),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_5__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_5__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(5),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_7__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_7__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(7),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_21__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_21__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(21),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_30__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_30__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPC0_DIV_RESULT_0_0_28__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_28__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(28),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_2__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_2__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(2),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_29__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_29__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPC0_DIV_RESULT_0_0_20__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_20__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(20),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_26__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_26__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(26),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_8__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_8__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(8),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_11__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_11__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(11),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_15__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_15__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(15),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_22__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_22__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(22),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_25__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_25__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_12__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_12__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(12),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_10__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_10__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(10),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_27__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_27__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(27),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_13__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_13__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(13),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_16__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_16__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(16),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_6__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_6__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(6),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_19__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_19__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(19),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_31__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_31__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2_REP1\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1_REP1\(0));
\GRFPC0_DIV_RESULT_0_0_23__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_23__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(23),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPC0_DIV_RESULT_0_0_24__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_24__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(24),
datac => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
datad => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIDS482_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100110001001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_3_S\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_I_O2\(1));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_95_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95_I_A2_0\(0),
dataa => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1656_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIGP8S1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0_A\);
GRFPU0_GRFPU_X0_ITER_FLUSH0_RNIKLQS: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1_0_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN41_DP_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_3\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_0\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3534_REGDEPX2_0_A2_RNIPRSV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
GRFPC0_FP_PIPELINE_FPUSTART_7_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_5\,
dataa => \GRFPC0.RFA.ST\,
datab => \GRFPC0.RFA.LD_REP1\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_2\,
datad => \GRFPC0.FP_PIPELINE.FPUSTART_7_3\);
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011000000110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\(1));
\GRFPC0_EX_CTRL_ID_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_4\,
dataa => \GRFPC0.RFA.ST\,
datab => \GRFPC0.RFA.LD\,
datac => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_1\,
datad => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI4RTA1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101001100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_0\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIL4051_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2_A\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNICHFJ_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_83_2_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.LDLOCK_M_3\,
dataa => N_97,
datab => N_100,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datad => \GRFPC0.LDLOCK_1_M_2_X\);
GRFPC0_VFIFO_WR_1_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.VFIFO.WR_1_SQMUXA_0\,
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_235TT_0_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M1_E_1\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3476_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_A4_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A4_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_1\(1),
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_O2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_1_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8\(1));
GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_M4_E_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0_M4_E_0\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN726_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_6_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EMAXP112\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_O2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2_0_A3_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
GRFPU0_GRFPU_X0_S_SP_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_24\,
dataa => \GRFPU0.GRFPU_X0.S_SP_16\,
datab => \GRFPU0.GRFPU_X0.S_SP_17\,
datac => \GRFPU0.GRFPU_X0.S_SP_14\,
datad => \GRFPU0.GRFPU_X0.S_SP_15\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_46\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_33\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_34\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_31\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_32\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_45\,
dataa => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_29\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_30\,
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_27\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_28\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_O2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_O2_0_0\(0),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2_0_A3_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_2_0\(1),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_5_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_1\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_VST2_REG_4_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.REST_1_1_2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_A2_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_1_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_O2_1\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A4_1_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_2_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_0_TZ_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0_TZ_0\(1),
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360TT_1_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360TT_1_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A4_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010111001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A4_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2_0_O2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_4_2_TZ_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_4_2_TZ_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_17_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_15_0\(1));
GRFPC0_FP_PIPELINE_15_REGDEPX2_475TT_1_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475TT_1_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_17_1\(1),
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_15_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
GRFPC0_FP_PIPELINE_11_REGDEPX2_355TT_1_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5226_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_1_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_1_0\(1),
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_14\(1));
GRFPC0_FP_PIPELINE_3_REGDEPX2_115TT_1_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M3_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1727_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_0\(22),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M5_E_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101011111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M5_E_0\,
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2_0_A3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\,
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_17\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_15\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\);
GRFPU0_GRFPU_X0_VST2_INF_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_0\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
GRFPC0_VFIFO_PC_0_1_SQMUXA_0_A2_M1_E_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_1\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_38,
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\);
GRFPC0_FP_PIPELINE_UN6_OP3_0_X_RNICGFI: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FIFO.FULL_M_0_2_0\,
dataa => N_99,
datab => N_101,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
datad => \GRFPC0.FP_PIPELINE.UN6_OP3_0_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(0),
dataa => N_93,
datab => N_95,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15));
GRFPC0_WREN_2_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100011")
port map (
combout => \GRFPC0.WREN_2_SQMUXA_3\,
dataa => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A1\(1),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A5_0_A0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A5_0_A0\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2549_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0\,
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_3_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_4\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0_TZ\);
\GRFPC0_R_FSR_TEM_RNIBUGE1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011000100")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_0__G3_1\,
dataa => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPC0.R.FSR.TEM\(0),
datac => \GRFPC0.DIV.EXCT_0_0_0__G3_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O4\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_1\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3354_DEP\);
GRFPC0_FP_PIPELINE_1_REGDEP146: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.FPUSEL_1_0_3__G0_E_3\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\);
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_4\,
dataa => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_11\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6\(1),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6_2\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1\(0),
dataa => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_4_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_7\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1),
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1\(1),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6_2\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1));
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_1_M6_I_0_A3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A3_2\,
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_0_A2_I_O3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A5_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\(1),
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0_1\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_204_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0_4\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3\(0),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_2\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_2\(19),
dataa => N_93,
datab => N_94,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A2_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_23_IV_I_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_23_IV_I_A3\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_1\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6\(0),
dataa => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_4\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_4\,
dataa => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_0_I\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_I_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_4\(0),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14\(2),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_0_A2_0_0_A2_0_A3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A2_0_0_I\);
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.ID_0\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
datac => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_4\(0),
dataa => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_11\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1_2\(0),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\,
dataa => \GRFPC0.DIV.EXCT\(5),
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45\,
dataa => \GRFPC0.OP2\(57),
datab => \GRFPC0.OP2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2_0\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1\(4),
dataa => \GRFPC0.OP1_0_IV\(61),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\(4),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_3\(4),
datad => \GRFPC0.OP1_0_IV\(56));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46\,
dataa => \GRFPC0.OP2\(55),
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_0\,
datac => \GRFPC0.OP2\(61),
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_3\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_I_A2_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_I_A2_10\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_0_A2_I_O3\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_3\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_18_0_O2\(0),
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_5\(1),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.RDD_REP3\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_11\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6592_REGDEPX2_0_A2_0_0_A4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_REP1\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_A4_0_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_A4_0_0_A4\,
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2_2_I_O4\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_0\(1),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN888_REGDEPX2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_I_X3_3_RNI9IRA2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
dataa => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_I_X3_3\,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\,
datad => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(0),
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_X\(0),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(0),
dataa => N_79,
datab => N_81,
datac => \GRFPC0.D.LDLCK_0_0_10__G3_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(9),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(10),
dataa => N_97,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datac => \GRFPC0.CPI_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_6_STDEP_278_0_O2_I_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_0_O2_I_A3\(1),
dataa => N_242,
datab => N_245,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP_1_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_MEM_CTRL_PEND_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3\,
dataa => \GRFPC0.MEM.CTRL.LD\,
datab => \GRFPC0.FP_PIPELINE.UN56_PENDEXC_X\,
datac => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3_2\,
datad => CPO_EXCZ);
GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_M3_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E\,
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_2_0_A2_I_O3\,
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E_1\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_M9_I_M4_0_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_0\,
dataa => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2\(0),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1196_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2\(0),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_6\(0),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1608_REGDEPX2_0_A2_1_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
dataa => \GRFPC0.FP_PIPELINE.UN86_HOLDN_3\,
datab => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datac => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_2\,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_12_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12\(1),
dataa => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(28),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4_0\(1));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\,
dataa => \GRFPC0.FPR.ID\(0),
datab => \GRFPC0.MEM.CTRL.ID\(0),
datac => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_5\);
GRFPC0_FP_PIPELINE_1_REGDEP160: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => RFI2_RD2ADDRZ(3),
datac => \GRFPC0.FP_PIPELINE.1.REGDEP160_0\,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7_3\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN271_REGDEPX2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3_0\(1));
GRFPC0_STDDEP_0_SQMUXA_19_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_19_I_O4\,
dataa => N_243,
datab => N_242,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_0_STDEP10_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP10_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_STDDEP_0_SQMUXA_158_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_158_1_I_O2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\);
GRFPC0_FP_PIPELINE_1_REGDEP132: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.FP_PIPELINE.1.REGDEP132_1\,
datac => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.FP_PIPELINE.1.REGDEP132_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_A4_0\(1),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN3078_REGDEPX2_0_A2_0_A2\,
datad => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3476_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_4\(1));
GRFPC0_FP_PIPELINE_VDIV_VALID2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID2_4\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_1\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2\(3),
dataa => \GRFPC0.OP1_0_IV\(60),
datab => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_4\(3),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_3\(3),
datad => \GRFPC0.OP1_0_IV\(56));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(51),
dataa => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_M2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
GRFPC0_FP_PIPELINE_1_REGDEP118: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
dataa => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.FP_PIPELINE.1.REGDEP118_1\,
datac => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.FP_PIPELINE.1.REGDEP118_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(27),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(27),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_5\(1),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4_0\(0),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.RFA.RDD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1\(8),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A4_0\(0),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.INST\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_O2\(0));
\GRFPC0_D_STLCK_RNO_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_4\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_3\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN259_DEP_2_X_RNIP1GP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_7_I_I_A4_I_O2\,
dataa => N_242,
datab => N_243,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1575_DEP_2_X_RNIO7BR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_15_I_0_O4\,
dataa => N_242,
datab => N_244,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_3_2\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4\(0),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3529_DEP\,
datac => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.RDD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(23),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21));
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_0_M_9\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_3\(0),
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\(0));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4841_DEP_2_X_RNI7A7T: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_28_I_0_O2\,
dataa => N_174,
datab => N_175,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\,
datad => \GRFPC0.RFA.LD_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2_0_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A2_0_I_O4\,
dataa => N_176,
datab => N_173,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_1_X\,
datad => \GRFPC0.RFA.LD\);
GRFPC0_EX_CTRL_LD_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2\,
dataa => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_2_X\,
datab => \GRFPC0.RFA.LD\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_STDDEP_0_SQMUXA_9_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_9_I_O4\,
dataa => N_175,
datab => N_176,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3857_DEP_1_X\,
datad => \GRFPC0.RFA.LD_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_STDEP_0_SQMUXA_92_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_92_1\,
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(21),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
GRFPU0_GRFPU_X0_UN2_BCO_LSB_2_RNI5IFV2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_10\(3),
dataa => \GRFPU0.GRFPU_X0.L1_0_10_0\(3),
datab => \GRFPU0.GRFPU_X0.L1_0_10_1\(3),
datac => \GRFPU0.GRFPU_X0.UN2_BCO_LSB_2\,
datad => \GRFPU0.GRFPU_X0.L1_0_1_5_I_1\(1));
GRFPU0_GRFPU_X0_UN28_BCO_LSB_RNIVHF42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.L1_5_0_A\(3),
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\);
\GRFPU0_GRFPU_X0_ITER_ND_I_RNI9Q701_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_0_A\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
GRFPU0_GRFPU_X0_COMB_BIAS15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15_2\,
datad => \GRFPU0.GRFPU_X0.COMB.BIAS15_3_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(27),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(27));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_14_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_7\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.NX\,
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_5\(0),
datad => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT5\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(35),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(23),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_0\(23));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(31),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(31));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_0\(38));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(51),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(51));
GRFPU0_GRFPU_X0_COMB_UN1_ST2_FLOP_4_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_5\);
\GRFPU0_GRFPU_X0_L1_4_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datac => \GRFPU0.GRFPU_X0.L1_4_3_1\(3),
datad => \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_RNDOP_29_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111100000000011")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.MULO.MRES\(67));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2_0\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I_M4\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_O4\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_M4\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_O4\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datad => \GRFPU0.MULO.MRES\(119));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIJRFI2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_A3_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3\);
GRFPC0_VEX_CTRL_PEND_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\,
dataa => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0_X\,
datac => \GRFPC0.D.FLDLCK_0_0_G1_0\,
datad => CPO_EXCZ);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(43));
\GRFPU0_GRFPU_X0_L1_4_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.L1_4_4_A\(3),
datad => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_4_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4_A\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(44));
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_A2_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_4_0_A3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_4_I_O2\);
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIHU5C2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_S\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_4_I_O2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(20));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(50),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(50),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(50));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(25));
\GRFPU0_GRFPU_X0_TZI_RNIL7MV1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(3),
dataa => \GRFPU0.GRFPU_X0.TZI\(21),
datab => \GRFPU0.GRFPU_X0.TZI\(20),
datac => \GRFPU0.GRFPU_X0.L1_2_3_0\(3),
datad => \GRFPU0.GRFPU_X0.UN13_BCO_LSB\);
\GRFPU0_GRFPU_X0_REST_1_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.REST_1_2_0\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(44),
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(44));
GRFPC0_DEP_1_SQMUXA_88_0_A3_I_O2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100011111111")
port map (
combout => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
dataa => \GRFPC0.FIFO.INST_0\(10),
datab => \GRFPC0.FIFO.INST_0\(11),
datac => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_A\);
GRFPC0_DEP_1_SQMUXA_88_0_A3_I_O2_0_0_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011101100111")
port map (
combout => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_A\,
dataa => \GRFPC0.FIFO.INST_0\(8),
datab => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_O2_0_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2_0\);
GRFPU0_GRFPU_X0_UN213_BCO_LSB_RNIOARL3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_0\(4),
dataa => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datab => \GRFPU0.GRFPU_X0.UN213_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_4\(3));
\GRFPU0_GRFPU_X0_BCO_MSB_2_I_1_RNI65451_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2\(4),
dataa => \GRFPU0.GRFPU_X0.L2_2\(4),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN93_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_0\(3));
GRFPU0_GRFPU_X0_COMB_VST1_V4_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_15_5\,
dataa => \GRFPC0.V.STDATA_14\(9),
datab => \GRFPC0.V.STDATA_14\(7),
datac => \GRFPC0.V.STDATA_14\(8),
datad => \GRFPC0.V.STDATA_14_REP1\(11));
\GRFPU0_GRFPU_X0_INF_ABS0_3_RNIBN2C2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(24),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(25),
datac => \GRFPU0.GRFPU_X0.L1_0_0_2\(3),
datad => \GRFPU0.GRFPU_X0.UN243_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(3),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(11),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(10),
datac => \GRFPU0.GRFPU_X0.L1_2_5_0\(3),
datad => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_TZI2_RNIA7RK1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3),
dataa => \GRFPU0.GRFPU_X0.TZI2\(20),
datab => \GRFPU0.GRFPU_X0.L1_2_0_A3_0\(3),
datac => \GRFPU0.GRFPU_X0.TZI2_I_M2\(21),
datad => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.L1_4_5_A\(3),
datad => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_5_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5_A\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_IV_0_RNO_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SIGN2_I_M\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD2\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M3_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_A2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_NZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_LT_EXPT14LTO10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO10\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO6\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_6\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN14_C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2_0\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN22_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN22_DP\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2_0\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN35_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP_1\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_9\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_1\,
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_11_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11\(1),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(11),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_25_IV_0_O2_I_A2\(1));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_4\(0),
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A2_0\(1));
GRFPC0_FP_PIPELINE_VFIFO_RD10_X_RNI39JB1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.FIFO.RD_M\(0),
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datad => CPO_EXCZ);
GRFPC0_EX_CTRL_RDWR_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307_A3\,
dataa => N_3,
datab => \GRFPC0.RFA.RDWR\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datad => \GRFPC0.N_17807_I_0_G1\);
GRFPU0_GRFPU_X0_COMB_TMP316_3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2_2\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\);
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_5\);
GRFPU0_GRFPU_X0_TMP3_0_SQMUXA_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_M2\,
datac => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2_A\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\);
GRFPU0_GRFPU_X0_TMP3_0_SQMUXA_I_O2_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110000011100")
port map (
combout => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_O2_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_UN63_BCO_LSB_RNI61VG1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.L1_5_A\(3),
datad => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI9S5S_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_A\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_L1_1_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_0_A3_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datad => \GRFPU0.GRFPU_X0.L1_1_0_A3_1_0\(0));
\GRFPC0_D_STLCK_RNO_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_176_I_M_1\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_4_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_M10_I_A5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_M10_I_A5_0\,
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3401_REGDEPX2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_M4_A1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A1\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2_1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_175_1_M9_I_A0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A0\,
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2549_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V17_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_0_A3\,
dataa => \GRFPC0.INST\(24),
datab => \GRFPC0.INST\(23),
datac => \GRFPC0.INST\(21),
datad => \GRFPC0.INST_I_M5\(19));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_393_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_393_0_A3_0\(1),
dataa => \GRFPC0.V.STDATA_14_REP1\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_0_X_RNISUSL: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I_A4_0\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\,
datad => CPO_LDLOCKZ);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_0_X_RNISUSL_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_A4_0\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\,
datad => CPO_LDLOCKZ);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\(1),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(11),
datad => \GRFPC0.V.STDATA_14\(18));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_0_0\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_6_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6884_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_9_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_7_STDEP_284_0_IV_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_284_0_IV_I_0\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_FPUSTART_7_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_6\,
dataa => \GRFPC0.RFA2.FOP\(0),
datab => \GRFPC0.RFA2.FOP\(1),
datac => \GRFPC0.FPR.ALLOW\(2),
datad => \GRFPC0.UN1_FPR.ALLOW_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_A2_3_YY_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_YY\(41),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.MULO.MRES\(101),
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0_0\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_A2_3_XX_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_3_XX\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(4),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_YY_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_YY\(59),
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0_0\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_XX_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_XX\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M2\(22),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_5_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_5_1\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_6_0\,
dataa => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_2_0\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11_0\(1));
GRFPU0_GRFPU_X0_ST1_V_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\,
dataa => \GRFPC0.RFA2.FLUSH\,
datab => \GRFPU0.GRFPU_X0.COMB.UN11_FLUSH\,
datac => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP2\);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_23_IV_I_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_123_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_123_0_A3_0\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_5_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL5_5_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(28),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_3\,
dataa => \GRFPC0.V.STDATA_14\(7),
datab => \GRFPC0.V.STDATA_14\(8),
datac => \GRFPC0.V.STDATA_14_REP1\(11),
datad => \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(21),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_10_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_10\(15),
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11_1_X_RNIJGV61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_D_STLCK_RNO_7_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_594_I_M_2\(0),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1\(0),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
\GRFPC0_D_STLCK_RNO_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1));
\GRFPC0_FP_PIPELINE_9_STDEP_390_0_IV_I_A5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_390_0_IV_I_A5\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_212_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0\(1),
dataa => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.V.STDATA_14\(15),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A2_0\(1),
datad => \GRFPC0.V.STDATA_14_I_M_4\(14));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_4\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.RDD_REP3\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6032_REGDEPX2_0_A2_0_A2\);
\GRFPC0_D_STLCK_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4\(0),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_A4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_89_A0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A0\(1),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1226_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_289_A0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_A0\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4268_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
\GRFPU0_GRFPU_X0_L4_D_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100011101")
port map (
combout => \GRFPU0.GRFPU_X0.L4_D\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datab => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.L1_6_1_3_I_1\(1),
datad => \GRFPU0.GRFPU_X0.L1_6_1_3_I_A4\(1));
\GRFPU0_GRFPU_X0_L1_5_1_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_5_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.L1_5_1_5_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L1_1_1_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_1_1_4_0_TZ\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_TZ\(0));
\GRFPU0_GRFPU_X0_L1_0_1_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_0_1_4_0_TZ\(0));
\GRFPU0_GRFPU_X0_L1_2_1_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_4_1_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1));
GRFPC0_WR_CTRL_RDD_RNIVVTQ4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001010")
port map (
combout => D_M3_0,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_19292_1_I_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_4_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000011000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_4\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => D_M2_E_0_1,
datac => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_4_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => D_M1_E,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
dataa => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_38,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0_X\,
datad => CPO_LDLOCKZ);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_4_0_TZ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_4_0_TZ\(1),
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6606_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_0_2_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_TZ\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_1_0_A2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_1_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2\(0));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_4_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_1_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03_0_G0\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M22_4_03_0_G2\);
\GRFPU0_GRFPU_X0_L3_0_3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datac => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_0_0\(1),
datad => \GRFPU0.GRFPU_X0.L1_0_1_1_I_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_O2_4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_O2_4_0\(1),
dataa => \GRFPC0.V.STDATA_14_I_M2\(0),
datab => \GRFPC0.V.STDATA_14_REP0\(6),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_0_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2\);
\GRFPC0_V_STDATA_14_RNIBN921_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000000000")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_O3_1\,
dataa => \GRFPC0.V.STDATA_14\(8),
datab => \GRFPC0.V.STDATA_14\(10),
datac => \GRFPC0.V.STDATA_14\(11),
datad => \GRFPC0.V.STDATA_14_REP0\(6));
GRFPC0_RFA_WRITE_RD_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000101")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST_I\(10),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ_A\);
GRFPC0_RFA_WRITE_RD_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011001110111")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1_2575_TZ_A\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I_X\(6),
datac => \GRFPC0.INST_I\(10),
datad => \GRFPC0.INST_I\(11));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI9ASE1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000010")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ_A\);
GRFPU0_GRFPU_X0_ITER_SIGN_RNI17FH: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_O2_2374_TZ_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_TZ\(0));
\GRFPU0_GRFPU_X0_L1_1_1_6_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_6_0\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(21),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(20),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(22),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(23));
\GRFPU0_GRFPU_X0_L1_3_1_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_5_0\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(5),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(6),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(7));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0\(0),
dataa => \GRFPU0.GRFPU_X0.TZI\(21),
datab => \GRFPU0.GRFPU_X0.TZI\(20),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L1_0_1_4_I_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4_I_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datac => \GRFPU0.GRFPU_X0.L1_0_1_4_I_I_A\(1),
datad => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_2\);
\GRFPU0_GRFPU_X0_L1_0_1_4_I_I_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4_I_I_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A3_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_0_1\(0),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_I_I_A2_0_A2\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_10\(0),
dataa => N_80,
datab => N_79,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_10\(1),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14\(2),
datac => \GRFPC0.V.STDATA_14_I_M_6\(0),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O3\(1),
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6592_REGDEPX2_0_A2_0_0_A4\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_15\(1));
\GRFPC0_D_STLCK_RNO_5_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A3\(1),
dataa => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2_0\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_16_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_16\(0),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_O2\(1),
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1));
\GRFPC0_FP_PIPELINE_1_0_STDEP_65_0_IV_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.STDEP_65_0_IV_I_O2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5\(31),
dataa => N_80,
datab => N_79,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_0_X\(9));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_17_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_17\(1),
dataa => N_80,
datab => N_79,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_0_X\(9));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_18_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_18\(1),
dataa => N_93,
datab => N_84,
datac => N_92,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX_0_A2_0_X\);
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_O3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_O3_1\(0),
dataa => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_1\(1),
datab => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0));
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_0_M6_I_0_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_3\,
dataa => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_0_A2_I_O3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_V_STDATA_14_RNIEU2L_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_I_I_A2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_4_0_S_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4_0\(0),
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14_M_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_299_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2\(0),
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN496_REGDEPX_0_O2_0_RNI5HRE4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0_O2_0\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
GRFPC0_V_STDATA_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010100010000")
port map (
combout => \GRFPC0.V.STDATA_0_SQMUXA_1\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.DIV.EXC\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8\(0),
dataa => \GRFPC0.V.STDATA_14_I_M2\(0),
datab => \GRFPC0.V.STDATA_14\(1),
datac => \GRFPC0.V.STDATA_14\(2),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_0_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_174_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2609_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4373_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_O2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_2\(1),
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN726_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_O2\(0),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2_2_I_O4\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
\GRFPC0_OP1_0_IV_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101000000")
port map (
combout => \GRFPC0.RFO1_I_M_0\(19),
dataa => N_646,
datab => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_0_SQMUXA_REP1\);
GRFPC0_FP_PIPELINE_0_1_FIFO_INST_V_TMP_IV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_O2\(0),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_4_0_S_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4_0_S_0_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_I_I_A2_1_A2_1_A2\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_212_0_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3\(1),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3167_REGDEPX2\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_2\(1),
dataa => \GRFPC0.V.STDATA_14_I_M2\(0),
datab => \GRFPC0.V.STDATA_14\(1),
datac => \GRFPC0.V.STDATA_14\(2),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\);
\GRFPC0_V_STDATA_14_RNIEU2L_5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5516_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_V_STDATA_14_RNIEU2L_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_1\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_0_A3_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_21_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_21_0_A2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_9_1\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(18),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_7\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2_0_A2_1_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_1\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_1\(0));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_0_M6_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3167_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(25),
dataa => N_79,
datab => N_80,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_1\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2_0_A2_1_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4\(1),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A2_1_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_4\(9),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_FCC_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => CPO_CCZ(1),
dataa => \GRFPC0.FP_PIPELINE.FCC_1_M3\(1),
datab => \GRFPC0.FP_PIPELINE.FCC_1_M2_X\(1),
datac => \GRFPC0.FP_PIPELINE.FCC_1_M2S4\);
\GRFPC0_FP_PIPELINE_FCC_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => CPO_CCZ(0),
dataa => \GRFPC0.FP_PIPELINE.FCC_1_M3\(0),
datab => \GRFPC0.FP_PIPELINE.FCC_1_M2_X\(0),
datac => \GRFPC0.FP_PIPELINE.FCC_1_M2S4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
dataa => \GRFPC0.DIV.INST\(30),
datab => \GRFPC0.WR2.CTRL.PC\(30),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
dataa => \GRFPC0.DIV.INST\(29),
datab => \GRFPC0.WR2.CTRL.PC\(29),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
dataa => \GRFPC0.DIV.INST\(28),
datab => \GRFPC0.WR2.CTRL.PC\(28),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
dataa => \GRFPC0.DIV.INST\(27),
datab => \GRFPC0.WR2.CTRL.PC\(27),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
dataa => \GRFPC0.DIV.INST\(26),
datab => \GRFPC0.WR2.CTRL.PC\(26),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
dataa => \GRFPC0.DIV.INST\(25),
datab => \GRFPC0.WR2.CTRL.PC\(25),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(24),
dataa => \GRFPC0.DIV.INST\(24),
datab => \GRFPC0.WR2.CTRL.PC\(24),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
dataa => \GRFPC0.DIV.INST\(23),
datab => \GRFPC0.WR2.CTRL.PC\(23),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
dataa => \GRFPC0.DIV.INST\(22),
datab => \GRFPC0.WR2.CTRL.PC\(22),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
dataa => \GRFPC0.DIV.INST\(21),
datab => \GRFPC0.WR2.CTRL.PC\(21),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
dataa => \GRFPC0.DIV.INST\(20),
datab => \GRFPC0.WR2.CTRL.PC\(20),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
dataa => \GRFPC0.DIV.INST\(19),
datab => \GRFPC0.WR2.CTRL.PC\(19),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.WR2.CTRL.PC\(16),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.WR2.CTRL.PC\(14),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
dataa => \GRFPC0.DIV.INST\(13),
datab => \GRFPC0.WR2.CTRL.PC\(13),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
dataa => \GRFPC0.DIV.INST\(11),
datab => \GRFPC0.WR2.CTRL.PC\(11),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
dataa => \GRFPC0.DIV.INST\(9),
datab => \GRFPC0.WR2.CTRL.PC\(9),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
dataa => \GRFPC0.WR2.CTRL.PC\(4),
datab => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(4),
dataa => N_395,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(4),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(1),
dataa => N_392,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(1),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(2),
dataa => N_393,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(3),
dataa => N_394,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(3),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(8),
dataa => N_399,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(8),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(47),
dataa => \GRFPC0.WR2.RREG.RES\(47),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_47__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(21),
dataa => N_412,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(21),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(24),
dataa => N_415,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(24),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(25),
dataa => N_416,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(25),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(27),
dataa => N_418,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(27),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(59),
dataa => \GRFPC0.WR2.RREG.RES\(59),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_59__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(29),
dataa => N_420,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(29),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(30),
dataa => N_421,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(30),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(31),
dataa => N_422,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(31),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(32),
dataa => \GRFPC0.WR.RREG.RES\(32),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(1),
dataa => \GRFPC0.WR.RREG.RES\(1),
datab => \GRFPC0.DIV.RESULT_0_0_1__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(34),
dataa => \GRFPC0.WR.RREG.RES\(34),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(41),
dataa => \GRFPC0.WR.RREG.RES\(41),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(41));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(44),
dataa => \GRFPC0.WR.RREG.RES\(44),
datab => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(47),
dataa => \GRFPC0.WR2.RREG.RES\(47),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_47__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(47),
dataa => \GRFPC0.WR.RREG.RES\(47),
datab => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(50),
dataa => \GRFPC0.WR.RREG.RES\(50),
datab => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(52),
dataa => \GRFPC0.WR.RREG.RES\(52),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(52));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(21),
dataa => \GRFPC0.WR.RREG.RES\(21),
datab => \GRFPC0.DIV.RESULT_0_0_21__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(55),
dataa => \GRFPC0.WR.RREG.RES\(55),
datab => \GRFPC0.DIV.RESULT_0_0_55__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(56),
dataa => \GRFPC0.WR.RREG.RES\(56),
datab => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(58),
dataa => \GRFPC0.WR.RREG.RES\(58),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(59),
dataa => \GRFPC0.WR.RREG.RES\(59),
datab => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_1_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(62),
dataa => \GRFPC0.WR2.RREG.RES\(62),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_62__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(62),
dataa => \GRFPC0.WR.RREG.RES\(62),
datab => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(31),
dataa => \GRFPC0.OP2_6\(31),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(31));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(63),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datab => \GRFPC0.WR.RREG.RES\(63),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_WRDATA_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(31),
dataa => N_423,
datab => N_424,
datac => N_462,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(31));
\GRFPC0_OP2_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(44),
dataa => \GRFPC0.WR2.RREG.RES\(44),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_44__G3\);
\GRFPC0_WRDATA_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(1),
dataa => N_423,
datab => N_424,
datac => N_432,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(1));
\GRFPC0_WRDATA_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(2),
dataa => N_423,
datab => N_424,
datac => N_433,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(2));
\GRFPC0_WRDATA_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(3),
dataa => N_423,
datab => N_424,
datac => N_434,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(3));
\GRFPC0_WRDATA_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(5),
dataa => N_423,
datab => N_424,
datac => N_436,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(5));
\GRFPC0_WRDATA_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(9),
dataa => N_423,
datab => N_424,
datac => N_440,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(9));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(44),
dataa => \GRFPC0.WR2.RREG.RES\(44),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_44__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(50),
dataa => \GRFPC0.WR2.RREG.RES\(50),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_50__G3\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(4),
dataa => \GRFPC0.DIV.EXCT\(4),
datab => \GRFPC0.R.FSR.AEXC\(4),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
\GRFPC0_WRDATA_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(0),
dataa => N_423,
datab => N_424,
datac => N_431,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(0));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(1),
dataa => \GRFPC0.DIV.EXCT\(1),
datab => \GRFPC0.R.FSR.AEXC\(1),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
\GRFPC0_OP2_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(50),
dataa => \GRFPC0.WR2.RREG.RES\(50),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_50__G3\);
\GRFPC0_OP2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(1),
dataa => \GRFPC0.OP2_6\(1),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(1));
\GRFPC0_OP2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(21),
dataa => \GRFPC0.OP2_6\(21),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(21));
\GRFPC0_OP2_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(59),
dataa => \GRFPC0.WR2.RREG.RES\(59),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_59__G3\);
\GRFPC0_OP2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(29),
dataa => \GRFPC0.OP2_6\(29),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(29));
\GRFPC0_OP2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(30),
dataa => \GRFPC0.OP2_6\(30),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(30));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(1),
dataa => N_105,
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15_A\(1),
dataa => N_104,
datab => N_105,
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15\(0),
dataa => N_105,
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_15_A\(0),
dataa => N_104,
datab => N_105,
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13\(0));
\GRFPC0_OP2_1_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(56),
dataa => \GRFPC0.WR2.RREG.RES\(56),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_56__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(56),
dataa => \GRFPC0.WR2.RREG.RES\(56),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_56__G3\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_A5_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5_0_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_3_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_0\(7),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5\(1),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\);
GRFPC0_FP_PIPELINE_8_REGDEPX2_250_1_M6_I_0_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_0\,
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_2_0_A2_I_O3\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2_2_I_O3_I_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1));
\GRFPC0_EX_RREG_EXCT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(0),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPC0.DIV.EXCT_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(0),
dataa => N_391,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPU0_GRFPU_X0_COMB_VEXC_5_IV_0_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datac => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_R_FSR_CEXC_RNO_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(0),
dataa => \GRFPC0.WR2.RREG.EXCT\(0),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.EXCT_0_0_0__G3\,
datad => \GRFPC0.V.FSR.CEXC_5_SQMUXA\);
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_O3_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0));
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_O3_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0));
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_O3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_3\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O3_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_O3_6\,
dataa => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\);
GRFPC0_FP_PIPELINE_2_STDEP_88_SEL0_0_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_88_SEL0_0_I_A4\,
dataa => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_9\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\);
GRFPC0_UN1_STDEP1222: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000010110000")
port map (
combout => \GRFPC0.UN1_STDEP1222\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2352_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_9_STDEP_394_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_394_0_IV_I_A2\(0),
dataa => N_175,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_1_0_X\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_0\(0),
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_O2_0\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPC0_D_LDLCK_RNO_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G3\,
dataa => N_80,
datab => N_79,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX_1_I_O4_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(6));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_274_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_274_0_A4\(0),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_1_I_O2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_272_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_272_IV_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_7_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_7\(9),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_1\(8),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(20),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0_X\(21));
GRFPC0_FP_PIPELINE_0_STDEP_12_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2_0_O2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\(12),
dataa => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_A4_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_3\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\);
\GRFPC0_D_STLCK_RNO_4_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_1\(1),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_9_0_A2\(0),
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_1_RNIOO9J4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_A3_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL0_0_1_1_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_0_1_1_O4\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\);
\GRFPC0_WRDATA_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(28),
dataa => N_423,
datab => N_424,
datac => N_459,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(28));
\GRFPC0_WRDATA_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(20),
dataa => N_423,
datab => N_424,
datac => N_451,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(20));
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPC0_LDLOCK_1_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_15\,
dataa => N_105,
datab => \GRFPC0.LDLOCK_1_6\,
datac => \GRFPC0.LDLOCK_1_3\,
datad => \GRFPC0.LDLOCK_1_15_A\);
GRFPC0_LDLOCK_1_15_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_15_A\,
dataa => N_104,
datab => N_105,
datac => \GRFPC0.LDLOCK_1_10\,
datad => \GRFPC0.LDLOCK_1_13\);
GRFPC0_LDLOCK_1_30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_30\,
dataa => N_105,
datab => \GRFPC0.LDLOCK_1_21\,
datac => \GRFPC0.LDLOCK_1_18\,
datad => \GRFPC0.LDLOCK_1_30_A\);
GRFPC0_LDLOCK_1_30_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_30_A\,
dataa => N_104,
datab => N_105,
datac => \GRFPC0.LDLOCK_1_25\,
datad => \GRFPC0.LDLOCK_1_28\);
\GRFPC0_FP_PIPELINE_14_STDEP_580_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_580_0\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(31),
dataa => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(31),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\(31));
\GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(0));
\GRFPC0_WRDATA_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(14),
dataa => N_423,
datab => N_424,
datac => N_445,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(14));
\GRFPC0_WRDATA_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(6),
dataa => N_423,
datab => N_424,
datac => N_437,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(6));
GRFPC0_V_FSR_CEXC_4_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_V_FSR_CEXC_4_SQMUXA_RNIC9A71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010101010101")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M4_0\,
dataa => N_3,
datab => \GRFPC0.R.FSR.RD_0_0_0__G1_E_X\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
dataa => \GRFPC0.DIV.INST\(6),
datab => \GRFPC0.WR2.CTRL.PC\(6),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
dataa => \GRFPC0.DIV.INST\(12),
datab => \GRFPC0.WR2.CTRL.PC\(12),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_0_STDEP_8_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_8_3_0_O2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\);
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_4\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\(1),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14\(2),
datac => \GRFPC0.V.STDATA_14_I_M_6\(0),
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\);
GRFPC0_FP_PIPELINE_5_STDEP_212_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\);
GRFPC0_FP_PIPELINE_5_STDEP_212_SEL0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_212_SEL0_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_2\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(25),
dataa => \GRFPC0.EX.CTRL.PC\(25),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(25));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_23_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_23_IV\(1),
dataa => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14\(2),
datac => \GRFPC0.V.STDATA_14_I_M_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_0_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_22_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_22_IV\(1),
dataa => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.V.STDATA_14\(15),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11_0\(1),
datad => \GRFPC0.V.STDATA_14_I_M_4\(14));
GRFPC0_FP_PIPELINE_1_UN1_VEX_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD\,
dataa => \GRFPC0.RFA.RD\(0),
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.FP_PIPELINE.RS2_1_X\(0));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNIT5VC2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_M3\,
dataa => \GRFPC0.V.STDATA_14\(10),
datab => \GRFPC0.V.STDATA_14_REP1\(11),
datac => \GRFPC0.V.STDATA_14_REP0\(6),
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(31),
dataa => \GRFPC0.WR.RREG.RES\(31),
datab => \GRFPC0.DIV.RESULT_0_0_31__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(36),
dataa => \GRFPC0.WR.RREG.RES\(36),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_WRDATA_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(25),
dataa => N_423,
datab => N_424,
datac => N_456,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(25));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(57),
dataa => \GRFPC0.WR.RREG.RES\(57),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(9),
dataa => \GRFPC0.OP2_6\(9),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(9));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(9),
dataa => \GRFPC0.WR.RREG.RES\(9),
datab => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(9),
dataa => N_400,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(9),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(15),
dataa => \GRFPC0.WR.RREG.RES\(15),
datab => \GRFPC0.DIV.RESULT_0_0_15__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(15),
dataa => N_406,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(15),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_OP2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(15),
dataa => \GRFPC0.OP2_6\(15),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(15));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(16),
dataa => \GRFPC0.WR.RREG.RES\(16),
datab => \GRFPC0.DIV.RESULT_0_0_16__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_WRDATA_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(17),
dataa => N_423,
datab => N_424,
datac => N_448,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(17));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(49),
dataa => \GRFPC0.WR.RREG.RES\(49),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(60),
dataa => \GRFPC0.WR.RREG.RES\(60),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(60));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(61),
dataa => \GRFPC0.WR.RREG.RES\(61),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(61));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A3_1\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(10),
dataa => \GRFPC0.WR.RREG.RES\(10),
datab => \GRFPC0.DIV.RESULT_0_0_10__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(10),
dataa => \GRFPC0.OP2_6\(10),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(10));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(10),
dataa => N_401,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(19),
dataa => N_410,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(19),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(35),
dataa => \GRFPC0.WR.RREG.RES\(35),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(37),
dataa => \GRFPC0.WR.RREG.RES\(37),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_WRDATA_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(7),
dataa => N_423,
datab => N_424,
datac => N_438,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(7));
\GRFPC0_OP2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(7),
dataa => \GRFPC0.OP2_6\(7),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(7));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(39),
dataa => \GRFPC0.WR.RREG.RES\(39),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_WRDATA_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(11),
dataa => N_423,
datab => N_424,
datac => N_442,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(11));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(11),
dataa => \GRFPC0.WR.RREG.RES\(11),
datab => \GRFPC0.DIV.RESULT_0_0_11__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(11),
dataa => \GRFPC0.OP2_6\(11),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(11));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(11),
dataa => N_402,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_OP2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(28),
dataa => \GRFPC0.OP2_6\(28),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(28));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(28),
dataa => \GRFPC0.WR.RREG.RES\(28),
datab => \GRFPC0.DIV.RESULT_0_0_28__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(16),
dataa => \GRFPC0.OP2_6\(16),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(16));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(28),
dataa => N_419,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(28),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(16),
dataa => N_407,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(16),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(33),
dataa => \GRFPC0.WR.RREG.RES\(33),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(8),
dataa => \GRFPC0.WR.RREG.RES\(8),
datab => \GRFPC0.DIV.RESULT_0_0_8__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(8),
dataa => \GRFPC0.OP2_6\(8),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(8));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(18),
dataa => \GRFPC0.WR.RREG.RES\(18),
datab => \GRFPC0.DIV.RESULT_0_0_18__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(18),
dataa => \GRFPC0.OP2_6\(18),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(18));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(18),
dataa => N_409,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(18),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(4),
dataa => \GRFPC0.WR.RREG.RES\(4),
datab => \GRFPC0.DIV.RESULT_0_0_4__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(4),
dataa => \GRFPC0.OP2_6\(4),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(4));
\GRFPC0_OP2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(14),
dataa => \GRFPC0.OP2_6\(14),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(14));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(14),
dataa => \GRFPC0.WR.RREG.RES\(14),
datab => \GRFPC0.DIV.RESULT_0_0_14__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(14),
dataa => N_405,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(14),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_22_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_22_IV_0\(1),
dataa => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.V.STDATA_14\(15),
datac => \GRFPC0.V.STDATA_14_I_M_4\(14),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(2),
dataa => \GRFPC0.WR.RREG.RES\(2),
datab => \GRFPC0.DIV.RESULT_0_0_2__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(2),
dataa => \GRFPC0.OP2_6\(2),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(2));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(6),
dataa => \GRFPC0.WR.RREG.RES\(6),
datab => \GRFPC0.DIV.RESULT_0_0_6__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(6),
dataa => N_397,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(6),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_OP2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(6),
dataa => \GRFPC0.OP2_6\(6),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(6));
\GRFPC0_EX_RREG_EXCT_0_0_2__G4\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110001010000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\,
dataa => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datac => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(20),
dataa => \GRFPC0.WR.RREG.RES\(20),
datab => \GRFPC0.DIV.RESULT_0_0_20__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(20),
dataa => \GRFPC0.OP2_6\(20),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(20));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(20),
dataa => N_411,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(20),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FIFO_INST_1_RNI84VN3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN4931_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\(0),
dataa => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_350_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_350\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_1_I_M_2\(25));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(43),
dataa => \GRFPC0.WR.RREG.RES\(43),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(43));
\GRFPC0_OP1_0_IV_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101000000")
port map (
combout => \GRFPC0.RFO1_I_M_0\(11),
dataa => N_638,
datab => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_0_SQMUXA_REP1\);
\GRFPC0_OP2_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_I_M2\(5),
dataa => \GRFPC0.OP2_6_I_M2\(5),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5_I_M2\(5));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(5),
dataa => \GRFPC0.WR.RREG.RES\(5),
datab => \GRFPC0.DIV.RESULT_0_0_5__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(5),
dataa => N_396,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(5),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(46),
dataa => \GRFPC0.WR.RREG.RES\(46),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP1_0_IV_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101000000")
port map (
combout => \GRFPC0.RFO1_I_M_0\(14),
dataa => N_641,
datab => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_0_SQMUXA_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(62),
dataa => \GRFPC0.WR2.RREG.RES\(62),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_62__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(30),
dataa => \GRFPC0.WR.RREG.RES\(30),
datab => \GRFPC0.DIV.RESULT_0_0_30__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(29),
dataa => \GRFPC0.WR.RREG.RES\(29),
datab => \GRFPC0.DIV.RESULT_0_0_29__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_WRDATA_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(26),
dataa => N_423,
datab => N_424,
datac => N_457,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(26));
\GRFPC0_OP2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(26),
dataa => \GRFPC0.OP2_6\(26),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(26));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(26),
dataa => \GRFPC0.WR.RREG.RES\(26),
datab => \GRFPC0.DIV.RESULT_0_0_26__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(26),
dataa => N_417,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(26),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(25),
dataa => \GRFPC0.WR.RREG.RES\(25),
datab => \GRFPC0.DIV.RESULT_0_0_25__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(24),
dataa => \GRFPC0.OP2_6\(24),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(24));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(24),
dataa => \GRFPC0.WR.RREG.RES\(24),
datab => \GRFPC0.DIV.RESULT_0_0_24__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(23),
dataa => \GRFPC0.OP2_6\(23),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(23));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(23),
dataa => \GRFPC0.WR.RREG.RES\(23),
datab => \GRFPC0.DIV.RESULT_0_0_23__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_WRDATA_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(23),
dataa => N_423,
datab => N_424,
datac => N_454,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(23));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(23),
dataa => N_414,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(23),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(53),
dataa => \GRFPC0.WR2.RREG.RES\(53),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_53__G3\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(53),
dataa => \GRFPC0.WR.RREG.RES\(53),
datab => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(53),
dataa => \GRFPC0.WR2.RREG.RES\(53),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_53__G3\);
\GRFPC0_WRDATA_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(19),
dataa => N_423,
datab => N_424,
datac => N_450,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(19));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(51),
dataa => \GRFPC0.WR.RREG.RES\(51),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(17),
dataa => \GRFPC0.OP2_6\(17),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(17));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(17),
dataa => \GRFPC0.WR.RREG.RES\(17),
datab => \GRFPC0.DIV.RESULT_0_0_17__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(17),
dataa => N_408,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(17),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_WRDATA_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(29),
dataa => N_423,
datab => N_424,
datac => N_460,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(29));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(48),
dataa => \GRFPC0.WR.RREG.RES\(48),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_WRDATA_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(16),
dataa => N_423,
datab => N_424,
datac => N_447,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(16));
\GRFPC0_OP2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(12),
dataa => \GRFPC0.OP2_6\(12),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(12));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(12),
dataa => \GRFPC0.WR.RREG.RES\(12),
datab => \GRFPC0.DIV.RESULT_0_0_12__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(12),
dataa => N_403,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(12),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_OP2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(0),
dataa => \GRFPC0.OP2_6\(0),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(0));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(0),
dataa => \GRFPC0.WR.RREG.RES\(0),
datab => \GRFPC0.DIV.RESULT_0_0_0__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(7),
dataa => \GRFPC0.WR.RREG.RES\(7),
datab => \GRFPC0.DIV.RESULT_0_0_7__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(7),
dataa => N_398,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(7),
datad => \GRFPC0.WR.CTRL.RDD_REP3\);
\GRFPC0_OP2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(3),
dataa => \GRFPC0.OP2_6\(3),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(3));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(3),
dataa => \GRFPC0.WR.RREG.RES\(3),
datab => \GRFPC0.DIV.RESULT_0_0_3__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_WRDATA_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(4),
dataa => N_423,
datab => N_424,
datac => N_435,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(4));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(27),
dataa => \GRFPC0.WR.RREG.RES\(27),
datab => \GRFPC0.DIV.RESULT_0_0_27__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(27),
dataa => \GRFPC0.OP2_6\(27),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(27));
\GRFPC0_WRDATA_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(10),
dataa => N_423,
datab => N_424,
datac => N_441,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(10));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(42),
dataa => \GRFPC0.WR.RREG.RES\(42),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(38),
dataa => \GRFPC0.WR.RREG.RES\(38),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.WR2.CTRL.PC\(2),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
dataa => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.WR2.CTRL.PC\(17),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3_REP1\);
\GRFPC0_OP2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(22),
dataa => \GRFPC0.OP2_6\(22),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(22));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(19),
dataa => \GRFPC0.WR.RREG.RES\(19),
datab => \GRFPC0.DIV.RESULT_0_0_19__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_OP2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(19),
dataa => \GRFPC0.OP2_6\(19),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(19));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2_I_M2\(13),
dataa => N_404,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(13),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1_I_M2\(13),
dataa => \GRFPC0.WR.RREG.RES\(13),
datab => \GRFPC0.DIV.RESULT_0_0_13__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
\GRFPC0_OP2_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_I_M2\(13),
dataa => \GRFPC0.OP2_I_M3\(13),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_I_M3_0\(13));
\GRFPC0_WRDATA_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(13),
dataa => N_423,
datab => N_424,
datac => N_444,
datad => \GRFPC0.WRDATA_I_M3_X\(13));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1_I_M2\(45),
dataa => \GRFPC0.WR.RREG.RES\(45),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\);
GRFPC0_FP_PIPELINE_8_STDEP_336_SEL0_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL0_0_I_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4666_DEP_2\,
datac => \GRFPC0.N_19067_1_I_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0));
GRFPC0_FP_PIPELINE_5_STDEP_216_SEL0_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL0_0_I_O2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\);
GRFPC0_FP_PIPELINE_5_STDEP_216_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_0\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\);
GRFPC0_FP_PIPELINE_2_STDEP_96_SEL0_0_I_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_96_SEL0_0_I_A4\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_208_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\);
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_26_0_A2_0_A2_0_A2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_0_A2_0_A2_I\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_VWR2_CTRL_RDD_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001101")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2\,
dataa => \GRFPC0.WR.CTRL.LD\,
datab => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN1_CPI_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_12\,
dataa => N_39,
datab => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => CPO_EXCZ);
GRFPC0_FP_PIPELINE_6_STDEP_252_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100001101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_2\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_107_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A3_3\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\);
\GRFPC0_FP_PIPELINE_6_STDEP_256_3_0_O3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A3_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_0_1\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_3_1\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_O3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_O3_0\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_3\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\);
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL0_0_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110100")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\);
\GRFPC0_D_STLCK_RNO_6_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_2\(0),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\);
\GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_DEP_2_IV_I_A2_RNICOGA4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_A2_7\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_1_I_M_2\(25));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_2_0_O2_RNI7S884: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_158_I_M_I_A3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_O3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_O3_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\(31));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_2_X_RNI6NO81: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_3_5\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.STDDEP_0_SQMUXA_14_I_0\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_O2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_O2_3\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\(1),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
dataa => \GRFPC0.DIV.INST\(7),
datab => \GRFPC0.WR2.CTRL.PC\(7),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
dataa => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.WR2.CTRL.PC\(15),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_1_0_A2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2886_REGDEPX2_0_A3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\);
\GRFPC0_FIFO_INST_1_RNI7G2I1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_A4\,
dataa => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_M2\);
\GRFPC0_D_STLCK_RNO_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_0\(1),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_1_I_M_2\(25));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_92_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_92_IV\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_WRDATA_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(8),
dataa => N_423,
datab => N_424,
datac => N_439,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(8));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(40),
dataa => \GRFPC0.WR.RREG.RES\(40),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP1\);
\GRFPC0_OP2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(25),
dataa => \GRFPC0.OP2_6\(25),
datab => \GRFPC0.OP2_SN_M8\,
datac => \GRFPC0.OP2_5\(25));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(22),
dataa => N_413,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(22),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(22),
dataa => \GRFPC0.WR.RREG.RES\(22),
datab => \GRFPC0.DIV.RESULT_0_0_22__G3\,
datac => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X\);
\GRFPC0_WRDATA_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI2_WRDATAZ(22),
dataa => N_423,
datab => N_424,
datac => N_453,
datad => \GRFPC0.FP_PIPELINE.WRDATA_6_X\(22));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(54),
dataa => \GRFPC0.WR.RREG.RES\(54),
datab => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1_I_O2_X_REP2\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(54));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2\(0),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_V_STDATA_14_RNIC4021_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5003_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2_0\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_O2_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_6_2\(0),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_7\(0));
GRFPC0_FP_PIPELINE_1_UN1_WR2_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(0),
datac => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.INST_I_M2\(0));
GRFPC0_FP_PIPELINE_1_UN1_WR_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(0),
datac => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.INST_I_M2\(0));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(0),
datac => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.INST_I_M2\(0));
GRFPC0_FP_PIPELINE_1_UN1_EX_CTRL_RD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111010110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_EX.CTRL.RD\,
dataa => N_38,
datab => \GRFPC0.RFA.RS2\(0),
datac => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.INST_I_M2\(0));
GRFPC0_FP_PIPELINE_4_STDEP682: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP682\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\);
GRFPC0_FP_PIPELINE_4_STDEP683: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP683\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\);
GRFPC0_FP_PIPELINE_5_STDEP851_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP851_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP\);
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_254_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001110")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.UN1_FIFO.INST_0_9\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
dataa => \GRFPC0.WR2.CTRL.PC\(3),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
dataa => \GRFPC0.DIV.INST\(5),
datab => \GRFPC0.WR2.CTRL.PC\(5),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(10),
dataa => \GRFPC0.DIV.INST\(10),
datab => \GRFPC0.WR2.CTRL.PC\(10),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(31),
dataa => \GRFPC0.DIV.INST\(31),
datab => \GRFPC0.WR2.CTRL.PC\(31),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
dataa => \GRFPC0.DIV.INST\(8),
datab => \GRFPC0.WR2.CTRL.PC\(8),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
dataa => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.WR2.CTRL.PC\(18),
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.VDIV.PEND_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_6\(0),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
datad => \GRFPC0.STDDEP_0_SQMUXA_88_I_I_A2_I\);
\GRFPC0_D_STLCK_RNO_5_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G3\,
dataa => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_6_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2\(1),
dataa => N_175,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_1_0_X\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17_X\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13_1_I_O4_X_RNI4QPA1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\(0),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\);
\GRFPC0_FP_PIPELINE_8_STDEP_358_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358\(1),
dataa => N_241,
datab => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_0\,
datac => \GRFPC0.EX.CTRL.RDD_REP3\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_8_STDEP_358_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_0_IV_I_A2\(0),
dataa => N_241,
datab => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_0\,
datac => \GRFPC0.EX.CTRL.RDD_REP3\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_2_X_RNIJP3S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_3\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.CPI_I_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_2_X_RNI9J921: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_1\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_42_0_IV_I_A2_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.FIFO.INST_1_M_2\(25));
GRFPC0_VDIV_EXC_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.VDIV.EXC_0_SQMUXA\,
dataa => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\);
GRFPC0_VDIV_EXC_1_SQMUXA_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.VDIV.EXC_1_SQMUXA_0_O2\,
dataa => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\);
GRFPC0_UN1_WR2_EXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110100")
port map (
combout => \GRFPC0.UN1_WR2.EXC\,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.WR2.CTRL.PEND\,
datac => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\);
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_20_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_20_IV\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_UN1_FIFO_INST_0_16_I_I2_I_A2_RNIEUUI: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_7\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.UN1_FIFO.INST_0_16_I_I2_I_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_4\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.UN1_FIFO.INST_0_16_I_I2_I_A2\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3944_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
GRFPC0_FP_PIPELINE_UN24_OP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN24_OP\,
dataa => N_99,
datab => N_101,
datac => \GRFPC0.FP_PIPELINE.UN6_OP3_0_X\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK27_X\);
GRFPC0_MEM_CTRL_LD_RNIM7QD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001001100")
port map (
combout => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I_1\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.MEM.CTRL.LD\,
datad => CPO_EXCZ);
\GRFPC0_FID_1_IV_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FID_1_IV_0_A3\(0),
dataa => N_39,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_FID_1_IV_0_A3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FID_1_IV_0_A3_3\(0),
dataa => N_39,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_FP_PIPELINE_13_0_STDEP_545_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_0_IV_I_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_I_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.CPI_M_1_X\(64),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\);
GRFPC0_WR_CTRL_LD_RNI73NN7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010001000")
port map (
combout => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2_3\,
dataa => N_3,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNICI4L7_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.MEM.CTRL.INST_0_0_0__G2_I\,
dataa => N_38,
datab => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN27_PENDEXC_RNI9QA18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.DIV.INST_0_0_0__G2_I\,
dataa => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
datab => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_UN1_CPI_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_13\,
dataa => N_39,
datab => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datad => CPO_EXCZ);
GRFPC0_RFAREG_R_STATE_4_M2S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001100")
port map (
combout => \GRFPC0.RFAREG.R.STATE_4_M2S2\,
dataa => N_40,
datab => \GRFPC0.DIV.PEND_1_0_G1_0_I_A5_0\,
datac => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0));
GRFPC0_FP_PIPELINE_15_STDEP_612_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\);
\GRFPC0_D_STLCK_RNO_8_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_3\(1),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP_0_A2\,
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_D_STLCK_RNO_10_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G3\,
dataa => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11_1_X_RNIKNC51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_7\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_2\(0),
dataa => \GRFPC0.CPI_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A2_0\(0),
dataa => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2_0\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_7_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_5\(1),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.RFA.RDD\);
GRFPC0_FP_PIPELINE_10_STDEP_412_SEL1_I_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL1_I_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\);
\GRFPC0_FP_PIPELINE_5_STDEP_208_3_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_208_3_0_O2_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\);
GRFPC0_FP_PIPELINE_4_STDEP_172_SEL0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\);
GRFPC0_FP_PIPELINE_4_STDEP_172_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\);
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\);
GRFPC0_FP_PIPELINE_FCC_VALID_9_I_M4_I_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_I_M2\,
dataa => \GRFPC0.MEM.CTRL.CCWR\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_0\);
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_O2_0\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_0\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL0_0_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\);
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL1_I_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_2\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_4\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\,
datac => \GRFPC0.N_19067_1_I_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\);
\GRFPC0_FP_PIPELINE_13_STDEP_540_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_540_0\(1),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_13_STDEP_528_SEL1_I_0_A2_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL1_I_0_A2_I_O2\,
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0_0\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3974_DEP_2\);
GRFPC0_FP_PIPELINE_13_STDEP_528_SEL0_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528_SEL0_0_I_O2\,
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\,
datac => \GRFPC0.N_19067_1_I_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\,
datad => \GRFPC0.N_19067_1_I_I_O2\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_O2_0_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_O2_0_I_A2\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(1),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(7),
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV_0\(7),
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(42),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(42),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(37));
GRFPU0_GRFPU_X0_COMB_SHV2LTO3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO3\,
dataa => \GRFPU0.GRFPU_X0.C_ADD3\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.SHV2LT2\);
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_O2_1\,
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD9\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_A\(1),
datad => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O4_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000101110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_A\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD9\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(20),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(20),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(39),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(35));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_3_0_A2_0\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_10_RNI5TEE4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010111110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(32),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(32),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(56),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2\(55),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(51),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_O4_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(46),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(46),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(46),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_O4_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O4_0\(48),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(49),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(49),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(36));
\GRFPU0_GRFPU_X0_BCO_MSB_3_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000100")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(15),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(16),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(18));
GRFPU0_GRFPU_X0_COMB_RNDOP19_0_O3_RNIF1VA1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.STATE_1_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M4_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(19));
\GRFPU0_GRFPU_X0_BCO_MSB_2_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001110")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7));
\GRFPU0_GRFPU_X0_L1_4_1_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(4),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(3));
GRFPU0_GRFPU_X0_VITER_EXP_1_SQMUXA_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_2\);
GRFPU0_GRFPU_X0_VITER_EXP_1_SQMUXA_1_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(33),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(15),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(27),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(27));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_0_A2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_A2\(50),
dataa => \GRFPU0.GRFPU_X0.G_53_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_O3\(50));
GRFPU0_GRFPU_X0_COMB_RNDOP19_0_O3_RNIF1VA1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\);
GRFPU0_GRFPU_X0_VST3_INF_1_SQMUXA_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100110010")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.INF_1_SQMUXA_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101010101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_5\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M2_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_O6_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001100")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_O6\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M2\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_4\(1),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.RDD_REP2\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_0_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_A2_2\(62),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datab => \GRFPU0.GRFPU_X0.COMB.EXP57_0_O2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(31),
dataa => \GRFPC0.EX.CTRL.PC\(31),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(27),
dataa => \GRFPC0.EX.CTRL.PC\(27),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(26),
dataa => \GRFPC0.EX.CTRL.PC\(26),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(20),
dataa => \GRFPC0.EX.CTRL.PC\(20),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(20),
datac => \GRFPC0.V.STDATA_0_SQMUXA_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(18),
dataa => \GRFPC0.EX.CTRL.PC\(18),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(16),
dataa => \GRFPC0.EX.CTRL.PC\(16),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(15),
dataa => \GRFPC0.EX.CTRL.PC\(15),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(14),
dataa => \GRFPC0.EX.CTRL.PC\(14),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(8),
dataa => \GRFPC0.EX.CTRL.PC\(8),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(4),
dataa => \GRFPC0.EX.CTRL.PC\(4),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(3),
dataa => \GRFPC0.EX.CTRL.PC\(3),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(3));
\GRFPU0_GRFPU_X0_VST3_REG_37_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_34\);
\GRFPU0_GRFPU_X0_VST3_REG_37_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_9\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_31_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD2\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(3));
\GRFPU0_GRFPU_X0_L1_4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_5_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_1_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_3\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_1_2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN93_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN98_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_5_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(57),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(57),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(54),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(52),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(55),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_M4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M4\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(15));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_M3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010001000111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.LOB\,
datac => \GRFPU0.MULO.MRES\(69),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3_A\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_M3_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100111001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_M3_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(35));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(40));
\GRFPU0_GRFPU_X0_L1_0_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_3_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_1_3_0\(0),
datad => \GRFPU0.GRFPU_X0.UN208_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_1_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_4\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_3_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_1_3_0\(0),
datad => \GRFPU0.GRFPU_X0.UN213_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_2_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_3_0\(0),
datad => \GRFPU0.GRFPU_X0.UN218_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_3\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_2_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_3_1_2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(57),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M2\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(42));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M12_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G2\);
\GRFPU0_DIVROM0_DATA_1_MUX_15_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_6\(0),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_3\(0),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_15_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_10\(0),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_13\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_13\(1),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_10\(1),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_15_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_3\(1),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_6\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_15_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011111010")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_3\(3),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_6\(3),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(3));
\GRFPU0_DIVROM0_DATA_1_MUX_15_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100101011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_13\(3),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_10\(3));
\GRFPU0_DIVROM0_DATA_1_MUX_15_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_14\(4),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_7\(4));
\GRFPU0_DIVROM0_DATA_1_MUX_15_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_14\(5),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_7\(5));
\GRFPU0_GRFPU_X0_ST3_REG_RNIVA7D1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI1C081_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_RNIVVNM_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_RNISBOM_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001001010010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(56),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNIGPQ51_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
GRFPU0_GRFPU_X0_COMB_VST3_REG46_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_6_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_5\);
\GRFPC0_EX_CTRL_VCNT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001100010011000")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
dataa => \GRFPC0.FP_PIPELINE.UN4_CNTX\(0),
datab => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datac => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2));
\GRFPC0_EX_CTRL_VCNT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
dataa => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datab => \GRFPC0.FP_PIPELINE.UN4_CNTX\(0),
datac => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(6),
dataa => \GRFPC0.EX.CTRL.PC\(6),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(2),
dataa => \GRFPC0.EX.CTRL.PC\(2),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(12),
dataa => \GRFPC0.EX.CTRL.PC\(12),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(12));
\GRFPC0_R_STDATA_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.R.STDATA_0_0_1__G2\,
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(1),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\);
\GRFPC0_R_STDATA_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.R.STDATA_0_0_0__G2\,
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(0),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(11),
dataa => \GRFPC0.EX.CTRL.PC\(11),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(13),
dataa => \GRFPC0.EX.CTRL.PC\(13),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(19),
dataa => \GRFPC0.EX.CTRL.PC\(19),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(21),
dataa => \GRFPC0.EX.CTRL.PC\(21),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(21));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4\(0),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A2_1_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(53),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(60),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_REP2\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(29));
\GRFPU0_GRFPU_X0_L1_2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010001011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_6\(0),
dataa => \GRFPU0.GRFPU_X0.L1_2_1_2_0\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_1_2_I_1\(1),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_6_I\(0),
datad => \GRFPU0.GRFPU_X0.UN83_BCO_LSB_0_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(50),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(50),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_A2_4_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2_4\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(40));
\GRFPU0_GRFPU_X0_L1_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_3_1_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\);
\GRFPU0_GRFPU_X0_L1_2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(58),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(59));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(4),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(3),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNILC781_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(12),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_O2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2_0\(21),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_0\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_1\(16));
\GRFPU0_GRFPU_X0_L1_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_3\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_0_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN88_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_3_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN103_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0_I_M2\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(18));
\GRFPU0_GRFPU_X0_L1_5_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111110001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_4\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datac => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_I\(1));
\GRFPU0_GRFPU_X0_L1_4_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(1),
dataa => \GRFPU0.GRFPU_X0.L1_4_1_3_I_1\(1),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_4_I_0\(1),
datac => \GRFPU0.GRFPU_X0.L1_4_3_1\(3),
datad => \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\);
GRFPU0_GRFPU_X0_COMB_VCS_ITER_1_I_M3_RNI585O: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.COMB.VCS_ITER_1_I_M3\);
\GRFPU0_GRFPU_X0_L1_5_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_1_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
dataa => \GRFPU0.GRFPU_X0.L1_5_1_0\(3),
datab => \GRFPU0.GRFPU_X0.L1_2_1_2_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_4_1\(3));
\GRFPU0_GRFPU_X0_L3_1_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_2\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datab => \GRFPU0.GRFPU_X0.UN33_BCO_LSB_0_0_A2\,
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4));
\GRFPU0_GRFPU_X0_L2_0_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(2),
dataa => \GRFPU0.GRFPU_X0.UN2_BCO_LSB_2\,
datab => \GRFPU0.GRFPU_X0.L1_0_1_5_I_1\(1),
datac => \GRFPU0.GRFPU_X0.UN8_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_0_10\(3));
\GRFPU0_GRFPU_X0_L1_6_1_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(19),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M2\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(30),
dataa => \GRFPC0.EX.CTRL.PC\(30),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(30),
datac => \GRFPC0.V.STDATA_0_SQMUXA_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(23),
dataa => \GRFPC0.EX.CTRL.PC\(23),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(29),
dataa => \GRFPC0.EX.CTRL.PC\(29),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(47));
\GRFPU0_GRFPU_X0_L1_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\);
\GRFPU0_GRFPU_X0_L1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datab => \GRFPU0.GRFPU_X0.L1_0_1_1_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_1_2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\);
\GRFPU0_GRFPU_X0_L3_0_3_I_S_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_I_S\(3),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_3_0_O2\(2),
datac => \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\,
datad => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\);
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_1_RNIKQ9S_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_I_I_A2\(4),
dataa => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_3_0_O2\(2),
datac => \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\,
datad => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(47),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(47),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_DIVROM0_DATA_1_MUX_15_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_13\(2),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_10\(2),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_15_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011001010111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_15_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_6\(2),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_3\(2));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G2\);
\GRFPU0_GRFPU_X0_VST3_REG_37_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(28),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_13\);
\GRFPU0_GRFPU_X0_VST3_REG_37_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_36\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\);
\GRFPU0_GRFPU_X0_VST2_EXC_13_I_M_0_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.UN1_ST1.FLTYPE2_65\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4),
dataa => \GRFPU0.GRFPU_X0.L1_1\(3),
datab => \GRFPU0.GRFPU_X0.L1_4\(3));
\GRFPU0_GRFPU_X0_L2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_3\(1),
datab => \GRFPU0.GRFPU_X0.L1_2_2\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_A2\(3));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(1),
dataa => \GRFPU0.GRFPU_X0.L1_5\(1),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(1),
datac => \GRFPU0.GRFPU_X0.L1_4\(3));
\GRFPU0_GRFPU_X0_L1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_2_I_I_A2\(1),
datad => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0_A2\);
\GRFPU0_GRFPU_X0_L4_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L3_1\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L2_0_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_4\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_4\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_4\(3));
\GRFPU0_GRFPU_X0_L2_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_2\(1),
dataa => \GRFPU0.GRFPU_X0.L1_2_3\(1),
datab => \GRFPU0.GRFPU_X0.L1_3_3\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3));
\GRFPU0_GRFPU_X0_L1_4_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_5_2_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_1_2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(1),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(1),
datab => \GRFPU0.GRFPU_X0.L1_4_3\(1),
datac => \GRFPU0.GRFPU_X0.L1_4_2\(3));
\GRFPU0_GRFPU_X0_L1_5_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_2_0_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_1_2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
dataa => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.L1_4_2\(3));
\GRFPU0_GRFPU_X0_L2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_3_2\(1),
datab => \GRFPU0.GRFPU_X0.L1_2\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_0\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(5),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_10_0\(1),
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2_0_A2_0_A2_1_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(45),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(45),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(5),
dataa => \GRFPC0.EX.CTRL.PC\(5),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(9),
dataa => \GRFPC0.EX.CTRL.PC\(9),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(22),
dataa => \GRFPC0.EX.CTRL.PC\(22),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(22),
datac => \GRFPC0.V.STDATA_0_SQMUXA_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(10),
dataa => \GRFPC0.EX.CTRL.PC\(10),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(24),
dataa => \GRFPC0.EX.CTRL.PC\(24),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(7),
dataa => \GRFPC0.EX.CTRL.PC\(7),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(7));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110001010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(9),
datac => \GRFPC0.V.STDATA_14\(7),
datad => \GRFPC0.V.STDATA_14\(12));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_O3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001001000110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_O3_2\,
dataa => \GRFPC0.V.STDATA_14\(7),
datab => \GRFPC0.V.STDATA_14\(8),
datac => \GRFPC0.V.STDATA_14\(5),
datad => \GRFPC0.V.STDATA_14_REP1\(6));
\GRFPU0_GRFPU_X0_L1_0_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110000000101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_7\(1),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(30),
datab => \GRFPU0.GRFPU_X0.L1_0_0_2\(3),
datac => \GRFPU0.GRFPU_X0.UN243_BCO_LSB_1\,
datad => \GRFPU0.GRFPU_X0.UN243_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(1),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(7),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(6),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_I\(1),
datad => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_1\,
datac => \GRFPU0.GRFPU_X0.L1_4_6_A\(1),
datad => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_6_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_3_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_4\(0),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4_0\(0),
datac => \GRFPU0.GRFPU_X0.L1_3_1_4_0\(0),
datad => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.L1_3_4_A\(1),
datac => \GRFPU0.GRFPU_X0.L1_3_1_4_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_4_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_4_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M3\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(2));
\GRFPU0_GRFPU_X0_REST_2_RNIU3EH_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.REST_2\(5));
GRFPU0_GRFPU_X0_ST1_V_RNIPV661_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.REST_2\(5));
\GRFPU0_GRFPU_X0_REST_2_RNIU3EH_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.REST_2\(5));
GRFPU0_GRFPU_X0_COMB_VST2_ADD2_RNI9JE8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\);
GRFPU0_GRFPU_X0_COMB_VST2_QSNAN12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.QSNAN12\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_I_O3\);
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.REST_1_2\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(39));
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0_A4_0\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\);
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I_X2_RNID5SK1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101100001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(22),
dataa => \GRFPC0.RFA2.FLUSH\,
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000011111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_A2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.EXPT_0\(0),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD11\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18LT10\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3\);
\GRFPU0_GRFPU_X0_L4_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_2\(2),
datab => \GRFPU0.GRFPU_X0.L3_0_1\(2),
datac => \GRFPU0.GRFPU_X0.L3_0\(5));
\GRFPU0_GRFPU_X0_L2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_3\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_3\(1),
datac => \GRFPU0.GRFPU_X0.L1_0\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(6),
dataa => \GRFPU0.MULO.MRES\(66),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(1),
dataa => \GRFPU0.GRFPU_X0.L1_4\(1),
datab => \GRFPU0.GRFPU_X0.L1_5_2\(1),
datac => \GRFPU0.GRFPU_X0.L1_4_1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datab => NN_2,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(6),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(2),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M34_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M30_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M26_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G2\);
\GRFPU0_GRFPU_X0_L1_1_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_5\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_1_4_I_1\(1),
datab => \GRFPU0.GRFPU_X0.L2_0_4_2\(4),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN8_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(1),
dataa => \GRFPU0.GRFPU_X0.L1_2_3_0\(3),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_1_4_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN13_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001110101010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_5\(1),
dataa => \GRFPU0.GRFPU_X0.UN18_BCO_LSB_1\,
datab => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_A4\(1),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_0\(1),
datad => \GRFPU0.GRFPU_X0.UN18_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_1\,
datac => \GRFPU0.GRFPU_X0.L1_4_5_A\(1),
datad => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_4_5_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_5_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001110101010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_6\(1),
dataa => \GRFPU0.GRFPU_X0.UN28_BCO_LSB_1\,
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_A4\(1),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_0\(1),
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\);
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I_X2_RNI75JG: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
dataa => N_3,
datab => \GRFPC0.RFA2.FLUSH\,
datac => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I_X2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(17),
dataa => \GRFPC0.EX.CTRL.PC\(17),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(17));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M26_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G2\);
\GRFPC0_INST_I_0_M3_RNI03EU_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_1\,
dataa => \GRFPC0.INST_I_0_M3\(13),
datab => \GRFPC0.INST\(9),
datac => \GRFPC0.INST_I\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(28),
dataa => \GRFPC0.EX.CTRL.PC\(28),
datab => \GRFPC0.V.STDATA_0_SQMUXA_4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(28));
GRFPC0_VFIFO_FULL_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.VFIFO.FULL_1_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.UN4_CNTX\(0),
datab => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datac => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\);
\GRFPC0_RFA2_FOP_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4_A\,
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.INST_I\(11));
\GRFPC0_RFA2_FOP_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011101100111")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I_A4_A\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I_X\(6),
datac => \GRFPC0.INST_I\(10));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD7\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD5\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD9\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD8\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD4\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0_M4\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD3\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_0\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datab => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD4\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2\(56),
dataa => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datab => \GRFPU0.GRFPU_X0.UN23_EXP\(4),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_6\(53));
\GRFPU0_GRFPU_X0_COMB_TMP3_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.INF\,
datab => \GRFPU0.GRFPU_X0.COMB.ITER_OF\);
GRFPU0_GRFPU_X0_COMB_VST4_REG30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG30\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_4\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_5\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77\);
GRFPU0_GRFPU_X0_COMB_GETINF_UN9_MODE_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_4\,
datad => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_X2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNIT27D1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI64081_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI84081_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M34_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M30_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03_0_G0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001010110101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(52),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(23));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000010011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.COMB.EXP57_0_O2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(52));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_A_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(52),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_2\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_O2_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_O2_0\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_6\(53));
GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(23));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_0\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datab => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD6\);
\GRFPU0_GRFPU_X0_L3_1_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111110000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datab => \GRFPU0.GRFPU_X0.L3_1_1_A\(2),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4));
\GRFPU0_GRFPU_X0_L3_1_1_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1_A\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
\GRFPU0_GRFPU_X0_L1_2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_4\(1),
dataa => \GRFPU0.GRFPU_X0.L1_2_0_A3_0\(3),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_1\(1),
datac => \GRFPU0.GRFPU_X0.L1_2_1_5_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(34),
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5));
GRFPU0_GRFPU_X0_UN1_ITER_OF_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.COMB.ITER_OF\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\);
\GRFPU0_GRFPU_X0_ST3_REG_RNI3G081_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI2SV71_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI538D1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNI3R7D1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNIELQ51_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G1\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2\(19));
GRFPU0_GRFPU_X0_VST2_REG_5_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_5_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.REST_2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI00CB4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1_1\(24),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI1ICT2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_M4_I_O2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_O2_RNI7VU54_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_L2_0_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(2),
dataa => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0_A2\,
datab => \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\,
datac => \GRFPU0.GRFPU_X0.L1_0_1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(43),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(43),
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPC0_D_STLCK_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110100000")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_5\,
dataa => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0_0_I_A2\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\(0),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(0));
GRFPC0_RFA2_RS2SEL_RET_2_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000010")
port map (
combout => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.RD\(3),
datac => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_1_1\);
GRFPC0_D_FLDLCK_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1_1_0\,
dataa => \GRFPC0.MEM.CTRL.CCWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.D.FLDLCK_0_0_G1_0\,
datad => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_0\);
GRFPU0_GRFPU_X0_ST2_REG_RET_1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG127\,
datad => \GRFPU0.GRFPU_X0.COMB.UINT17\);
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110001010")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_1\,
dataa => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(5),
datac => \GRFPC0.INST_I_X\(6),
datad => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0_0\);
GRFPC0_STDDEP_0_SQMUXA_77_I_O2_RNI5CC11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_10_0\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A2_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_0\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(38));
\GRFPC0_R_FSR_CEXC_RNO_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\,
dataa => \GRFPC0.DIV.EXCT\(3),
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
datac => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
GRFPC0_UN1_RDWR_3_SQMUXA_4_C_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001100000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA_4_C_1\,
dataa => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(7),
datac => \GRFPC0.INST\(31),
datad => \GRFPC0.INST_I\(12));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIN0E93_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100011111")
port map (
combout => D_M4_I_0,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(47),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_M\(108));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(49),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1\(46),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1_A\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_1_A_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1_A\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datac => \GRFPU0.MULO.MRES\(107),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(42),
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_M\(103));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(39),
dataa => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(50),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(57),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datac => \GRFPU0.MULO.MRES\(117),
datad => \GRFPU0.GRFPU_X0.MULO_M\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1\(48),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1_A\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_5_1_A_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_5_1_A\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datac => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(54),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(58),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datac => \GRFPU0.MULO.MRES\(118),
datad => \GRFPU0.GRFPU_X0.MULO_M\(119));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_55_M4_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_55_M4_0_A2_1\,
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datab => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(26),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(26),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(26),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(23),
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(19),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(19),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(21),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(21),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(32),
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36),
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(97));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(14),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1\(44),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1_A\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_1_A_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5_1_A\(44),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(44),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001110101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0_0\(12),
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD6\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(20),
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(20),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(20),
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(35),
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(13),
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(28),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(28),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(30),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(30),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(30),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(18),
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.MULO_I_M\(79));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3_0\,
dataa => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datab => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M2\(45),
datad => \GRFPU0.GRFPU_X0.G_51\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A2_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A2_1\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(52),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPU0_GRFPU_X0_UN166_RNDOP_RNIRELN5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => D_M3_0_0,
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPC0_D_STLCK_RNO_4_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_1_0\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33));
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_RFA_RDWR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000100000000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_2\,
dataa => N_39,
datab => N_97,
datac => N_98,
datad => \GRFPC0.D.FSTLCK_M_2_X\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(20));
GRFPU0_GRFPU_X0_UN1_VALLOW_1_SQMUXA_INV_0_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_0\);
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_A4_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_A4_5_0\(0),
dataa => N_105,
datab => N_104,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\(12));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(12),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\(12));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_4_03\);
GRFPC0_RFA_AFSR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2_4\,
dataa => N_39,
datab => N_109,
datac => N_112,
datad => \GRFPC0.FP_PIPELINE.LDLOCK23_3_X\);
GRFPC0_RFA_LD_0_0_G1_0_1809_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010100000000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_1\,
dataa => N_39,
datab => N_97,
datac => N_98,
datad => \GRFPC0.D.FSTLCK_M_2_X\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI6RI22_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_61_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN28_DP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_2\,
dataa => \GRFPC0.OP2\(62),
datab => \GRFPC0.OP2\(53),
datac => \GRFPC0.OP2\(56),
datad => \GRFPC0.OP2\(54));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2_0\,
dataa => \GRFPC0.OP2\(62),
datab => \GRFPC0.OP2\(56),
datac => \GRFPC0.OP2\(55),
datad => \GRFPC0.OP2\(61));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A1_0\(1),
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(7),
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(7),
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_11_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_0\(0));
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_I_S_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_6\,
dataa => \GRFPC0.WR.CTRL.INST\(20),
datab => \GRFPC0.WR.CTRL.INST\(22),
datac => \GRFPC0.WR.CTRL.INST\(21),
datad => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_4\);
GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_M6_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001001111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M6_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M3_E\);
GRFPC0_FP_PIPELINE_VRFA_ST_1_SN_M1_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_1\,
dataa => N_108,
datab => N_109,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST_1_SN_M1_0_0_X\,
datad => \GRFPC0.D.FSTLCK_M_2_X\);
GRFPC0_WR2_CTRL_STDFQ_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2_0\,
dataa => N_39,
datab => N_389,
datac => N_388,
datad => \GRFPC0.WR.CTRL.STDFQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A3_1_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A3_1_0\(48),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPC0_D_STDLCK_RNO_13_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_5_0_0\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\(12));
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O3_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_5_0\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_0\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(54),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(53),
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3_1\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53));
GRFPU0_GRFPU_X0_VST3_REG_4_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100010011")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_35\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(35),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\(33),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\(33),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(36),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\);
GRFPC0_EX_CTRL_SEQERR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2_0\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.RFA.SEQERR\,
datad => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_EX_CTRL_AFSR_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_A2_0_0\,
dataa => N_39,
datab => N_3,
datac => \GRFPC0.RFA.AFSR\,
datad => \GRFPC0.WR2.CTRL.SEQERR\);
\GRFPC0_OP1_0_IV_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(51),
dataa => \GRFPC0.EX.RREG.RES\(51),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_2_S\(51));
\GRFPC0_OP1_0_IV_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(46),
dataa => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datac => \GRFPC0.OP1_0_IV_2_S\(46));
\GRFPC0_OP1_0_IV_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(48),
dataa => \GRFPC0.EX.RREG.RES\(48),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_2_S\(48));
\GRFPC0_OP1_0_IV_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(40),
dataa => \GRFPC0.WR.RREG.RES\(40),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(3),
datac => \GRFPC0.OP1_0_IV_2_S\(40));
\GRFPC0_OP1_0_IV_2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(41),
dataa => \GRFPC0.EX.RREG.RES\(41),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(41));
\GRFPC0_OP1_0_IV_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(43),
dataa => \GRFPC0.WR2.RREG.RES\(43),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datac => \GRFPC0.OP1_0_IV_0\(43));
\GRFPC0_OP1_0_IV_2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(56),
dataa => \GRFPC0.EX.RREG.RES\(56),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_0\(56));
\GRFPC0_OP1_0_IV_2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(62),
dataa => \GRFPC0.EX.RREG.RES\(62),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_2_S\(62));
\GRFPC0_OP1_0_IV_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.OP1_0_IV_2\(50),
dataa => \GRFPC0.EX.RREG.RES\(50),
datab => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datac => \GRFPC0.OP1_0_IV_2_S\(50));
\GRFPU0_GRFPU_X0_L3_0_3_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datad => \GRFPU0.GRFPU_X0.L3_0_3_0_0\(5));
\GRFPU0_GRFPU_X0_L3_0_4_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_4_2\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datad => \GRFPU0.GRFPU_X0.L3_0_4_0\(5));
\GRFPC0_D_STLCK_RNO_5_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1_0_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_2\,
dataa => \GRFPU0.GRFPU_X0.C_ADD6\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD6\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
dataa => \GRFPC0.WR.CTRL.ID\(7),
datab => \GRFPU0.GRFPU_X0.RDY_F0_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\,
dataa => \GRFPC0.DIV.ID\(7),
datab => \GRFPU0.GRFPU_X0.RDY_F0_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_I_0_O2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_4\,
dataa => \GRFPC0.EX.CTRL.ID\(7),
datab => \GRFPU0.GRFPU_X0.RDY_F0_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\,
dataa => \GRFPC0.MEM.CTRL.ID\(7),
datab => \GRFPU0.GRFPU_X0.RDY_F0_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0_2\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2_0\,
dataa => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.WR2.CTRL.LD\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_16\,
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.MULO.MRES\(91),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_10\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_15\,
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_2\,
datad => \GRFPU0.MULO.MRES\(87));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_14\,
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.MULO.MRES\(73),
datac => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_2\);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G4_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_57\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_15\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_16\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_41\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_51\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_54\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_7\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_8\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_29\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_45\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_26\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_61\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_62\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_63\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_22\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_14\,
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\,
datad => \GRFPU0.MULO.MRES\(89));
GRFPU0_GRFPU_X0_NXX_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_11\,
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.NXX_6\,
datac => \GRFPU0.MULO.MRES\(89),
datad => \GRFPU0.GRFPU_X0.NXX_10\);
GRFPU0_GRFPU_X0_NXX_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_8\,
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.MULO.MRES\(94),
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_1\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_0_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_2_0\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => N_45794_2,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPU0_GRFPU_X0_COMB_UN2_FLOP_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\,
dataa => \GRFPC0.V.STDATA_14\(9),
datab => \GRFPC0.V.STDATA_14\(7),
datac => \GRFPC0.V.STDATA_14\(5));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_0\(7),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_0\(6),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_3_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_0\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A3_0\(1),
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27),
datac => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.DEP_2_I_I_0_A3_0\(0));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\(32),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G1\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03_1\);
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_204_0_A2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_1_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0));
GRFPU0_GRFPU_X0_ST3_EMAX_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\,
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.C_ADD1\,
datac => \GRFPU0.GRFPU_X0.C_ADD10\,
datad => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_L1_0_6_0_A2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6_0_A2_0_1\(1),
dataa => \GRFPU0.GRFPU_X0.TZI\(7),
datab => \GRFPU0.GRFPU_X0.TZI_I_M2\(4),
datac => \GRFPU0.GRFPU_X0.TZI\(6),
datad => \GRFPU0.GRFPU_X0.TZI\(5));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_243_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_243_0_A3_0\(1),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD0\,
datac => \GRFPU0.GRFPU_X0.C_ADD1\,
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT31_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_2\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_0\);
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A2_1_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1_0\(15),
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0));
\GRFPU0_GRFPU_X0_L3_0_3_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.L1_1_1_I_1\(1),
datad => \GRFPU0.GRFPU_X0.L1_0_1_1_I_1\(1));
GRFPC0_FP_PIPELINE_FPUSTART_7_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000101010")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_2\,
dataa => \GRFPC0.FP_PIPELINE.FPUSTART_7_0_X\,
datab => \GRFPC0.RFA.READ_RS1\,
datac => \GRFPC0.RFA2.RS1DEP\,
datad => \GRFPC0.RFA2.RS2DEP\);
GRFPU0_GRFPU_X0_EXPOP_1_SQMUXA_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP2\);
GRFPU0_GRFPU_X0_ST2_REG_RET_5_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010010000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3440_I_M_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_0_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_13_2\(0));
GRFPC0_FP_PIPELINE_UN14_OP_7_2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN14_OP_7_2_0_0\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14\(8),
datac => \GRFPC0.V.STDATA_14\(5));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A4_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A4_0_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.N_25113_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_0\(1),
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5681_REGDEPX2_0_A2_0_A2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIOJ2T_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_O2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_NZ_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1_0\);
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datad => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_2_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_1_1\(0),
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_4_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.N_25113_2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_3_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_4_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1));
\GRFPU0_GRFPU_X0_REST_1_2_IV_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(11));
\GRFPU0_GRFPU_X0_REST_2_IV_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(20));
GRFPU0_GRFPU_X0_S_SP_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_23\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datab => \GRFPU0.GRFPU_X0.ST3.STICKY\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datad => \GRFPU0.GRFPU_X0.S_SP_13\);
GRFPU0_GRFPU_X0_S_SP_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_22\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datac => \GRFPU0.GRFPU_X0.S_SP_11\,
datad => \GRFPU0.GRFPU_X0.S_SP_18\);
GRFPC0_FP_PIPELINE_UN25_HOLDN_A0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_A0_2\,
dataa => N_38,
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.FP_PIPELINE.UN23_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000011100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.LOB\);
GRFPC0_FP_PIPELINE_UN29_WREN_1_A1_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_A1_2_1\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\);
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_UN205_HOLDN_A0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_A0_0\,
dataa => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_1_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1));
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_M9_I_M4_0_A3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_M9_I_M4_0_A3_1\,
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.RDD_REP3\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2_0_A2_I_O4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_2_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A2_0_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A3_0_0\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4268_REGDEPX2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_6_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_0\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_1_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_2\);
GRFPU0_GRFPU_X0_UN1_VST2_REG82_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.REST_1_1_U\(2),
datad => \GRFPU0.GRFPU_X0.REST_2\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A4_0_0\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_9_0_A2_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0_0\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1667_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A3_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_1\(1));
\GRFPU0_GRFPU_X0_REST_1_2_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_0\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_VST2_INF_1_SQMUXA_1_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
\GRFPU0_GRFPU_X0_REST_2_2_RNI62I81_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G2_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.REST_2_2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(27),
datad => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_1_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A4_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A4_0_0\(1),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_1_1\(1),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2_0_A2_0_A2\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_5\,
dataa => \GRFPC0.FPR.ID\(5),
datab => \GRFPC0.MEM.CTRL.ID\(5),
datac => \GRFPC0.FP_PIPELINE.UN1_MEM.CTRL.ID_3_0_X3\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\);
\GRFPU0_GRFPU_X0_L1_6_1_5_0_I_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_5_0_I_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(56));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_2_0_RNIDGCU_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_A1_0\,
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_3_0\(0),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_1_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
GRFPC0_FP_PIPELINE_2_REGDEPX2_85_1_M9_I_A4_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85_1_M9_I_A4_0_0\,
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_1_0_A2_0_A4\);
GRFPC0_VFIFO_WR_0_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA_1_0\,
dataa => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_1\(1),
datac => \GRFPC0.FIFO.VCNT_1\(2),
datad => \GRFPC0.FIFO.FULL\);
GRFPU0_GRFPU_X0_COMB_VST3_REG71_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\);
GRFPU0_GRFPU_X0_COMB_UN1_ST3_FLOP_4_RNIH2IQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_5\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_1\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_5_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\);
GRFPC0_VFIFO_WR_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA_0\,
dataa => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.VCNT_0\(2),
datad => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_3_1\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNILE591_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_1\);
\GRFPU0_GRFPU_X0_L1_1_0_A3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_0_A3_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
GRFPC0_STDDEP_0_SQMUXA_5_I_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_5_I_O2_1\,
dataa => N_175,
datab => N_176,
datac => N_174,
datad => N_173);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(27),
dataa => N_78,
datab => N_84,
datac => N_79,
datad => N_80);
\GRFPC0_FP_PIPELINE_0_REGDEPX_36_0_A5_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5_1_1\(1),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_0\(8),
dataa => N_89,
datab => N_90,
datac => N_97,
datad => N_95);
\GRFPC0_FP_PIPELINE_0_REGDEPX_14_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_14_0_A2_0\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.CPI_I_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_2_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1));
\GRFPC0_INST_I_A2_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000001")
port map (
combout => \GRFPC0.INST_I_A2_1\(10),
dataa => \GRFPC0.FIFO.INST_0\(10),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_I_A2_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010100")
port map (
combout => \GRFPC0.INST_I_A2_0\(10),
dataa => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
GRFPC0_EX_CTRL_LD_RNIA6811: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G3\,
dataa => N_243,
datab => N_244,
datac => \GRFPC0.D.STDLCK_0_0_9__G3_0_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_M6_I_A3_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_M6_I_A3_2_1\,
dataa => \GRFPC0.V.STDATA_14\(23),
datab => \GRFPC0.V.STDATA_14\(24),
datac => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\);
GRFPU0_GRFPU_X0_COMB_VST2_REG107: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG107_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2\(1),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2\(19),
dataa => N_79,
datab => N_80,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX_0_A2_0_A2_X\);
GRFPC0_STDDEP_0_SQMUXA_170_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3974_DEP_2\);
GRFPC0_UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\);
GRFPC0_FP_PIPELINE_12_REGDEPX2_370_1_M3_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_1_M3_E\,
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2_1_I_O3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_3\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3439_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\,
dataa => N_79,
datab => N_81,
datac => N_80,
datad => N_82);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4063_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\,
dataa => N_81,
datab => N_82,
datac => N_79,
datad => N_80);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_19_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_19_1\(0),
dataa => N_84,
datab => N_78,
datac => N_79,
datad => N_81);
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2503_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2503_REGDEPX\,
dataa => N_79,
datab => N_80,
datac => N_81,
datad => N_82);
GRFPC0_FP_PIPELINE_14_STDEP_568_SEL1_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568_SEL1_I_0_A2_1\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3974_DEP_2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1\(0),
dataa => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_2\(0),
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP_2\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_14_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_14\(1),
dataa => N_80,
datab => N_82,
datac => N_81,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_X\(27));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(1),
dataa => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8\(1),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\(5),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN348_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN348_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_3_REGDEPX2_115_1_M9_I_M4_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_7_0_A3_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_1\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9\(1),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9_0\(1));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_6_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_6_0_A4\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_7_0_A3_1\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3\(1),
dataa => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_4\(1),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2_0_A2_I_O4\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_0_A2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_2\,
dataa => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2_0_A2_RNI0GPK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.N_19067_1_I_I_A2_I_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_5\,
dataa => \GRFPC0.N_19292_1_I_0_O2\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\);
GRFPC0_FP_PIPELINE_10_STDEP_412_SEL0_0_1_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_412_SEL0_0_1_0_O2\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4648_DEP_2_I_O2\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4648_DEP_2_I_O2\);
GRFPC0_FP_PIPELINE_12_STDEP_492_SEL0_0_1_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_7_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_7_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP_2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4\(7),
dataa => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_1\(8),
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(31),
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\);
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL1_I_0_A2_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_8\,
dataa => \GRFPC0.N_19292_1_I_0_O2\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\);
\GRFPC0_EX_CTRL_RD_RNIVL8L_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(1),
datad => \GRFPC0.N_19067_1_I_I_O2\);
GRFPC0_FP_PIPELINE_14_STDEP_576_SEL0_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4666_DEP_2\);
GRFPC0_V_STDATA_0_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.V.STDATA_0_SQMUXA_3\,
dataa => N_248,
datab => N_249,
datac => \GRFPC0.MEM.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.UN54_HOLDN\);
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_O3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_2\(0),
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2_0_O2\);
GRFPC0_FP_PIPELINE_STDDEP_1_IV_0_A2_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_IV_0_A2_0_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_3\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O3_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4_1\);
GRFPC0_FP_PIPELINE_2_STDEP_92_SEL0_0_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_SEL0_0_1_I_O2\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2_0_O2\);
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0),
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2_0_A2\);
GRFPC0_FP_PIPELINE_8_STDEP_336_SEL1_I_0_A2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_336_SEL1_I_0_A2_0_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4666_DEP_2\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_A4_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1_0\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8\(1),
dataa => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_21_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_21\(1),
dataa => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_11_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_11\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10\(0),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.RDD_REP2\,
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_1\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_FP_PIPELINE_5_STDEP_216_SEL1_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_216_SEL1_I_0_A2_1\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\);
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_2\);
GRFPC0_FP_PIPELINE_9_STDEP_368_SEL1_I_0_A2_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_368_SEL1_I_0_A2_0_O2_0\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1_0_A2\);
GRFPC0_FP_PIPELINE_LDLOCK23_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK23_4\,
dataa => N_100,
datab => N_101,
datac => N_98,
datad => N_99);
GRFPC0_FP_PIPELINE_VRFA_ST4_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST4_0_A3\,
dataa => N_97,
datab => N_98,
datac => N_99,
datad => \GRFPC0.FP_PIPELINE.LDLOCK19_A_X\);
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2316_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3628_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_26_I_I4_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_26_I_I4_I_O2\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_A3_2\(0),
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1_0_A2\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1\(1),
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1_0\(1));
GRFPC0_STDDEP_0_SQMUXA_77_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1022_DEP_2_I_O2\);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2006_DEP_2_RNIRE8D1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.N_19292_1_I_0_O2\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2006_DEP_2\);
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_7\(0),
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1022_DEP_2_I_O2\);
GRFPC0_STDDEP_0_SQMUXA_67_I_O2_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_67_I_O2_I_O2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_1_0_A3_0_A2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(1),
dataa => N_79,
datab => N_81,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX_2_0_A3_0_A2_X\);
GRFPC0_DIV_PEND_1_0_G1_0_I_A5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.DIV.PEND_1_0_G1_0_I_A5_0\,
dataa => N_425,
datab => N_424,
datac => N_459,
datad => N_423);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN1988_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN1988_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3300_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3300_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_26_0_A2_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_26_0_A2_0_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_0_STDEP_8_SEL1_I_0_A2_1_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL1_I_0_A2_1_0_A2\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_2_0_A2\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN3956_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1332_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_0_A2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A2_0_A2_0_A2_0_A2\(0),
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.N_21857\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_13_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_13\(1),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_18_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_18\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2_0_A2_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_0_A2_0_A2_0_A2\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3871_DEP_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3871_DEP_0_A3\,
dataa => N_242,
datab => N_243,
datac => N_245,
datad => N_244);
\GRFPC0_FP_PIPELINE_0_STDEP_38_0_O2_I_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_0_O2_I_A3\(1),
dataa => N_242,
datab => N_243,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_UN42_HOLDN_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2\,
dataa => \GRFPC0.WR2.CNT\(0),
datab => \GRFPC0.WR2.CTRL.STDFQ\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.FP_PIPELINE.UN42_HOLDN_0_O2_0_X\);
\GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_1\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP3\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
GRFPC0_FP_PIPELINE_FCC_1_M2S4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2S4\,
dataa => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.FCC_VALID_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\,
datad => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_EX_CTRL_STDFQ_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.EX.CTRL.STDFQ_0_0_G1_0_1712_A2\,
dataa => N_39,
datab => \GRFPC0.RFA.STDFQ\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_VRFA_SEQERR_5_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.VRFA.SEQERR_5_SQMUXA_1\,
dataa => N_100,
datab => N_101,
datac => \GRFPC0.VRFA.SEQERR_5_SQMUXA_1_0\,
datad => \GRFPC0.LDLOCK_1_M_4_X\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1));
GRFPC0_STDDEP_0_SQMUXA_87_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_STDDEP_0_SQMUXA_21_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_21_0_A2\,
dataa => N_173,
datab => N_174,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_2_0_A2_X\,
datad => \GRFPC0.RFA.LD_REP1\);
GRFPC0_STDDEP_0_SQMUXA_20_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_20_I_O2\,
dataa => N_173,
datab => N_174,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_2_0_A2_X\,
datad => \GRFPC0.RFA.LD_REP1\);
GRFPC0_STDDEP_0_SQMUXA_23_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_23_I_O2\,
dataa => N_176,
datab => N_175,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3857_DEP_1_X\,
datad => \GRFPC0.RFA.LD_REP1\);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_20_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_20\(0),
dataa => N_96,
datab => N_94,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX_0_A4_1_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_5_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1_0\);
GRFPC0_FP_PIPELINE_UN1_FIFO_VCNT_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
dataa => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1_0\);
GRFPU0_GRFPU_X0_COMB_VST1_V4_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_5\,
dataa => \GRFPC0.V.STDATA_14\(9),
datab => \GRFPC0.V.STDATA_14\(7),
datac => \GRFPC0.V.STDATA_14\(8),
datad => \GRFPC0.V.STDATA_14_REP1\(11));
GRFPU0_GRFPU_X0_COMB_SHV2LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LT2\,
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.SHV2LT2_0\);
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1\,
dataa => \GRFPU0.GRFPU_X0.C_ADD0\,
datab => \GRFPU0.GRFPU_X0.C_ADD1\,
datac => \GRFPU0.GRFPU_X0.C_ADD6\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD2\,
datab => \GRFPU0.GRFPU_X0.C_ADD3\,
datac => \GRFPU0.GRFPU_X0.C_ADD6\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2_1\(1));
GRFPU0_GRFPU_X0_UN38_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datac => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_A\,
datad => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_2\);
GRFPU0_GRFPU_X0_UN38_BCO_LSB_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(1),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_I_O2_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7_2\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_I_O2_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_74_7\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_0_7_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_IV_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(7),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV_0\(7),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2_REP2\);
GRFPU0_GRFPU_X0_UN1_QP1_SP_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1));
\GRFPU0_GRFPU_X0_L1_5_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.L1_5_1_0\(3),
datad => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\,
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.MULO.MRES\(82),
datad => \GRFPU0.MULO.MRES\(94));
GRFPU0_GRFPU_X0_UN163_BCO_LSB_RNIVB0E1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.L1_1_0\(3),
datad => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.L1_4_0\(3),
datad => \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\);
GRFPU0_GRFPU_X0_VITER_R_I_1_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(54),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53));
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\);
GRFPU0_GRFPU_X0_COMB_VST3_REG46_0_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_0_7_1\);
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2_0\);
GRFPC0_FP_PIPELINE_CNTX14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.CNTX14\,
dataa => \GRFPC0.FP_PIPELINE.UN4_CNTX\(0),
datab => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datac => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2));
GRFPC0_UN1_PENDEXC_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100100000000")
port map (
combout => \GRFPC0.UN1_PENDEXC_5\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_3\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53));
GRFPU0_GRFPU_X0_COMB_VST2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3_0\);
GRFPU0_GRFPU_X0_UN43_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN43_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datac => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_A\,
datad => \GRFPU0.GRFPU_X0.L1_1_1_5_I_1\(1));
GRFPU0_GRFPU_X0_UN43_BCO_LSB_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(60),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_BCO_MSB_3_I_1_RNIG3V11_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_A2\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(4),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(3),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPU0_GRFPU_X0_UN98_BCO_LSB_RNI0K9C1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datac => \GRFPU0.GRFPU_X0.L1_2_0_0\(3),
datad => \GRFPU0.GRFPU_X0.UN98_BCO_LSB\);
\GRFPU0_GRFPU_X0_BCO_MSB_3_3_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_I\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(15),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(16),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(18));
GRFPU0_GRFPU_X0_UN128_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(14));
GRFPU0_GRFPU_X0_UN123_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN123_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(4),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(3));
GRFPU0_GRFPU_X0_UN8_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datac => \GRFPU0.GRFPU_X0.UN8_BCO_LSB_A\,
datad => \GRFPU0.GRFPU_X0.L1_1_1_4_I_1\(1));
GRFPU0_GRFPU_X0_UN8_BCO_LSB_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_BCO_LSB_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_8_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
\GRFPC0_FIFO_INST_1_RNI84VN3_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1403_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2285_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2285_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPU0_GRFPU_X0_UN208_BCO_LSB_RNIT3BR1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.L1_0_4_0\(3),
datad => \GRFPU0.GRFPU_X0.UN208_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.L1_2_2_0\(3),
datad => \GRFPU0.GRFPU_X0.UN218_BCO_LSB\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_4_RNIOEE61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\,
datad => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\,
datad => \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(5),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPC0_FP_PIPELINE_UN8_OP_7_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN8_OP_7_6\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(9),
datac => \GRFPC0.V.STDATA_14\(7),
datad => \GRFPC0.V.STDATA_14\(8));
GRFPU0_GRFPU_X0_UN248_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(21),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(20),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(22),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(23));
GRFPU0_GRFPU_X0_UN243_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN243_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(28),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(29),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(30));
GRFPU0_GRFPU_X0_UN258_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(5),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(7),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(6));
GRFPU0_GRFPU_X0_UN253_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(12),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(13),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(14),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15));
GRFPU0_GRFPU_X0_UN58_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_0\);
\GRFPU0_GRFPU_X0_L1_0_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datac => \GRFPU0.GRFPU_X0.L1_0_1_0_0\(3),
datad => \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\);
GRFPU0_GRFPU_X0_UN53_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.L1_3_1_4_I_1\(1));
GRFPU0_GRFPU_X0_COMB_VST2_REG107_RNINCAM1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.REST_2\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\);
GRFPU0_GRFPU_X0_UN13_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datac => \GRFPU0.GRFPU_X0.UN13_BCO_LSB_A\,
datad => \GRFPU0.GRFPU_X0.L1_2_1_4_I_1\(1));
GRFPU0_GRFPU_X0_UN13_BCO_LSB_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_BCO_LSB_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
GRFPU0_GRFPU_X0_UN18_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN18_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datad => \GRFPU0.GRFPU_X0.UN18_BCO_LSB_1\);
GRFPU0_GRFPU_X0_UN23_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datad => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_0\);
\GRFPU0_GRFPU_X0_L1_4_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datac => \GRFPU0.GRFPU_X0.L1_4_1_0\(3),
datad => \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_0_A4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datad => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI5IDT_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_LT_EXPT14LTO6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO6\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT27_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_4_S\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN14_C_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2_0\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD11\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\);
\GRFPU0_GRFPU_X0_L1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datac => \GRFPU0.GRFPU_X0.L1_0_0_0\(3),
datad => \GRFPU0.GRFPU_X0.UN88_BCO_LSB\);
\GRFPU0_GRFPU_X0_EXPOP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP\(1),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD55\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(6),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(2),
datac => \GRFPU0.GRFPU_X0.N_67_I_0_A2\);
GRFPU0_GRFPU_X0_UN28_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB_0\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2S2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_0_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\,
datad => \GRFPU0.MULO.MRES_BUF\(121));
\GRFPU0_GRFPU_X0_COMB_RMND_13_1_0__M3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0_0\(0));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNICMV42_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_4\);
GRFPU0_GRFPU_X0_COMB_DPRES4_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.COMB.DPRES4_1\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES4_7_3\);
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNIV5L51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ITER_OF\,
dataa => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_EXP_0_SQMUXA_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP2\);
GRFPU0_GRFPU_X0_UN63_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.UN63_BCO_LSB_0\);
GRFPU0_GRFPU_X0_UN48_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datac => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_A\,
datad => \GRFPU0.GRFPU_X0.L1_2_1_5_I_1\(1));
GRFPU0_GRFPU_X0_UN48_BCO_LSB_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_A\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2\(0),
dataa => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0));
\GRFPC0_D_STLCK_RNO_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_216_I_M_2\(0),
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_300TT_0_M1_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300TT_0_M1_E\,
dataa => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_13_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M4_RNIQQM31_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_4_2\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(15),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(16),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(18));
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O3_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_O3_0_0\(0),
dataa => N_173,
datab => N_174,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4185_DEP_1_X\,
datad => \GRFPC0.RFA.LD\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A3_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_2_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_5_0_A2_0\(1));
\GRFPC0_DIV_EXCT_0_0_2__G0_0_A3_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1\,
dataa => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datab => \GRFPU0.GRFPU_X0.ST4.IOF\,
datac => \GRFPU0.GRFPU_X0.ST4.MOF\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_24_IV_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_24_IV_I_A2_0\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_2_0\(1),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_5_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0_0\);
\GRFPC0_FP_PIPELINE_RS2_1_X_RNI5QUB_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_3\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.FPUSEL_1_0_3__G0_E_3_A\,
datac => RFI2_RD2ADDRZ(0));
\GRFPC0_FP_PIPELINE_RS2_1_X_RNIS6V7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_3_A\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(3));
\GRFPC0_D_STLCK_RNO_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_A1\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_1_1_O2_RNIQB4D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => D_M3_1,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0_TZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_0_TZ\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5298_REGDEPX2_1_I_O4_RNIJP7M: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_A2_0\,
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_0\(0),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_M4_A4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A4_0\,
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6929_REGDEPX2\);
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNI5N3BE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(42),
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.MULO.MRES\(101),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNI1298D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(42),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD36\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNI4U2DC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(39),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNII06DC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(39),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD33\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNIU6VGG: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(45),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNITP6BE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(45),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNIJ04EJ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(49),
dataa => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNII4PPF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(49),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD43\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNICSC2F: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(43),
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNIKKTJD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(43),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD37\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNIOHHVH: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(47),
dataa => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNI1VF2F: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(47),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNIV9D5K: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_YY\(50),
dataa => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA_RNICND5G: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M_XX\(50),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD44\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0_0\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_0\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_D_STLCK_RNO_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_0\(1),
dataa => N_104,
datab => N_105,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_2_X_RNI95CQ_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A3_7_0\(1),
dataa => N_105,
datab => N_104,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_D_STLCK_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_0_0\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A3_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_522_0_IV_I_A3_2_0\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_1_O2_RNIQB4D_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => D_M2_E_2_0,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A3_1_0\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_M4\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_O2\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_0\(8),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_212_0_A3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A3_0_0\(1),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_23_IV_I_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_23_IV_I_A3_0\(0),
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2_RNI3QN41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_3_0\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1386_DEP_RNIL8CD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1575_DEP_2_X_RNIO7BR_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G3_0\,
dataa => N_242,
datab => N_244,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4841_DEP_2_X_RNI7A7T_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_590_I_M_2_0\(0),
dataa => N_174,
datab => N_175,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\,
datad => \GRFPC0.RFA.LD_REP1\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1561_DEP_0_X_RNI0AMQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_190_I_M_1_0\(0),
dataa => N_175,
datab => N_173,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP_0_X\,
datad => \GRFPC0.RFA.LD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(5),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => \GRFPC0.CPI_I_M_1_X\(64),
datad => N_97);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN962_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN962_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5444_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\,
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011111101")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPC0_FIFO_INST_1_RNI84VN3_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3608_REGDEPX2_I_I_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5\(15),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1_0\(15),
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL1_I_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_1_0_A3_0_A2\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2_0\);
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_0_A2_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A3\(0),
dataa => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2\(0),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_0\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_8_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8_0_A2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3_0\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4612_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A4\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A2_9_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_9\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_3\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\);
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_1_1_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datad => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_299_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_1\(1));
\GRFPC0_D_STLCK_RNO_8_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_A2_1\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_4_X\(1),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_299_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_A2_0\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_0\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_A4\(0),
dataa => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
GRFPC0_OP1_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.OP1_1_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.RS1_3_X\(0));
GRFPC0_OP1_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.OP1_0_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.RS1_3_X\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_2\(1),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_5_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1\(23),
dataa => N_84,
datab => N_92,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_X\(15),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2637_REGDEPX2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_89_A1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89_A1\(1),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2_0_A2_1_A2\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_239_A1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_239_A1\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A2_0_0\(1));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_40_M8_I_M4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I_M4_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_0\(40),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1TT_40_M2_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_YY\(37),
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_D_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M_XX\(37),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD31\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_L1_1_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_L1_4_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_L1_1_1_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(45));
\GRFPU0_GRFPU_X0_L1_0_1_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_L1_3_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29));
\GRFPU0_GRFPU_X0_L1_4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_L1_3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_L1_2_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(16));
\GRFPU0_GRFPU_X0_L1_1_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_L1_5_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L1_1_1_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datac => \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ_A\(0),
datad => \GRFPU0.GRFPU_X0.TZI2\(9));
\GRFPU0_GRFPU_X0_L1_1_1_5_0_TZ_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001100001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5_0_TZ_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP2\);
\GRFPU0_GRFPU_X0_L1_2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_L1_3_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_L1_0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_L1_5_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPU0_GRFPU_X0_L1_2_1_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_3_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(37));
\GRFPU0_GRFPU_X0_L1_4_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21));
\GRFPU0_GRFPU_X0_L1_5_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13));
\GRFPU0_GRFPU_X0_L1_4_1_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_5_1_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_1_1_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L1_2_1_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_2_1_4_A4_0_0\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.TZI2\(15),
datab => \GRFPU0.GRFPU_X0.TZI2\(14),
datac => \GRFPU0.GRFPU_X0.TZI2\(13));
\GRFPU0_GRFPU_X0_L1_0_1_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_0_1_4_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L1_2_1_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110110000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ_A\(0),
datad => \GRFPU0.GRFPU_X0.TZI2\(17));
\GRFPU0_GRFPU_X0_L1_2_1_5_0_TZ_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_0_TZ_A\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001010000010")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_14_IV_2372_TZ\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2370\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\);
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I_M2\(1),
datab => \GRFPU0.GRFPU_X0.TZI2_I_0_M3\(7),
datac => \GRFPU0.GRFPU_X0.TZI2\(5));
\GRFPU0_GRFPU_X0_L1_2_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_BCO_MSB_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_2_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_L1_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_BCO_MSB_1_7_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(24),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(25),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(17),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(16),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(18));
\GRFPU0_GRFPU_X0_BCO_MSB_4_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(1),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(2));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(9),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(8),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(10));
\GRFPU0_GRFPU_X0_VITER_R_I_33_IV_TZ_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_33_IV_TZ\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.MULO.DRES_S\(66),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_BCO_MSB_3_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001011")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.TZI2\(22),
datad => \GRFPU0.GRFPU_X0.TZI2_I_M2\(21));
\GRFPU0_GRFPU_X0_BCO_MSB_5_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_BCO_MSB_6_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_14_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_14\(1),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN3078_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_0\(0),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_6\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_8\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_2_3\(0));
\GRFPC0_FIFO_INST_0_RNIAEFJ1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4135_REGDEPX_I_I_A2\,
dataa => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4152_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3840_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3840_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_2\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_1_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_3\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_4\(1),
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.EX.CTRL.RDD_REP4\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_15\(1),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2_0_A2_0_0_A4\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_16_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_16\(0),
dataa => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_6_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_6_2\(1),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1));
\GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_DEP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.DEP\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX_2\);
\GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX_2\);
GRFPC0_STDDEP_0_SQMUXA_107_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_107_I_O4\,
dataa => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
\GRFPC0_V_STDATA_14_RNIEU2L_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3752_REGDEPX2_I_I_A2_0_A2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3736_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX_0_A2\,
dataa => N_96,
datab => N_95,
datac => N_93,
datad => N_94);
GRFPC0_FP_PIPELINE_15_0_CHECK_DEP_UN4759_REGDEPX_I_0_O4_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_I_0_O4_I_A2\,
dataa => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_15_0_CHECK_DEP_UN4776_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4776_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0_1\(19),
dataa => N_89,
datab => N_90,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(9));
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_15\(1),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_16_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_16\(1),
dataa => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1));
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_0_M6_I_0_A3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_0\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_0_A2\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0));
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_0_M6_I_0_A3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A3_1\,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2_0_A2_1_A2\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2049_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2049_REGDEPX2_0_O2\,
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_I_O2\(0),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1359_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3855_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.CHECK_DEP.UN3855_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_INST_I_A2_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010100")
port map (
combout => \GRFPC0.INST_I_A2_0\(3),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
\GRFPC0_INST_I_A2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000001")
port map (
combout => \GRFPC0.INST_I_A2_1\(3),
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(7),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0_2\(8),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_81,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX_2_0_A3_0_A2_X\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_12\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4373_REGDEPX2\);
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4464_REGDEPX_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX_0_A3\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_4_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2_4_3\(1),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_2_X_RNI8OGT: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_I_I_0_A2\(0),
dataa => N_105,
datab => N_104,
datac => \GRFPC0.CPI_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\);
GRFPC0_V_STDATA_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.V.STDATA_0_SQMUXA\,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN888_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5091_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4268_REGDEPX2\);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_9_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_14_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_19_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5739_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_1_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2594_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3872_REGDEPX2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2_0_A2_1_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_INST_I_A2_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000001")
port map (
combout => \GRFPC0.INST_I_A2_1\(14),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3946_REGDEPX2_0_A2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2_0_A2_0_O2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2\(0),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2_0\(1),
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000111110001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_I_O2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_18_0_O2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_A4_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_299_I_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299_I_O2_1\(0),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4328_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4328_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0_A2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_I_A2_0\(0),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_O2\(0),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_I_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_I_A2_0\(1),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_1_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_3_2\,
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2_REP1\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4814_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4754_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1286_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_14_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_14\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6092_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN222_REGDEPX2_0_A3_0_A2_1_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_0_A3_0_A2_1_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_20_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP2\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3372_REGDEPX2\);
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_0_M6_I_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_0_M6_I_0_A3\,
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2_0_A3\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_0_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3311_REGDEPX2_I_I_A2_0_0_A3\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3167_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3167_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_1_2\(0),
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(17),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_OP1_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.OP1_I_A2\(0),
dataa => \GRFPC0.FP_PIPELINE.RS1D_1_X\,
datab => \GRFPC0.RFA2.RS1SEL\(7),
datac => \GRFPC0.OP1_1_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_RES_1_6_0_O2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100110001001")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_O2\(2),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A5_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A5_3\(1),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\(5));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_0_A5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0_A5\(0),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2_0_A2\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_1_1\(1),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.RDD_REP4\,
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_0_I\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(0));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_15_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(1),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7_2\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_1\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0),
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_5_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111010000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_2\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4\(1),
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.N_25984_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A4_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN527_REGDEPX_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(30),
dataa => \GRFPC0.WR2.CTRL.INST\(30),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(29),
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(28),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(27),
dataa => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(26),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(25),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(24),
dataa => \GRFPC0.WR2.CTRL.INST\(24),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(23),
dataa => \GRFPC0.WR2.CTRL.INST\(23),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(22),
dataa => \GRFPC0.WR2.CTRL.INST\(22),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(21),
dataa => \GRFPC0.WR2.CTRL.INST\(21),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(20),
dataa => \GRFPC0.WR2.CTRL.INST\(20),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(19),
dataa => \GRFPC0.WR2.CTRL.INST\(19),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(16),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(14),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(13),
dataa => \GRFPC0.WR2.CTRL.INST\(13),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(11),
dataa => \GRFPC0.WR2.CTRL.INST\(11),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(9),
dataa => \GRFPC0.WR2.CTRL.INST\(9),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(4),
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(0));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(32),
dataa => N_391,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(32),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(34),
dataa => N_393,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(34),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(41),
dataa => N_400,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(41),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(44),
dataa => N_403,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(44),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(47),
dataa => N_406,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(47),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(50),
dataa => N_409,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(50),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(52),
dataa => N_411,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(52),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(55),
dataa => N_414,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(55),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(56),
dataa => N_415,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(56),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(58),
dataa => N_417,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(58),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(59),
dataa => N_418,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(59),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(62),
dataa => N_421,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(62),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(63),
dataa => N_422,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(63),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(32),
dataa => \GRFPC0.OP2_6\(32),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(32));
\GRFPC0_OP2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(34),
dataa => \GRFPC0.OP2_6\(34),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(34));
\GRFPC0_OP2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(41),
dataa => \GRFPC0.OP2_6\(41),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(41));
\GRFPC0_STDATA_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(1),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(1),
datad => \GRFPC0.STDATA_1_X\(1));
\GRFPC0_OP2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(52),
dataa => \GRFPC0.OP2_6\(52),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(52));
\GRFPC0_OP2_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(55),
dataa => \GRFPC0.OP2_6\(55),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(55));
\GRFPC0_OP2_6_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(31),
dataa => \GRFPC0.OP2_3\(31),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(31));
\GRFPC0_WRDATA_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(31),
dataa => N_423,
datab => N_424,
datac => N_462,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(63));
\GRFPC0_STDATA_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(12),
dataa => \GRFPC0.R.STDATA\(12),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(12));
\GRFPC0_WRDATA_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(1),
dataa => N_423,
datab => N_424,
datac => N_432,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(33));
\GRFPC0_WRDATA_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(2),
dataa => N_423,
datab => N_424,
datac => N_433,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(34));
\GRFPC0_STDATA_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(2),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(2),
datad => \GRFPC0.STDATA_1_X\(2));
\GRFPC0_WRDATA_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(3),
dataa => N_423,
datab => N_424,
datac => N_434,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(35));
\GRFPC0_WRDATA_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(5),
dataa => N_423,
datab => N_424,
datac => N_436,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(37));
\GRFPC0_WRDATA_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(9),
dataa => N_423,
datab => N_424,
datac => N_440,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(41));
\GRFPC0_WRDATA_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(0),
dataa => N_423,
datab => N_424,
datac => N_431,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(32));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(2),
dataa => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPC0.R.FSR.AEXC\(2),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
\GRFPC0_OP2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(40),
dataa => \GRFPC0.OP2_6\(40),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(40));
\GRFPC0_STDATA_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(0),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(0),
datad => \GRFPC0.STDATA_1_X\(0));
\GRFPC0_STDATA_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(31),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(31),
datad => \GRFPC0.STDATA_1_X\(31));
\GRFPC0_OP2_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(1),
dataa => \GRFPC0.OP2_3\(1),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(1));
\GRFPC0_OP2_6_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(21),
dataa => \GRFPC0.OP2_3\(21),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(21));
\GRFPC0_OP2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(58),
dataa => \GRFPC0.OP2_6\(58),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(58));
\GRFPC0_OP2_6_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(29),
dataa => \GRFPC0.OP2_3\(29),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(29));
\GRFPC0_OP2_6_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(30),
dataa => \GRFPC0.OP2_3\(30),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(30));
\GRFPC0_FP_PIPELINE_WRADDR_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => RFI2_WRADDRZ(1),
dataa => N_423,
datab => N_428,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(1));
\GRFPC0_STDATA_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(11),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(11),
datad => \GRFPC0.STDATA_1_X\(11));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011111100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_0\(3),
dataa => \GRFPC0.DIV.EXCT\(3),
datab => \GRFPC0.R.FSR.AEXC\(3),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
\GRFPC0_OP2_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(63),
dataa => \GRFPC0.OP2_6\(63),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(63));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.N_23889\,
dataa => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.DEP_2_I_I_0_A3_0\(0),
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_1_1\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1));
\GRFPC0_WR_RREG_RES_0_0_53__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(53),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(53));
\GRFPC0_WR_RREG_RES_0_0_56__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(56),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(56));
\GRFPC0_WR_RREG_RES_0_0_59__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(59),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(59));
\GRFPC0_WR_RREG_RES_0_0_62__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(62),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(62));
GRFPC0_VFIFO_VCNT_0_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000000")
port map (
combout => \GRFPC0.VFIFO.VCNT_0_0_SQMUXA\,
dataa => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.VCNT_0\(2),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101111")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
dataa => \GRFPC0.WR2.RREG.EXCT\(0),
datab => \GRFPC0.DIV.EXCT_0_0_0__G3_0\,
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
GRFPC0_FP_PIPELINE_0_STDEP_12_SEL1_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_12_SEL1_I_0_A2_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A3_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_5\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_STDDEP_0_SQMUXA_116_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_116_I\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_2_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1));
\GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3528_REGDEPX_1_0_I\);
GRFPC0_FP_PIPELINE_3_REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_1_M9_I_M4_0_A4_0_1_0\,
dataa => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(7),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4\(7),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => N_97,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1\(6),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(6));
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX_282_0_A4_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_12_0_A3_0_2\(1),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_6_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_6\(9),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0\(0),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
\GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_2\(12),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FIFO.INST_1_M_2\(25));
\GRFPC0_D_STLCK_RNO_10_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000110000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
datac => N_103,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_25_IV_I_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_25_IV_I_A2\(1),
dataa => N_105,
datab => N_104,
datac => \GRFPC0.CPI_I_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\);
\GRFPC0_WRDATA_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(28),
dataa => N_423,
datab => N_424,
datac => N_459,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(60));
\GRFPC0_WRDATA_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(20),
dataa => N_423,
datab => N_424,
datac => N_451,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(52));
GRFPC0_STDDEP_0_SQMUXA_94_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_94_I_O4\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(31),
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
\GRFPC0_WRDATA_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(14),
dataa => N_423,
datab => N_424,
datac => N_445,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(46));
\GRFPC0_WRDATA_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(6),
dataa => N_423,
datab => N_424,
datac => N_437,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(38));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(1),
dataa => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(1),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(6),
dataa => \GRFPC0.WR2.CTRL.INST\(6),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(12),
dataa => \GRFPC0.WR2.CTRL.INST\(12),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12));
GRFPC0_FP_PIPELINE_7_STDEP_292_SEL1_I_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\);
GRFPC0_FP_PIPELINE_0_EXSEL4_I_A2_RNI2E8S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RESV_6_IV_I_I_O2_0_O2\,
dataa => N_38,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.0.EXSEL4_I_A2\,
datad => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA_X\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_1_0_A2\(1));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3858_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3858_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(27),
datad => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_0_2\(1),
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1106_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_455_I_A2_3\(0),
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1547_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1547_REGDEPX2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_V_STDATA_14_RNIEU2L_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_I_I_A2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_M6_I_A3_0_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6398_REGDEPX2_I_I_A2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_V_STDATA_14_RNIEU2L_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5957_REGDEPX2_I_0_O3_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_9_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_9_1\(1),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0));
\GRFPC0_V_STDATA_14_RNIEU2L_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(4),
datab => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.V.STDATA_14\(2));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_3_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A3\(0),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A2_0_A2_0_A2_0_A2\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1_1\(1));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_11_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\(0),
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.EX.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4238_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_4\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6900_REGDEPX2\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_3\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6929_REGDEPX2\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6414_REGDEPX2_0_A3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2_0_A3_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2886_REGDEPX2_0_A3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2886_REGDEPX2_0_A3_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_WRADDR_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => RFI2_WRADDRZ(2),
dataa => N_423,
datab => N_429,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(2));
\GRFPC0_FP_PIPELINE_WRADDR_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => RFI2_WRADDRZ(3),
dataa => N_423,
datab => N_430,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN785_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN334_REGDEPX2_0_A2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_0_A2_0_A2_1_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_WRADDR_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => RFI2_WRADDRZ(0),
dataa => N_423,
datab => N_427,
datac => \GRFPC0.FP_PIPELINE.UN33_DEBUG_UNIT_X\,
datad => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(25),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(25));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_9_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_9\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6488_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_8\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD_REP3\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6459_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_0_1\(1),
dataa => \GRFPC0.V.STDATA_14\(21),
datab => \GRFPC0.V.STDATA_14_I_M2\(19),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_6\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_O2_1\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_0_A4\(0),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_5\(0),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5120_REGDEPX2_1_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_3_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010101010101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_3_0_O2\,
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(52),
datac => \GRFPC0.OP1_0_IV\(51),
datad => \GRFPC0.OP1_0_IV\(53));
\GRFPC0_STDATA_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(4),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(4),
datad => \GRFPC0.STDATA_1_X\(4));
\GRFPC0_OP2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(36),
dataa => \GRFPC0.OP2_6\(36),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(36));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(36),
dataa => N_395,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(36),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_WRDATA_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(25),
dataa => N_423,
datab => N_424,
datac => N_456,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(57));
\GRFPC0_OP2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(57),
dataa => \GRFPC0.OP2_6\(57),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(57));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(57),
dataa => N_416,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(57),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_WR_RREG_RES_0_0_50__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(50),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(50));
\GRFPC0_WR_RREG_RES_0_0_47__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(47),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(47));
\GRFPC0_WR_RREG_RES_0_0_44__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.RES_1_3\(44),
datac => \GRFPU0.GRFPU_X0.RES_1_5\(44));
\GRFPC0_STDATA_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(9),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(9),
datad => \GRFPC0.STDATA_1_X\(9));
\GRFPC0_OP2_6_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(9),
dataa => \GRFPC0.OP2_3\(9),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(9));
\GRFPC0_STDATA_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(15),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(15),
datad => \GRFPC0.STDATA_1_X\(15));
\GRFPC0_OP2_6_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(15),
dataa => \GRFPC0.OP2_3\(15),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(15));
\GRFPC0_STDATA_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(16),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(16),
datad => \GRFPC0.STDATA_1_X\(16));
\GRFPC0_WRDATA_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(17),
dataa => N_423,
datab => N_424,
datac => N_448,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(49));
\GRFPC0_OP2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(49),
dataa => \GRFPC0.OP2_6\(49),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(49));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(49),
dataa => N_408,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(49),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(60),
dataa => \GRFPC0.OP2_6\(60),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(60));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(60),
dataa => N_419,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(60),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_STDATA_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(29),
dataa => \GRFPC0.R.STDATA\(29),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(29));
\GRFPC0_OP2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(61),
dataa => \GRFPC0.OP2_6\(61),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_5\(61));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(61),
dataa => N_420,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(61),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_175_1_M9_I_A4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_1_M9_I_A4_0\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2564_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A4_0\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0));
\GRFPC0_STDATA_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(10),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(10),
datad => \GRFPC0.STDATA_1_X\(10));
\GRFPC0_OP2_6_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(10),
dataa => \GRFPC0.OP2_3\(10),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(10));
\GRFPC0_OP2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(54),
dataa => \GRFPC0.OP2_6\(54),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(54));
\GRFPC0_EX_RREG_EXCT_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_5__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(5),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\);
\GRFPC0_STDATA_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(3),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(3),
datad => \GRFPC0.STDATA_1_X\(3));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(35),
dataa => N_394,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(35),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_OP2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(35),
dataa => \GRFPC0.OP2_6\(35),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(35));
\GRFPC0_OP2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(37),
dataa => \GRFPC0.OP2_6\(37),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(37));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(37),
dataa => N_396,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(37),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_WRDATA_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(7),
dataa => N_423,
datab => N_424,
datac => N_438,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(39));
\GRFPC0_OP2_6_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(7),
dataa => \GRFPC0.OP2_3\(7),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(7));
\GRFPC0_OP2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(39),
dataa => \GRFPC0.OP2_6\(39),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(39));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(39),
dataa => N_398,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(39),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_WRDATA_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(11),
dataa => N_423,
datab => N_424,
datac => N_442,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(43));
\GRFPC0_OP2_6_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(28),
dataa => \GRFPC0.OP2_3\(28),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(28));
\GRFPC0_STDATA_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(28),
dataa => \GRFPC0.R.STDATA\(28),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(28));
\GRFPC0_OP2_6_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(16),
dataa => \GRFPC0.OP2_3\(16),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(16));
\GRFPC0_OP2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(33),
dataa => \GRFPC0.OP2_6\(33),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(33));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(33),
dataa => N_392,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(33),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_OP2_6_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(8),
dataa => \GRFPC0.OP2_3\(8),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(8));
\GRFPC0_STDATA_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111110101100")
port map (
combout => CPO_DATAZ(18),
dataa => \GRFPC0.R.STDATA\(18),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(18));
\GRFPC0_OP2_6_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(18),
dataa => \GRFPC0.OP2_3\(18),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(18));
\GRFPC0_OP2_6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(4),
dataa => \GRFPC0.OP2_3\(4),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(4));
\GRFPC0_OP2_6_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(14),
dataa => \GRFPC0.OP2_3\(14),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(14));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_15_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6108_REGDEPX2_0_A2_0_A2\);
\GRFPC0_OP2_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(2),
dataa => \GRFPC0.OP2_3\(2),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(2));
\GRFPC0_STDATA_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(6),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(6),
datad => \GRFPC0.STDATA_1_X\(6));
\GRFPC0_OP2_6_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(6),
dataa => \GRFPC0.OP2_3\(6),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(6));
\GRFPC0_EX_RREG_EXCT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_1__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(1),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\);
\GRFPC0_STDATA_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(20),
dataa => \GRFPC0.R.STDATA\(20),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(20));
\GRFPC0_OP2_6_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(20),
dataa => \GRFPC0.OP2_3\(20),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(20));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_2\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5372_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2_0_A2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2609_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2609_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3491_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3491_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_0\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\);
\GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1));
\GRFPC0_FP_PIPELINE_14_STDEP_580_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_580_0_O2\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(43),
dataa => N_402,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(43),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP_0_A2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_OP2_6_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6_I_M2\(5),
dataa => \GRFPC0.OP2_3_I_M2\(5),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4\(5));
\GRFPC0_STDATA_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(5),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(5),
datad => \GRFPC0.STDATA_1_X\(5));
\GRFPC0_STDATA_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(14),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(14),
datad => \GRFPC0.STDATA_1_X\(14));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(46),
dataa => N_405,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(46),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_STDATA_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(30),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(30),
datad => \GRFPC0.STDATA_1_X\(30));
\GRFPC0_WRDATA_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(26),
dataa => N_423,
datab => N_424,
datac => N_457,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(58));
\GRFPC0_STDATA_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(26),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(26),
datad => \GRFPC0.STDATA_1_X\(26));
\GRFPC0_OP2_6_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(26),
dataa => \GRFPC0.OP2_3\(26),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(26));
\GRFPC0_STDATA_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(25),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(25),
datad => \GRFPC0.STDATA_1_X\(25));
\GRFPC0_OP2_6_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(24),
dataa => \GRFPC0.OP2_3\(24),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(24));
\GRFPC0_STDATA_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(24),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(24),
datad => \GRFPC0.STDATA_1_X\(24));
\GRFPC0_OP2_6_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(23),
dataa => \GRFPC0.OP2_3\(23),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(23));
\GRFPC0_STDATA_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(23),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(23),
datad => \GRFPC0.STDATA_1_X\(23));
\GRFPC0_WRDATA_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(23),
dataa => N_423,
datab => N_424,
datac => N_454,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(55));
\GRFPC0_STDATA_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(21),
dataa => \GRFPC0.R.STDATA\(21),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(21));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(53),
dataa => N_412,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(53),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(51),
dataa => \GRFPC0.OP2_6\(51),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(51));
\GRFPC0_STDATA_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(19),
dataa => \GRFPC0.R.STDATA\(19),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(19));
\GRFPC0_WRDATA_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(19),
dataa => N_423,
datab => N_424,
datac => N_450,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(51));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(51),
dataa => N_410,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(51),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_6_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(17),
dataa => \GRFPC0.OP2_3\(17),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(17));
\GRFPC0_STDATA_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100000")
port map (
combout => CPO_DATAZ(17),
dataa => \GRFPC0.R.STDATA\(17),
datab => \GRFPC0.EX.CTRL.AFSR\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.STDATA_0\(17));
\GRFPC0_OP2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(48),
dataa => \GRFPC0.OP2_6\(48),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(48));
\GRFPC0_WRDATA_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(29),
dataa => N_423,
datab => N_424,
datac => N_460,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(61));
\GRFPC0_WRDATA_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(16),
dataa => N_423,
datab => N_424,
datac => N_447,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(48));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(48),
dataa => N_407,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(48),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_6_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(12),
dataa => \GRFPC0.OP2_3\(12),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(12));
\GRFPC0_OP2_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(0),
dataa => \GRFPC0.OP2_3\(0),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(0));
\GRFPC0_STDATA_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(7),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(7),
datad => \GRFPC0.STDATA_1_X\(7));
\GRFPC0_WRDATA_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(4),
dataa => N_423,
datab => N_424,
datac => N_435,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(36));
\GRFPC0_STDATA_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(27),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(27),
datad => \GRFPC0.STDATA_1_X\(27));
\GRFPC0_OP2_6_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(27),
dataa => \GRFPC0.OP2_3\(27),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(27));
\GRFPC0_WRDATA_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(10),
dataa => N_423,
datab => N_424,
datac => N_441,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(42));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(42),
dataa => N_401,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(42),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_OP2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(42),
dataa => \GRFPC0.OP2_6\(42),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(42));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110011001100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(0),
dataa => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(0),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
\GRFPC0_OP2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(38),
dataa => \GRFPC0.OP2_6\(38),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(38));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(38),
dataa => N_397,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(38),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(2),
dataa => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(17),
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6032_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6032_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2504_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_OP2_6_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(22),
dataa => \GRFPC0.OP2_3\(22),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(22));
\GRFPC0_OP2_6_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(19),
dataa => \GRFPC0.OP2_3\(19),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(19));
\GRFPC0_OP2_I_M3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_I_M3\(13),
dataa => \GRFPC0.OP2_I_M3_4\(13),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_I_M3_3\(13));
\GRFPC0_WRDATA_I_M2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(13),
dataa => N_423,
datab => N_424,
datac => N_444,
datad => \GRFPC0.WRDATA_I_M3\(45));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_I_M2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2_I_M2\(45),
dataa => N_404,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(45),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPC0_OP2_I_M2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_I_M2\(45),
dataa => \GRFPC0.OP2_I_M3\(45),
datab => \GRFPC0.OP2_SN_M8_REP2\,
datac => \GRFPC0.OP2_I_M3_0\(45));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_1\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_7\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0),
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_18_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_18_I\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\);
GRFPC0_STDDEP_0_SQMUXA_155_1_I_X2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000011110000111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_X2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0));
GRFPC0_FP_PIPELINE_STDBL_1_1_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDBL_1_1_U\,
dataa => N_97,
datab => N_98,
datac => N_38,
datad => \GRFPC0.FP_PIPELINE.STDBL_1_1_0_X\);
\GRFPC0_R_STATE_RNIKM2P7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010100000000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2_1\,
dataa => N_113,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1004_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1004_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_VWR2_CTRL_RDD_1_I_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_O2_1\,
dataa => N_39,
datab => \GRFPC0.WR.CTRL.VCNT\(0),
datac => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.PENDEXC23\);
GRFPC0_FP_PIPELINE_UN17_SHARE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
dataa => \GRFPC0.WR.CTRL.LD\,
datab => \GRFPC0.WR.CTRL.CCWR\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datad => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_9\,
dataa => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_3_0_A2_0\(0));
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL0_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_0_1\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_1_0_A3_0_A2\);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1678_DEP_RNIO2MQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.N_19572_1_I_0_O2\,
dataa => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_M4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001001010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_M4\(0),
dataa => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL0_0_I_O3\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_256_3_0_O3_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\(0),
datad => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A3_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_A3_4\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_1_0_A3_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_STDDEP_0_SQMUXA_118_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_118_I\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX_RNI34501: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN496_REGDEPX_0_O2_0_RNIQ30U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_106_I_0_0_O4_I_O2\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0_O2_0\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_DEP_2_IV_I_A2_RNI1BLP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_122_I_I_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\(0),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_STDDEP_0_SQMUXA_96_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_96_0_A3\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.DEP_2_I_I_0_A3_0\(0),
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_D_STLCK_RNO_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_82_I_I_A2\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_2_X_RNIE2R11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_80_I_I_A2_I\,
dataa => N_105,
datab => N_104,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_2_X_RNI8OCS: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_105_I_0_O4\,
dataa => N_104,
datab => N_105,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_X_RNITP7T_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_98_I_I_A2_I_O2\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_26_0_A2_1_A2_0_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_26_0_A2_1_A2_0_0_A2\(1),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3));
GRFPC0_STDDEP_0_SQMUXA_155_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1660_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6473_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6473_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_V_STDATA_1_M7S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110111110000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7S2\,
dataa => N_248,
datab => N_249,
datac => \GRFPC0.UN1_DIV.EXC\,
datad => \GRFPC0.UN1_WR2.EXC\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(7),
dataa => \GRFPC0.WR2.CTRL.INST\(7),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(15),
dataa => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_174_0_A3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_174_0_A3\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0));
GRFPC0_STDDEP_0_SQMUXA_101: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_101\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_STDDEP_0_SQMUXA_123: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_123\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_DEP_2_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.DEP_2_IV\(0),
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2_0\(0),
datad => \GRFPC0.FIFO.INST_1_M_2\(25));
\GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_REP1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_5\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4299_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4299_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6063_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6063_REGDEPX2_0_O2\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_EX_RREG_EXCT_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_4__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(4),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\);
\GRFPC0_STDATA_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(8),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(8),
datad => \GRFPC0.STDATA_1_X\(8));
\GRFPC0_WRDATA_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(8),
dataa => N_423,
datab => N_424,
datac => N_439,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(40));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(40),
dataa => N_399,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(40),
datad => \GRFPC0.WR.CTRL.RDD_REP4\);
\GRFPC0_OP2_6_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(25),
dataa => \GRFPC0.OP2_3\(25),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4\(25));
\GRFPC0_STDATA_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000010000")
port map (
combout => CPO_DATAZ(22),
dataa => \GRFPC0.EX.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.STDATA_0\(22),
datad => \GRFPC0.STDATA_1_X\(22));
\GRFPC0_WRDATA_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => RFI1_WRDATAZ(22),
dataa => N_423,
datab => N_424,
datac => N_453,
datad => \GRFPC0.FP_PIPELINE.WRDATA_3\(54));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010101010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(54),
dataa => N_413,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13_X\,
datac => \GRFPC0.WR2.RREG.RES\(54),
datad => \GRFPC0.WR.CTRL.RDD_REP5\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_O2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_O2\(31),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP1_0_IV\(54),
datac => \GRFPC0.OP1_0_IV\(52),
datad => \GRFPC0.OP1_0_IV\(53));
\GRFPC0_OP2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(43),
dataa => \GRFPC0.OP2_6\(43),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(43));
\GRFPC0_OP2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2\(46),
dataa => \GRFPC0.OP2_6\(46),
datab => \GRFPC0.OP2_SN_M8_REP1\,
datac => \GRFPC0.OP2_5\(46));
\GRFPC0_OP2_6_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(11),
dataa => \GRFPC0.OP2_3\(11),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(11));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_1\(0),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5120_REGDEPX2_1_I_O2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_A3_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_A3_2_1\(0),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_3_2\(0),
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14_M_1_0_A2\(14));
\GRFPC0_V_STDATA_14_RNIC4021_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6326_REGDEPX2_I_I_A2_1_A2\,
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A3_0_1_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_I_I_A2_0_A2\,
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
\GRFPC0_V_STDATA_14_RNIC4021_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4121_REGDEPX2_I_I_A2\,
dataa => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.V.STDATA_14_I_M2\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(15));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_7\(0),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_2_0_A2_I_O3\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2_2_I_O3_I_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A4_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_282_0_IV_I_A4_1_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\);
GRFPC0_STDDEP_0_SQMUXA_111: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_111\,
dataa => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12));
GRFPC0_UN1_FIFO_INST_0_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111101")
port map (
combout => \GRFPC0.UN1_FIFO.INST_0_9\,
dataa => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\);
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1327_REGDEPX_RNI25F01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_112_I_I_A3\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(3),
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(5),
dataa => \GRFPC0.WR2.CTRL.INST\(5),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(10),
dataa => \GRFPC0.WR2.CTRL.INST\(10),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(31),
dataa => \GRFPC0.WR2.CTRL.INST\(31),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_1_2\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A4\(0),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP_0_A2\,
datac => \GRFPC0.EX.CTRL.RDD_REP4\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDEP_1_0_IV_I_A2_1_1\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.CPI_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11_1_X_RNIPBRV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_129_I_I_A2_I_O4\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_11_1_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4984_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX_0_A2\,
dataa => N_95,
datab => N_96,
datac => N_94,
datad => N_93);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_3_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_3_1\(7),
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(8),
dataa => \GRFPC0.WR2.CTRL.INST\(8),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(18),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.UN1_WR2.EXC\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_5\(0),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10_0_A2\(1),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_2_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_I\(0),
dataa => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_A2_4\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD_REP1\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2_0_A2_0_A2\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_13_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_13\(0),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_0_X\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_X\(8));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_5\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2680_REGDEPX_2_RNI3PBU: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_88_I_I_A2_I\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\,
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_D_STLCK_RNO_10_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_27_I_I_A3_I\,
dataa => N_242,
datab => N_243,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN259_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2\,
dataa => N_245,
datab => N_242,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP_1_X\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_DEP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP\(0),
dataa => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0));
GRFPC0_FP_PIPELINE_15_0_CHECK_DEP_UN4791_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4791_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4167_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_0_A2_RNIHHHP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_108_I_0_0_O3\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_0_A2\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_X_RNIU67R: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_137_I_I_A2_I_O2\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_X_RNITP7T: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_85_I_I_A2_I_O2\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\);
GRFPC0_STDDEP_0_SQMUXA_124_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_124_I_O2\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_VFIFO_INST_1_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_0\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
GRFPC0_VFIFO_INST_0_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000000000000")
port map (
combout => \GRFPC0.VFIFO.INST_0_1_0\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_UN1_DIV_EXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.UN1_DIV.EXC\,
dataa => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.DIV.EXC\);
GRFPC0_WR2_EXC_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000110000")
port map (
combout => \GRFPC0.WR2.EXC_0_0_G0_0_M3\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => N_38,
datac => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.UN1_WR2.CTRL.SEQERR\);
\GRFPC0_FP_PIPELINE_1_REGDEPX_30_0_A5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX_30_0_A5\(1),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN527_REGDEPX_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\(5));
\GRFPC0_FP_PIPELINE_0_REGDEPX_36_0_A5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX_36_0_A5\(1),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_X\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_1\(0),
dataa => N_89,
datab => N_90,
datac => N_97,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_X\(8));
\GRFPC0_R_STATE_RNIKLGJ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010001010")
port map (
combout => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I_2\,
dataa => N_3,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_4\(0),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4527_DEP_1_X\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_2_X\,
datad => \GRFPC0.EX.CTRL.RDD_REP2\);
\GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_DEP_2_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.DEP_2_IV\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_STDDEP_0_SQMUXA_110: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_110\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
GRFPC0_FP_PIPELINE_1_UN1_VEX_CTRL_RD_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_0\,
dataa => \GRFPC0.RFA.RD\(1),
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_UN1_VEX_CTRL_RD_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_1\,
dataa => \GRFPC0.RFA.RD\(2),
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => RFI2_RD2ADDRZ(1));
GRFPC0_FP_PIPELINE_1_UN1_VEX_CTRL_RD_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_2\,
dataa => \GRFPC0.RFA.RD\(3),
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => RFI2_RD2ADDRZ(2));
GRFPC0_FP_PIPELINE_1_UN1_VEX_CTRL_RD_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_VEX.CTRL.RD_1_3\,
dataa => \GRFPC0.RFA.RD\(4),
datab => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => RFI2_RD2ADDRZ(3));
GRFPC0_FP_PIPELINE_UN11_SHARE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
dataa => \GRFPC0.MEM.CTRL.LD\,
datab => \GRFPC0.MEM.CTRL.CCWR\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\);
\GRFPC0_R_STATE_RNINUUO7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101011111111")
port map (
combout => \GRFPC0.N_17807_I_0_G1\,
dataa => N_39,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_456_3_I_A2_2\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_2_X_RNI95CQ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_131_I_0_O4\,
dataa => N_104,
datab => N_105,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_5_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_STDDEP_0_SQMUXA_77_I_O2_RNI3OUJ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_A2_12\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_2_RNIUES9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_8\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\);
\GRFPC0_D_STLCK_RNO_4_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A3_1\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\);
GRFPC0_FP_PIPELINE_FCC_VALID_9_I_M4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_0\,
dataa => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A2\(1),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0_4\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(23),
dataa => N_82,
datab => N_81,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_1_0_0_A2_X\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_A2_3\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_0\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1),
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_FP_PIPELINE_12_0_STDEP_505_0_IV_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.STDEP_505_0_IV_I_A2_0\(0),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datac => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100001110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_9\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_4\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12_2_X\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A3_2\(0),
dataa => N_241,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1247_DEP\,
datac => \GRFPC0.EX.CTRL.RDD_REP2\,
datad => \GRFPC0.EX.CTRL.LD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2\(5),
dataa => N_81,
datab => N_82,
datac => \GRFPC0.N_25443_2\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_0_X\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3\(5),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_0\(0),
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_A4_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25),
datad => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0));
\GRFPC0_D_STLCK_RNO_12_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_26_I_I_A3_I\,
dataa => N_175,
datab => N_176,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3857_DEP_1_X\,
datad => \GRFPC0.RFA.LD_REP1\);
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_10\(0),
dataa => N_172,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_1_X\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4841_DEP_2_X\,
datad => \GRFPC0.RFA.RDD\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1561_DEP_0_X_RNIBSTK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_14_I_0\,
dataa => N_175,
datab => N_173,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP_0_X\,
datad => \GRFPC0.RFA.LD_REP1\);
\GRFPC0_INST_I_A2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000001")
port map (
combout => \GRFPC0.INST_I_A2_1\(4),
dataa => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_STDDEP_0_SQMUXA_119_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_119_0_A2\,
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_9_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_9\(15),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_0_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1_I_M_2\(25));
\GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_DEP_2_IV_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100110111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_2_IV\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_STDDEP_0_SQMUXA_84: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_84\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_A2_1_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111011111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_A2_1_I\(0),
dataa => N_105,
datab => N_104,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_10_2_X\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_O2_0\,
dataa => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3354_DEP\);
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_148_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148_0_A2\(0),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_5_1\(0));
\GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_DEP_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\);
\GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_DEP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP\(1),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_25_IV_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_IV\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.CPI_M_1_X\(64),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13_1_I_O4_X\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_A2_4\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_STDDEP_0_SQMUXA_113_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_113_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
GRFPC0_UN1_FIFO_INST_0_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.UN1_FIFO.INST_0_12\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\);
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_110_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\,
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1));
\GRFPC0_OP2_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(3),
dataa => \GRFPC0.OP2_3\(3),
datab => \GRFPC0.RFA2.RS2SEL\(7),
datac => \GRFPC0.OP2_4\(3));
GRFPC0_FP_PIPELINE_FIFOV2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FIFOV2\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M84_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_UINT17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UINT17\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_10\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC18LTO10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC18LTO10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_4\(0),
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD9\,
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD9\,
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O4_1\(0),
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD9\,
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
GRFPU0_GRFPU_X0_ITER_NX_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000000110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4_I_M\,
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.DRES_S\(66),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_0_O3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001100000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0_0_O3\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_13_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000111010")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_9\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_0\(57),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.G_53_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_1_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0_M2\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(41),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_REP3_RNI38GB2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_8_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0_X2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(60),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(60),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(60),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(61),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_0_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(61),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(61),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(57),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_7_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_7\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3\(31),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD25\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\(31),
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_1\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.G_53_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIJR9N_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_1\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_A2_5_0_A3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_5_0_A3\(33),
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_A2_6_I_O2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_6_I_O2\(33),
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2_REP1\(48),
datad => \GRFPU0.GRFPU_X0.G_53_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_9_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_9\(31),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_13\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_9\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(20),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.INST\(20),
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(20));
\GRFPU0_DIVROM0_DATA_1_MUX_7_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101111101010111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_7\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_5\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(31),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(27),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(26),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(18),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(16),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(16),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(15),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(14),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(14),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(8),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(8),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(4),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(4),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(3),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(3),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(3));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_0_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2\(1),
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPU0.GRFPU_X0.UN1_RAW1\(0),
datac => \GRFPU0.GRFPU_X0.UN1_DP\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M2\(17),
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(18),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD12\,
datab => \GRFPU0.MULO.DRES_S\(77),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(18),
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD12\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_2\(59),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(27),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(27),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(16),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(16),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(15),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(15),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(24),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(24),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(33),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(33),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_A_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(31),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(31),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(29),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(30),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD24\,
datab => \GRFPU0.MULO.DRES_S\(89),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(30),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD24\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2\(29),
dataa => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(29),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_STATE_45_0_M2_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.STATE_45_0_M2_0\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(27),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD21\,
datab => \GRFPU0.MULO.DRES_S\(86),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(27),
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD21\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(10),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD4\,
datab => \GRFPU0.MULO.DRES_S\(69),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(10),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD4\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(22),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD16\,
datab => \GRFPU0.MULO.DRES_S\(81),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(22),
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD16\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(25),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD19\,
datab => \GRFPU0.MULO.DRES_S\(84),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(25),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD19\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(14),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD8\,
datab => \GRFPU0.MULO.DRES_S\(73),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(14),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD8\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(26),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD20\,
datab => \GRFPU0.MULO.DRES_S\(85),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(26),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD20\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(38),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD32\,
datab => \GRFPU0.MULO.DRES_S\(97),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(38),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD32\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(29),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD23\,
datab => \GRFPU0.MULO.DRES_S\(88),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(29),
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD23\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(56),
dataa => \GRFPU0.MULO.DRES_S\(115),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD50\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(56),
dataa => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD50\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(28),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD22\,
datab => \GRFPU0.MULO.DRES_S\(87),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_A_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(28),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD22\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(12),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD6\,
datab => \GRFPU0.MULO.DRES_S\(71),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_A_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(12),
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD6\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_1\(16),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_3\(16),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(55),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.EXP_14\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(21),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD15\,
datab => \GRFPU0.MULO.DRES_S\(80),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(21),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD15\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(32),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(35),
dataa => \GRFPU0.MULO.DRES_S\(94),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD29\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(35),
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD29\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(19),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD13\,
datab => \GRFPU0.MULO.DRES_S\(78),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(19),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD13\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(31),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD25\,
datab => \GRFPU0.MULO.DRES_S\(90),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(31),
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD25\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(34),
dataa => \GRFPU0.MULO.DRES_S\(93),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD28\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(34),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD28\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(58),
dataa => \GRFPU0.MULO.DRES_S\(117),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD52\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(58),
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(33),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD27\,
datab => \GRFPU0.MULO.DRES_S\(92),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(33),
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD27\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(49),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(58),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
datac => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(57),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(57),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datac => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(57),
dataa => \GRFPU0.MULO.DRES_S\(116),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD51\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(57),
dataa => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(45),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(16),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD10\,
datab => \GRFPU0.MULO.DRES_S\(75),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(16),
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(51),
dataa => \GRFPU0.MULO.DRES_S\(110),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD45\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(51),
dataa => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD45\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(11),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD5\,
datab => \GRFPU0.MULO.DRES_S\(70),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(11),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD5\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(55),
dataa => \GRFPU0.MULO.DRES_S\(114),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD49\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(55),
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD49\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(13),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD7\,
datab => \GRFPU0.MULO.DRES_S\(72),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(13),
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(52),
dataa => \GRFPU0.MULO.DRES_S\(111),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD46\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(52),
dataa => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD46\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M2\(12),
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(54),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
datac => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(57),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(39),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_REST_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.REST_2_A\(5));
\GRFPU0_GRFPU_X0_REST_2_A_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000111110000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_A\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(46),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(46),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(54),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(54),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(23),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD17\,
datab => \GRFPU0.MULO.DRES_S\(82),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(23),
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD17\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(37),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD31\,
datab => \GRFPU0.MULO.DRES_S\(96),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(37),
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(15),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD9\,
datab => \GRFPU0.MULO.DRES_S\(74),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(15),
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_33\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G0\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_29\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_25\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03_1\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.L3_REP1\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G1\);
\GRFPU0_SQRTROM0_DATA_1_MUX_7_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(0),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(1),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(1));
\GRFPU0_SQRTROM0_DATA_1_MUX_7_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(3),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(3));
\GRFPU0_SQRTROM0_DATA_1_MUX_7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101011011000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(4),
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_4\(3));
\GRFPU0_SQRTROM0_DATA_1_MUX_7_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001101110010001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_4\(5));
\GRFPU0_DIVROM0_DATA_1_MUX_7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_7\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.DATA_1_MUX_6\(4),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_3\(4));
\GRFPU0_DIVROM0_DATA_1_MUX_7_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010110110001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_7\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_6\(5),
datad => \GRFPU0.DIVROM0.DATA_1_MUX_2\(5));
\GRFPU0_DIVROM0_DATA_1_MUX_14_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110010101100100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_14\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_MUX_14_A\(4),
datad => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_1\);
\GRFPU0_DIVROM0_DATA_1_MUX_14_A_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001100010011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_14_A\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(54),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIR5L31_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(14));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIT5L31_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(15),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(15));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIV5L31_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(16),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNITDL31_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(22));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIAUL31_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(27),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(27));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L3\(5),
datab => \GRFPU0.GRFPU_X0.L4_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\);
GRFPU0_GRFPU_X0_COMB_UN8_SIGN1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN8_SIGN1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datad => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\);
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_CCV12_RNIO3NA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_3_SQMUXA_S4_2_I_O2\,
dataa => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datab => \GRFPU0.GRFPU_X0.COMB.CCV12\);
GRFPU0_GRFPU_X0_VST2_EXC_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
GRFPU0_GRFPU_X0_UN1_CCV12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110011011100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_CCV12\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(3),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(3),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_IDOUT_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(4),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(4),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(6),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14_REP0\(6),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(2),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(2),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIVDL31_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(23),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(23));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(53),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(12),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(12),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(0),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.INST\(0),
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.V.STDATA_14_I_M2\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(1),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.INST\(1),
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(11),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14_REP1\(11),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(11));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\,
datad => \GRFPU0.GRFPU_X0.UN8_DIFF2\(53));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI4HK21_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_761\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(13),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(13),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(19),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14_I_M2\(19),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(21),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(21),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(21));
\GRFPU0_GRFPU_X0_L1_0_5_0_O3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5_0_O3\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.L1_0_5_0_A2_0_0\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(53),
dataa => \GRFPU0.MULO.DRES_S\(112),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD47\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(53),
dataa => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD47\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O2_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011011100000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_3\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_3\(5));
\GRFPU0_GRFPU_X0_L3_0_3_0_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_3\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_4\(1),
datad => \GRFPU0.GRFPU_X0.UN83_BCO_LSB_0_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(50),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(50),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
GRFPU0_GRFPU_X0_UN1_VCS_ITER15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(59),
dataa => \GRFPU0.MULO.DRES_S\(118),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD53\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(59),
dataa => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(42),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(39),
dataa => \GRFPU0.MULO.DRES_S\(99),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD34\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0_A\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_0_A_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0_A\(39),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD34\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0\(40),
dataa => \GRFPU0.MULO.DRES_S\(100),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD35\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0_A\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M4_0_A_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4_0_A\(40),
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O4_2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
GRFPU0_GRFPU_X0_COMB_VCS_ITER_1_I_M3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VCS_ITER_1_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_1\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\(58));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_I_M2\(21));
GRFPU0_GRFPU_X0_ST2_RDY_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.RDY_0_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\);
\GRFPU0_GRFPU_X0_REST_1_1_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011111000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_1_2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
\GRFPU0_GRFPU_X0_REST_1_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.REST_1_2_2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
GRFPU0_GRFPU_X0_UN1_ST1_FLTYPE2_65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST1.FLTYPE2_65\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(30),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.INST\(30),
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(30));
GRFPU0_GRFPU_X0_COMB_UN2_FLOP_16_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_16_6\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(12),
datac => \GRFPC0.V.STDATA_14\(10),
datad => \GRFPC0.V.STDATA_14_REP0\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(23),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(23),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(29),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(29));
\GRFPC0_FIFO_INST_1_RNI84VN3_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_I_I_A2_1_A2_1_A2\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(47),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(47),
datac => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I\);
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_0\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.UN83_BCO_LSB_0_0_O2\,
datad => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_1\(2));
\GRFPU0_GRFPU_X0_L1_1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_4\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_3_I\(1),
datad => \GRFPU0.GRFPU_X0.UN213_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_I\(1),
datad => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2\(1),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_1_1_I\(1),
datab => \GRFPU0.GRFPU_X0.L1_0_1_2_I_I_A3\(1),
datac => \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\);
\GRFPU0_GRFPU_X0_L1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001101010011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3\(1),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_4_I\(1),
datab => \GRFPU0.GRFPU_X0.L1_3_1_1_I\(1),
datac => \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\);
\GRFPU0_GRFPU_X0_L1_4_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_5_1_I\(1),
datad => \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_6_1_I\(1),
datad => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\);
\GRFPU0_GRFPU_X0_L4_2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN168_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNI1EL31_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(24),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(24));
\GRFPU0_GRFPU_X0_L3_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN238_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_L1_0_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_1_3_I\(1),
datad => \GRFPU0.GRFPU_X0.UN208_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_2_I\(1),
datad => \GRFPU0.GRFPU_X0.UN218_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_3_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_4_2_I\(1),
datad => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_4_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_5_2_I\(1),
datad => \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_5_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_6_2_I\(1),
datad => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datac => \GRFPU0.GRFPU_X0.L1_6_1_2_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN238_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_1_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001101010101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_3\(1),
dataa => \GRFPU0.GRFPU_X0.L1_1_1_2_I_1\(1),
datab => \GRFPU0.GRFPU_X0.L2_2\(4),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN93_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_I\(1),
datad => \GRFPU0.GRFPU_X0.UN98_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3\(9),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD3\,
datab => \GRFPU0.MULO.DRES_S\(68),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3_A\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M3_A_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M3_A\(9),
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(5),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(5),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(5));
GRFPC0_FP_PIPELINE_UN8_OP_7_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\,
dataa => \GRFPC0.V.STDATA_14\(12),
datab => \GRFPC0.V.STDATA_14\(5),
datac => \GRFPC0.V.STDATA_14_REP0\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(9),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(9),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(22),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.INST\(22),
datac => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(10),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(10),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(24),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(24),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(24));
GRFPC0_FP_PIPELINE_UN17_OP_7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN17_OP_7_3\,
dataa => \GRFPC0.V.STDATA_14\(13),
datab => \GRFPC0.V.STDATA_14\(9),
datac => \GRFPC0.V.STDATA_14\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(7),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14\(7),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(7));
\GRFPU0_GRFPU_X0_L1_0_1_6_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_6_0\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(28),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(29),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(30));
GRFPU0_GRFPU_X0_UN242_BCO_MSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(1),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(2),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(3));
\GRFPU0_GRFPU_X0_BCO_MSB_4_5_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(1),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(2),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(3));
\GRFPU0_GRFPU_X0_L1_2_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_7\(1),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(14),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_1_7_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_7\(1),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(22),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(23),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_0\(57),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2\(57),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_L1_2_1_6_0_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_6_0_I\(0),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(13),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(14),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15));
\GRFPU0_GRFPU_X0_L1_3_1_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.L1_3_1_4_A4_0\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_7_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_7\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(2),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M3\(15));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0_RNIK5VD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\);
\GRFPU0_GRFPU_X0_L1_4_1_4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.L1_4_1_4_A4_0\(0));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(3),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIKTFA1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
GRFPU0_GRFPU_X0_COMB_FLOP4_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIHTFA1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001110100011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000111110101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(6),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(5),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M4_0_O2_RNIVG4V1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.G_34_I_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_O2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.ND_I_0_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_M3_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M3\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\);
\GRFPU0_GRFPU_X0_L4_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2\(2),
dataa => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_0_1_I\,
datab => \GRFPU0.GRFPU_X0.L1_6_1_I_A4\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010001010101000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\);
\GRFPU0_GRFPU_X0_L1_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_5_I\(1),
datad => \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_L1_5_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_6_I\(1),
datad => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\);
GRFPU0_GRFPU_X0_VST2_V_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000010010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.V_0_SQMUXA\,
dataa => \GRFPC0.RFA2.FID\(5),
datab => \GRFPU0.GRFPU_X0.ST1.IDCST\(5),
datac => \GRFPC0.RFA2.FLUSH\,
datad => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT4\);
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001111101101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN77_FLUSH_I\,
dataa => \GRFPC0.RFA2.FID\(5),
datab => \GRFPU0.GRFPU_X0.ITER.IDCST\(5),
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT4\);
GRFPU0_GRFPU_X0_COMB_UN1_SGNFOF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.FPMUL0.UN1_SIN_3_ADD55\,
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPU0_GRFPU_X0_ST3_V_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110000010010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.V_0_I_A2\,
dataa => \GRFPC0.RFA2.FID\(5),
datab => \GRFPU0.GRFPU_X0.ST2.IDCST\(5),
datac => \GRFPC0.RFA2.FLUSH\,
datad => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT4\);
\GRFPU0_GRFPU_X0_IDOUT_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(5),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(5),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
GRFPU0_GRFPU_X0_UN1_VALLOW: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100001111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_O2_0\,
datad => \GRFPU0.MULO.MRES\(97));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2\,
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD0\,
datac => \GRFPU0.MULO.MRES_BUF\(121),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2_A\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2_A\,
dataa => \GRFPU0.FPMUL0.CSADD.S1_1\(68),
datab => \GRFPU0.MULO.MRES\(68),
datac => \GRFPU0.MULO.MRES_BUF\(121),
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
GRFPU0_GRFPU_X0_COMB_UN63_BLSB_0_A2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010110100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIUC6R_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_0_385\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datad => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_0_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_0_A2_2_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_25_IV_0_O2_I_A2\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(17),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_14_I_M2\(17),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_5\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2_0_A2_0_0_A4\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V18_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18_1\,
dataa => \GRFPC0.INST\(21),
datab => \GRFPC0.INST_I_M5\(19));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001001010000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_O3\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST\(5),
datac => \GRFPC0.INST_I_X\(6),
datad => \GRFPC0.INST_I\(8));
GRFPC0_FP_PIPELINE_IS_RS1V_TMP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111010111110")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP_0\,
dataa => \GRFPC0.INST_I_M5\(19),
datab => \GRFPC0.INST_I\(11),
datac => \GRFPC0.INST_I\(12));
GRFPC0_FP_PIPELINE_RSDEC_RS1V4_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_1\,
dataa => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datab => \GRFPC0.INST_I_0_M2_X\(13),
datac => \GRFPC0.INST_I_0_M2_0_X\(13),
datad => \GRFPC0.INST_I\(8));
GRFPC0_STDDEP_0_SQMUXA_24_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_24_0_A2_0\,
dataa => N_173,
datab => N_174,
datac => N_175,
datad => N_176);
GRFPC0_FP_PIPELINE_UN24_FPUSTART: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
dataa => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0_X\,
datab => \GRFPC0.RFA.ST\,
datac => \GRFPC0.RFA.LD_REP1\,
datad => \GRFPC0.FP_PIPELINE.FPUSTART_7\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(28),
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI_3_X\,
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(28));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_12_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_12_0_A2_0\(0),
dataa => N_173,
datab => N_174,
datac => N_175,
datad => N_176);
\GRFPC0_UN1_PENDEXC_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010001110111")
port map (
combout => \GRFPC0.UN1_PENDEXC_3\(0),
dataa => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD10_X\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC23\,
datad => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
\GRFPC0_INST_I_A2_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010100")
port map (
combout => \GRFPC0.INST_I_A2_0\(4),
dataa => \GRFPC0.FIFO.INST_1\(4),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNI5QB41_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111100000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(2),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\);
GRFPU0_GRFPU_X0_ITER_SIGN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_M3\,
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_I_O3\,
datad => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\);
GRFPU0_GRFPU_X0_COMB_UN13_ITER_OF_RNIUD891: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_X2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datad => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_O2\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.MULO.MRES_BUF\(121),
datac => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD53\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
GRFPU0_GRFPU_X0_ST4_MOF_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19993_I_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.MULO.MRES_BUF\(121),
datac => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD53\,
datad => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_UN1_ST3_EMINM1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.EMINM1\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.EMINM1\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_2_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIRUQT1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(2),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_2\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_4_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_4\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIT6RT1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(3),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNI9NST1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(9),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNIL5L31_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(11),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(11));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_A2_4_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_A2_4\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_O2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_O2\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_6\(53));
\GRFPU0_GRFPU_X0_L1_6_1_4_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_4_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.UN68_BCO_LSB_0_1\);
\GRFPU0_GRFPU_X0_L1_5_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011100110011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datac => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\,
datad => \GRFPU0.GRFPU_X0.L1_5_5_A\(1));
\GRFPU0_GRFPU_X0_L1_5_5_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5_A\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\);
\GRFPU0_GRFPU_X0_L1_1_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_6\(1),
dataa => \GRFPU0.GRFPU_X0.TZI2\(9),
datab => \GRFPU0.GRFPU_X0.TZI2\(8),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN43_BCO_LSB\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_A_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010100000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_A\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNI5EL31_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(26),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(26));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_1\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datad => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_I_A2_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_I_A2_1\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datad => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(2),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(2),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_IDOUT_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(1),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(1),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_IDOUT_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101010")
port map (
combout => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(0),
datab => \GRFPU0.GRFPU_X0.ST3.IDCST\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
datad => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_RNI3EL31_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(25),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
datac => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_8_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_8\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O2\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(36),
dataa => \GRFPU0.MULO.DRES_S\(95),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD30\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(36),
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD30\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(24),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD18\,
datab => \GRFPU0.MULO.DRES_S\(83),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(24),
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD18\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
GRFPU0_GRFPU_X0_COMB_S_DP_1_1_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U\,
dataa => \GRFPU0.GRFPU_X0.ST3.STICKY\,
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U_A\);
GRFPU0_GRFPU_X0_COMB_S_DP_1_1_U_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100011011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_U_A\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
GRFPU0_GRFPU_X0_UN143_BCO_LSB_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2\(8),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD2\,
datab => \GRFPU0.MULO.DRES_S\(67),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_A_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_I_M2_A\(8),
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3\(44),
dataa => \GRFPU0.MULO.DRES_S\(103),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD38\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_A_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010111110011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_3_A\(44),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP_I_REP1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_2_01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\);
GRFPC0_RFA2_RS2DEP_RNO_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111110110111110")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_1\,
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(3),
datac => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(1));
GRFPC0_RFA2_RS2DEP_RNO_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111111110001")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2598_TZ_M4_0_0\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.RD\(4),
datad => RFI2_RD2ADDRZ(3));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_56_M6_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_56_M6_I_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datab => \GRFPU0.MULO.MRES\(94),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datab => \GRFPU0.MULO.MRES\(90),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => \GRFPU0.MULO.MRES\(87),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => \GRFPU0.MULO.MRES\(73),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datab => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(58),
datab => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datab => \GRFPU0.MULO.MRES\(68),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datab => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.MULO.MRES\(80),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(52),
datab => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.MULO.MRES\(100),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.MULO.MRES\(98),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datab => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(53),
datab => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(57),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(57),
datab => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datab => \GRFPU0.MULO.MRES\(89),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datab => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0_0\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.MULO.MRES\(101),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datab => \GRFPU0.MULO.MRES\(71),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datab => \GRFPU0.MULO.MRES\(111),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(54),
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datab => \GRFPU0.MULO.MRES\(70),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(56),
datab => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(59),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
datab => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datab => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(55),
datab => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datab => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datab => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datab => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => \GRFPU0.MULO.MRES\(76),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.MULO.MRES\(85),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datab => \GRFPU0.MULO.MRES\(86),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datab => \GRFPU0.MULO.MRES\(79),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datab => \GRFPU0.MULO.MRES\(93),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.MULO.MRES\(91),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.MULO.MRES\(66),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(5),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(0),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(60),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(2),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(1),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
datab => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(3),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(4),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_IV_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV_0\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.VITER.ND_I_4_SQMUXA_REP2\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_REP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_2_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2_0\(56),
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_8_RNI8KEM7_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M7_I_A4_1\,
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD45\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0_0\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST_I\(12),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.INST_I\(11));
GRFPC0_FP_PIPELINE_1_WR2EN10_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10_2\,
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(1),
datac => RFI2_RD2ADDRZ(3),
datad => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_WRENX10_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10_2\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => RFI2_RD2ADDRZ(3),
datad => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_REGDEP132_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132_1\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4),
datac => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(3));
GRFPC0_FP_PIPELINE_1_REGDEP132_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132_0\,
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_REGDEP160_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP160_0\,
dataa => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(0));
GRFPC0_FP_PIPELINE_1_REGDEP118_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118_1\,
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(3),
datac => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(3));
GRFPC0_FP_PIPELINE_1_REGDEP118_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118_0\,
dataa => \GRFPC0.WR2.CTRL.RD\(2),
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(1));
GRFPC0_FP_PIPELINE_1_REGDEP146_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010010000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP146_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RDWR\,
datac => RFI2_RD2ADDRZ(1));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_I_A2_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_I_A2_1_1\,
dataa => \GRFPC0.INST\(31),
datab => \GRFPC0.INST_I\(10),
datac => \GRFPC0.INST_I\(12),
datad => \GRFPC0.INST_I\(11));
GRFPC0_STDEP_2_SQMUXA_133_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_133_0\,
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\(53),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD47\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M4\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4_3\(38),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD32\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M4\(38));
GRFPC0_RFA_ST_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_1622_A2_2\,
dataa => N_99,
datab => N_101,
datac => N_102,
datad => N_109);
GRFPU0_GRFPU_X0_ITER_V_REP3_RNIG58I7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_3_TZ_TZ_0\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A0_3_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A0_3_1\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.MULO.MRES\(112),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(43),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datac => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000010111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(45),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datad => \GRFPU0.MULO.MRES\(105));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23),
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_UN166_RNDOP_RNIQ2N26_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000100010")
port map (
combout => D_M4_I_A4_0_0,
dataa => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(9),
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(9),
datad => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_UN166_RNDOP_RNITMLN5_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => D_M3_E_0_0,
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(5),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(5),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI7TT81_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
GRFPC0_MEM_CTRL_PEND_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0_A3_2\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.MEM.CTRL.VCNT\(1),
datac => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(51));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE46_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_3\,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(57),
datac => \GRFPC0.OP2\(58),
datad => \GRFPC0.OP2\(60));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN28_DP_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN28_DP_5\,
dataa => \GRFPC0.OP2\(57),
datab => \GRFPC0.OP2\(58),
datac => \GRFPC0.OP2\(61),
datad => \GRFPC0.OP2\(52));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_5\,
dataa => \GRFPC0.OP2\(57),
datab => \GRFPC0.OP2\(58),
datac => \GRFPC0.OP2\(52),
datad => \GRFPC0.OP2\(54));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_1_2\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datac => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O2_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_4\(3),
dataa => \GRFPC0.OP1_0_IV\(61),
datab => \GRFPC0.OP1_0_IV\(57),
datac => \GRFPC0.OP1_0_IV\(55));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O2_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_I_O2_3\(3),
dataa => \GRFPC0.OP1_0_IV\(58),
datab => \GRFPC0.OP1_0_IV\(62),
datac => \GRFPC0.OP1_0_IV\(59));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_1_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\(4),
dataa => \GRFPC0.OP1_0_IV\(60),
datab => \GRFPC0.OP1_0_IV\(57),
datac => \GRFPC0.OP1_0_IV\(55));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_1_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_3\(4),
dataa => \GRFPC0.OP1_0_IV\(58),
datab => \GRFPC0.OP1_0_IV\(62),
datac => \GRFPC0.OP1_0_IV\(59));
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_I_S_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_S_4\,
dataa => \GRFPC0.WR.CTRL.INST\(30),
datab => \GRFPC0.WR.CTRL.INST\(24),
datac => \GRFPC0.WR.CTRL.INST\(23),
datad => \GRFPC0.WR.CTRL.INST\(31));
GRFPU0_GRFPU_X0_VALLOW_4_SQMUXA_6_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_0_1\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(54),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(53),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111000001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_3_400\);
\GRFPC0_INST_I_A2_0_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010000010100")
port map (
combout => \GRFPC0.INST_I_A2_0_0\(11),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7\);
\GRFPC0_INST_I_A2_0_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010000010100")
port map (
combout => \GRFPC0.INST_I_A2_0_0\(12),
dataa => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\);
GRFPC0_FP_PIPELINE_UN205_HOLDN_3_7_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_3_7_2\,
dataa => N_113,
datab => N_38,
datac => N_112,
datad => N_39);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101000100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.MULO.MRES_BUF\(121));
\GRFPC0_OP1_0_IV_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(55),
dataa => \GRFPC0.WR2.RREG.RES\(55),
datab => \GRFPC0.WR.RREG.RES\(55),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(55),
dataa => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.DIV.RESULT\(55),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(52),
dataa => \GRFPC0.WR2.RREG.RES\(52),
datab => \GRFPC0.WR.RREG.RES\(52),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(52),
dataa => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.DIV.RESULT\(52),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPU0_GRFPU_X0_BCO_MSB_2_4_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_4_I_0\(1),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
\GRFPC0_OP1_0_IV_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(57),
dataa => \GRFPC0.EX.RREG.RES\(57),
datab => \GRFPC0.DIV.RESULT\(57),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(54),
dataa => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.EX.RREG.RES\(54),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(54),
dataa => \GRFPC0.WR2.RREG.RES\(54),
datab => \GRFPC0.DIV.RESULT\(54),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(61),
dataa => \GRFPC0.WR2.RREG.RES\(61),
datab => \GRFPC0.WR.RREG.RES\(61),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_0_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(61),
dataa => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.DIV.RESULT\(61),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(58),
dataa => \GRFPC0.WR2.RREG.RES\(58),
datab => \GRFPC0.WR.RREG.RES\(58),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(58),
dataa => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.DIV.RESULT\(58),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(60),
dataa => \GRFPC0.WR2.RREG.RES\(60),
datab => \GRFPC0.WR.RREG.RES\(60),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(60),
dataa => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.DIV.RESULT\(60),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(51),
dataa => \GRFPC0.WR2.RREG.RES\(51),
datab => \GRFPC0.WR.RREG.RES\(51),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(37),
dataa => \GRFPC0.WR2.RREG.RES\(37),
datab => \GRFPC0.WR.RREG.RES\(37),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(37),
dataa => \GRFPC0.EX.RREG.RES\(37),
datab => \GRFPC0.DIV.RESULT\(37),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(39),
dataa => \GRFPC0.WR2.RREG.RES\(39),
datab => \GRFPC0.WR.RREG.RES\(39),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(39),
dataa => \GRFPC0.EX.RREG.RES\(39),
datab => \GRFPC0.DIV.RESULT\(39),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(46),
dataa => \GRFPC0.MEM.RREG.RES\(46),
datab => \GRFPC0.EX.RREG.RES\(46),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(48),
dataa => \GRFPC0.WR2.RREG.RES\(48),
datab => \GRFPC0.WR.RREG.RES\(48),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(40),
dataa => \GRFPC0.MEM.RREG.RES\(40),
datab => \GRFPC0.EX.RREG.RES\(40),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(35),
dataa => \GRFPC0.WR2.RREG.RES\(35),
datab => \GRFPC0.WR.RREG.RES\(35),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(35),
dataa => \GRFPC0.MEM.RREG.RES\(35),
datab => \GRFPC0.DIV.RESULT\(35),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(41),
dataa => \GRFPC0.MEM.RREG.RES\(41),
datab => \GRFPC0.DIV.RESULT\(41),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(49),
dataa => \GRFPC0.WR2.RREG.RES\(49),
datab => \GRFPC0.WR.RREG.RES\(49),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(32),
dataa => \GRFPC0.WR2.RREG.RES\(32),
datab => \GRFPC0.WR.RREG.RES\(32),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(32),
dataa => \GRFPC0.MEM.RREG.RES\(32),
datab => \GRFPC0.DIV.RESULT\(32),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(33),
dataa => \GRFPC0.WR2.RREG.RES\(33),
datab => \GRFPC0.WR.RREG.RES\(33),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(33),
dataa => \GRFPC0.EX.RREG.RES\(33),
datab => \GRFPC0.DIV.RESULT\(33),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(38),
dataa => \GRFPC0.WR2.RREG.RES\(38),
datab => \GRFPC0.WR.RREG.RES\(38),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(38),
dataa => \GRFPC0.EX.RREG.RES\(38),
datab => \GRFPC0.DIV.RESULT\(38),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(36),
dataa => \GRFPC0.WR2.RREG.RES\(36),
datab => \GRFPC0.WR.RREG.RES\(36),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(43),
dataa => \GRFPC0.MEM.RREG.RES\(43),
datab => \GRFPC0.EX.RREG.RES\(43),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(43),
dataa => \GRFPC0.WR.RREG.RES\(43),
datab => \GRFPC0.DIV.RESULT\(43),
datac => \GRFPC0.RFA2.RS1SEL\(3),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_I_A2_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_1\(45),
dataa => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.DIV.RESULT\(45),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_I_A2_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_0\(45),
dataa => \GRFPC0.WR2.RREG.RES\(45),
datab => \GRFPC0.WR.RREG.RES\(45),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(42),
dataa => \GRFPC0.WR2.RREG.RES\(42),
datab => \GRFPC0.WR.RREG.RES\(42),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(42),
dataa => \GRFPC0.MEM.RREG.RES\(42),
datab => \GRFPC0.DIV.RESULT\(42),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(34),
dataa => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPC0.WR.RREG.RES\(34),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(34),
dataa => \GRFPC0.EX.RREG.RES\(34),
datab => \GRFPC0.DIV.RESULT\(34),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
GRFPC0_UN28_WREN_M8_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111000")
port map (
combout => \GRFPC0.UN28_WREN_M8_I_1\,
dataa => \GRFPC0.WR2.CTRL.AFSR\,
datab => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.CTRL.SEQERR\);
\GRFPC0_OP1_0_IV_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(56),
dataa => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.DIV.RESULT\(56),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(53),
dataa => \GRFPC0.WR2.RREG.RES\(53),
datab => \GRFPC0.WR.RREG.RES\(53),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(53),
dataa => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.DIV.RESULT\(53),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(59),
dataa => \GRFPC0.WR2.RREG.RES\(59),
datab => \GRFPC0.WR.RREG.RES\(59),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_1_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(62),
dataa => \GRFPC0.WR2.RREG.RES\(62),
datab => \GRFPC0.WR.RREG.RES\(62),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(26),
dataa => \GRFPC0.WR2.RREG.RES\(26),
datab => \GRFPC0.WR.RREG.RES\(26),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(26),
dataa => \GRFPC0.EX.RREG.RES\(26),
datab => \GRFPC0.DIV.RESULT\(26),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(47),
dataa => \GRFPC0.MEM.RREG.RES\(47),
datab => \GRFPC0.EX.RREG.RES\(47),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(2),
dataa => \GRFPC0.WR2.RREG.RES\(2),
datab => \GRFPC0.WR.RREG.RES\(2),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(2),
dataa => \GRFPC0.MEM.RREG.RES\(2),
datab => \GRFPC0.DIV.RESULT\(2),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(31),
dataa => \GRFPC0.WR2.RREG.RES\(31),
datab => \GRFPC0.WR.RREG.RES\(31),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(31),
dataa => \GRFPC0.MEM.RREG.RES\(31),
datab => \GRFPC0.DIV.RESULT\(31),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(24),
dataa => \GRFPC0.WR2.RREG.RES\(24),
datab => \GRFPC0.WR.RREG.RES\(24),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(24),
dataa => \GRFPC0.MEM.RREG.RES\(24),
datab => \GRFPC0.DIV.RESULT\(24),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(3),
dataa => \GRFPC0.MEM.RREG.RES\(3),
datab => \GRFPC0.EX.RREG.RES\(3),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(3),
dataa => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.DIV.RESULT\(3),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(22),
dataa => \GRFPC0.WR2.RREG.RES\(22),
datab => \GRFPC0.WR.RREG.RES\(22),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(22),
dataa => \GRFPC0.EX.RREG.RES\(22),
datab => \GRFPC0.DIV.RESULT\(22),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(0),
dataa => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.WR.RREG.RES\(0),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(0),
dataa => \GRFPC0.MEM.RREG.RES\(0),
datab => \GRFPC0.DIV.RESULT\(0),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(20),
dataa => \GRFPC0.WR2.RREG.RES\(20),
datab => \GRFPC0.WR.RREG.RES\(20),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(20),
dataa => \GRFPC0.EX.RREG.RES\(20),
datab => \GRFPC0.DIV.RESULT\(20),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(19),
dataa => \GRFPC0.WR2.RREG.RES\(19),
datab => \GRFPC0.WR.RREG.RES\(19),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(19),
dataa => \GRFPC0.EX.RREG.RES\(19),
datab => \GRFPC0.DIV.RESULT\(19),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(9),
dataa => \GRFPC0.WR2.RREG.RES\(9),
datab => \GRFPC0.WR.RREG.RES\(9),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(9),
dataa => \GRFPC0.EX.RREG.RES\(9),
datab => \GRFPC0.DIV.RESULT\(9),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(16),
dataa => \GRFPC0.WR2.RREG.RES\(16),
datab => \GRFPC0.DIV.RESULT\(16),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(16),
dataa => \GRFPC0.MEM.RREG.RES\(16),
datab => \GRFPC0.EX.RREG.RES\(16),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(4),
dataa => \GRFPC0.WR2.RREG.RES\(4),
datab => \GRFPC0.WR.RREG.RES\(4),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(4),
dataa => \GRFPC0.MEM.RREG.RES\(4),
datab => \GRFPC0.DIV.RESULT\(4),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(15),
dataa => \GRFPC0.WR2.RREG.RES\(15),
datab => \GRFPC0.WR.RREG.RES\(15),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(15),
dataa => \GRFPC0.MEM.RREG.RES\(15),
datab => \GRFPC0.DIV.RESULT\(15),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(50),
dataa => \GRFPC0.WR2.RREG.RES\(50),
datab => \GRFPC0.WR.RREG.RES\(50),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(25),
dataa => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPC0.WR.RREG.RES\(25),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(25),
dataa => \GRFPC0.MEM.RREG.RES\(25),
datab => \GRFPC0.DIV.RESULT\(25),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(10),
dataa => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPC0.WR.RREG.RES\(10),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(10),
dataa => \GRFPC0.EX.RREG.RES\(10),
datab => \GRFPC0.DIV.RESULT\(10),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(30),
dataa => \GRFPC0.WR2.RREG.RES\(30),
datab => \GRFPC0.WR.RREG.RES\(30),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(30),
dataa => \GRFPC0.MEM.RREG.RES\(30),
datab => \GRFPC0.DIV.RESULT\(30),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(6),
dataa => \GRFPC0.WR2.RREG.RES\(6),
datab => \GRFPC0.WR.RREG.RES\(6),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(6),
dataa => \GRFPC0.EX.RREG.RES\(6),
datab => \GRFPC0.DIV.RESULT\(6),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(7),
dataa => \GRFPC0.WR2.RREG.RES\(7),
datab => \GRFPC0.WR.RREG.RES\(7),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(7),
dataa => \GRFPC0.EX.RREG.RES\(7),
datab => \GRFPC0.DIV.RESULT\(7),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(23),
dataa => \GRFPC0.WR2.RREG.RES\(23),
datab => \GRFPC0.WR.RREG.RES\(23),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(23),
dataa => \GRFPC0.EX.RREG.RES\(23),
datab => \GRFPC0.DIV.RESULT\(23),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(17),
dataa => \GRFPC0.WR2.RREG.RES\(17),
datab => \GRFPC0.WR.RREG.RES\(17),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(17),
dataa => \GRFPC0.EX.RREG.RES\(17),
datab => \GRFPC0.DIV.RESULT\(17),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(14),
dataa => \GRFPC0.WR2.RREG.RES\(14),
datab => \GRFPC0.WR.RREG.RES\(14),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(14),
dataa => \GRFPC0.EX.RREG.RES\(14),
datab => \GRFPC0.DIV.RESULT\(14),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(11),
dataa => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPC0.WR.RREG.RES\(11),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(11),
dataa => \GRFPC0.EX.RREG.RES\(11),
datab => \GRFPC0.DIV.RESULT\(11),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(1),
dataa => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.WR.RREG.RES\(1),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(1),
dataa => \GRFPC0.MEM.RREG.RES\(1),
datab => \GRFPC0.DIV.RESULT\(1),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(8),
dataa => \GRFPC0.WR2.RREG.RES\(8),
datab => \GRFPC0.WR.RREG.RES\(8),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(8),
dataa => \GRFPC0.EX.RREG.RES\(8),
datab => \GRFPC0.DIV.RESULT\(8),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_I_A2_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_1\(13),
dataa => \GRFPC0.EX.RREG.RES\(13),
datab => \GRFPC0.WR.RREG.RES\(13),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(1),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_I_A2_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_I_A2_0\(13),
dataa => \GRFPC0.MEM.RREG.RES\(13),
datab => \GRFPC0.DIV.RESULT\(13),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(6));
\GRFPC0_OP1_0_IV_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(28),
dataa => \GRFPC0.WR2.RREG.RES\(28),
datab => \GRFPC0.WR.RREG.RES\(28),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(28),
dataa => \GRFPC0.MEM.RREG.RES\(28),
datab => \GRFPC0.DIV.RESULT\(28),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(5),
dataa => \GRFPC0.WR2.RREG.RES\(5),
datab => \GRFPC0.WR.RREG.RES\(5),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(5),
dataa => \GRFPC0.MEM.RREG.RES\(5),
datab => \GRFPC0.DIV.RESULT\(5),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(27),
dataa => \GRFPC0.MEM.RREG.RES\(27),
datab => \GRFPC0.EX.RREG.RES\(27),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(27),
dataa => \GRFPC0.WR2.RREG.RES\(27),
datab => \GRFPC0.DIV.RESULT\(27),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(18),
dataa => \GRFPC0.MEM.RREG.RES\(18),
datab => \GRFPC0.EX.RREG.RES\(18),
datac => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(18),
dataa => \GRFPC0.WR2.RREG.RES\(18),
datab => \GRFPC0.DIV.RESULT\(18),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(21),
dataa => \GRFPC0.WR2.RREG.RES\(21),
datab => \GRFPC0.WR.RREG.RES\(21),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(21),
dataa => \GRFPC0.MEM.RREG.RES\(21),
datab => \GRFPC0.DIV.RESULT\(21),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(29),
dataa => \GRFPC0.WR2.RREG.RES\(29),
datab => \GRFPC0.WR.RREG.RES\(29),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(3));
\GRFPC0_OP1_0_IV_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(29),
dataa => \GRFPC0.MEM.RREG.RES\(29),
datab => \GRFPC0.DIV.RESULT\(29),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(12),
dataa => \GRFPC0.WR2.RREG.RES\(12),
datab => \GRFPC0.WR.RREG.RES\(12),
datac => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_OP1_0_IV_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(12),
dataa => \GRFPC0.MEM.RREG.RES\(12),
datab => \GRFPC0.DIV.RESULT\(12),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL\(6));
\GRFPC0_OP1_0_IV_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(44),
dataa => \GRFPC0.MEM.RREG.RES\(44),
datab => \GRFPC0.DIV.RESULT\(44),
datac => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(6));
\GRFPC0_OP1_0_IV_2_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110010101111")
port map (
combout => \GRFPC0.OP1_0_IV_2\(63),
dataa => \GRFPC0.WR2.RREG.RES\(63),
datab => \GRFPC0.WR.RREG.RES\(63),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(4),
datad => \GRFPC0.RFA2.RS1SEL_REP2\(3));
\GRFPC0_OP1_0_IV_1_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_1\(63),
dataa => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPC0.EX.RREG.RES\(63),
datac => \GRFPC0.RFA2.RS1SEL_REP1\(1),
datad => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_OP1_0_IV_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000101011001111")
port map (
combout => \GRFPC0.OP1_0_IV_0\(63),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datab => \GRFPC0.DIV.RESULT\(63),
datac => \GRFPC0.RFA2.RS1SEL_REP2\(6),
datad => \GRFPC0.RFA2.RS1SEL_REP1\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_0_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_0_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\);
GRFPC0_FP_PIPELINE_UN1_WR2_RREG_RESV_RNI87J71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE6_0_0\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.DIV.VALID_REP1\,
datac => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPU0_GRFPU_X0_L3_0_3_0_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_0\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_L3_0_4_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_4_0\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_1\,
dataa => \GRFPU0.GRFPU_X0.C_ADD9\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD9\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(8));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD10\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD10\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(7));
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_RNI57JB1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_9_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(16));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_13\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(16));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(12));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_9\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(19));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
dataa => \GRFPC0.WR.CTRL.ID\(5),
datab => \GRFPC0.WR.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
dataa => \GRFPC0.WR.CTRL.ID\(4),
datab => \GRFPC0.WR.CTRL.ID\(3),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\,
dataa => \GRFPC0.WR.CTRL.ID\(1),
datab => \GRFPC0.WR.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\,
dataa => \GRFPC0.DIV.ID\(5),
datab => \GRFPC0.DIV.ID\(0),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\,
dataa => \GRFPC0.DIV.ID\(4),
datab => \GRFPC0.DIV.ID\(2),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\,
dataa => \GRFPC0.DIV.ID\(3),
datab => \GRFPC0.DIV.ID\(1),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_I_0_O2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_3\,
dataa => \GRFPC0.EX.CTRL.ID\(3),
datab => \GRFPC0.EX.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_I_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_2\,
dataa => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.EX.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_I_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101111011110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_I_0_O2_1\,
dataa => \GRFPC0.EX.CTRL.ID\(1),
datab => \GRFPC0.EX.CTRL.ID\(5),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
dataa => \GRFPC0.MEM.CTRL.ID\(3),
datab => \GRFPC0.MEM.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
dataa => \GRFPC0.MEM.CTRL.ID\(5),
datab => \GRFPC0.MEM.CTRL.ID\(4),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\,
dataa => \GRFPC0.MEM.CTRL.ID\(1),
datab => \GRFPC0.MEM.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_3\,
dataa => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.WR2.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(5),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
dataa => \GRFPC0.WR2.CTRL.ID\(4),
datab => \GRFPC0.WR2.CTRL.ID\(3),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(4),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(3));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
dataa => \GRFPC0.WR2.CTRL.ID\(1),
datab => \GRFPC0.WR2.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(1),
datad => \GRFPU0.GRFPU_X0.IDOUT_I_M2\(0));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_12_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12_0\,
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.MRES\(79),
datac => \GRFPU0.MULO.MRES\(92));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\,
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_VST3_EXC_1_0_F1_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_51\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_11\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_12\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_9\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_10\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_50\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_23\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_24\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_21\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_22\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_49\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_19\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_20\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_17\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_18\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_48\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_31\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_32\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_29\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_30\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_47\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_27\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_28\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_25\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_26\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_45\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_3\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_4\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_1\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_2\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_22\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_59\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_60\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_57\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_58\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_21\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_55\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_56\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_53\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_54\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_20\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_51\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_52\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_49\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_50\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_19\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_47\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_48\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_45\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_46\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_18\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_43\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_44\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_41\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_42\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_17\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_39\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_40\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_37\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_38\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_16\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_35\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_36\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_33\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_34\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_4\,
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.MRES\(89));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_3\,
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.MULO.MRES\(76),
datac => \GRFPU0.MULO.MRES\(88));
\GRFPU0_GRFPU_X0_TZI2_RNI6HPT_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_7_0\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datad => \GRFPU0.GRFPU_X0.TZI2\(14));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\,
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.MRES\(88));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_8\,
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.MULO.MRES\(87));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_6\,
dataa => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.MULO.MRES\(71));
GRFPU0_GRFPU_X0_NXX_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_9\,
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.MULO.MRES\(92),
datad => \GRFPU0.MULO.MRES\(93));
GRFPU0_GRFPU_X0_NXX_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_6\,
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
dataa => \GRFPU0.MULO.MRES\(66),
datab => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65),
datab => \GRFPU0.MULO.MRES\(66),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(0),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(60),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
datac => \GRFPU0.GRFPU_X0.UN1_VALLOW\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\);
GRFPU0_GRFPU_X0_COMB_SHV2LTO5_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO5_0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD5\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(4));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNIQCIH1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_2\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(24));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_0_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_V_STDATA_1S2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_1\,
dataa => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.WR.CTRL.PEND\,
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
GRFPU0_GRFPU_X0_ITER_V_REP3_RNIDCOD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_42\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_41\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(1));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datad => \GRFPU0.DIVROM0.RADDR\(5));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001001000001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_22\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datad => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_21\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_19\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_17\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_13\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_11\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_9\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_0_2\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.C_ADD10\);
\GRFPU0_GRFPU_X0_TZI_RNIGFQE1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_10_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(5));
\GRFPU0_GRFPU_X0_TZI_I_M2_RNIRD421_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_10_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI_I_M2\(4));
\GRFPU0_GRFPU_X0_L1_2_5_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(8));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_204_0_A3_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_333_0_A3_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_333_0_A3_0_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.V.STDATA_14_M_1_0_A2\(14));
GRFPU0_GRFPU_X0_ST3_EMIN_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD7\,
datac => \GRFPU0.GRFPU_X0.C_ADD8\,
datad => \GRFPU0.GRFPU_X0.C_ADD9\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_S_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_S_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN35_DP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN35_DP_1\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD2\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD3\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datad => \GRFPU0.GRFPU_X0.UN8_C_ADD7\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\,
dataa => \GRFPC0.WR2.CTRL.INST\(24),
datab => \GRFPC0.WR2.CTRL.INST\(31),
datac => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.WR2.CTRL.INST\(23));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT31_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT31_0\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD4\,
datad => \GRFPU0.GRFPU_X0.UN8_C_ADD5\);
GRFPU0_GRFPU_X0_COMB_SHV2LT2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LT2_0\,
dataa => \GRFPU0.GRFPU_X0.C_ADD2\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD2\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\,
datad => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(1));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_UN41_DP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.UN41_DP_0\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD10\);
GRFPC0_FP_PIPELINE_FPUSTART_7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_3\,
dataa => \GRFPC0.FPR.ALLOW\(1),
datab => \GRFPC0.RFA2.FOP\(0),
datac => \GRFPC0.RFA.WRITE_RD\,
datad => \GRFPC0.RFA2.DIVLCK\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.LDLOCK_1_M_1\,
dataa => N_98,
datab => N_100,
datac => N_102,
datad => N_97);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIUDK51_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_2_0_A2_0_0\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPC0_EX_CTRL_ID_RNO_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_2\,
dataa => \GRFPC0.RFA.WRITE_RD\,
datab => \GRFPC0.RFA2.DIVLCK\,
datac => \GRFPC0.RFA.READ_RS1\,
datad => \GRFPC0.RFA2.RS1DEP\);
\GRFPC0_EX_CTRL_ID_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000101")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3_1\,
dataa => N_39,
datab => \GRFPC0.FPR.ALLOW\(1),
datac => \GRFPC0.RFA2.FOP\(0),
datad => \GRFPC0.RFA2.RS2DEP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_5_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_4_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
GRFPU0_GRFPU_X0_UN23_BCO_LSB_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_L3_0_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
GRFPU0_GRFPU_X0_UN28_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
GRFPU0_GRFPU_X0_UN58_BCO_LSB_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
GRFPU0_GRFPU_X0_UN63_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN63_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI\(20));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD4\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD5\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_0_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.RDD_REP2\);
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI2\(5));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A4_0_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.WR.CTRL.RDD_REP1\);
GRFPC0_MEM_CTRL_PEND_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010000000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G2_1\,
dataa => \GRFPC0.DIV.EXC_0_2_X\,
datab => \GRFPC0.MEM.CTRL.PEND\,
datac => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_I_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNI4TIH1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G5_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.C_ADD10\);
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_4_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPU0_GRFPU_X0_S_SP_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_18\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(3));
GRFPU0_GRFPU_X0_S_SP_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_17\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(10));
GRFPU0_GRFPU_X0_S_SP_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_16\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(6));
GRFPU0_GRFPU_X0_S_SP_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_15\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(26));
GRFPU0_GRFPU_X0_S_SP_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_14\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(20));
GRFPU0_GRFPU_X0_S_SP_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_13\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(58),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(59),
datac => \GRFPU0.MULO.MRES\(66));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(37),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(22),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(35));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(21),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(18),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(19));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(56),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(57),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(55));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(52),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(53),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(50),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(51));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(40),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(41),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(34),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(39));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(33),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(45),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(46));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(36),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(26),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(27));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(49),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(47),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(48));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(31),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(43),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(44));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(42),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(23),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(24));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(38),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_7_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_7_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(60),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_1_3\,
dataa => \GRFPU0.GRFPU_X0.C_ADD2\,
datab => \GRFPU0.GRFPU_X0.C_ADD3\,
datac => \GRFPU0.GRFPU_X0.C_ADD4\,
datad => \GRFPU0.GRFPU_X0.C_ADD5\);
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_6\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_1_1\(1),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FIFO_INST_1_RNI68CA1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_0\,
dataa => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.INST_1\(8),
datad => \GRFPC0.FIFO.INST_1\(12));
\GRFPU0_GRFPU_X0_L2_0_10_0_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_10_0_0\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2_0\,
dataa => \GRFPC0.FIFO.VCNT_0\(1),
datab => \GRFPC0.FIFO.VCNT_1\(1),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2));
GRFPC0_FP_PIPELINE_VDIV_VALID2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_4\,
dataa => \GRFPC0.DIV.ID\(1),
datab => \GRFPC0.FPR.ID\(1),
datac => \GRFPC0.DIV.ID\(0),
datad => \GRFPC0.FPR.ID\(0));
GRFPC0_FP_PIPELINE_VDIV_VALID2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
dataa => \GRFPC0.DIV.ID\(4),
datab => \GRFPC0.FPR.ID\(4),
datac => \GRFPC0.DIV.ID\(3),
datad => \GRFPC0.FPR.ID\(3));
GRFPC0_FP_PIPELINE_VDIV_VALID2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
dataa => \GRFPC0.DIV.ID\(5),
datab => \GRFPC0.FPR.ID\(5),
datac => \GRFPC0.DIV.ID\(2),
datad => \GRFPC0.FPR.ID\(2));
GRFPC0_FP_PIPELINE_VDIV_VALID2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_1\,
dataa => \GRFPC0.DIV.ID\(7),
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_M4_A0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A0_0\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_A2_0_0\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A2_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_2_1\(1),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD7\);
GRFPC0_MEM_CTRL_DIV_RNIOS2B1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G3_A0_0\,
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_6_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_6_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.EX.CTRL.INST\(1),
datac => \GRFPC0.EX.CTRL.INST\(2),
datad => \GRFPC0.EX.CTRL.RDD_REP3\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_19\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(11),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(19));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(2),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(3),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(5));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_17\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(25));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(16),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(23));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_15\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(17),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(27));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(15),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(14),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(21));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_13\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(6),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(4),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(10));
GRFPC0_FP_PIPELINE_8_REGDEPX2_250_1_M6_I_0_A3_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_1_M6_I_0_A3_2_0\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_0\,
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.RDD_REP2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A2_5_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_5_1\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_10_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_10_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(26));
\GRFPU0_GRFPU_X0_COMB_RMND_13_1_0__M3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RMND_13_1_0_.M3_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.MULO.MRES\(69));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
dataa => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPC0.R.FSR.TEM\(2),
datac => \GRFPC0.DIV.EXCT\(1),
datad => \GRFPC0.R.FSR.TEM\(1));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
dataa => \GRFPC0.DIV.EXCT\(4),
datab => \GRFPC0.R.FSR.TEM\(4),
datac => \GRFPC0.DIV.EXCT\(3),
datad => \GRFPC0.R.FSR.TEM\(3));
GRFPU0_GRFPU_X0_COMB_TMP316_3_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0_A2_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPC0_EX_CTRL_ID_RNI0U1N_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111110110")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\,
dataa => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.FPR.ID\(5),
datac => \GRFPC0.EX.CTRL.ID\(1),
datad => \GRFPC0.FPR.ID\(1));
\GRFPC0_EX_CTRL_ID_RNIOT0N_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111110110")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\,
dataa => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FPR.ID\(0),
datac => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.FPR.ID\(2));
\GRFPC0_EX_CTRL_ID_RNI5S4N_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111011")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\,
dataa => \GRFPC0.EX.CTRL.ID\(7),
datab => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.EX.CTRL.ID\(4),
datad => \GRFPC0.FPR.ID\(4));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17));
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_A2_1_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_A2_1_3_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_2\,
dataa => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.WR2.RREG.EXCT\(2),
datac => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.WR2.RREG.EXCT\(1));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
dataa => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.WR2.RREG.EXCT\(4),
datac => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.WR2.RREG.EXCT\(3));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_0\,
dataa => \GRFPC0.R.FSR.TEM\(0),
datab => \GRFPC0.WR2.RREG.EXCT\(0),
datac => \GRFPC0.WR2.RREG.EXCT\(5));
GRFPC0_VFIFO_PC_0_1_SQMUXA_0_A2_M1_E_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E_2_0\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A4_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A4_0_1\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.RDD_REP2\,
datad => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A3_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_0_1\(1),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.RDD_REP3\,
datad => \GRFPC0.WR.RREG.RESV\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_1_M8_I_A0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_1_M8_I_A0_1\,
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_15_REGDEPX2_475_1_M9_I_M4_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_1_M9_I_M4_A2_0\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_2\,
dataa => \GRFPC0.FPR.ID\(1),
datab => \GRFPC0.WR2.CTRL.ID\(1),
datac => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.WR2.CTRL.ID\(0));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_1\,
dataa => \GRFPC0.FPR.ID\(5),
datab => \GRFPC0.WR2.CTRL.ID\(5),
datac => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.WR2.CTRL.ID\(4));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011011110110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
dataa => \GRFPC0.FPR.ID\(2),
datab => \GRFPC0.WR2.CTRL.ID\(2),
datac => \GRFPC0.WR2.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111111110110")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
dataa => \GRFPC0.FPR.ID\(4),
datab => \GRFPC0.MEM.CTRL.ID\(4),
datac => \GRFPC0.FPR.ID\(2),
datad => \GRFPC0.MEM.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111101")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.MEM.CTRL.ID\(7),
datac => \GRFPC0.FPR.ID\(1),
datad => \GRFPC0.MEM.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
dataa => \GRFPC0.FPR.ID\(4),
datab => \GRFPC0.WR.CTRL.ID\(4),
datac => \GRFPC0.FPR.ID\(3),
datad => \GRFPC0.WR.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001000000001001")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\,
dataa => \GRFPC0.FPR.ID\(5),
datab => \GRFPC0.WR.CTRL.ID\(5),
datac => \GRFPC0.FPR.ID\(2),
datad => \GRFPC0.WR.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
dataa => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR.CTRL.ID\(7),
datac => \GRFPC0.FPR.ID\(1),
datad => \GRFPC0.WR.CTRL.ID\(1));
\GRFPU0_GRFPU_X0_L1_6_1_5_I_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_5_I_0_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_1\(0),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
GRFPU0_GRFPU_X0_COMB_TMP316_2_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_DPRES4_7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES4_7_3\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_BIAS15_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15_3_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_BIAS15_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_UN1_ST2_FLOP_4_I_O2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_I_O2_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIOKCP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_I_O2_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UN1_ST3_FLOP_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_4\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_2\,
dataa => \GRFPC0.WR.CTRL.PEND\,
datab => \GRFPC0.MEM.CTRL.PEND\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datad => \GRFPC0.EX.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A0_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A3_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_O2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_O2_1\(1),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_0_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_0_2_0\(0),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_4_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_4_1_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(27),
datad => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_0_0\(0),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_M3_E_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280_0_M3_E_1\,
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(18));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_3\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
GRFPC0_FP_PIPELINE_11_REGDEPX2_355TT_1_M1_E_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355TT_1_M1_E_0\,
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(15));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPC0_FP_PIPELINE_7_REGDEPX2_235TT_0_M1_E_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235TT_0_M1_E_1\,
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(14),
datad => \GRFPC0.WR2.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_3_REGDEPX2_115TT_1_M1_E_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115TT_1_M1_E_0\,
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPU0_GRFPU_X0_L1_0_2_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2_0_A2_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI4HR11_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_73_7_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_16_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_16_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
GRFPU0_GRFPU_X0_COMB_VST2_REG107_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG107_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI2RF21_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_5\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIARF21_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_4\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7));
GRFPU0_GRFPU_X0_COMB_GETINF_UN9_MODE_0_A2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_4\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
datac => \GRFPU0.GRFPU_X0.ST3.EXC\(0),
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(1));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIARF21_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_4\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_A_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_75_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL1_I_0_A2_0_O3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_256_SEL1_I_0_A2_0_O3_0\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_UN1_FIFO_VCNT_1_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1_0\,
dataa => \GRFPC0.FIFO.VCNT_1\(1),
datab => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_5_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_5_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_1_0_A4_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_A4_0\(1),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_12_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12_0\(1),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_0_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_0_2_1\(1),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
GRFPU0_GRFPU_X0_VITER_FLUSH0_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_COMB_VST3_REG46_0_A2_6_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2_6_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPC0_STDDEP_0_SQMUXA_17_I_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_17_I_0_O2_0\,
dataa => N_243,
datab => N_244,
datac => N_245,
datad => N_242);
GRFPC0_VRFA_SEQERR_5_SQMUXA_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.VRFA.SEQERR_5_SQMUXA_1_0\,
dataa => N_108,
datab => N_109,
datac => N_98,
datad => N_99);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_I_O3_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101000110011")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_I_O3_0_O2_0\,
dataa => N_89,
datab => N_90,
datac => N_85,
datad => N_86);
GRFPC0_FP_PIPELINE_FCC_1_M2S4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\,
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.MEM.RREG.RESV\);
\GRFPC0_D_STLCK_RNO_4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_A3\,
dataa => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_0_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3199_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1327_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_3_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_3_0_A2_0\(0),
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_1_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6151_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6180_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2815_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
dataa => N_80,
datab => N_81,
datac => N_82,
datad => N_79);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2191_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0_A2\,
dataa => N_80,
datab => N_82,
datac => N_81,
datad => N_79);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1678_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1678_DEP\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_UN1639_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1639_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_UN3008_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4256_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4256_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN512_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5269_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN391_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_6_0_CHECK_DEP_UN1968_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_204_0_A2_0_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A2_0_4\(0),
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3386_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4373_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4373_REGDEPX2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4283_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN681_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN726_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN726_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN755_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN800_REGDEPX2_0_A2_2_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_2_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4268_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4268_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5210_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3372_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3372_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3327_REGDEPX2_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2_0_A3\,
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3543_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3543_DEP\,
dataa => N_243,
datab => N_245,
datac => N_242,
datad => N_244);
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3320_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1368_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2352_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2352_DEP\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datad => \GRFPC0.MEM.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3354_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3354_DEP\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A3_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A3_1_2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7004_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7004_REGDEPX2\,
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_RFA2_RS2SEL_REP2_RNI8R532_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.OP2_SN_M8\,
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(1),
datab => \GRFPC0.RFA2.RS2SEL\(3),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(7));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN740_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1350_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1212_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1212_REGDEPX2_0_O2\,
dataa => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5181_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2535_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A2_0_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A2_0_I\,
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(17),
datad => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_A2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_3\(0),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN695_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_6_0_CHECK_DEP_UN1983_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2919_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2919_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_UN1671_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3231_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3231_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_5\,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\);
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN616_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\,
dataa => N_95,
datab => N_96,
datac => N_93,
datad => N_94);
GRFPC0_STDEP_0_SQMUXA_128: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_128\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4_REP1\);
\GRFPC0_R_STATE_RNISTAQ_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000101")
port map (
combout => N_45794_2,
dataa => N_39,
datab => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A2_2\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\,
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1));
GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_UN2263_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.UN2263_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_RFA_LD_0_0_G1_0_1809_A2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2_7\,
dataa => N_102,
datab => N_112,
datac => N_108,
datad => N_109);
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2087_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3335_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_2_1_CHECK_DEP_UN839_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1463_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
\GRFPU0_DIVROM0_DATA_1_MUX_14_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100000001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_14\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_4\);
GRFPC0_FP_PIPELINE_1_UN87_PENDEXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
dataa => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_1\(1),
datac => \GRFPC0.FIFO.VCNT_1\(2));
\GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_DEP_2_IV_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2\(0),
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26));
GRFPU0_GRFPU_X0_COMB_UINT17_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_10\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_VST3_RDY41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.RDY41\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1_0_A2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_A2_3_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_A2_3\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.G_53_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2056_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26));
GRFPU0_GRFPU_X0_COMB_UN1_ST2_FLOP_4_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_4_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_A2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_A2\(41),
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38));
GRFPU0_GRFPU_X0_UN113_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(41));
GRFPU0_GRFPU_X0_UN108_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
GRFPU0_GRFPU_X0_UN33_BCO_LSB_0_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN33_BCO_LSB_0_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
GRFPU0_GRFPU_X0_COMB_CCV18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV18\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_COMB_CCV12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV12\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_UN213_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN213_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(45));
\GRFPU0_GRFPU_X0_BCO_MSB_1_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
GRFPU0_GRFPU_X0_UN148_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55));
GRFPU0_GRFPU_X0_UN163_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
GRFPU0_GRFPU_X0_UN158_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPU0_GRFPU_X0_BCO_MSB_5_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_UN218_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN218_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(37));
GRFPU0_GRFPU_X0_UN208_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN208_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
GRFPU0_GRFPU_X0_UN238_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN238_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(5));
GRFPU0_GRFPU_X0_UN228_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21));
GRFPU0_GRFPU_X0_UN233_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13));
GRFPU0_GRFPU_X0_UN223_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29));
\GRFPU0_GRFPU_X0_BCO_MSB_3_2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_2_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(31));
\GRFPU0_GRFPU_X0_BCO_MSB_4_2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_2_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(23));
\GRFPU0_GRFPU_X0_BCO_MSB_1_3_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_3_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47));
\GRFPU0_GRFPU_X0_BCO_MSB_6_2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_2_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(7));
\GRFPU0_GRFPU_X0_BCO_MSB_5_2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_2_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
GRFPU0_GRFPU_X0_UN98_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN98_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(17));
GRFPU0_GRFPU_X0_UN103_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN103_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPU0_GRFPU_X0_BCO_MSB_3_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
GRFPU0_GRFPU_X0_UN93_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN93_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4240_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27),
datac => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1\(28));
GRFPC0_FP_PIPELINE_RSDEC_RS1V5_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5_0_A2_1\,
dataa => \GRFPC0.INST\(7),
datab => \GRFPC0.INST_I\(10),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.INST_I\(11));
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_L1_3_1_4_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_4_A4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
GRFPU0_GRFPU_X0_VST2_RDY_0_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.RDY_0_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.COMB.UINT17\);
\GRFPU0_GRFPU_X0_L1_4_1_4_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_4_A4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_3_1_3_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_3_A4_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_A2_0_RNINU513: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIG16N_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_77\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(18));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIH16N_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_78\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_GT_EXPT18LT10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18LT10\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
datad => \GRFPU0.GRFPU_X0.UN8_C_ADD10\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT27_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_9\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD4\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD5\,
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datad => \GRFPU0.GRFPU_X0.UN8_C_ADD11\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN7_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C_ADD10\);
\GRFPU0_GRFPU_X0_BCO_MSB_6_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(47));
\GRFPU0_GRFPU_X0_BCO_MSB_5_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
GRFPU0_GRFPU_X0_UN88_BCO_LSB: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN88_BCO_LSB\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EMAXP112: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EMAXP112\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0));
GRFPU0_GRFPU_X0_COMB_VST3_REG40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG40\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0));
GRFPU0_GRFPU_X0_ITER_EMIN_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G5\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_A2_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_A2_11\,
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_7_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_7_0_A2\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I\(12),
datac => \GRFPC0.INST_I\(8),
datad => \GRFPC0.INST_I\(11));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3529_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3529_DEP\,
dataa => N_173,
datab => N_175,
datac => N_174,
datad => N_176);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNI7K5B1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_9\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3));
GRFPU0_GRFPU_X0_COMB_VST3_RDY9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.RDY9\,
dataa => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(2),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(1));
GRFPU0_GRFPU_X0_COMB_TMP316_2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316_2_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_ITER_FLUSH0_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.FLUSH0_1_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_O3_0_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_O3_0_A4_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_5_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_5_1\(0),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(1));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_8_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_10_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_10_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_1_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_1_2\(1),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_3_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26));
GRFPU0_GRFPU_X0_COMB_OP_GT_VST3_EXC40LT9_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_A2_3_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(15));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD6\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_1_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_S_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001100000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_S\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_1_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1_0\(52),
dataa => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52),
datac => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0));
GRFPC0_UN1_FPR_ALLOW_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPC0.UN1_FPR.ALLOW_0\,
dataa => \GRFPC0.FPR.ALLOW\(1),
datab => \GRFPC0.RFA2.FOP\(0),
datac => \GRFPC0.FPR.ALLOW\(0));
GRFPC0_UN1_VFIFO_RD_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPC0.UN1_VFIFO.RD_0_A2_0\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.RD_REP3\(0),
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\);
\GRFPU0_GRFPU_X0_L1_4_3_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3_1\(3),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_0\(9),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNIBTA01_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI60KT_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_0_A3_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_11_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_11_0\(1),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.V.STDATA_14_I_M2\(17));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A4_1_0\(0),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_0_A4_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_0_A4_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_3_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A2_7_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410_0_A2_7_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_0_0\(0),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(25),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_0_A2_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_0_A2_3_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_A3_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_1_0\(0),
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5444_REGDEPX2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100011100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_1\,
dataa => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.RD_REP1\(0),
datac => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.V.STDATA_14\(18));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5444_REGDEPX2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2_0\,
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.V.STDATA_14_I_M2\(17));
\GRFPC0_DIV_INST_RNIG8EL_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G3_A0_0\,
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_I_A2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_I_A2_1_0\(0),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_A2_0_0\(1),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_A2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_1\(1),
dataa => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_EX_CTRL_INST_RNISTPI_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G3_A5_0\,
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(0),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A3_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A3_3_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_A0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_A0_1_0\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RS1V\,
datac => \GRFPC0.DIV.RDD\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_1_0\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_9_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_9_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_2_0\(1),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_0_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_0_2_0\(0),
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_15_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_15_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_I_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_I_A2_0_0\(1),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_1_1_0\(23),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_84,
datad => N_92);
GRFPC0_FP_PIPELINE_UN24_OP_RNICU6S: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G3_0\,
dataa => N_80,
datab => N_82,
datac => N_113,
datad => \GRFPC0.FP_PIPELINE.UN24_OP\);
\GRFPU0_GRFPU_X0_BCO_MSB_2_2_I_I_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_2_I_I_A2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_L1_0_1_2_I_I_A3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_2_I_I_A3\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPU0_GRFPU_X0_UN138_BCO_LSB_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN138_BCO_LSB_0_A3\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPU0_GRFPU_X0_COMB_VST2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPC0_EX_CTRL_RDD_REP1_RNIQSPM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4\,
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4048_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
dataa => N_93,
datab => N_94,
datac => N_95,
datad => N_96);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2800_REGDEPX_0_A5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX_0_A5\,
dataa => N_93,
datab => N_94,
datac => N_96,
datad => N_95);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5150_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3842_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5136_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5165_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_2_3\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6488_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6488_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2564_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2564_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1TT_40_M2_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1TT_40_M2_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datab => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datac => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(43));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI6DTO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011101010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_TZ_TZ\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_BCO_MSB_3_2_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_2_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32));
\GRFPU0_GRFPU_X0_BCO_MSB_4_2_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_2_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24));
\GRFPU0_GRFPU_X0_BCO_MSB_1_3_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_3_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_3_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40));
\GRFPU0_GRFPU_X0_BCO_MSB_5_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_BCO_MSB_3_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_BCO_MSB_2_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_BCO_MSB_5_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53));
\GRFPU0_GRFPU_X0_BCO_MSB_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
\GRFPU0_GRFPU_X0_BCO_MSB_6_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_BCO_MSB_5_2_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_2_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16));
\GRFPU0_GRFPU_X0_BCO_MSB_6_2_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_2_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_A3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_A3\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_D\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(49));
\GRFPU0_GRFPU_X0_L1_2_1_4_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_4_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(19));
\GRFPU0_GRFPU_X0_L1_1_1_4_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(11));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI\(14));
\GRFPU0_GRFPU_X0_L1_0_1_4_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI2\(3));
\GRFPU0_GRFPU_X0_L1_5_1_5_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_5_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_M3_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M3_E\,
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_19292_1_I_0_O2\);
\GRFPC0_D_STLCK_RNO_11_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001001101010111")
port map (
combout => R_M2_0,
dataa => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPU0_GRFPU_X0_COMB_UN57_RNDOP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.MULO.MRES\(96),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPC0_DIV_EXCT_0_0_0__G3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_0__G3\,
dataa => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110110101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\);
\GRFPU0_GRFPU_X0_BCO_MSB_3_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_BCO_MSB_4_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_L1_0_1_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
\GRFPU0_GRFPU_X0_BCO_MSB_2_1_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_1_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_BCO_MSB_4_0_TZ_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_0_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
\GRFPU0_GRFPU_X0_BCO_MSB_1_5_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI\(7));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_0_A4_0_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001010101")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_0_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datad => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_L3_0_3_0_A2_0_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_0_0\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3505_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2_0_O2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_12\,
dataa => N_104,
datab => N_105,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_UN1656_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1656_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_27_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_27_I_O2\(0),
dataa => N_105,
datab => N_104,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_UN2575_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_UN1_FIFO_INST_0_16_I_I2_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.UN1_FIFO.INST_0_16_I_I2_I_A2\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_7_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_7_I\,
dataa => N_106,
datab => N_107,
datac => N_104,
datad => N_105);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6108_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6108_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_O2_1\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5606_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5561_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5681_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5681_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN631_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX\,
dataa => N_81,
datab => N_82,
datac => N_79,
datad => N_80);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6165_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6165_REGDEPX2\,
dataa => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_4_0\,
dataa => N_106,
datab => N_107,
datac => N_104,
datad => N_105);
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2887_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_I_O2_0_O3_0_O5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_I_O2_0_O3_0_O5\,
dataa => N_86,
datab => N_90,
datac => N_88,
datad => N_89);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3813_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2696_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3887_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_I_A2_5_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_I_A2_5_1\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(25),
datac => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5298_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3751_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3751_REGDEPX_0_A2\,
dataa => N_79,
datab => N_80,
datac => N_82,
datad => N_81);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_9\,
dataa => N_105,
datab => N_104,
datac => N_107,
datad => N_106);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2004_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN3078_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN3078_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_5_2\(8),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1015_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2196_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2_0_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_6\,
dataa => N_106,
datab => N_107,
datac => N_105,
datad => N_104);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_2\(5),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(29));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_0_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1_0_I_O4\,
dataa => N_105,
datab => N_104,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_0_1_IS_RS1V_TMP_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011011110110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.IS_RS1V.TMP_I_O2\,
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_0_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_2\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN271_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN271_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2549_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2549_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6443_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6443_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3534_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2_0_A2\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN888_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN888_REGDEPX2_0_A2\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4),
datad => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN873_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_M6_I_0_A3_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160_0_M6_I_0_A3_2_1\,
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3401_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3401_REGDEPX2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2078_REGDEPX2_0_A2_0_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2078_REGDEPX2_0_A2_0_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_18_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_18_0_O2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_2_3\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_5_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_5_1\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(0),
datac => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4344_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4254_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2637_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2637_REGDEPX2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1314_REGDEPX2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2_0_A2_1_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_4_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4_0_O2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_1_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(14),
datad => \GRFPC0.WR2.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011101100111011")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.RDD_REP1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_4_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_3\(1),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(14),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1682_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(4));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1727_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1727_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1755_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0_A2\,
dataa => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(16),
datad => \GRFPC0.DIV.INST\(18));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1608_REGDEPX2_0_A2_1_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1608_REGDEPX2_0_A2_1_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1637_REGDEPX2_0_A2_1_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2_0_A2_1_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1667_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1667_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1167_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1167_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1196_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1196_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_1_2\(0),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.RREG.RESV\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6459_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6459_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1300_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(29),
dataa => N_656,
datab => N_720,
datac => N_426,
datad => N_425);
\GRFPC0_FP_PIPELINE_DBGDATA_4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(21),
dataa => N_648,
datab => N_712,
datac => N_426,
datad => N_425);
\GRFPC0_FP_PIPELINE_DBGDATA_4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => CPO_DBG_DATAZ(18),
dataa => N_645,
datab => N_709,
datac => N_426,
datad => N_425);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(4),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(4),
datab => \GRFPC0.R.FSR.TEM\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(1),
datab => \GRFPC0.R.FSR.TEM\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_2_2\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(0),
datac => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1592_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1592_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5973_REGDEPX2_0_A3_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2_0_A3_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6900_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6900_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5577_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3356_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2915_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2915_REGDEPX2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2960_REGDEPX2_0_A2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2_0_A2_0_A2_1_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6884_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6884_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN205_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.V.STDATA_14\(2));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6839_REGDEPX2_0_A2_0_0_I_O2_0_O4\,
dataa => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.RD_REP1\(0),
datac => \GRFPC0.FIFO.INST_1\(4),
datad => \GRFPC0.V.STDATA_14\(3));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1988_REGDEPX2_0_A2_0_0_A2_0_A3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1988_REGDEPX2_0_A2_0_0_A2_0_A3_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(4),
datad => \GRFPC0.V.STDATA_14\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_4\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_1_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_1_0_A2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6929_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6929_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN205_REGDEPX2_0_A2_0_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_0_A2_0_0_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(4),
datad => \GRFPC0.V.STDATA_14\(3));
\GRFPC0_FIFO_INST_0_RNIPV541_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000001010")
port map (
combout => \GRFPC0.OP2_SN_M4\,
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_1\(0),
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(28),
dataa => N_655,
datab => N_719,
datac => N_426,
datad => N_425);
\GRFPC0_FP_PIPELINE_DBGDATA_4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(12),
dataa => N_639,
datab => N_703,
datac => N_426,
datad => N_425);
GRFPC0_OP1_2_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPC0.OP1_2_SQMUXA\,
dataa => N_167,
datab => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST\,
datad => \GRFPC0.RFA2.RS1SEL\(7));
\GRFPU0_GRFPU_X0_RES_1_6_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_0_A2_2\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_A4_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_A4_0\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O4\,
dataa => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_0\(4),
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPC0.OP1_0_IV\(52),
datac => \GRFPC0.OP1_0_IV\(53));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_2_1\(0),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(25),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_1\(5),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A3_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_0_1\(1),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(25),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_0_1\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(25),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_85TT_1_M1_E_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_1\,
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_6_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_6_1\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(14),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_5_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_5_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_2_1\(0),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(0),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_1_1\(6),
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_84,
datad => N_78);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_4_1\(7),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_0_1\(0),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(14),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD_REP2\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_17_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_17_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_0_1\(1),
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(0),
datac => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_REGDEPX_36_0_A5_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000000")
port map (
combout => \GRFPC0.N_25443_2\,
dataa => N_113,
datab => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_78,
datad => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_3\(0),
dataa => N_94,
datab => N_96,
datac => N_113,
datad => \GRFPC0.FP_PIPELINE.UN24_OP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_2_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A4_0_1\(1),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(14),
datac => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.N_25984_1\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_0_A4_1_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_0_A4_1_2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_FCC_1_M0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M0\(1),
dataa => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES\(1),
datad => \GRFPC0.WR2.RREG.RES\(1));
\GRFPC0_FP_PIPELINE_FCC_1_M0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M0\(0),
dataa => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES\(0),
datad => \GRFPC0.WR2.RREG.RES\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M1\(1),
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.MEM.RREG.RES\(1),
datad => \GRFPC0.EX.RREG.RES\(1));
\GRFPC0_FP_PIPELINE_FCC_1_M1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100001110000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M1\(0),
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.MEM.RREG.RES\(0),
datad => \GRFPC0.EX.RREG.RES\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M3\(1),
dataa => \GRFPC0.WR2.CTRL.AFSR\,
datab => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datad => \GRFPC0.R.FSR.FCC\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(30),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(29),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(28),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(27),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(26),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(25),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(24),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(23),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(23),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(22),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(21),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(21),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(20),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(19),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(19),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(16),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(14),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(14),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(11),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(9),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(4),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(1),
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.V.STDATA_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(0),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.V.STDATA_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_0_I_M2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000001011010111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2_0\(1),
dataa => \GRFPC0.V.STDATA_14_REP0\(6),
datab => \GRFPC0.OP1_0_IV\(52),
datac => \GRFPC0.OP2\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_X2_0\(1));
\GRFPU0_GRFPU_X0_RES_1_5_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(62),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(62));
\GRFPU0_GRFPU_X0_RES_1_5_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(59));
\GRFPU0_GRFPU_X0_RES_1_5_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(56));
\GRFPU0_GRFPU_X0_RES_1_5_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(53));
\GRFPU0_GRFPU_X0_RES_1_3_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(62),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(62));
\GRFPU0_GRFPU_X0_RES_1_3_A_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(62),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(10),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(59));
\GRFPU0_GRFPU_X0_RES_1_3_A_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(56));
\GRFPU0_GRFPU_X0_RES_1_3_A_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(53));
\GRFPU0_GRFPU_X0_RES_1_3_A_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
dataa => \GRFPC0.DIV.RESULT\(52),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(52),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_FP_PIPELINE_WRDATA_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(27),
dataa => \GRFPC0.DIV.RESULT\(27),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(27),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
dataa => \GRFPC0.DIV.RESULT\(55),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(55),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_FP_PIPELINE_WRDATA_3_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
dataa => \GRFPC0.DIV.RESULT\(63),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(63),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_6_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(32),
dataa => \GRFPC0.OP2_3\(32),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(32));
\GRFPC0_OP2_5_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(32),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(32),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(32));
\GRFPC0_OP2_6_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(34),
dataa => \GRFPC0.OP2_3\(34),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(34));
\GRFPC0_OP2_5_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(34),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(34),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(34));
\GRFPC0_OP2_6_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(41),
dataa => \GRFPC0.OP2_3\(41),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(41));
\GRFPC0_OP2_5_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(41),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(41),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(41));
\GRFPC0_OP2_6_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(44),
dataa => \GRFPC0.OP2_3\(44),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(44));
\GRFPC0_OP2_6_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(47),
dataa => \GRFPC0.OP2_3\(47),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(47));
\GRFPC0_STDATA_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(1),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(1),
datad => \GRFPC0.EX.RREG.RES\(33));
\GRFPC0_OP2_4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(18),
dataa => N_677,
datab => N_741,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_6_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(52),
dataa => \GRFPC0.OP2_3\(52),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(52));
\GRFPC0_OP2_5_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(52),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(52),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(52));
\GRFPC0_OP2_6_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(55),
dataa => \GRFPC0.OP2_3\(55),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(55));
\GRFPC0_OP2_5_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(55),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(55),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(55));
\GRFPC0_OP2_6_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(56),
dataa => \GRFPC0.OP2_3\(56),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(56));
\GRFPC0_OP2_4_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(27),
dataa => N_686,
datab => N_750,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_6_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(62),
dataa => \GRFPC0.OP2_3\(62),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(62));
\GRFPC0_OP2_5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(31),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(31),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(31));
\GRFPC0_OP2_4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(31),
dataa => N_690,
datab => N_754,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(31),
dataa => \GRFPC0.DIV.RESULT\(31),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(31),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_STDATA_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(2),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(2),
datad => \GRFPC0.EX.RREG.RES\(34));
\GRFPC0_OP2_6_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(63),
dataa => \GRFPC0.OP2_3\(63),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(63));
\GRFPC0_STDATA_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(12),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(12),
datad => \GRFPC0.EX.RREG.RES\(44));
\GRFPC0_FP_PIPELINE_WRDATA_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(1),
dataa => \GRFPC0.DIV.RESULT\(1),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(1),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
dataa => \GRFPC0.DIV.RESULT\(34),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(34),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(2),
dataa => \GRFPC0.DIV.RESULT\(2),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(2),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(3),
dataa => \GRFPC0.DIV.RESULT\(3),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(3),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(9),
dataa => N_668,
datab => N_732,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_FP_PIPELINE_WRDATA_3_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
dataa => \GRFPC0.DIV.RESULT\(41),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(41),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
dataa => \GRFPC0.DIV.RESULT\(32),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(32),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(0),
dataa => \GRFPC0.DIV.RESULT\(0),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(1),
datab => \GRFPC0.WR2.RREG.EXCT\(1),
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_OP2_6_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(40),
dataa => \GRFPC0.OP2_3\(40),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(40));
\GRFPC0_OP2_5_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(40),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(40),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(40));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(4),
datab => \GRFPC0.WR2.RREG.EXCT\(4),
datac => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_STDATA_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(0),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(0),
datad => \GRFPC0.EX.RREG.RES\(32));
\GRFPC0_OP2_6_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(50),
dataa => \GRFPC0.OP2_3\(50),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(50));
\GRFPC0_STDATA_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(30),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(30),
datad => \GRFPC0.EX.RREG.RES\(62));
\GRFPC0_STDATA_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(31),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(31),
datad => \GRFPC0.EX.RREG.RES\(63));
\GRFPC0_FP_PIPELINE_WRDATA_3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
dataa => \GRFPC0.DIV.RESULT\(58),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(58),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(1),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(1),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(1));
\GRFPC0_OP2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(1),
dataa => N_660,
datab => N_724,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_4_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(12),
dataa => N_671,
datab => N_735,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(21),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(21),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(21));
\GRFPC0_OP2_4_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(21),
dataa => N_680,
datab => N_744,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_FP_PIPELINE_WRDATA_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(21),
dataa => \GRFPC0.DIV.RESULT\(21),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(21),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_4_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(23),
dataa => N_682,
datab => N_746,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_4_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(24),
dataa => N_683,
datab => N_747,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_6_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(58),
dataa => \GRFPC0.OP2_3\(58),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(58));
\GRFPC0_OP2_5_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(58),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(58),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(58));
\GRFPC0_OP2_6_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(59),
dataa => \GRFPC0.OP2_3\(59),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(59));
\GRFPC0_OP2_5_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(29),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(29),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(29));
\GRFPC0_OP2_5_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(30),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(30),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(30));
\GRFPC0_OP2_4_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(30),
dataa => N_689,
datab => N_753,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_INST_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(21),
dataa => \GRFPC0.FIFO.INST_1\(21),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(21));
\GRFPC0_INST_A_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(21),
dataa => N_99,
datab => \GRFPC0.FIFO.INST_0\(21),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13\(1),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(15),
datac => \GRFPC0.D.LDLCK\(7),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13_A\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(23),
datad => \GRFPC0.D.LDLCK\(31));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13\(0),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(14),
datac => \GRFPC0.D.LDLCK\(6),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_13_A\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(22),
datad => \GRFPC0.D.LDLCK\(30));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10\(1),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(13),
datac => \GRFPC0.D.LDLCK\(5),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10_A\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(21),
datad => \GRFPC0.D.LDLCK\(29));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10\(0),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(12),
datac => \GRFPC0.D.LDLCK\(4),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_10_A\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(20),
datad => \GRFPC0.D.LDLCK\(28));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6\(1),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(11),
datac => \GRFPC0.D.LDLCK\(3),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6_A\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(19),
datad => \GRFPC0.D.LDLCK\(27));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6\(0),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(10),
datac => \GRFPC0.D.LDLCK\(2),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_6_A\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(18),
datad => \GRFPC0.D.LDLCK\(26));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3\(1),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(9),
datac => \GRFPC0.D.LDLCK\(1),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3_A\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3_A\(1),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(17),
datad => \GRFPC0.D.LDLCK\(25));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3\(0),
dataa => N_107,
datab => \GRFPC0.D.LDLCK\(8),
datac => \GRFPC0.D.LDLCK\(0),
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3_A\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_3_A\(0),
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.LDLCK\(16),
datad => \GRFPC0.D.LDLCK\(24));
GRFPC0_LDLOCK_1_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_21\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(26),
datac => \GRFPC0.D.STLCK\(10),
datad => \GRFPC0.LDLOCK_1_21_A\);
GRFPC0_LDLOCK_1_21_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_21_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(11),
datad => \GRFPC0.D.STLCK\(27));
GRFPC0_LDLOCK_1_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_13\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(22),
datac => \GRFPC0.D.STLCK\(6),
datad => \GRFPC0.LDLOCK_1_13_A\);
GRFPC0_LDLOCK_1_13_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_13_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(7),
datad => \GRFPC0.D.STLCK\(23));
GRFPC0_LDLOCK_1_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_10\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(20),
datac => \GRFPC0.D.STLCK\(4),
datad => \GRFPC0.LDLOCK_1_10_A\);
GRFPC0_LDLOCK_1_10_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_10_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(5),
datad => \GRFPC0.D.STLCK\(21));
\GRFPC0_STDATA_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(11),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(11),
datad => \GRFPC0.EX.RREG.RES\(43));
\GRFPC0_OP2_5_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(63),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(63),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(63));
\GRFPC0_R_FSR_RD_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_0__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(30),
datab => \GRFPC0.R.FSR.RD\(0),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_R_FSR_RD_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_1__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(31),
datab => \GRFPC0.R.FSR.RD\(1),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_R_FSR_TEM_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_0__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(23),
datab => \GRFPC0.R.FSR.TEM\(0),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_R_FSR_TEM_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_1__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(24),
datab => \GRFPC0.R.FSR.TEM\(1),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_R_FSR_TEM_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_2__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPC0.R.FSR.TEM\(2),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_R_FSR_TEM_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_4__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(27),
datab => \GRFPC0.R.FSR.TEM\(4),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_EX_RREG_EXCT_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_2__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(2),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\);
\GRFPC0_EX_RREG_EXCT_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101000000")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_3__G0_I\,
dataa => N_38,
datab => \GRFPC0.EX.RREG.EXCT\(3),
datac => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3));
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL1_I_0_A2_0_O3_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL1_I_0_A2_0_O3_1\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_11_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2_12\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_0_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O2_1\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3944_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3944_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_2_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_2_1\(6),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV_REP1\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010100000001")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_0_A2_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(6));
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1760_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_13\,
dataa => N_105,
datab => N_104,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4855_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
dataa => N_245,
datab => N_242,
datac => N_243,
datad => N_244);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_3_0\,
dataa => N_104,
datab => N_105,
datac => N_106,
datad => N_107);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_O3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\(0),
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_UN5_SHARE_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010111010101110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN5_SHARE_I_O2\,
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.LD\);
GRFPC0_FP_PIPELINE_7_STDEP_292_SEL0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL0_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\);
GRFPC0_LDLOCK_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_3\,
dataa => N_107,
datab => \GRFPC0.D.STDLCK\(4),
datac => \GRFPC0.D.STDLCK\(0),
datad => \GRFPC0.LDLOCK_3_A\);
GRFPC0_LDLOCK_3_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_3_A\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.STDLCK\(8),
datad => \GRFPC0.D.STDLCK\(12));
GRFPC0_LDLOCK_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_6\,
dataa => N_107,
datab => \GRFPC0.D.STDLCK\(5),
datac => \GRFPC0.D.STDLCK\(1),
datad => \GRFPC0.LDLOCK_6_A\);
GRFPC0_LDLOCK_6_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_6_A\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.STDLCK\(9),
datad => \GRFPC0.D.STDLCK\(13));
GRFPC0_LDLOCK_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_10\,
dataa => N_107,
datab => \GRFPC0.D.STDLCK\(6),
datac => \GRFPC0.D.STDLCK\(2),
datad => \GRFPC0.LDLOCK_10_A\);
GRFPC0_LDLOCK_10_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_10_A\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.STDLCK\(10),
datad => \GRFPC0.D.STDLCK\(14));
GRFPC0_LDLOCK_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_13\,
dataa => N_107,
datab => \GRFPC0.D.STDLCK\(7),
datac => \GRFPC0.D.STDLCK\(3),
datad => \GRFPC0.LDLOCK_13_A\);
GRFPC0_LDLOCK_13_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_13_A\,
dataa => N_106,
datab => N_107,
datac => \GRFPC0.D.STDLCK\(11),
datad => \GRFPC0.D.STDLCK\(15));
GRFPC0_LDLOCK_1_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_25\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(28),
datac => \GRFPC0.D.STLCK\(12),
datad => \GRFPC0.LDLOCK_1_25_A\);
GRFPC0_LDLOCK_1_25_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_25_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(13),
datad => \GRFPC0.D.STLCK\(29));
GRFPC0_LDLOCK_1_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_28\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(30),
datac => \GRFPC0.D.STLCK\(14),
datad => \GRFPC0.LDLOCK_1_28_A\);
GRFPC0_LDLOCK_1_28_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_28_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(15),
datad => \GRFPC0.D.STLCK\(31));
GRFPC0_LDLOCK_1_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_3\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(16),
datac => \GRFPC0.D.STLCK\(0),
datad => \GRFPC0.LDLOCK_1_3_A\);
GRFPC0_LDLOCK_1_3_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_3_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(1),
datad => \GRFPC0.D.STLCK\(17));
GRFPC0_LDLOCK_1_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_6\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(18),
datac => \GRFPC0.D.STLCK\(2),
datad => \GRFPC0.LDLOCK_1_6_A\);
GRFPC0_LDLOCK_1_6_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_6_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(3),
datad => \GRFPC0.D.STLCK\(19));
GRFPC0_LDLOCK_1_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPC0.LDLOCK_1_18\,
dataa => N_103,
datab => \GRFPC0.D.STLCK\(24),
datac => \GRFPC0.D.STLCK\(8),
datad => \GRFPC0.LDLOCK_1_18_A\);
GRFPC0_LDLOCK_1_18_A: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPC0.LDLOCK_1_18_A\,
dataa => N_107,
datab => N_103,
datac => \GRFPC0.D.STLCK\(9),
datad => \GRFPC0.D.STLCK\(25));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27),
datac => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_WRDATA_3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(14),
dataa => \GRFPC0.DIV.RESULT\(14),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(14),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
GRFPC0_V_FSR_CEXC_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_1\,
dataa => \GRFPC0.WR2.CTRL.AFSR\,
datab => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.V.FSR.CEXC_4_SQMUXA\);
GRFPC0_FP_PIPELINE_UN54_HOLDN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN54_HOLDN\,
dataa => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.WR2.CTRL.PEND\,
datac => \GRFPC0.WR.CTRL.PEND\);
\GRFPC0_INST_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(16),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(16));
\GRFPC0_INST_A_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(16),
dataa => N_94,
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(6),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(12),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(13),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(13));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1696_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN44_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datad => \GRFPC0.MEM.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_M3_E_I_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111101111111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M3_E_I_1\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_V_STDATA_14_RNIBPQT_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100000000")
port map (
combout => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14\(14));
\GRFPC0_V_STDATA_14_I_M2_RNIGV511_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100000000")
port map (
combout => \GRFPC0.V.STDATA_14_M_0\(0),
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14_I_M2\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_370_0_A3_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370_0_A3_0_1\(0),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(0),
datac => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RDD_REP4\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6077_REGDEPX2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6077_REGDEPX2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4313_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4313_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_6_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_6_1\(0),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.RDD_REP2\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_6_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_6_2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.RDD_REP3\);
\GRFPC0_V_STDATA_14_I_M2_RNIGV511_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPC0.V.STDATA_14_I_M_6\(0),
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14_I_M2\(0));
\GRFPC0_V_STDATA_14_RNIBPQT_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPC0.V.STDATA_14_I_M_4\(14),
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(25),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5226_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5226_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1698_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A3_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A3_1_0\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_WRDATA_3_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
dataa => \GRFPC0.DIV.RESULT\(36),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(36),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_STDATA_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(4),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(4),
datad => \GRFPC0.EX.RREG.RES\(36));
\GRFPC0_OP2_5_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(36),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(36),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(36));
\GRFPC0_OP2_6_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(36),
dataa => \GRFPC0.OP2_3\(36),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(36));
\GRFPC0_FP_PIPELINE_WRDATA_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(25),
dataa => \GRFPC0.DIV.RESULT\(25),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(25),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
dataa => \GRFPC0.DIV.RESULT\(57),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(57),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(57),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(57),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(57));
\GRFPC0_OP2_6_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(57),
dataa => \GRFPC0.OP2_3\(57),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(57));
\GRFPU0_GRFPU_X0_RES_1_3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(50));
\GRFPU0_GRFPU_X0_RES_1_3_A_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_5_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(50));
\GRFPU0_GRFPU_X0_RES_1_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(44));
\GRFPU0_GRFPU_X0_RES_1_3_A_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_3_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110011111010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.RES_1_3_A\(47));
\GRFPU0_GRFPU_X0_RES_1_3_A_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000001011111")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_3_A\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_5_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(44));
\GRFPU0_GRFPU_X0_RES_1_5_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_5\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.RES_1_4\(47));
\GRFPC0_STDATA_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(9),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(9),
datad => \GRFPC0.EX.RREG.RES\(41));
\GRFPC0_FP_PIPELINE_WRDATA_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(9),
dataa => \GRFPC0.DIV.RESULT\(9),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(9),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_5_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(9),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(9),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(9));
\GRFPC0_STDATA_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(15),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(15),
datad => \GRFPC0.EX.RREG.RES\(47));
\GRFPC0_FP_PIPELINE_WRDATA_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(15),
dataa => \GRFPC0.DIV.RESULT\(15),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(15),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(15),
dataa => N_674,
datab => N_738,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(15),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(15),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(15));
\GRFPC0_STDATA_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(16),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(16),
datad => \GRFPC0.EX.RREG.RES\(48));
\GRFPC0_FP_PIPELINE_WRDATA_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(17),
dataa => \GRFPC0.DIV.RESULT\(17),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(17),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
dataa => \GRFPC0.DIV.RESULT\(49),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(49),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(49),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(49),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(49));
\GRFPC0_OP2_6_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(49),
dataa => \GRFPC0.OP2_3\(49),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(49));
\GRFPC0_OP2_5_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(60),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(60),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(60));
\GRFPC0_OP2_6_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(60),
dataa => \GRFPC0.OP2_3\(60),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(60));
\GRFPC0_FP_PIPELINE_WRDATA_3_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
dataa => \GRFPC0.DIV.RESULT\(60),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(60),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(29),
dataa => N_688,
datab => N_752,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(29),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(29),
datad => \GRFPC0.EX.RREG.RES\(61));
\GRFPC0_FP_PIPELINE_WRDATA_3_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
dataa => \GRFPC0.DIV.RESULT\(61),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(61),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(61),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(61),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(61));
\GRFPC0_OP2_6_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(61),
dataa => \GRFPC0.OP2_3\(61),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(61));
\GRFPC0_STDATA_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(10),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(10),
datad => \GRFPC0.EX.RREG.RES\(42));
\GRFPC0_OP2_4_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(10),
dataa => N_669,
datab => N_733,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(10),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(10),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(10));
\GRFPC0_FP_PIPELINE_FCC_1_M3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011110000000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M3\(0),
dataa => \GRFPC0.WR2.CTRL.AFSR\,
datab => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datad => \GRFPC0.R.FSR.FCC\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(19),
dataa => N_646,
datab => N_710,
datac => N_426,
datad => N_425);
\GRFPC0_OP2_4_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(22),
dataa => N_681,
datab => N_745,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(54),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(54),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(54));
\GRFPC0_OP2_6_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(54),
dataa => \GRFPC0.OP2_3\(54),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(54));
\GRFPC0_FP_PIPELINE_WRDATA_3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
dataa => \GRFPC0.DIV.RESULT\(35),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(35),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_STDATA_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(3),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(3),
datad => \GRFPC0.EX.RREG.RES\(35));
\GRFPC0_OP2_5_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(35),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(35),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(35));
\GRFPC0_OP2_6_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(35),
dataa => \GRFPC0.OP2_3\(35),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(35));
\GRFPC0_OP2_4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(5),
dataa => N_664,
datab => N_728,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(37),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(37),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(37));
\GRFPC0_OP2_6_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(37),
dataa => \GRFPC0.OP2_3\(37),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(37));
\GRFPC0_FP_PIPELINE_WRDATA_3_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
dataa => \GRFPC0.DIV.RESULT\(37),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(37),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(7),
dataa => \GRFPC0.DIV.RESULT\(7),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(7),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_5_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(7),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(7),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(7));
\GRFPC0_OP2_5_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(39),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(39),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(39));
\GRFPC0_OP2_6_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(39),
dataa => \GRFPC0.OP2_3\(39),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(39));
\GRFPC0_FP_PIPELINE_WRDATA_3_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
dataa => \GRFPC0.DIV.RESULT\(39),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(39),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(11),
dataa => \GRFPC0.DIV.RESULT\(11),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(11),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_5_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(11),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(11),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(11));
\GRFPC0_FP_PIPELINE_WRDATA_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(28),
dataa => \GRFPC0.DIV.RESULT\(28),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(28),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_4_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(28),
dataa => N_687,
datab => N_751,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_OP2_5_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(28),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(28),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(28));
\GRFPC0_STDATA_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(28),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(28),
datad => \GRFPC0.EX.RREG.RES\(60));
\GRFPC0_OP2_5_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(16),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(16),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(16));
\GRFPC0_FP_PIPELINE_WRDATA_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
dataa => \GRFPC0.DIV.RESULT\(33),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(33),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_5_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(33),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(33),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(33));
\GRFPC0_OP2_6_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(33),
dataa => \GRFPC0.OP2_3\(33),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(33));
\GRFPC0_OP2_5_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(8),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(8),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(8));
\GRFPC0_OP2_4_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(8),
dataa => N_667,
datab => N_731,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_STDATA_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(18),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(18),
datad => \GRFPC0.EX.RREG.RES\(50));
\GRFPC0_FP_PIPELINE_WRDATA_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(18),
dataa => \GRFPC0.DIV.RESULT\(18),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(18),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_5_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(18),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(18),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(18));
\GRFPC0_OP2_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(4),
dataa => N_663,
datab => N_727,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(4),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(4),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(4));
\GRFPC0_OP2_4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(14),
dataa => N_673,
datab => N_737,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(14),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(14),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(14));
\GRFPC0_OP2_5_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(46),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(46),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(46));
\GRFPC0_INST_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(28),
dataa => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(28));
\GRFPC0_INST_A_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(28),
dataa => N_106,
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(29),
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(29));
\GRFPC0_INST_A_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(29),
dataa => N_107,
datab => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_OP2_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(2),
dataa => N_661,
datab => N_725,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(2),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(2),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(2));
\GRFPC0_STDATA_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(6),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(6),
datad => \GRFPC0.EX.RREG.RES\(38));
\GRFPC0_FP_PIPELINE_WRDATA_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(6),
dataa => \GRFPC0.DIV.RESULT\(6),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(6),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_OP2_5_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(6),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(6),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(6));
\GRFPC0_FP_PIPELINE_WRDATA_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(20),
dataa => \GRFPC0.DIV.RESULT\(20),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(20),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_STDATA_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(20),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(20),
datad => \GRFPC0.EX.RREG.RES\(52));
\GRFPC0_OP2_4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(20),
dataa => N_679,
datab => N_743,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(20),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(20),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(20));
\GRFPC0_FP_PIPELINE_DBGDATA_4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(20),
dataa => N_647,
datab => N_711,
datac => N_426,
datad => N_425);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6869_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_I_O4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_0_A2_I_O4\(0),
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_3_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_3_I\(0),
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_INST_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(5),
dataa => \GRFPC0.FIFO.INST_1\(5),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(5));
\GRFPC0_INST_A_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(5),
dataa => N_83,
datab => \GRFPC0.FIFO.INST_0\(5),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_12_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001100000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_2\(1),
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_2_1\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1226_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1226_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_14\,
dataa => N_105,
datab => N_104,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_2_0_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2_0_0_A3\,
dataa => N_105,
datab => N_104,
datac => N_106,
datad => N_107);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_8\,
dataa => N_107,
datab => N_106,
datac => N_104,
datad => N_105);
GRFPC0_STDDEP_0_SQMUXA_120_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101111111111111")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_120_I_O2\,
dataa => N_107,
datab => N_106,
datac => N_104,
datad => N_105);
\GRFPC0_FP_PIPELINE_WRDATA_3_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
dataa => \GRFPC0.DIV.RESULT\(43),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(43),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1386_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_EXEN7_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010000100001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7_3\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2),
datac => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(1));
\GRFPC0_OP2_5_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5_I_M2\(5),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2_I_M2\(5),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1_I_M2\(5));
\GRFPC0_STDATA_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(5),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(5),
datad => \GRFPC0.EX.RREG.RES\(37));
\GRFPC0_FP_PIPELINE_WRDATA_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(5),
dataa => \GRFPC0.DIV.RESULT\(5),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(5),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
dataa => \GRFPC0.DIV.RESULT\(46),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(46),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_STDATA_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(14),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(14),
datad => \GRFPC0.EX.RREG.RES\(46));
\GRFPC0_R_FSR_TEM_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_3__G2\,
dataa => \GRFPC0.WR2.RREG.RES\(26),
datab => \GRFPC0.R.FSR.TEM\(3),
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_WRDATA_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(26),
dataa => \GRFPC0.DIV.RESULT\(26),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(26),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_4_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(26),
dataa => N_685,
datab => N_749,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
\GRFPC0_STDATA_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(26),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(26),
datad => \GRFPC0.EX.RREG.RES\(58));
\GRFPC0_OP2_5_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(26),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(26),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(26));
\GRFPC0_STDATA_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(25),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(25),
datad => \GRFPC0.EX.RREG.RES\(57));
\GRFPC0_OP2_5_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(24),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(24),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(24));
\GRFPC0_STDATA_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(24),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(24),
datad => \GRFPC0.EX.RREG.RES\(56));
\GRFPC0_OP2_5_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(23),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(23),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(23));
\GRFPC0_STDATA_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(23),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(23),
datad => \GRFPC0.EX.RREG.RES\(55));
\GRFPC0_FP_PIPELINE_WRDATA_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(23),
dataa => \GRFPC0.DIV.RESULT\(23),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(23),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_STDATA_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(21),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(21),
datad => \GRFPC0.EX.RREG.RES\(53));
\GRFPC0_OP2_6_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(53),
dataa => \GRFPC0.OP2_3\(53),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(53));
\GRFPC0_OP2_5_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(51),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(51),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(51));
\GRFPC0_OP2_6_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(51),
dataa => \GRFPC0.OP2_3\(51),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_4_X\(51));
\GRFPC0_STDATA_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(19),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(19),
datad => \GRFPC0.EX.RREG.RES\(51));
\GRFPC0_FP_PIPELINE_WRDATA_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(19),
dataa => \GRFPC0.DIV.RESULT\(19),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(19),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
dataa => \GRFPC0.DIV.RESULT\(51),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(51),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_4_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(17),
dataa => N_676,
datab => N_740,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(17),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(17),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(17));
\GRFPC0_STDATA_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(17),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(17),
datad => \GRFPC0.EX.RREG.RES\(49));
\GRFPC0_FP_PIPELINE_DBGDATA_4_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => CPO_DBG_DATAZ(17),
dataa => N_644,
datab => N_708,
datac => N_426,
datad => N_425);
\GRFPC0_OP2_4_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(16),
dataa => N_675,
datab => N_739,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(48),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(48),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_1\(48));
\GRFPC0_OP2_6_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(48),
dataa => \GRFPC0.OP2_3\(48),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(48));
\GRFPC0_FP_PIPELINE_WRDATA_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(29),
dataa => \GRFPC0.DIV.RESULT\(29),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(29),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(16),
dataa => \GRFPC0.DIV.RESULT\(16),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(16),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
dataa => \GRFPC0.DIV.RESULT\(48),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(48),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_5_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(12),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(12),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(12));
\GRFPC0_OP2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(0),
dataa => N_659,
datab => N_723,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(0),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(0),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(0));
\GRFPC0_STDATA_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(7),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(7),
datad => \GRFPC0.EX.RREG.RES\(39));
\GRFPC0_OP2_4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(7),
dataa => N_666,
datab => N_730,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(3),
dataa => \GRFPC0.RFA2.RS2SEL_REP2\(2),
datab => \GRFPC0.OP2_2\(3),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(3));
\GRFPC0_FP_PIPELINE_WRDATA_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(4),
dataa => \GRFPC0.DIV.RESULT\(4),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(4),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_STDATA_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(27),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(27),
datad => \GRFPC0.EX.RREG.RES\(59));
\GRFPC0_OP2_5_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(27),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(27),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(27));
\GRFPC0_FP_PIPELINE_WRDATA_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(10),
dataa => \GRFPC0.DIV.RESULT\(10),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(10),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
dataa => \GRFPC0.DIV.RESULT\(42),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(42),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_5_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(42),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(42),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(42));
\GRFPC0_OP2_6_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(42),
dataa => \GRFPC0.OP2_3\(42),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(42));
\GRFPC0_OP2_5_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(38),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(38),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(38));
\GRFPC0_OP2_6_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(38),
dataa => \GRFPC0.OP2_3\(38),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(38));
\GRFPC0_FP_PIPELINE_WRDATA_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
dataa => \GRFPC0.DIV.RESULT\(38),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(38),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_4_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(6),
dataa => N_665,
datab => N_729,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(2),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(17),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(17));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1622_REGDEPX2_0_A2_1_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2_0_A2_1_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1181_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN285_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5591_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_OP2_5_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(22),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(22),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(22));
\GRFPC0_OP2_4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(19),
dataa => N_678,
datab => N_742,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_5_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(19),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(19),
datac => \GRFPC0.RFA2.RS2SEL\(6),
datad => \GRFPC0.OP2_1\(19));
\GRFPC0_OP2_I_M3_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_I_M3_0\(13),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_I_M3_2\(13),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_I_M3_1\(13));
\GRFPC0_WRDATA_I_M3_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.WRDATA_I_M3_0\(13),
dataa => \GRFPC0.DIV.RESULT\(13),
datab => \GRFPC0.WRDATA_I_M3_1\(13),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_STDATA_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(13),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(13),
datad => \GRFPC0.EX.RREG.RES\(45));
\GRFPC0_OP2_I_M3_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_I_M3_3\(13),
dataa => N_672,
datab => N_736,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP2\);
\GRFPC0_WRDATA_I_M3_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.WRDATA_I_M3\(45),
dataa => \GRFPC0.DIV.RESULT\(45),
datab => \GRFPC0.WRDATA_I_M3_0\(45),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
\GRFPC0_OP2_I_M3_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_I_M3_0\(45),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_I_M3_2\(45),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(6),
datad => \GRFPC0.OP2_I_M3_1\(45));
\GRFPC0_OP2_I_M3_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_I_M3\(45),
dataa => \GRFPC0.OP2_I_M3_4\(45),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(7),
datac => \GRFPC0.OP2_I_M3_3_X\(45));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0));
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_7\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL0_0_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_456_SEL0_0_I_O2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_O2_2\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_3_1_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.D.FSTLCK_M_1\,
dataa => N_100,
datab => N_101,
datac => N_108,
datad => N_109);
GRFPC0_FP_PIPELINE_UN1_CPI_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_4\,
dataa => N_113,
datab => N_112,
datac => N_110,
datad => N_111);
\GRFPC0_INST_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100101100000")
port map (
combout => \GRFPC0.INST\(18),
dataa => \GRFPC0.FIFO.RD_REP2\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.VFIFO.INST_1_4_X\(18),
datad => \GRFPC0.VFIFO.INST_0_4_X\(18));
\GRFPC0_INST_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(15),
dataa => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(15));
\GRFPC0_INST_A_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(15),
dataa => N_93,
datab => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(27),
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(27));
\GRFPC0_INST_A_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(27),
dataa => N_105,
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(17),
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(17));
\GRFPC0_INST_A_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(17),
dataa => N_95,
datab => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_DIV_PEND_RNO_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111100101")
port map (
combout => \GRFPC0.DIV.PEND_1_0_G1_0_1263_I_M5\,
dataa => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_26_0_A2_2_0_A2_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110101100")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_2_0_A2_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(3),
datab => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_26_0_A2_1_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101001111111111")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_328_3_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPC0.N_24899_1\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_26_0_A2_1_I_O2\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_M2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_14_STDEP_564_0_IV_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3628_DEP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP_1\,
dataa => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(7),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(15),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(15));
\GRFPC0_INST_I_0_M3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100101100000")
port map (
combout => \GRFPC0.INST_I_0_M3\(13),
dataa => \GRFPC0.FIFO.RD_REP2\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\,
datac => \GRFPC0.INST_I_0_M2_X\(13),
datad => \GRFPC0.INST_I_0_M2_0_X\(13));
\GRFPC0_FIFO_INST_1_RNISEC11_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011101111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.IS_RDD.TMP_1_I_I_O4_0_M2\,
dataa => \GRFPC0.FIFO.INST_1\(7),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.INST_1\(8),
datad => \GRFPC0.FIFO.INST_1\(12));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_4_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011111110111")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_4_I_O3\(0),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_265_0_A2_1_0\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.RDD_REP2\,
datad => \GRFPC0.WR.RREG.RESV\);
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3476_REGDEPX2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3476_REGDEPX2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A2_1_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_A2_1_0_A2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_STDATA_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(8),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(8),
datad => \GRFPC0.EX.RREG.RES\(40));
\GRFPC0_FP_PIPELINE_WRDATA_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(8),
dataa => \GRFPC0.DIV.RESULT\(8),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(8),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRDATA_3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
dataa => \GRFPC0.DIV.RESULT\(40),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(40),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_OP2_5_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(25),
dataa => \GRFPC0.RFA2.RS2SEL_REP3\(2),
datab => \GRFPC0.OP2_2\(25),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(25));
\GRFPC0_OP2_4_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(25),
dataa => N_684,
datab => N_748,
datac => \GRFPC0.RFA.RS2D_REP1\,
datad => \GRFPC0.OP2_SN_M4_REP1\);
GRFPC0_FP_PIPELINE_UN23_HOLDN: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN23_HOLDN\,
dataa => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.WR2.CTRL.LD\);
GRFPC0_FP_PIPELINE_UN1_WR2_CTRL_CCWR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR2.CTRL.CCWR\,
dataa => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.WR2.CTRL.CCWR\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.DIV.RD_M\(0),
dataa => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.DIV.RD\(0),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_STDATA_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100100000")
port map (
combout => \GRFPC0.STDATA_0\(22),
dataa => N_249,
datab => N_248,
datac => \GRFPC0.EX.RREG.RES\(22),
datad => \GRFPC0.EX.RREG.RES\(54));
\GRFPC0_FP_PIPELINE_WRDATA_3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(22),
dataa => \GRFPC0.DIV.RESULT\(22),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(22),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP1\);
\GRFPC0_FP_PIPELINE_WRDATA_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(54),
dataa => \GRFPC0.DIV.RESULT\(54),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(54),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN_REP2\);
GRFPC0_R_FSR_NONSTD_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.R.FSR.NONSTD_0_0_G2\,
dataa => \GRFPC0.WR2.RREG.RES\(22),
datab => \GRFPC0.R.FSR.NONSTD\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLUSH0_IV_I_O2_0\,
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPC0.OP1_0_IV\(52),
datac => \GRFPC0.OP1_0_IV\(53));
\GRFPC0_OP2_4_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(11),
dataa => N_670,
datab => N_734,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
\GRFPC0_OP2_6_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(43),
dataa => \GRFPC0.OP2_3\(43),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(43));
\GRFPC0_OP2_5_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001000")
port map (
combout => \GRFPC0.OP2_5\(43),
dataa => \GRFPC0.RFA2.RS2SEL_REP4\(2),
datab => \GRFPC0.OP2_2\(43),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(6),
datad => \GRFPC0.OP2_1\(43));
\GRFPC0_OP2_6_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPC0.OP2_6\(46),
dataa => \GRFPC0.OP2_3\(46),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(7),
datac => \GRFPC0.OP2_4_X\(46));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_M2\(4),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP1_0_IV\(54),
datac => \GRFPC0.OP1_0_IV\(51));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_1_1\(1),
dataa => \GRFPC0.V.STDATA_14\(11),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP\,
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.RD_REP4\(0),
datad => \GRFPC0.V.STDATA_14\(10));
GRFPC0_FP_PIPELINE_10_REGDEPX2_310_1_M6_I_0_O2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_1_M6_I_0_O2_1\,
dataa => \GRFPC0.FIFO.RD\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_O2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_O2_2\(0),
dataa => \GRFPC0.FIFO.RD\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_RD_1_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1_I_M2\(0),
dataa => \GRFPC0.RFA.RD\(0),
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_0_M6_I_0_A2_0_0_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_0_M6_I_0_A2_0_0_I\,
dataa => \GRFPC0.V.STDATA_14_M_0\(0),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_2_2\(0),
dataa => \GRFPC0.V.STDATA_14_M_1_0_A2\(14),
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_I_A2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_A2_4\(0),
dataa => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_I_O2\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2_REP1\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A3_5_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_122_0_IV_I_A3_5\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_22_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011111111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
dataa => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_22_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
dataa => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
GRFPC0_FP_PIPELINE_VDIV_EXEC_7_F0_RNI6KOS: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_19_1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_O2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612_3_0_O2_1\(0),
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O3_3\,
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_REP1_RNIMQ2I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_580_I_M_1\(0),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A2_4_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_0_A2_4_1\(1),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_5_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A2_5_1\(1),
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.RREG.RESV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010011000100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_3\(0),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(3),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(5),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(10),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(31),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(31));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010100010")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A3_2\(0),
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(25),
datac => \GRFPC0.WR2.CTRL.RDD_REP1\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A4_0_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000110000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A4_0_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.RDD\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_15\,
dataa => N_104,
datab => N_105,
datac => N_106,
datad => N_107);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(8),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(8),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18),
dataa => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(18),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(18));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6606_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6606_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5724_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3960_REGDEPX2_0_A2_1_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_0_A2_1_A2_0_A2\,
dataa => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5283_REGDEPX2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2_0_A2_1_A2\,
dataa => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_0_O2_1_RNIVL8K_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_3\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_0_O2_1\(0));
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4479_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_UN2607_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1247_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1247_DEP\,
dataa => N_244,
datab => N_245,
datac => N_242,
datad => N_243);
\GRFPC0_D_STLCK_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_O3_6_1\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_19067_1_I_I_A2_I_O2\);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN5183_DEP_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP_0_A2\,
dataa => N_244,
datab => N_245,
datac => N_242,
datad => N_243);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_9_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_9_0_A2\(0),
dataa => N_242,
datab => N_243,
datac => N_244,
datad => N_245);
\GRFPC0_INST_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(24),
dataa => \GRFPC0.FIFO.INST_1\(24),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(24));
\GRFPC0_INST_A_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(24),
dataa => N_102,
datab => \GRFPC0.FIFO.INST_0\(24),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(7),
dataa => \GRFPC0.FIFO.INST_1\(7),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(7));
\GRFPC0_INST_A_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(7),
dataa => N_85,
datab => \GRFPC0.FIFO.INST_0\(7),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_I_M5_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST_I_M5\(19),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_M5_A\(19));
\GRFPC0_INST_I_M5_A_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_I_M5_A\(19),
dataa => N_97,
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011010010000")
port map (
combout => \GRFPC0.INST_I_M2\(1),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\,
datad => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\);
\GRFPC0_INST_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(23),
dataa => \GRFPC0.FIFO.INST_1\(23),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(23));
\GRFPC0_INST_A_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(23),
dataa => N_101,
datab => \GRFPC0.FIFO.INST_0\(23),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_I_A2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100100001001")
port map (
combout => \GRFPC0.INST_I_A2_2\(1),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\,
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_VDIV_PEND_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.VDIV.PEND_0_SQMUXA\,
dataa => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.DIV.EXC\);
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2488_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2488_REGDEPX\,
dataa => N_95,
datab => N_96,
datac => N_93,
datad => N_94);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1240_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1240_REGDEPX\,
dataa => N_95,
datab => N_96,
datac => N_93,
datad => N_94);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN928_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\,
dataa => N_95,
datab => N_96,
datac => N_94,
datad => N_93);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2176_REGDEPX_0_A5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX_0_A5\,
dataa => N_95,
datab => N_96,
datac => N_94,
datad => N_93);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_0_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210_0_A4_0_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datac => \GRFPC0.FIFO.INST_1_M_2\(25));
\GRFPC0_MEM_CTRL_VCNT_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
dataa => \GRFPC0.EX.CTRL.VCNT\(0),
datab => \GRFPC0.EX.CTRL.VCNT\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_0_0_O4_I_O3_RNIQ2KC1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O2\(1),
dataa => \GRFPC0.CPI_I_M_1_X\(64),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP_X\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1_I_O4\);
GRFPC0_FP_PIPELINE_PENDEXC_1_0_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111101001111")
port map (
combout => CPO_EXCZ,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_STDDEP_0_SQMUXA_77_I_O2_RNI7O001: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_638_I_M_I_O2_8\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP3\,
datab => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_77_I_O2\);
\GRFPC0_D_STLCK_RNO_4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_O2_1\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\);
GRFPC0_FP_PIPELINE_FCC_VALID_9_I_M4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011100000111")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_VALID_9_I_M4_1\,
dataa => \GRFPC0.WR.CTRL.AFSR\,
datab => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_INST_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(26),
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(26));
\GRFPC0_INST_A_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(26),
dataa => N_104,
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_INST_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST_I_M2\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E_REP1\,
datad => \GRFPC0.INST_I_M2_A\(0));
\GRFPC0_INST_I_M2_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_I_M2_A\(0),
dataa => N_78,
datab => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_EX_CTRL_RDD_REP4_RNI7AMU: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_5\(1),
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_518_I_M_I_O2_6\(1));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_O3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010011110100")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_0_O3_0\(1),
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.FP_PIPELINE.12.STDEP_492_SEL0_0_1_0_O3\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1233_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\,
dataa => N_173,
datab => N_174,
datac => N_175,
datad => N_176);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN5169_DEP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP\,
dataa => N_175,
datab => N_176,
datac => N_173,
datad => N_174);
\GRFPC0_INST_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(31),
dataa => \GRFPC0.FIFO.INST_1\(31),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(31));
\GRFPC0_INST_A_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(31),
dataa => N_109,
datab => \GRFPC0.FIFO.INST_0\(31),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_FP_PIPELINE_3_1_CHECK_DEP_UN1151_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4583_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN207_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3959_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_0_STDEP_20_0_IV_I_O3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101111111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_2\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A2_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_RNIJFF61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_3_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_REP1_RNI6CUU: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_O3_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP1\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_1_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_1\(12),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\,
datad => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_110_IV_0_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110111001101")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_110_IV_0_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111011011110110")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_O2\(1),
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_OP2_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110011001010")
port map (
combout => \GRFPC0.OP2_4\(3),
dataa => N_662,
datab => N_726,
datac => \GRFPC0.RFA.RS2D\,
datad => \GRFPC0.OP2_SN_M4\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3797_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2033_REGDEPX2_0_A2_1_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2_0_A2_1_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4238_REGDEPX2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000100000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4238_REGDEPX2_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN710_REGDEPX2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.EX.CTRL.INST\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_4_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_4_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\);
\GRFPU0_GRFPU_X0_L2_0_4_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4_2\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
datad => \GRFPU0.GRFPU_X0.TZI\(14));
GRFPU0_GRFPU_X0_UN2_BCO_LSB_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_BCO_LSB_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datad => \GRFPU0.GRFPU_X0.TZI\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(18),
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD12\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(42),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_1_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011000100110001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_7_I_M\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(47),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(47),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(13),
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD7\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
GRFPU0_GRFPU_X0_UN38_BCO_LSB_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datad => \GRFPU0.GRFPU_X0.TZI2\(3));
\GRFPU0_GRFPU_X0_L1_6_1_4_0_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_4_0_I_A2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(57));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI6ME51_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010100010101000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_REST_1_1_U_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000111010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_1_U\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(20),
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD14\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(35),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD29\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(39),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(39),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_A_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(21),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD15\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
GRFPU0_GRFPU_X0_ITER_NX_RNO_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.COMB.UN57_RNDOP_0\,
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
\GRFPU0_GRFPU_X0_UN1_INTO_RNIBA5R_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000100011111")
port map (
combout => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(57),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A2_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_2\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_1\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
GRFPU0_GRFPU_X0_ST1_OP1NX_RNINEP41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN1_2_I_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(32),
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD26\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD17\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(53),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(7),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(7),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(48),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(12),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(12),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(46),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(14),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(14),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(44),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(16),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(16),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(38),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(22),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(22),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_0\(46),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_1\(46),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_0\(48),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A4_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A4_2\(48),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_2\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_1\(44),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(44),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20664\,
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_2\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_A_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(28),
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD22\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(45),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(26),
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD20\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD8\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD5\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(49),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD28\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100001001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.MULO.MRES\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(57),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100001001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(58),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.MULO.MRES\(118),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(58),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_1\(55),
dataa => \GRFPU0.GRFPU_X0.UN23_EXP\(3),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA_0_O2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD3\);
\GRFPU0_GRFPU_X0_L1_6_1_3_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_3_I_1\(1),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD51\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\,
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(36),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD30\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011000000")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD51_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_A2\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(22),
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(29),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(9),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_L1_4_1_3_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_3_I_1\(1),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD35\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_RNO_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111000001110")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(120),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_2\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datac => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20));
GRFPU0_GRFPU_X0_VITER_ND_I_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2\(24),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(30),
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD24\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(59),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2\(31),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M1_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\);
\GRFPU0_DIVROM0_DATA_1_MUX_6_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000001101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.G_53_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\,
datad => \GRFPU0.GRFPU_X0.G_51_REP1\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(0),
dataa => \GRFPC0.V.STDATA_14_REP1\(6),
datab => \GRFPC0.OP2\(52));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(1),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(53),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(4),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(56),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(4));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(6),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(58),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(6));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(7),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(59),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(7));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(8),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(60),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(8));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(9),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(61),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(9));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100111001001110")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(10),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(62),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(31),
dataa => \GRFPC0.EX.CTRL.INST\(31),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(27),
dataa => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(26),
dataa => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(18),
dataa => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(16),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(15),
dataa => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(14),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(8),
dataa => \GRFPC0.EX.CTRL.INST\(8),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(4),
dataa => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(3),
dataa => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(3));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M2_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_33_RNO_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G1\);
\GRFPU0_GRFPU_X0_UN1_DP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000100101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_DP\(0),
dataa => \GRFPC0.OP1_0_IV\(52),
datab => \GRFPC0.OP1_0_IV\(53),
datac => \GRFPC0.OP2\(53),
datad => \GRFPC0.OP2\(52));
\GRFPU0_GRFPU_X0_UN1_RAW1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000100101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RAW1\(0),
dataa => \GRFPC0.OP1_0_IV\(55),
datab => \GRFPC0.OP2\(56),
datac => \GRFPC0.OP1_0_IV\(56),
datad => \GRFPC0.OP2\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(18),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(24),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(42),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(47));
\GRFPU0_GRFPU_X0_DIFFIN2_4_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(46));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_I_M2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2_0\(38),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(12),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(1),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(29),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(23),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(6),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(22),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(39),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(28),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(48));
\GRFPU0_GRFPU_X0_DIFFIN2_4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(5),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(9),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(11),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(26),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(32),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(49));
\GRFPU0_GRFPU_X0_DIFFIN2_4_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(7),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(36),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(2),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_RMND_7_I_M3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011010011010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RMND_7_I_M3\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.NORM\,
datac => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_3\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.DRES_S\(76),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2_2\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD11\,
datac => \GRFPU0.FPMUL0.UN1_SIN_3_ADD11\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_EXP_14_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => \GRFPU0.GRFPU_X0.UN23_EXP\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(30),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(41),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD26\,
datac => \GRFPU0.FPMUL0.UN1_SIN_3_ADD26\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.MULO.DRES_S\(91),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD43\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.MULO.DRES_S\(108),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.MULO.DRES_S\(104),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.MULO.DRES_S\(107),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD42\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_DIFFIN2_4_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(25),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(59));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(16));
\GRFPU0_GRFPU_X0_DIFFIN2_4_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(16),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(24));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(14));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(50),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(51),
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(51),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(20),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(7));
\GRFPU0_GRFPU_X0_DIFFIN2_4_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(3),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(56),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(56));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(2));
\GRFPU0_GRFPU_X0_COMB_EXP_14_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.UN23_EXP\(5));
\GRFPU0_GRFPU_X0_S3ADDI_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(28),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(28));
\GRFPU0_GRFPU_X0_S3ADDI_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(49));
\GRFPU0_GRFPU_X0_S3ADDI_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(48),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(48));
\GRFPU0_GRFPU_X0_S3ADDI_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(47),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(47));
\GRFPU0_GRFPU_X0_S3ADDI_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(46),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(46));
\GRFPU0_GRFPU_X0_S3ADDI_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(45),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(45));
\GRFPU0_GRFPU_X0_S3ADDI_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(44),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(44));
\GRFPU0_GRFPU_X0_S3ADDI_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(43),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(43));
\GRFPU0_GRFPU_X0_S3ADDI_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(42),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(42));
\GRFPU0_GRFPU_X0_S3ADDI_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(41),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(41));
\GRFPU0_GRFPU_X0_S3ADDI_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(40),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(40));
\GRFPU0_GRFPU_X0_S3ADDI_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(39),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(39));
\GRFPU0_GRFPU_X0_S3ADDI_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(38),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(38));
\GRFPU0_GRFPU_X0_S3ADDI_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(37),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(37));
\GRFPU0_GRFPU_X0_S3ADDI_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(36),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(36));
\GRFPU0_GRFPU_X0_S3ADDI_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(35),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(35));
\GRFPU0_GRFPU_X0_S3ADDI_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(34));
\GRFPU0_GRFPU_X0_S3ADDI_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(33),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(33));
\GRFPU0_GRFPU_X0_S3ADDI_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(32),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(32));
\GRFPU0_GRFPU_X0_S3ADDI_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(31),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(31));
\GRFPU0_GRFPU_X0_S3ADDI_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(30),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(30));
\GRFPU0_GRFPU_X0_S3ADDI_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(29),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD14\,
datac => \GRFPU0.FPMUL0.UN1_SIN_3_ADD14\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(80),
datac => \GRFPU0.MULO.DRES_S\(79),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD33\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.MULO.DRES_S\(98),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(13));
\GRFPU0_GRFPU_X0_DIFFIN2_4_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(13),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(16),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD40\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.MULO.DRES_S\(105),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(33));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(41));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(32));
\GRFPU0_GRFPU_X0_S3ADDI_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110000001010")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(51),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(50));
\GRFPU0_GRFPU_X0_S3ADDI_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(27),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(27));
\GRFPU0_GRFPU_X0_S3ADDI_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(26),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(26));
\GRFPU0_GRFPU_X0_S3ADDI_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(25),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(25));
\GRFPU0_GRFPU_X0_S3ADDI_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(24),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(24));
\GRFPU0_GRFPU_X0_S3ADDI_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(23),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(23));
\GRFPU0_GRFPU_X0_S3ADDI_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(22),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(22));
\GRFPU0_GRFPU_X0_S3ADDI_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(21),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(21));
\GRFPU0_GRFPU_X0_S3ADDI_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(20),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(20));
\GRFPU0_GRFPU_X0_S3ADDI_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(19),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(19));
\GRFPU0_GRFPU_X0_S3ADDI_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(18),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(18));
\GRFPU0_GRFPU_X0_S3ADDI_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(17),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(17));
\GRFPU0_GRFPU_X0_S3ADDI_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(16),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(16));
\GRFPU0_GRFPU_X0_S3ADDI_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(15),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(15));
\GRFPU0_GRFPU_X0_S3ADDI_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(14),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111010010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.FPMUL0.UN1_SIN_3_ADD48\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.MULO.DRES_S\(113),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(15),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD37\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.MULO.DRES_S\(102),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(10));
\GRFPU0_GRFPU_X0_DIFFIN2_4_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(10),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(46));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(19));
\GRFPU0_GRFPU_X0_DIFFIN2_4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(19),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M7_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111101100001011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M14_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M15_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M13_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010110000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111111100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G0\,
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03_0_G0\,
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_2_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G2\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\);
\GRFPU0_SQRTROM0_DATA_1_MUX_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_4_6_0__ROM\,
datac => \GRFPU0.SQRTROM0.DATA_1_0_6_0__ROM\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_3_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_1_6_0__ROM\,
datad => \GRFPU0.SQRTROM0.DATA_1_5_6_0__ROM\);
\GRFPU0_SQRTROM0_DATA_1_MUX_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_0\,
datac => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_0\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(1));
\GRFPU0_SQRTROM0_DATA_1_MUX_3_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_0\,
datad => \GRFPU0.SQRTROM0.DATA_1_5_6__ROM_0\);
\GRFPU0_SQRTROM0_DATA_1_MUX_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_2\,
datac => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_2\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(3));
\GRFPU0_SQRTROM0_DATA_1_MUX_3_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_2\,
datad => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_3\);
\GRFPU0_SQRTROM0_DATA_1_MUX_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111001101010001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_3\,
datad => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_3\);
\GRFPU0_SQRTROM0_DATA_1_MUX_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_6_6_0__ROM\,
datac => \GRFPU0.SQRTROM0.DATA_1_2_6_0__ROM\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_3_6_0__ROM\,
datad => \GRFPU0.SQRTROM0.DATA_1_7_6_0__ROM\);
\GRFPU0_SQRTROM0_DATA_1_MUX_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_0\,
datac => \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_0\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(1));
\GRFPU0_SQRTROM0_DATA_1_MUX_6_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_0\,
datad => \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_0\);
\GRFPU0_SQRTROM0_DATA_1_MUX_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_MUX_5\(3),
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_4\(3));
\GRFPU0_SQRTROM0_DATA_1_MUX_6_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010101110101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_2\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_1_6_0__ROM\,
datac => \GRFPU0.DIVROM0.DATA_1_0_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_3_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_2_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_3_6_0__ROM\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_0\,
datac => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_3_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_0\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_2\,
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_2\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(3));
\GRFPU0_DIVROM0_DATA_1_MUX_3_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_2\,
datad => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_2\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111110100110001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_3\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_2\(4));
\GRFPU0_DIVROM0_DATA_1_MUX_6_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_5_6_0__ROM\,
datac => \GRFPU0.DIVROM0.DATA_1_4_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_6_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_6_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_7_6_0__ROM\);
\GRFPU0_DIVROM0_DATA_1_MUX_6_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_0\,
datac => \GRFPU0.DIVROM0.DATA_1_4_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_6_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_6_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_7_6__ROM_0\);
\GRFPU0_DIVROM0_DATA_1_MUX_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_2\,
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(3));
\GRFPU0_DIVROM0_DATA_1_MUX_6_A_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010001110110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_2\);
\GRFPU0_DIVROM0_DATA_1_MUX_6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110001100100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_2\,
datad => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\);
\GRFPU0_DIVROM0_DATA_1_MUX_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_9_6_0__ROM\,
datac => \GRFPU0.DIVROM0.DATA_1_8_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_10_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_10_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_11_6_0__ROM\);
\GRFPU0_DIVROM0_DATA_1_MUX_10_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_11_6__ROM_0\,
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_10_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_0\);
\GRFPU0_DIVROM0_DATA_1_MUX_10_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011001010100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_2\,
datad => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_1\);
\GRFPU0_DIVROM0_DATA_1_MUX_13_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_13_6_0__ROM\,
datac => \GRFPU0.DIVROM0.DATA_1_12_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(0));
\GRFPU0_DIVROM0_DATA_1_MUX_13_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100101011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_15_6_0__ROM\,
datad => \GRFPU0.DIVROM0.DATA_1_14_6_0__ROM\);
\GRFPU0_DIVROM0_DATA_1_MUX_13_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_13_6__ROM_0\,
datac => \GRFPU0.DIVROM0.DATA_1_12_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_13_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_14_6__ROM_0\,
datad => \GRFPU0.DIVROM0.DATA_1_15_6__ROM_0\);
\GRFPU0_DIVROM0_DATA_1_MUX_13_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011000110010")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_3\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000101000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\);
\GRFPC0_EX_CTRL_INST_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001100")
port map (
combout => \GRFPC0.EX.CTRL.INST_0_0_20__G1\,
dataa => N_167,
datab => \GRFPC0.EX.CTRL.INST\(20),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.UN1_PENDEXC_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010001101")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_M4\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100110010001101")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I_M4\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_ITER_SQRT_REP1_RNI5EKO2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011001000110010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000100100001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.RD_REP1\(0));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(6),
dataa => \GRFPC0.EX.CTRL.INST\(6),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(2),
dataa => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(17),
dataa => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\,
datad => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111010100100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(52));
\GRFPU0_GRFPU_X0_DIFFIN2_4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(14),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(12),
dataa => \GRFPC0.EX.CTRL.INST\(12),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(11),
dataa => \GRFPC0.EX.CTRL.INST\(11),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(11));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(21),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_COMB_VST2_DIFF2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(13),
dataa => \GRFPC0.EX.CTRL.INST\(13),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(19),
dataa => \GRFPC0.EX.CTRL.INST\(19),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(21),
dataa => \GRFPC0.EX.CTRL.INST\(21),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(21));
GRFPC0_DIVI_0_SQMUXA_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_2\,
dataa => \GRFPC0.FIFO.INST_0\(21),
datab => \GRFPC0.FIFO.INST_1\(21),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.V.STDATA_14_I_M2\(19));
\GRFPU0_GRFPU_X0_L1_0_2_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2_0_O2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_BCO_MSB_3_4_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI2_I_M2\(21));
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_I_A4_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I_M2\(1));
\GRFPU0_GRFPU_X0_L1_1_1_5_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI2\(8));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(4),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_8_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_A2_8\(58),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG107\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58));
\GRFPU0_GRFPU_X0_BCO_MSB_3_6_I_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_6_I\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_O2_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_L3_0_3_0_O2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_O2\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
GRFPU0_GRFPU_X0_UN73_BCO_LSB_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN73_BCO_LSB_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
GRFPU0_GRFPU_X0_UN78_BCO_LSB_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN78_BCO_LSB_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110010001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD44\,
datac => \GRFPU0.MULO.MRES_BUF\(120),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.MULO.DRES_S\(109),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(50),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\);
GRFPU0_GRFPU_X0_UN28_BCO_LSB_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_BCO_LSB_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(27),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(37),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100011001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_0_M2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010100110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_0_M2\(41),
dataa => \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3_I_M4\(41),
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP3\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_2\(38));
GRFPU0_GRFPU_X0_UN153_BCO_LSB_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(3),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(55),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(3));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000001000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(33),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
\GRFPU0_GRFPU_X0_UN1_RND_INC_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RND_INC\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.MULO.DRES_S\(101),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD36\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_L1_6_1_3_I_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_3_I_A4\(1),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD53\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\,
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(55),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(55));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(17));
\GRFPU0_GRFPU_X0_DIFFIN2_4_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(17),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(21));
\GRFPU0_GRFPU_X0_DIFFIN2_4_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(40),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_A2_2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3_REP1\(58));
\GRFPU0_DIVROM0_DATA_1_MUX_13_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010011111010")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_13_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_13_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_14_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_15_6__ROM_1\);
\GRFPU0_DIVROM0_DATA_1_MUX_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_1\,
datac => \GRFPU0.DIVROM0.DATA_1_4_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_6_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_6_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_6_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_7_6__ROM_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(54),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(54),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(5),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(57),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(5));
\GRFPU0_GRFPU_X0_DIFFIN2_4_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(43),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI_I_M2\(12));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIVAC21_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111101111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_12_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101000101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_12\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_REST_2_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001010100010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
\GRFPU0_GRFPU_X0_REST_1_2_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001010100010")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_COMB_SIGN2_1_I_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN2_1_I_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(23),
dataa => \GRFPC0.EX.CTRL.INST\(23),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(29),
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_1\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.MULO.DRES_S\(106),
datad => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_2\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
datad => \GRFPU0.MULO.MRES_BUF\(120));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2680_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(37),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\);
\GRFPU0_DIVROM0_DATA_1_MUX_10_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_11_6__ROM_1\,
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_10_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_10_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_1\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011011101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_1\,
datac => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_3_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010101100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_3_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_1\,
datad => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_1\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010111100100000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G2\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.COMB.BIAS15\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_0_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_3_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39));
\GRFPU0_GRFPU_X0_DIFFIN2_4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(15),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111110111111")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_1_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
GRFPU0_GRFPU_X0_VITER_ODDEXP_1_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ODDEXP_1_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_BCO_MSB_3_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
GRFPU0_GRFPU_X0_UN168_BCO_LSB_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.UN168_BCO_LSB_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
\GRFPU0_GRFPU_X0_L1_6_1_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
\GRFPU0_GRFPU_X0_BCO_MSB_4_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPU0_GRFPU_X0_L1_3_1_1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111110001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_L3_0_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(2),
dataa => \GRFPU0.GRFPU_X0.L2_0_3\(2),
datab => \GRFPU0.GRFPU_X0.L2_1_2\(2),
datac => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPC0_INST_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(25),
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(25));
\GRFPC0_INST_A_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(25),
dataa => N_103,
datab => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2_REP1\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1744_REGDEPX: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(16),
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111000000010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(44));
\GRFPU0_GRFPU_X0_DIFFIN2_4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(31),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000010000000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(8),
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datac => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(5),
dataa => \GRFPC0.EX.CTRL.INST\(5),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(5));
GRFPU0_GRFPU_X0_COMB_UN5_FLOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN5_FLOP\,
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14\(5));
GRFPC0_FP_PIPELINE_UN11_OP_7_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000011100100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_OP_7_1\,
dataa => \GRFPC0.FIFO.RD_REP1\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(9),
dataa => \GRFPC0.EX.CTRL.INST\(9),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(10),
dataa => \GRFPC0.EX.CTRL.INST\(10),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(24),
dataa => \GRFPC0.EX.CTRL.INST\(24),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24));
\GRFPC0_EX_CTRL_INST_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001100")
port map (
combout => \GRFPC0.EX.CTRL.INST_0_0_22__G1\,
dataa => N_169,
datab => \GRFPC0.EX.CTRL.INST\(22),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.UN1_PENDEXC_5\);
\GRFPC0_INST_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000100011111011")
port map (
combout => \GRFPC0.INST\(9),
dataa => \GRFPC0.FIFO.INST_1\(9),
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datac => \GRFPC0.VFIFO.INST_1_1_SQMUXA_M1_E\,
datad => \GRFPC0.INST_A\(9));
\GRFPC0_INST_A_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010011")
port map (
combout => \GRFPC0.INST_A\(9),
dataa => N_87,
datab => \GRFPC0.FIFO.INST_0\(9),
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA_0_A2_M1_E\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(7),
dataa => \GRFPC0.EX.CTRL.INST\(7),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(7));
GRFPU0_GRFPU_X0_COMB_UN20_FLOP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111100110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN20_FLOP\,
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.RD_REP4\(0),
datad => \GRFPC0.V.STDATA_14\(12));
GRFPC0_FP_PIPELINE_UN8_OP_7_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011011")
port map (
combout => \GRFPC0.FP_PIPELINE.UN8_OP_7_1\,
dataa => \GRFPC0.FIFO.RD_REP1\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.V.STDATA_14\(12));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.UN243_BCO_LSB_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(29));
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_RNIABJB1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011101")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_0_2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(10));
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(25),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD19\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
GRFPU0_GRFPU_X0_UN58_BCO_LSB_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_0_A4\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_L1_3_1_4_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_4_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101000011101110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_1\,
datac => \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_1\,
datad => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(2));
\GRFPU0_SQRTROM0_DATA_1_MUX_6_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010110011101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_6_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_1\,
datad => \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_1\);
\GRFPU0_SQRTROM0_DATA_1_MUX_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110110001101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_1\,
datac => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(2));
\GRFPU0_SQRTROM0_DATA_1_MUX_3_A_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011100100111")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_3_A\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_1\,
datac => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_1\);
GRFPU0_GRFPU_X0_UN1_VST2_REG82_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_COMB_UN6_SWAP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110111101101111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_SWAP\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
GRFPU0_GRFPU_X0_COMB_UN1_ST1_SIGN1_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.SIGN1_0_A3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPU0_GRFPU_X0_ST2_REG_RET_0_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP0\(21));
\GRFPU0_GRFPU_X0_L1_3_1_3_0_A4_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_3_0_A4\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\);
\GRFPU0_GRFPU_X0_L1_0_1_5_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_5_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(0));
GRFPU0_GRFPU_X0_UN18_BCO_LSB_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN18_BCO_LSB_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
GRFPU0_GRFPU_X0_UN23_BCO_LSB_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_L1_1_1_4_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(8));
\GRFPU0_GRFPU_X0_L1_2_1_4_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_4_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.TZI\(16));
\GRFPU0_GRFPU_X0_DIFFIN2_4_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(35),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_I_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_I_A4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M3_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(62));
\GRFPU0_GRFPU_X0_L3_0_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(2),
dataa => \GRFPU0.GRFPU_X0.L2_1\(2),
datab => \GRFPU0.GRFPU_X0.L2_0_1\(2),
datac => \GRFPU0.GRFPU_X0.L2\(4));
\GRFPU0_GRFPU_X0_L1_0_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100001111")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_3\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datac => \GRFPU0.GRFPU_X0.L1_0_1_I_1\(1),
datad => \GRFPU0.GRFPU_X0.UN88_BCO_LSB\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => NN_2,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M38_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M37_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M35_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M36_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110101001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G2\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_M\(2),
dataa => \GRFPC0.V.STDATA_14_REP2\(6),
datab => \GRFPC0.OP2\(54),
datac => \GRFPU0.GRFPU_X0.UN28_EXP\(2));
GRFPU0_GRFPU_X0_EXP_1_SQMUXA_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_1_SQMUXA_I\,
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\);
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_I_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_3_I_A4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_VST3_EXC_1_SQMUXA_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA_10\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG46_0_A2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000010101010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\);
GRFPU0_GRFPU_X0_VITER_R_I_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000100000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_ITER_STATE_RNID7RD_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_1_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.M4_0_0_O2_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.MULO.MRES\(98),
datac => \GRFPU0.MULO.MRES\(97));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111101101111011")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_O2_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
GRFPU0_GRFPU_X0_COMB_UN63_BLSB_0_A2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN63_BLSB_0_A2_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(7));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_212_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_212_0_A2_0\(1),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.V.STDATA_14_I_M2\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_25_IV_0_O2_I_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001000111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_25_IV_0_O2_I_A2\(1),
dataa => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.V.STDATA_14\(18));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN593_REGDEPX2_1_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001010011")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN593_REGDEPX2_1_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.V.STDATA_14_I_M2\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(17),
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(17));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M22_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M22_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M38_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M21_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100100001000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M21_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V4_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V4_0_A2_0\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I_X\(6),
datac => \GRFPC0.INST_I\(10),
datad => \GRFPC0.INST_I\(11));
\GRFPC0_INST_I_X_RNI1J4Q_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000010010000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_A5_1_806_I_A2_3\,
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I_X\(6),
datac => \GRFPC0.INST_I\(10),
datad => \GRFPC0.INST_I\(11));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_A2_12_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_0_A2_12_1\(1),
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.RD_REP1\(0),
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(28),
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(28));
\GRFPC0_EX_CTRL_INST_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000101000001100")
port map (
combout => \GRFPC0.EX.CTRL.INST_0_0_30__G1\,
dataa => N_177,
datab => \GRFPC0.EX.CTRL.INST\(30),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP0\,
datad => \GRFPC0.UN1_PENDEXC_5\);
GRFPU0_GRFPU_X0_COMB_SIGN_1_I_M3_RNIEBMM: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011010111111111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_1169_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datad => \GRFPU0.GRFPU_X0.COMB.SIGN_1_I_M3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIE21T_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000110110001101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPU0_GRFPU_X0_UN6_SGNFX_TERM_RNIJOV41_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0_A4_0_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(23));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001110011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100011011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001110011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100011011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110101")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010011100100111")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001110011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4_A\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001101100011011")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4_A\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M35_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M36_4_03_0_G0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110000100000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G0\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_O2_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_2_O2_0\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_I_O2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001011110010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_I_O2\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(9),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(11),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_7_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000010110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_7\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_6_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100000001000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_6\(53),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_16_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101111")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_O2_5\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\);
GRFPU0_GRFPU_X0_UN68_BCO_LSB_0_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN68_BCO_LSB_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_L3_0_5_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(2),
dataa => \GRFPU0.GRFPU_X0.L2_1_4\(2),
datab => \GRFPU0.GRFPU_X0.L2_0_5\(2),
datac => \GRFPU0.GRFPU_X0.L2_0_7\(4));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.TZI2\(13));
\GRFPU0_GRFPU_X0_L1_2_1_5_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111001010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
datad => \GRFPU0.GRFPU_X0.TZI2\(17));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000011001100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_0\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(26));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(22));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111001000000010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(30));
GRFPU0_GRFPU_X0_COMB_EXPINC_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001010100010101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPINC_1_0\,
dataa => \GRFPU0.MULO.MRES_BUF\(121),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD53\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
GRFPU0_GRFPU_X0_COMB_G_DP_1_U: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.COMB.G_DP_1_0\);
\GRFPU0_GRFPU_X0_S3ADDI_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(0));
\GRFPU0_GRFPU_X0_S3ADDI_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(1));
\GRFPU0_GRFPU_X0_S3ADDI_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(2));
\GRFPU0_GRFPU_X0_S3ADDI_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(3),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(3));
\GRFPU0_GRFPU_X0_S3ADDI_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(4),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(4));
\GRFPU0_GRFPU_X0_S3ADDI_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(5),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(5));
\GRFPU0_GRFPU_X0_S3ADDI_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(6),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(6));
\GRFPU0_GRFPU_X0_S3ADDI_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(7),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(7));
\GRFPU0_GRFPU_X0_S3ADDI_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(8),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(8));
\GRFPU0_GRFPU_X0_S3ADDI_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(9),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(9));
\GRFPU0_GRFPU_X0_S3ADDI_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(10),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(10));
\GRFPU0_GRFPU_X0_S3ADDI_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(11),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(11));
\GRFPU0_GRFPU_X0_S3ADDI_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(12),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(12));
\GRFPU0_GRFPU_X0_S3ADDI_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(13),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.S3ADDI_0\(13));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111000011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(34),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD4\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(43),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\,
datad => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010000001110000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(43),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000011010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0\);
GRFPU0_GRFPU_X0_ST3_QSNAN_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110110011101100")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.QSNAN_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.QSNAN\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A3_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A3_2_0\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_3\(0),
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_3_I_O3_2\(0));
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_0_A2_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_0_A2_1_0\,
dataa => \GRFPC0.INST\(9),
datab => \GRFPC0.INST_I\(12));
GRFPU0_GRFPU_X0_UN1_VALLOW_1_SQMUXA_INV_0_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_23\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_4_03\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_4_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_4_03\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE46_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE46_0\,
dataa => \GRFPC0.OP2\(62),
datab => \GRFPC0.OP2\(56));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN23_DP_0_A2_0\,
dataa => \GRFPC0.OP2\(62),
datab => \GRFPC0.OP2\(53));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_15_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_A2_6_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_4_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_4_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_30_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_30\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_4_03\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_15_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_15\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_4_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_4_03\);
\GRFPC0_R_STATE_RNIFFND_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I_O4_0_0\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0));
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNI3T5E_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0_A5_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFFV\);
\GRFPU0_GRFPU_X0_ITER_ALLOW_RNIR53I_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_2_M_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7_REP1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_9_S_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_9_S_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.COMB.INCX16_I_O2\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\,
dataa => \GRFPC0.WR2.CTRL.ID\(7),
datab => \GRFPU0.GRFPU_X0.RDY_F0_I\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_10\,
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.MULO.MRES\(89));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_6_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_2\,
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(83));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_2\,
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.MULO.MRES\(75));
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_41\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_14\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_13\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_64_29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_64_29\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_6\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_5\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_5\,
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.MULO.MRES\(95));
GRFPC0_STDDEP_0_SQMUXA_87_I_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_87_I_O2_0\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(26));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\,
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.MULO.MRES\(86));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\,
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.MRES\(79));
GRFPU0_GRFPU_X0_NXX_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_0\,
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.MULO.MRES\(75));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNIBFJH_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_VST3_REG_1_SQMUXA_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\);
GRFPU0_GRFPU_X0_UN1_ST2_FLTYPE2_8_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_0_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_0_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_A2_0_3\(0),
dataa => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(26));
GRFPU0_GRFPU_X0_S_SP_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_11\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(14));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_0_A2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LTO10_0_A2_0_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_O2_1\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD4\,
datab => \GRFPU0.GRFPU_X0.C_ADD5\);
GRFPU0_GRFPU_X0_VST2_REG_3_SQMUXA_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_3_SQMUXA_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_L1_0_5_0_A2_0_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5_0_A2_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPC0_DIV_EXCT_0_0_2__G0_0_A3_1_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.IOF\,
datab => \GRFPU0.GRFPU_X0.ST4.ADDOF\);
\GRFPU0_GRFPU_X0_L1_0_1_0_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_L1_0_0_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNIP6QO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNI7F5L_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_0_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_L1_4_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_L1_2_2_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIR6PI_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI87MH_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_A2_1_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
\GRFPU0_GRFPU_X0_L1_4_1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_L1_5_1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_0\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O3_4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_158_IV_0_O3_4_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIIT0I_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1_293_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
GRFPU0_GRFPU_X0_COMB_GETINF_UN9_MODE_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.INF\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(3));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIKT7H_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_9_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_9_0\(1),
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_8_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_8_0\(1),
dataa => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_1_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_1_2_0\(0),
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_0_0\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O3_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_O3_1_0\(1),
dataa => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FIFO_INST_1_RNI9VNP_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.DEP_2_I_I_0_A3_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_UN2368_REGDEPX_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_0_A2_0\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(28));
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD3_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_5_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_5_1_0\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_1_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_5_1_0\(15),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN496_REGDEPX_0_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0_O2_0\,
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN527_REGDEPX_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN527_REGDEPX_0\,
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(2));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A3_0_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX_138_0_A3_0_1_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_A4_1_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_A4_1_1_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_UN2992_REGDEPX_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN2992_REGDEPX_0\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(26));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN694_DEP_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_0\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_I_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP27_I_O2_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_3_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_3_0\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(2));
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_2_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPC0_DEP_1_SQMUXA_88_0_A3_I_O2_0_0_O2_0_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0_O2_0_0\,
dataa => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(7));
\GRFPC0_D_STLCK_RNO_9_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_A5\,
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_0_I_O2\);
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNIHGHM3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_51_M1_E\,
dataa => \GRFPU0.GRFPU_X0.RNDOP_14_IV\(0),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\);
GRFPU0_GRFPU_X0_COMB_UN77_FLUSH_I_X2_RNIU3PH3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\);
GRFPC0_EX_CTRL_CCWR_RNIODB5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1_0\,
dataa => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_51_M3_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_51_M3_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_4_RNO_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => D_M2_E_0_1,
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD46\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_8\(52));
GRFPC0_WR_CTRL_RDD_RNI254F: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => D_M2_E_4_0,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_3_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_3_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\);
GRFPC0_FP_PIPELINE_0_1_FIFO_INST_V_TMP_IV_RNI3G5P: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_M_2_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_1_0\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\);
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_204_0_A3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_204_0_A3_0\(0),
dataa => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A4_2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A4_2_0\(0),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(3));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_1_1_O2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2_0\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL1_I_0_A2_0_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL1_I_0_A2_0_A2_0\,
dataa => \GRFPC0.WR.CTRL.RDD_REP1\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_5_0_A2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_5_0_A2_0\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_S_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_0_S\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I\);
GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_M2_E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_M2_E\,
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_DIV_EXCT_0_0_0__G3_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_0__G3_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datab => \GRFPU0.GRFPU_X0.ST4.DEFERNX\);
\GRFPC0_FIFO_VCNT_1_RNO_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA_2_C1_1_TZ\,
dataa => \GRFPC0.FIFO.VCNT_1\(1),
datab => \GRFPC0.FIFO.VCNT_1\(0));
GRFPC0_FP_PIPELINE_UN1_VEX_CTRL_LD_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VEX.CTRL.LD_0\,
dataa => \GRFPC0.RFA.AFSR\,
datab => \GRFPC0.RFA.LD_REP1\);
\GRFPC0_D_STLCK_RNO_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_576_I_M_2586\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1_0_0_O4_I_O3\(1));
GRFPC0_FCC_VALID_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FCC_VALID_0_SQMUXA\,
dataa => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR.CTRL.CCWR\);
GRFPC0_UN1_WR2_CTRL_SEQERR: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.UN1_WR2.CTRL.SEQERR\,
dataa => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.PENDEXC_0_SQMUXA_0_A2\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5269_REGDEPX2_1_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5269_REGDEPX2_1_I_O4\,
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2006_DEP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2006_DEP_2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_10_STDEP_420_0_IV_I_O2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_420_0_IV_I_O2_3\(0),
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_1_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_I_O2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_18_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.EX.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_UN2592_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2592_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(16));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN80_REGDEPX_2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_2_0_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_I_I3_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_I3_0_O2\(1),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.RDD_REP1\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_18_I_O2_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_I_O2_I_O2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(0),
datab => \GRFPC0.EX.CTRL.RDD_REP1\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3318_DEP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3318_DEP_1\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN24_DEP_2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_2_0_A2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_13_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_I_O2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_13_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13_0_I_O2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.WR2.CTRL.RDD\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1022_DEP_2_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1022_DEP_2_I_O2\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN366_DEP_1_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1_0_A2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN24_DEP_1_0_A3_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP_1_0_A3_0_A2\,
dataa => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_6_I_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_6_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_I_O3\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_1_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1_I_O2\(1),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_I_O2\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_3_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_I_O2\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_0_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20_0_0_O2\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_3_0_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_0_0_O2\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_1\(0),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1\(6));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4568_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(16));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN190_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN3974_DEP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3974_DEP_2\,
dataa => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4152_REGDEPX_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_1_I_O2\,
dataa => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5696_REGDEPX2_2_I_O2_0_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5696_REGDEPX2_2_I_O2_0_O4\,
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.DEP_2_I_O2\(1),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_1\(6));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1448_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_1\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3632_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN190_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17));
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4447_REGDEPX_1_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4447_REGDEPX_1_I_O3\,
dataa => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(27));
GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_UN3528_REGDEPX_1_0_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3528_REGDEPX_1_0_I\,
dataa => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_5_0_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_I_O2\(1),
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_5_0_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_5_0_0_O2\(0),
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5298_REGDEPX2_1_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2_1_I_O4\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN830_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_7_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_1_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2_0\(1),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10_0_I_O2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16_0_I_O2\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.RDD\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2182_REGDEPX2_2_0_A2_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2182_REGDEPX2_2_0_A2_0_A4\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_10_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10_0_A2\(1),
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_A2_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_1_1\(1),
dataa => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FID_1_IV_0_A2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2\(4),
dataa => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_1_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_A2_1_0_A2\(0),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7062_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2_0_O2\,
dataa => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6592_REGDEPX2_0_A2_0_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6592_REGDEPX2_0_A2_0_0_A4\,
dataa => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2211_REGDEPX2_2_0_A2_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2_2_0_A2_0_A4\,
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(4));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6621_REGDEPX2_0_A2_0_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2_0_A2_0_0_A4\,
dataa => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_7_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_I_O2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1682_REGDEPX2_2_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1682_REGDEPX2_2_I_O4\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5710_REGDEPX2_1_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5710_REGDEPX2_1_I_O4\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(3));
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_1_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0_O2\(1),
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4828_REGDEPX2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4828_REGDEPX2_0_O2\,
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN800_REGDEPX2_0_A2_1_0_A2_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_0_A2_1_0_A2_0_A4\,
dataa => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.INST\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN400_REGDEPX2_2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_R_FSR_CEXC_RNO_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.DIV.EXCT_M\(4),
dataa => \GRFPC0.DIV.EXCT\(4),
datab => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
\GRFPC0_FID_1_IV_0_A2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2_1\(0),
dataa => \GRFPC0.MEM.CTRL.ID\(0),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0));
GRFPC0_V_FSR_CEXC_5_SQMUXA_RNINLPF: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_M5\,
dataa => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datab => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_V_STATE10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE10\,
dataa => \GRFPC0.DIV.VALID_REP1\,
datab => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1\);
\GRFPC0_R_FSR_CEXC_RNO_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.DIV.EXCT_M\(2),
dataa => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPC0.V.FSR.CEXC_6_SQMUXA\);
GRFPC0_FP_PIPELINE_UN1_WR_CTRL_ID_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.ID_0\,
dataa => \GRFPC0.WR.CTRL.ID\(0),
datab => \GRFPC0.FPR.ID\(0));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_I_X3_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_I_X3_3\,
dataa => \GRFPC0.FPR.ID\(3),
datab => \GRFPC0.EX.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_DIV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataa => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.RREG.RESV\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2139_REGDEPX2_0_A2_0_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2139_REGDEPX2_0_A2_0_0_A2\,
dataa => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_4_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.N_25113_2\,
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_2_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_12_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(0),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_5_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_5_1\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_2_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_I_O2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1271_REGDEPX2_0_A2_0_0_A2_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2_0_A2_0_0_A2_I_O4\,
dataa => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6533_REGDEPX2_1_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6533_REGDEPX2_1_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_OP1_0_IV_3_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.WR2.RREG.RES_I_M\(41),
dataa => \GRFPC0.WR2.RREG.RES\(41),
datab => \GRFPC0.RFA2.RS1SEL_REP2\(4));
\GRFPU0_GRFPU_X0_RES_1_6_I_A4_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_A4\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_0_I_X2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_X2_0\(1),
dataa => \GRFPC0.OP1_0_IV\(55),
datab => \GRFPC0.OP2\(55));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(0),
dataa => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(1),
dataa => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.V.STDATA_0_SQMUXA_3\);
GRFPC0_FP_PIPELINE_2_REGDEPX2_85TT_1_M1_E_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85TT_1_M1_E_2\,
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_15_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15_2\(1),
dataa => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_13_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_13_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(30),
dataa => \GRFPC0.MEM.CTRL.PC\(30),
datab => \GRFPC0.MEM.CTRL.INST\(30),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(29),
dataa => \GRFPC0.MEM.CTRL.PC\(29),
datab => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(28),
dataa => \GRFPC0.MEM.CTRL.PC\(28),
datab => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(27),
dataa => \GRFPC0.MEM.CTRL.PC\(27),
datab => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(26),
dataa => \GRFPC0.MEM.CTRL.PC\(26),
datab => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(25),
dataa => \GRFPC0.MEM.CTRL.PC\(25),
datab => \GRFPC0.MEM.CTRL.INST\(25),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(24),
dataa => \GRFPC0.MEM.CTRL.PC\(24),
datab => \GRFPC0.MEM.CTRL.INST\(24),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(23),
dataa => \GRFPC0.MEM.CTRL.PC\(23),
datab => \GRFPC0.MEM.CTRL.INST\(23),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(22),
dataa => \GRFPC0.MEM.CTRL.PC\(22),
datab => \GRFPC0.MEM.CTRL.INST\(22),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(21),
dataa => \GRFPC0.MEM.CTRL.PC\(21),
datab => \GRFPC0.MEM.CTRL.INST\(21),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(20),
dataa => \GRFPC0.MEM.CTRL.PC\(20),
datab => \GRFPC0.MEM.CTRL.INST\(20),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(19),
dataa => \GRFPC0.MEM.CTRL.PC\(19),
datab => \GRFPC0.MEM.CTRL.INST\(19),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(16),
dataa => \GRFPC0.MEM.CTRL.PC\(16),
datab => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(14),
dataa => \GRFPC0.MEM.CTRL.PC\(14),
datab => \GRFPC0.MEM.CTRL.INST\(14),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(11),
dataa => \GRFPC0.MEM.CTRL.PC\(11),
datab => \GRFPC0.MEM.CTRL.INST\(11),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(9),
dataa => \GRFPC0.MEM.CTRL.PC\(9),
datab => \GRFPC0.MEM.CTRL.INST\(9),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(4),
dataa => \GRFPC0.MEM.CTRL.PC\(4),
datab => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(2),
dataa => \GRFPC0.MEM.CTRL.PC\(2),
datab => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(30),
dataa => \GRFPC0.WR.CTRL.PC\(30),
datab => \GRFPC0.WR.CTRL.INST\(30),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(29),
dataa => \GRFPC0.WR.CTRL.PC\(29),
datab => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(28),
dataa => \GRFPC0.WR.CTRL.PC\(28),
datab => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(27),
dataa => \GRFPC0.WR.CTRL.PC\(27),
datab => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(26),
dataa => \GRFPC0.WR.CTRL.PC\(26),
datab => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(25),
dataa => \GRFPC0.WR.CTRL.PC\(25),
datab => \GRFPC0.WR.CTRL.INST\(25),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(24),
dataa => \GRFPC0.WR.CTRL.PC\(24),
datab => \GRFPC0.WR.CTRL.INST\(24),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(23),
dataa => \GRFPC0.WR.CTRL.PC\(23),
datab => \GRFPC0.WR.CTRL.INST\(23),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(22),
dataa => \GRFPC0.WR.CTRL.PC\(22),
datab => \GRFPC0.WR.CTRL.INST\(22),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(21),
dataa => \GRFPC0.WR.CTRL.PC\(21),
datab => \GRFPC0.WR.CTRL.INST\(21),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(20),
dataa => \GRFPC0.WR.CTRL.PC\(20),
datab => \GRFPC0.WR.CTRL.INST\(20),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(19),
dataa => \GRFPC0.WR.CTRL.PC\(19),
datab => \GRFPC0.WR.CTRL.INST\(19),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(16),
dataa => \GRFPC0.WR.CTRL.PC\(16),
datab => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(14),
dataa => \GRFPC0.WR.CTRL.PC\(14),
datab => \GRFPC0.WR.CTRL.INST\(14),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(11),
dataa => \GRFPC0.WR.CTRL.PC\(11),
datab => \GRFPC0.WR.CTRL.INST\(11),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(9),
dataa => \GRFPC0.WR.CTRL.PC\(9),
datab => \GRFPC0.WR.CTRL.INST\(9),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(4),
dataa => \GRFPC0.WR.CTRL.PC\(4),
datab => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(2),
dataa => \GRFPC0.WR.CTRL.PC\(2),
datab => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPU0_GRFPU_X0_RES_1_4_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(62),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(52),
dataa => \GRFPC0.WR2.RREG.RES\(52),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(52));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(24),
dataa => \GRFPC0.WR2.RREG.RES\(24),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_24__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(27),
dataa => \GRFPC0.WR2.RREG.RES\(27),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_27__G3\);
\GRFPC0_OP2_3_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(32),
dataa => \GRFPC0.EX.RREG.RES\(32),
datab => \GRFPC0.WR.RREG.RES\(32),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(32),
dataa => \GRFPC0.MEM.RREG.RES\(32),
datab => \GRFPC0.DIV.RESULT\(32),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(32),
dataa => \GRFPC0.WR2.RREG.RES\(32),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(32));
\GRFPC0_OP2_3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(34),
dataa => \GRFPC0.EX.RREG.RES\(34),
datab => \GRFPC0.WR.RREG.RES\(34),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(34),
dataa => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.DIV.RESULT\(34),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(34),
dataa => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(34));
\GRFPC0_OP2_3_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(41),
dataa => \GRFPC0.EX.RREG.RES\(41),
datab => \GRFPC0.WR.RREG.RES\(41),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(41),
dataa => \GRFPC0.MEM.RREG.RES\(41),
datab => \GRFPC0.DIV.RESULT\(41),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(41),
dataa => \GRFPC0.WR2.RREG.RES\(41),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(41));
\GRFPC0_OP2_3_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(44),
dataa => \GRFPC0.EX.RREG.RES\(44),
datab => \GRFPC0.WR.RREG.RES\(44),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_3_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(47),
dataa => \GRFPC0.EX.RREG.RES\(47),
datab => \GRFPC0.WR.RREG.RES\(47),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(47),
dataa => \GRFPC0.MEM.RREG.RES\(47),
datab => \GRFPC0.DIV.RESULT\(47),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(52),
dataa => \GRFPC0.EX.RREG.RES\(52),
datab => \GRFPC0.WR.RREG.RES\(52),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(52),
dataa => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.DIV.RESULT\(52),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(52),
dataa => \GRFPC0.WR2.RREG.RES\(52),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(52));
\GRFPC0_OP2_3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(55),
dataa => \GRFPC0.EX.RREG.RES\(55),
datab => \GRFPC0.WR.RREG.RES\(55),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(55),
dataa => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.DIV.RESULT\(55),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_1_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(55),
dataa => \GRFPC0.WR2.RREG.RES\(55),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.DIV.RESULT_0_0_55__G3\);
\GRFPC0_OP2_3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(56),
dataa => \GRFPC0.EX.RREG.RES\(56),
datab => \GRFPC0.WR.RREG.RES\(56),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_3_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(63),
dataa => \GRFPC0.EX.RREG.RES\(63),
datab => \GRFPC0.WR.RREG.RES\(63),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_3_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(62),
dataa => \GRFPC0.EX.RREG.RES\(62),
datab => \GRFPC0.WR.RREG.RES\(62),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(62),
dataa => \GRFPC0.MEM.RREG.RES\(62),
datab => \GRFPC0.DIV.RESULT\(62),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(31),
dataa => \GRFPC0.EX.RREG.RES\(31),
datab => \GRFPC0.WR.RREG.RES\(31),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(31),
dataa => \GRFPC0.MEM.RREG.RES\(31),
datab => \GRFPC0.DIV.RESULT\(31),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(31),
dataa => \GRFPC0.WR2.RREG.RES\(31),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_31__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(31),
dataa => \GRFPC0.WR2.RREG.RES\(31),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_31__G3\);
\GRFPC0_OP2_2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(44),
dataa => \GRFPC0.MEM.RREG.RES\(44),
datab => \GRFPC0.DIV.RESULT\(44),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(1),
dataa => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(34),
dataa => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(34));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(2),
dataa => \GRFPC0.WR2.RREG.RES\(2),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(3),
dataa => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_3__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(41),
dataa => \GRFPC0.WR2.RREG.RES\(41),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(41));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(12),
dataa => \GRFPC0.WR2.RREG.RES\(12),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_12__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(55),
dataa => \GRFPC0.WR2.RREG.RES\(55),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_55__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(32),
dataa => \GRFPC0.WR2.RREG.RES\(32),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(32));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(0),
dataa => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_0__G3\);
\GRFPC0_OP2_2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(40),
dataa => \GRFPC0.MEM.RREG.RES\(40),
datab => \GRFPC0.DIV.RESULT\(40),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(40),
dataa => \GRFPC0.WR2.RREG.RES\(40),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(40));
\GRFPC0_OP2_3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(50),
dataa => \GRFPC0.EX.RREG.RES\(50),
datab => \GRFPC0.WR.RREG.RES\(50),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(50),
dataa => \GRFPC0.MEM.RREG.RES\(50),
datab => \GRFPC0.DIV.RESULT\(50),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
dataa => \GRFPC0.WR2.RREG.EXCT\(2),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.EX.RREG.EXCT_0_0_2__G4\);
\GRFPC0_OP2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(1),
dataa => \GRFPC0.EX.RREG.RES\(1),
datab => \GRFPC0.WR.RREG.RES\(1),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(1),
dataa => \GRFPC0.MEM.RREG.RES\(1),
datab => \GRFPC0.DIV.RESULT\(1),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(1),
dataa => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_1__G3\);
\GRFPC0_OP2_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(21),
dataa => \GRFPC0.EX.RREG.RES\(21),
datab => \GRFPC0.WR.RREG.RES\(21),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(21),
dataa => \GRFPC0.MEM.RREG.RES\(21),
datab => \GRFPC0.DIV.RESULT\(21),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(21),
dataa => \GRFPC0.WR2.RREG.RES\(21),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_21__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(21),
dataa => \GRFPC0.WR2.RREG.RES\(21),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_21__G3\);
\GRFPC0_OP2_3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(58),
dataa => \GRFPC0.EX.RREG.RES\(58),
datab => \GRFPC0.WR.RREG.RES\(58),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(58),
dataa => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.DIV.RESULT\(58),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_1_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(58),
dataa => \GRFPC0.WR2.RREG.RES\(58),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(58));
\GRFPC0_OP2_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(59),
dataa => \GRFPC0.EX.RREG.RES\(59),
datab => \GRFPC0.WR.RREG.RES\(59),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(59),
dataa => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.DIV.RESULT\(59),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(29),
dataa => \GRFPC0.EX.RREG.RES\(29),
datab => \GRFPC0.WR.RREG.RES\(29),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(29),
dataa => \GRFPC0.MEM.RREG.RES\(29),
datab => \GRFPC0.DIV.RESULT\(29),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(29),
dataa => \GRFPC0.WR2.RREG.RES\(29),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_29__G3\);
\GRFPC0_OP2_3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(30),
dataa => \GRFPC0.EX.RREG.RES\(30),
datab => \GRFPC0.WR.RREG.RES\(30),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(30),
dataa => \GRFPC0.MEM.RREG.RES\(30),
datab => \GRFPC0.DIV.RESULT\(30),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(30),
dataa => \GRFPC0.WR2.RREG.RES\(30),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_30__G3\);
\GRFPC0_V_STDATA_14_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(14),
dataa => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_FP_PIPELINE_WRADDR_1_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(1),
dataa => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.WR2.CTRL.RD\(2),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_V_STDATA_14_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(18),
dataa => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_V_STDATA_14_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(16),
dataa => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_V_STDATA_14_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.V.STDATA_14\(15),
dataa => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.RD_REP4\(0),
datac => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_V_STDATA_14_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.V.STDATA_14\(6),
dataa => \GRFPC0.FIFO.RD_REP3\(0),
datab => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_V_STDATA_14_I_M2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14_I_M2\(0),
dataa => \GRFPC0.FIFO.INST_1\(0),
datab => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_V_STDATA_14_I_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14_I_M2\(17),
dataa => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_OP2_2_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(56),
dataa => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.DIV.RESULT\(56),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(63),
dataa => \GRFPC0.WR2.RREG.RES\(63),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datac => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(58),
dataa => \GRFPC0.WR2.RREG.RES\(58),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(58));
\GRFPC0_OP2_2_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(63),
dataa => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPC0.DIV.RESULT\(63),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_1_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_1\(63),
dataa => \GRFPC0.WR2.RREG.RES\(63),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(63),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(4));
GRFPC0_FP_PIPELINE_VDIV_RDD_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RDD_1\,
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.WR2.CTRL.RDD_REP1\,
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
dataa => \GRFPC0.WR2.CTRL.RD\(2),
datab => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
dataa => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_4_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55_0_A2_4_2\(0),
dataa => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_0_UN1_VDIV_EXEC_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC_I_O2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F0\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
dataa => \GRFPC0.WR2.RREG.EXCT\(3),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10\(0),
dataa => \GRFPC0.R.FSR.TEM\(0),
datab => \GRFPC0.DIV.EXCT\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_1_1\,
dataa => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2680_DEP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP_2\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2\,
dataa => \GRFPC0.EX.CTRL.RDD_REP3\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_0_1_1_O2\);
GRFPC0_FP_PIPELINE_7_STDEP_292_SEL1_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2\,
dataa => \GRFPC0.MEM.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_SEL1_I_0_A2_1\);
GRFPC0_FP_PIPELINE_7_STDEP_288_SEL1_I_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_288_SEL1_I_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.N_19292_1_I_0_O2\);
\GRFPC0_FID_1_IV_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2\(1),
dataa => \GRFPC0.EX.CTRL.ID\(1),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0));
GRFPC0_FP_PIPELINE_V_STDATA_1_M3S2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3S2\,
dataa => \GRFPC0.WR.CTRL.PEND\,
datab => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPU0_GRFPU_X0_UN38_EXP_RNIG4TO1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP2_M_V\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_REP1\,
datab => \GRFPU0.GRFPU_X0.UN38_EXP\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(6),
dataa => \GRFPC0.WR.CTRL.PC\(6),
datab => \GRFPC0.WR.CTRL.INST\(6),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(12),
dataa => \GRFPC0.WR.CTRL.PC\(12),
datab => \GRFPC0.WR.CTRL.INST\(12),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(13),
dataa => \GRFPC0.WR.CTRL.PC\(13),
datab => \GRFPC0.WR.CTRL.INST\(13),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(6),
dataa => \GRFPC0.MEM.CTRL.PC\(6),
datab => \GRFPC0.MEM.CTRL.INST\(6),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(12),
dataa => \GRFPC0.MEM.CTRL.PC\(12),
datab => \GRFPC0.MEM.CTRL.INST\(12),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(13),
dataa => \GRFPC0.MEM.CTRL.PC\(13),
datab => \GRFPC0.MEM.CTRL.INST\(13),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN44_DEP_2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2_0_O2\,
dataa => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN44_DEP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4648_DEP_2_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4648_DEP_2_I_O2\,
dataa => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3664_DEP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3664_DEP_1\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_EXSEL4_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXSEL4_I_A2\,
dataa => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4338_DEP_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4338_DEP_1_I_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_EX_CTRL_RD_RNIBEA7_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.N_19067_1_I_I_O2\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4666_DEP_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4666_DEP_2\,
dataa => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN402_DEP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN402_DEP_1\,
dataa => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN222_REGDEPX2_2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2_2_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_3_0_A2_0_A2_0_A2_0_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_A2_0_A2_0_A2_0_A2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
dataa => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_FP_PIPELINE_WRADDR_1_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(2),
dataa => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(3),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_WRADDR_1_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(3),
dataa => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(4),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_9_0_A2_0_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_9_0_A2_0_I_O2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2108_REGDEPX2_0_A2_0_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_WRADDR_1_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.WRADDR_1_0\(0),
dataa => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(1),
datac => \GRFPC0.FP_PIPELINE.UN29_WREN\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_3_0_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3_0_O2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.EX.CTRL.RDD_REP3\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
dataa => \GRFPC0.DIV.INST\(0),
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_8_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_8_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
dataa => \GRFPC0.DIV.INST\(14),
datab => \GRFPC0.DIV.RDD\);
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_1_1\,
dataa => \GRFPC0.DIV.RD\(2),
datab => RFI2_RD2ADDRZ(1));
\GRFPC0_FID_1_IV_0_A2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2\(5),
dataa => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_1\,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(60));
\GRFPU0_GRFPU_X0_RES_1_4_I_M2_I_M2_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(55),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_I_M2_I_M2_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_OP1_0_IV_5_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FPO_I_M\(31),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.DIV.RESULT_0_0_31__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(36),
dataa => \GRFPC0.WR2.RREG.RES\(36),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36));
\GRFPC0_OP2_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(36),
dataa => \GRFPC0.WR2.RREG.RES\(36),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36));
\GRFPC0_OP2_2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(36),
dataa => \GRFPC0.MEM.RREG.RES\(36),
datab => \GRFPC0.DIV.RESULT\(36),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(36),
dataa => \GRFPC0.EX.RREG.RES\(36),
datab => \GRFPC0.WR.RREG.RES\(36),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPU0_GRFPU_X0_RES_1_4_I_M2_I_M2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4_I_M2_I_M2\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(25),
dataa => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_25__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(57),
dataa => \GRFPC0.WR2.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(57));
\GRFPC0_OP2_1_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(57),
dataa => \GRFPC0.WR2.RREG.RES\(57),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(57));
\GRFPC0_OP2_2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(57),
dataa => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.DIV.RESULT\(57),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(57),
dataa => \GRFPC0.EX.RREG.RES\(57),
datab => \GRFPC0.WR.RREG.RES\(57),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPU0_GRFPU_X0_RES_1_4_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_4_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(9),
dataa => \GRFPC0.WR2.RREG.RES\(9),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR.RREG.RES_0_0_9__G3\);
\GRFPC0_OP2_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(9),
dataa => \GRFPC0.WR2.RREG.RES\(9),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR.RREG.RES_0_0_9__G3\);
\GRFPC0_OP2_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(9),
dataa => \GRFPC0.MEM.RREG.RES\(9),
datab => \GRFPC0.DIV.RESULT\(9),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(9),
dataa => \GRFPC0.EX.RREG.RES\(9),
datab => \GRFPC0.WR.RREG.RES\(9),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(15),
dataa => \GRFPC0.WR2.RREG.RES\(15),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_15__G3\);
\GRFPC0_OP2_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(15),
dataa => \GRFPC0.WR2.RREG.RES\(15),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_15__G3\);
\GRFPC0_OP2_2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(15),
dataa => \GRFPC0.MEM.RREG.RES\(15),
datab => \GRFPC0.DIV.RESULT\(15),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(15),
dataa => \GRFPC0.EX.RREG.RES\(15),
datab => \GRFPC0.WR.RREG.RES\(15),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP1_0_IV_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FPO_I_M\(48),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(48));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(17),
dataa => \GRFPC0.WR2.RREG.RES\(17),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_17__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(49),
dataa => \GRFPC0.WR2.RREG.RES\(49),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(49));
\GRFPC0_OP2_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(49),
dataa => \GRFPC0.WR2.RREG.RES\(49),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(49));
\GRFPC0_OP2_2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(49),
dataa => \GRFPC0.MEM.RREG.RES\(49),
datab => \GRFPC0.DIV.RESULT\(49),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(49),
dataa => \GRFPC0.EX.RREG.RES\(49),
datab => \GRFPC0.WR.RREG.RES\(49),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_1_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(60),
dataa => \GRFPC0.WR2.RREG.RES\(60),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(60));
\GRFPC0_OP2_2_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(60),
dataa => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.DIV.RESULT\(60),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(60),
dataa => \GRFPC0.EX.RREG.RES\(60),
datab => \GRFPC0.WR.RREG.RES\(60),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(60),
dataa => \GRFPC0.WR2.RREG.RES\(60),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(60));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(61),
dataa => \GRFPC0.WR2.RREG.RES\(61),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(61));
\GRFPC0_OP2_1_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(61),
dataa => \GRFPC0.WR2.RREG.RES\(61),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(61));
\GRFPC0_OP2_2_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(61),
dataa => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.DIV.RESULT\(61),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(61),
dataa => \GRFPC0.EX.RREG.RES\(61),
datab => \GRFPC0.WR.RREG.RES\(61),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(10),
dataa => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_10__G3\);
\GRFPC0_OP2_2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(10),
dataa => \GRFPC0.MEM.RREG.RES\(10),
datab => \GRFPC0.DIV.RESULT\(10),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(10),
dataa => \GRFPC0.EX.RREG.RES\(10),
datab => \GRFPC0.WR.RREG.RES\(10),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(54),
dataa => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.DIV.RESULT\(54),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(54),
dataa => \GRFPC0.EX.RREG.RES\(54),
datab => \GRFPC0.WR.RREG.RES\(54),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(35),
dataa => \GRFPC0.WR2.RREG.RES\(35),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(35));
\GRFPC0_OP2_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(35),
dataa => \GRFPC0.WR2.RREG.RES\(35),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(35));
\GRFPC0_OP2_2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(35),
dataa => \GRFPC0.MEM.RREG.RES\(35),
datab => \GRFPC0.DIV.RESULT\(35),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(37),
dataa => \GRFPC0.WR2.RREG.RES\(37),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(37));
\GRFPC0_OP2_2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(37),
dataa => \GRFPC0.MEM.RREG.RES\(37),
datab => \GRFPC0.DIV.RESULT\(37),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(37),
dataa => \GRFPC0.EX.RREG.RES\(37),
datab => \GRFPC0.WR.RREG.RES\(37),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(37),
dataa => \GRFPC0.WR2.RREG.RES\(37),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(37));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(7),
dataa => \GRFPC0.WR2.RREG.RES\(7),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_7__G3\);
\GRFPC0_OP2_2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(7),
dataa => \GRFPC0.MEM.RREG.RES\(7),
datab => \GRFPC0.DIV.RESULT\(7),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(7),
dataa => \GRFPC0.EX.RREG.RES\(7),
datab => \GRFPC0.WR.RREG.RES\(7),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(39),
dataa => \GRFPC0.WR2.RREG.RES\(39),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39));
\GRFPC0_OP2_2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(39),
dataa => \GRFPC0.MEM.RREG.RES\(39),
datab => \GRFPC0.DIV.RESULT\(39),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(39),
dataa => \GRFPC0.EX.RREG.RES\(39),
datab => \GRFPC0.WR.RREG.RES\(39),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(39),
dataa => \GRFPC0.WR2.RREG.RES\(39),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(11),
dataa => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_11__G3\);
\GRFPC0_OP2_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(11),
dataa => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_11__G3\);
\GRFPC0_OP2_2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(11),
dataa => \GRFPC0.MEM.RREG.RES\(11),
datab => \GRFPC0.DIV.RESULT\(11),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(11),
dataa => \GRFPC0.EX.RREG.RES\(11),
datab => \GRFPC0.WR.RREG.RES\(11),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(28),
dataa => \GRFPC0.WR2.RREG.RES\(28),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_28__G3\);
\GRFPC0_OP2_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(28),
dataa => \GRFPC0.WR2.RREG.RES\(28),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_28__G3\);
\GRFPC0_OP2_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(28),
dataa => \GRFPC0.MEM.RREG.RES\(28),
datab => \GRFPC0.DIV.RESULT\(28),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(28),
dataa => \GRFPC0.EX.RREG.RES\(28),
datab => \GRFPC0.WR.RREG.RES\(28),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(16),
dataa => \GRFPC0.WR2.RREG.RES\(16),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_16__G3\);
\GRFPC0_OP2_2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(16),
dataa => \GRFPC0.MEM.RREG.RES\(16),
datab => \GRFPC0.DIV.RESULT\(16),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(16),
dataa => \GRFPC0.EX.RREG.RES\(16),
datab => \GRFPC0.WR.RREG.RES\(16),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(33),
dataa => \GRFPC0.WR2.RREG.RES\(33),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(33));
\GRFPC0_OP2_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(33),
dataa => \GRFPC0.WR2.RREG.RES\(33),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(33));
\GRFPC0_OP2_2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(33),
dataa => \GRFPC0.MEM.RREG.RES\(33),
datab => \GRFPC0.DIV.RESULT\(33),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(33),
dataa => \GRFPC0.EX.RREG.RES\(33),
datab => \GRFPC0.WR.RREG.RES\(33),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(8),
dataa => \GRFPC0.WR2.RREG.RES\(8),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_8__G3\);
\GRFPC0_OP2_2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(8),
dataa => \GRFPC0.MEM.RREG.RES\(8),
datab => \GRFPC0.DIV.RESULT\(8),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(8),
dataa => \GRFPC0.EX.RREG.RES\(8),
datab => \GRFPC0.WR.RREG.RES\(8),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(18),
dataa => \GRFPC0.WR2.RREG.RES\(18),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_18__G3\);
\GRFPC0_OP2_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(18),
dataa => \GRFPC0.WR2.RREG.RES\(18),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_18__G3\);
\GRFPC0_OP2_2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(18),
dataa => \GRFPC0.MEM.RREG.RES\(18),
datab => \GRFPC0.DIV.RESULT\(18),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(18),
dataa => \GRFPC0.EX.RREG.RES\(18),
datab => \GRFPC0.WR.RREG.RES\(18),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(4),
dataa => \GRFPC0.WR2.RREG.RES\(4),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_4__G3\);
\GRFPC0_OP2_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(4),
dataa => \GRFPC0.MEM.RREG.RES\(4),
datab => \GRFPC0.DIV.RESULT\(4),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(4),
dataa => \GRFPC0.EX.RREG.RES\(4),
datab => \GRFPC0.WR.RREG.RES\(4),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(14),
dataa => \GRFPC0.WR2.RREG.RES\(14),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_14__G3\);
\GRFPC0_OP2_2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(14),
dataa => \GRFPC0.MEM.RREG.RES\(14),
datab => \GRFPC0.DIV.RESULT\(14),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(14),
dataa => \GRFPC0.EX.RREG.RES\(14),
datab => \GRFPC0.WR.RREG.RES\(14),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(14),
dataa => \GRFPC0.WR2.RREG.RES\(14),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_14__G3\);
GRFPC0_FP_PIPELINE_4_REGDEPX2_130_1_M6_I_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130_1_M6_I_0_A2\,
dataa => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220_1_M6_I_A3_I_1\,
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
\GRFPC0_OP2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(2),
dataa => \GRFPC0.WR2.RREG.RES\(2),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_2__G3\);
\GRFPC0_OP2_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(2),
dataa => \GRFPC0.MEM.RREG.RES\(2),
datab => \GRFPC0.DIV.RESULT\(2),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(2),
dataa => \GRFPC0.EX.RREG.RES\(2),
datab => \GRFPC0.WR.RREG.RES\(2),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(6),
dataa => \GRFPC0.WR2.RREG.RES\(6),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_6__G3\);
\GRFPC0_OP2_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(6),
dataa => \GRFPC0.WR2.RREG.RES\(6),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_6__G3\);
\GRFPC0_OP2_2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(6),
dataa => \GRFPC0.MEM.RREG.RES\(6),
datab => \GRFPC0.DIV.RESULT\(6),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(6),
dataa => \GRFPC0.EX.RREG.RES\(6),
datab => \GRFPC0.WR.RREG.RES\(6),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP1_0_IV_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FPO_I_M\(6),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPC0.DIV.RESULT_0_0_6__G3\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_3\,
dataa => \GRFPC0.WR2.CTRL.ID\(3),
datab => \GRFPC0.FPR.ID\(3));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_DIV: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
dataa => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.RREG.RESV\);
\GRFPC0_DIV_EXCT_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_2__G4\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_1_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_1_I_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_4_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_4_I_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0_O2\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(20),
dataa => \GRFPC0.WR2.RREG.RES\(20),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_20__G3\);
\GRFPC0_OP2_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(20),
dataa => \GRFPC0.WR2.RREG.RES\(20),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_20__G3\);
\GRFPC0_OP2_2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(20),
dataa => \GRFPC0.MEM.RREG.RES\(20),
datab => \GRFPC0.DIV.RESULT\(20),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(20),
dataa => \GRFPC0.EX.RREG.RES\(20),
datab => \GRFPC0.WR.RREG.RES\(20),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FID_1_IV_0_A2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2\(2),
dataa => \GRFPC0.EX.CTRL.ID\(2),
datab => \GRFPC0.FID_1_IV_0_A3_1\(0));
GRFPC0_FP_PIPELINE_UN1_MEM_CTRL_ID_3_0_X3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_MEM.CTRL.ID_3_0_X3\,
dataa => \GRFPC0.MEM.CTRL.ID\(3),
datab => \GRFPC0.FPR.ID\(3));
\GRFPC0_FID_1_IV_0_A2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FID_1_IV_0_A2_1\(3),
dataa => \GRFPC0.MEM.CTRL.ID\(3),
datab => \GRFPC0.FID_1_IV_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_0_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_0_0_O2\(1),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_I_A2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_I_A2\(0),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_I_O3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_I_O3\(0),
dataa => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_0_0_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1_0_0_O2\(1),
dataa => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(43),
dataa => \GRFPC0.WR2.RREG.RES\(43),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(43));
\GRFPC0_OP2_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(43),
dataa => \GRFPC0.WR2.RREG.RES\(43),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(43));
\GRFPC0_OP2_2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(43),
dataa => \GRFPC0.MEM.RREG.RES\(43),
datab => \GRFPC0.DIV.RESULT\(43),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2_0_A2\,
dataa => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_OP2_I_M3_4_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_I_M3_4\(45),
dataa => \GRFPC0.EX.RREG.RES\(45),
datab => \GRFPC0.WR.RREG.RES\(45),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_1_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1_I_M2\(5),
dataa => \GRFPC0.WR2.RREG.RES\(5),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.DIV.RESULT_0_0_5__G3\);
\GRFPC0_OP2_2_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2_I_M2\(5),
dataa => \GRFPC0.MEM.RREG.RES\(5),
datab => \GRFPC0.DIV.RESULT\(5),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(2));
\GRFPC0_OP2_3_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3_I_M2\(5),
dataa => \GRFPC0.EX.RREG.RES\(5),
datab => \GRFPC0.WR.RREG.RES\(5),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(5),
dataa => \GRFPC0.WR2.RREG.RES\(5),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_5__G3\);
\GRFPC0_OP2_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(46),
dataa => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(46));
\GRFPC0_OP2_2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(46),
dataa => \GRFPC0.MEM.RREG.RES\(46),
datab => \GRFPC0.DIV.RESULT\(46),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(46),
dataa => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(46));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(30),
dataa => \GRFPC0.WR2.RREG.RES\(30),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_30__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(26),
dataa => \GRFPC0.WR2.RREG.RES\(26),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_26__G3\);
\GRFPC0_OP2_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(26),
dataa => \GRFPC0.WR2.RREG.RES\(26),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_26__G3\);
\GRFPC0_OP2_2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(26),
dataa => \GRFPC0.MEM.RREG.RES\(26),
datab => \GRFPC0.DIV.RESULT\(26),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(26),
dataa => \GRFPC0.EX.RREG.RES\(26),
datab => \GRFPC0.WR.RREG.RES\(26),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(3),
dataa => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_0_0\(3));
\GRFPC0_OP2_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(25),
dataa => \GRFPC0.EX.RREG.RES\(25),
datab => \GRFPC0.WR.RREG.RES\(25),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(24),
dataa => \GRFPC0.WR2.RREG.RES\(24),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_24__G3\);
\GRFPC0_OP2_2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(24),
dataa => \GRFPC0.MEM.RREG.RES\(24),
datab => \GRFPC0.DIV.RESULT\(24),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(24),
dataa => \GRFPC0.EX.RREG.RES\(24),
datab => \GRFPC0.WR.RREG.RES\(24),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(23),
dataa => \GRFPC0.WR2.RREG.RES\(23),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_23__G3\);
\GRFPC0_OP2_2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(23),
dataa => \GRFPC0.MEM.RREG.RES\(23),
datab => \GRFPC0.DIV.RESULT\(23),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(23),
dataa => \GRFPC0.EX.RREG.RES\(23),
datab => \GRFPC0.WR.RREG.RES\(23),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(23),
dataa => \GRFPC0.WR2.RREG.RES\(23),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_23__G3\);
\GRFPC0_OP2_2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(53),
dataa => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.DIV.RESULT\(53),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(53),
dataa => \GRFPC0.EX.RREG.RES\(53),
datab => \GRFPC0.WR.RREG.RES\(53),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(51),
dataa => \GRFPC0.WR2.RREG.RES\(51),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51));
\GRFPC0_OP2_2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(51),
dataa => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.DIV.RESULT\(51),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(51),
dataa => \GRFPC0.EX.RREG.RES\(51),
datab => \GRFPC0.WR.RREG.RES\(51),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(19),
dataa => \GRFPC0.WR2.RREG.RES\(19),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_19__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(51),
dataa => \GRFPC0.WR2.RREG.RES\(51),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51));
\GRFPC0_OP2_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(17),
dataa => \GRFPC0.WR2.RREG.RES\(17),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_17__G3\);
\GRFPC0_OP2_2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(17),
dataa => \GRFPC0.MEM.RREG.RES\(17),
datab => \GRFPC0.DIV.RESULT\(17),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(17),
dataa => \GRFPC0.EX.RREG.RES\(17),
datab => \GRFPC0.WR.RREG.RES\(17),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(48),
dataa => \GRFPC0.WR2.RREG.RES\(48),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(48));
\GRFPC0_OP2_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(48),
dataa => \GRFPC0.MEM.RREG.RES\(48),
datab => \GRFPC0.DIV.RESULT\(48),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(48),
dataa => \GRFPC0.EX.RREG.RES\(48),
datab => \GRFPC0.WR.RREG.RES\(48),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(29),
dataa => \GRFPC0.WR2.RREG.RES\(29),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_29__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(16),
dataa => \GRFPC0.WR2.RREG.RES\(16),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_16__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(48),
dataa => \GRFPC0.WR2.RREG.RES\(48),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(48));
\GRFPC0_OP2_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(12),
dataa => \GRFPC0.WR2.RREG.RES\(12),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_12__G3\);
\GRFPC0_OP2_2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(12),
dataa => \GRFPC0.MEM.RREG.RES\(12),
datab => \GRFPC0.DIV.RESULT\(12),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(12),
dataa => \GRFPC0.EX.RREG.RES\(12),
datab => \GRFPC0.WR.RREG.RES\(12),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(0),
dataa => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_0__G3\);
\GRFPC0_OP2_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(0),
dataa => \GRFPC0.MEM.RREG.RES\(0),
datab => \GRFPC0.DIV.RESULT\(0),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(0),
dataa => \GRFPC0.EX.RREG.RES\(0),
datab => \GRFPC0.WR.RREG.RES\(0),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(7),
dataa => \GRFPC0.WR2.RREG.RES\(7),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_7__G3\);
\GRFPC0_OP2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(3),
dataa => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_3__G3\);
\GRFPC0_OP2_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(3),
dataa => \GRFPC0.MEM.RREG.RES\(3),
datab => \GRFPC0.DIV.RESULT\(3),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(4),
dataa => \GRFPC0.WR2.RREG.RES\(4),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_4__G3\);
\GRFPC0_OP2_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(27),
dataa => \GRFPC0.WR2.RREG.RES\(27),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_27__G3\);
\GRFPC0_OP2_2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(27),
dataa => \GRFPC0.MEM.RREG.RES\(27),
datab => \GRFPC0.DIV.RESULT\(27),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_3_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(27),
dataa => \GRFPC0.EX.RREG.RES\(27),
datab => \GRFPC0.WR.RREG.RES\(27),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(10),
dataa => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_10__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(42),
dataa => \GRFPC0.WR2.RREG.RES\(42),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42));
\GRFPC0_OP2_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(42),
dataa => \GRFPC0.WR2.RREG.RES\(42),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42));
\GRFPC0_OP2_2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(42),
dataa => \GRFPC0.MEM.RREG.RES\(42),
datab => \GRFPC0.DIV.RESULT\(42),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(42),
dataa => \GRFPC0.EX.RREG.RES\(42),
datab => \GRFPC0.WR.RREG.RES\(42),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(38),
dataa => \GRFPC0.WR2.RREG.RES\(38),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(38));
\GRFPC0_OP2_2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(38),
dataa => \GRFPC0.MEM.RREG.RES\(38),
datab => \GRFPC0.DIV.RESULT\(38),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(2));
\GRFPC0_OP2_3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(38),
dataa => \GRFPC0.EX.RREG.RES\(38),
datab => \GRFPC0.WR.RREG.RES\(38),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(38),
dataa => \GRFPC0.WR2.RREG.RES\(38),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(38));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(17),
dataa => \GRFPC0.WR.CTRL.PC\(17),
datab => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(17),
dataa => \GRFPC0.MEM.CTRL.PC\(17),
datab => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5150_REGDEPX2_1_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5150_REGDEPX2_1_I_O4\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5591_REGDEPX2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2_1\,
dataa => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN285_REGDEPX2_1_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2_1_0_A2_0_A2\,
dataa => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPC0_OP2_3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(22),
dataa => \GRFPC0.EX.RREG.RES\(22),
datab => \GRFPC0.WR.RREG.RES\(22),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(22),
dataa => \GRFPC0.WR2.RREG.RES\(22),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_22__G3\);
\GRFPC0_OP2_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(19),
dataa => \GRFPC0.EX.RREG.RES\(19),
datab => \GRFPC0.WR.RREG.RES\(19),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(19),
dataa => \GRFPC0.MEM.RREG.RES\(19),
datab => \GRFPC0.DIV.RESULT\(19),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(19),
dataa => \GRFPC0.WR2.RREG.RES\(19),
datab => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.DIV.RESULT_0_0_19__G3\);
\GRFPC0_OP2_I_M3_4_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_I_M3_4\(13),
dataa => \GRFPC0.EX.RREG.RES\(13),
datab => \GRFPC0.WR.RREG.RES\(13),
datac => \GRFPC0.RFA2.RS2SEL_REP2\(1));
\GRFPC0_OP2_I_M3_2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_I_M3_2\(13),
dataa => \GRFPC0.MEM.RREG.RES\(13),
datab => \GRFPC0.DIV.RESULT\(13),
datac => \GRFPC0.RFA2.RS2SEL_REP4\(2));
\GRFPC0_OP2_I_M3_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_I_M3_1\(13),
dataa => \GRFPC0.WR2.RREG.RES\(13),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPC0.DIV.RESULT_0_0_13__G3\);
\GRFPC0_WRDATA_I_M3_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.WRDATA_I_M3_1\(13),
dataa => \GRFPC0.WR2.RREG.RES\(13),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_13__G3\);
\GRFPC0_WRDATA_I_M3_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.WRDATA_I_M3_0\(45),
dataa => \GRFPC0.WR2.RREG.RES\(45),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(45));
\GRFPC0_OP2_I_M3_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_I_M3_2\(45),
dataa => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.DIV.RESULT\(45),
datac => \GRFPC0.RFA2.RS2SEL_REP4\(2));
\GRFPC0_OP2_I_M3_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_I_M3_1\(45),
dataa => \GRFPC0.WR2.RREG.RES\(45),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(45));
GRFPC0_FP_PIPELINE_VWR2_CTRL_RDD_1_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.CTRL.RDD_1_I_A2\,
dataa => \GRFPC0.WR.CTRL.LD\,
datab => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2_1\);
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_I_A2_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_I_A2_0\,
dataa => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O3_2\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_D_LDLCK_RNO_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_198_I_M_I_A2_1\(1),
dataa => \GRFPC0.FIFO.INST_1_I_M_2\(25),
datab => \GRFPC0.STDDEP_0_SQMUXA_83_I_0_O4\);
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_DIV_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0_A2\,
dataa => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.RREG.RESV\);
GRFPC0_FP_PIPELINE_PENDEXC23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.PENDEXC23\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0));
GRFPC0_FP_PIPELINE_UN27_PENDEXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.UN27_PENDEXC\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0));
GRFPC0_FP_PIPELINE_UN77_PENDEXC: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
dataa => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_19_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_19_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
dataa => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(0),
datab => \GRFPC0.DIV.RD\(0),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
GRFPC0_UN1_DIV_RDD: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.UN1_DIV.RDD\,
dataa => \GRFPC0.DIV.RDD_REP1\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_1_0\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(7),
dataa => \GRFPC0.WR.CTRL.PC\(7),
datab => \GRFPC0.WR.CTRL.INST\(7),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(15),
dataa => \GRFPC0.WR.CTRL.PC\(15),
datab => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(7),
dataa => \GRFPC0.MEM.CTRL.PC\(7),
datab => \GRFPC0.MEM.CTRL.INST\(7),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(15),
dataa => \GRFPC0.MEM.CTRL.PC\(15),
datab => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FIFO_INST_1_RNIT4VT_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
dataa => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN320_REGDEPX2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_7_0_A3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_7_0_A3_1\(1),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_12_I_O2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_I_O2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_7_2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7_2\(1),
dataa => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN320_REGDEPX2_2_0_A2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_2_0_A2_0_A2_0_A2\,
dataa => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6945_REGDEPX2_0_A2_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2_0_A2_I_O4\,
dataa => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_OP1_0_IV_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FPO_I_M\(40),
dataa => \GRFPC0.RFA2.RS1SEL\(0),
datab => \GRFPU0.GRFPU_X0.RES_1_6_I\(40));
\GRFPC0_OP2_3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(40),
dataa => \GRFPC0.EX.RREG.RES\(40),
datab => \GRFPC0.WR.RREG.RES\(40),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(8),
dataa => \GRFPC0.WR2.RREG.RES\(8),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_8__G3\);
\GRFPC0_FP_PIPELINE_WRDATA_3_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(40),
dataa => \GRFPC0.WR2.RREG.RES\(40),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(40));
\GRFPC0_OP2_2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(25),
dataa => \GRFPC0.MEM.RREG.RES\(25),
datab => \GRFPC0.DIV.RESULT\(25),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_OP2_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(25),
dataa => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPC0.RFA2.RS2SEL_REP1\(4),
datac => \GRFPC0.DIV.RESULT_0_0_25__G3\);
\GRFPC0_OP2_2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_2\(22),
dataa => \GRFPC0.MEM.RREG.RES\(22),
datab => \GRFPC0.DIV.RESULT\(22),
datac => \GRFPC0.RFA2.RS2SEL\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(22),
dataa => \GRFPC0.WR2.RREG.RES\(22),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RESULT_0_0_22__G3\);
\GRFPC0_OP2_1_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.OP2_1\(54),
dataa => \GRFPC0.WR2.RREG.RES\(54),
datab => \GRFPC0.RFA2.RS2SEL_REP2\(4),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(54));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3_0\(54),
dataa => \GRFPC0.WR2.RREG.RES\(54),
datab => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I\(54));
\GRFPU0_GRFPU_X0_RES_1_4_I_M2_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_4_I_M2\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_2\(4),
dataa => \GRFPC0.OP1_0_IV\(52),
datab => \GRFPC0.OP1_0_IV\(53));
\GRFPC0_OP2_3_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(46),
dataa => \GRFPC0.EX.RREG.RES\(46),
datab => \GRFPC0.WR.RREG.RES\(46),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_OP2_3_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(43),
dataa => \GRFPC0.EX.RREG.RES\(43),
datab => \GRFPC0.WR.RREG.RES\(43),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_I_O2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(14),
datab => \GRFPC0.EX.CTRL.RDD_REP1\);
GRFPC0_V_FSR_NONSTD_0_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
dataa => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.AFSR\);
GRFPC0_UN1_EX_CTRL_RDD_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.UN1_EX.CTRL.RDD_1\,
dataa => \GRFPC0.EX.CTRL.RDD_REP4\,
datab => \GRFPC0.UN1_RDWR_3_SQMUXA_4_0\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
dataa => \GRFPC0.WR2.CTRL.RD\(3),
datab => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_D_STLCK_RNO_8_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_A2_2_653\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22_REP1\(1),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_564_0_IV_I_M2\(1));
GRFPC0_FP_PIPELINE_VDIV_EXEC_7_F0_RNI5RNG: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_15_1_0_0_A2_I_O2\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F0\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_0_A2\);
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_239_0_O2_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_239_0_O2_0\(1),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6428_REGDEPX2_2_I_O3_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2_2_I_O3_I_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5546_REGDEPX2_1_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2_1_I_O3\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN236_REGDEPX2_1_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN236_REGDEPX2_1_0_A2_0_A2\,
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_A3_3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_0_A3_3_2\(0),
dataa => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A3_3_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A3_3_1\(1),
dataa => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.EX.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3782_REGDEPX2_2_0_A2_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_2_0_A2_I_O3\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3341_REGDEPX2_0_A2_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_0_A2_I_O3\,
dataa => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(3),
dataa => \GRFPC0.MEM.CTRL.PC\(3),
datab => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(3),
dataa => \GRFPC0.WR.CTRL.PC\(3),
datab => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(5),
dataa => \GRFPC0.WR.CTRL.PC\(5),
datab => \GRFPC0.WR.CTRL.INST\(5),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(10),
dataa => \GRFPC0.WR.CTRL.PC\(10),
datab => \GRFPC0.WR.CTRL.INST\(10),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(31),
dataa => \GRFPC0.WR.CTRL.PC\(31),
datab => \GRFPC0.WR.CTRL.INST\(31),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(5),
dataa => \GRFPC0.MEM.CTRL.PC\(5),
datab => \GRFPC0.MEM.CTRL.INST\(5),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(10),
dataa => \GRFPC0.MEM.CTRL.PC\(10),
datab => \GRFPC0.MEM.CTRL.INST\(10),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(31),
dataa => \GRFPC0.MEM.CTRL.PC\(31),
datab => \GRFPC0.MEM.CTRL.INST\(31),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1_0_A2_0_A2_0_A2_0_A4\,
dataa => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(8),
dataa => \GRFPC0.MEM.CTRL.PC\(8),
datab => \GRFPC0.MEM.CTRL.INST\(8),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(8),
dataa => \GRFPC0.WR.CTRL.PC\(8),
datab => \GRFPC0.WR.CTRL.INST\(8),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(18),
dataa => \GRFPC0.WR.CTRL.PC\(18),
datab => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.V.STDATA_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(18),
dataa => \GRFPC0.MEM.CTRL.PC\(18),
datab => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.V.STDATA_0_SQMUXA_3\);
GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_UN3543_REGDEPX_1_0_I_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3543_REGDEPX_1_0_I_O3\,
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN97_REGDEPX_2_0_A2_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2_0_A2_0_A2\,
dataa => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_0_A2_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5_0_A2_1\(1),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_VDIV_EXEC_7_F1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.EXEC_7_F1\,
dataa => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.UN68_HOLDN_REP1\);
\GRFPC0_V_STDATA_14_I_M2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPC0.V.STDATA_14_I_M2\(19),
dataa => \GRFPC0.FIFO.RD_REP4\(0),
datab => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_3_2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A3_3_2\(0),
dataa => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP_IV\,
datab => \GRFPC0.FIFO.INST_1_M_2\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\(31),
dataa => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1_I_M_2\(25));
GRFPC0_DEP_1_SQMUXA_88_0_A3_I_O2_0_0_RNIIV9D: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FIFO.INST_0_M_9\(25),
dataa => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.DEP_1_SQMUXA_88_0_A3_I_O2_0_0\);
GRFPC0_RFA_WRITE_RD_RNI3BA6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.RFA.WRITE_RD_M\,
dataa => \GRFPC0.RFA.WRITE_RD\,
datab => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_REP1\);
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_DIV_0_A3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0_A3\,
dataa => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.RREG.RESV\);
GRFPC0_FP_PIPELINE_ORV_TMP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.ORV.TMP\,
dataa => \GRFPC0.EX.CTRL.VCNT\(1),
datab => \GRFPC0.EX.CTRL.VCNT\(0));
\GRFPC0_MEM_CTRL_VCNT_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
dataa => \GRFPC0.EX.CTRL.VCNT\(0),
datab => \GRFPC0.EX.CTRL.VCNT\(1));
GRFPC0_FP_PIPELINE_ORV_TMP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
dataa => \GRFPC0.MEM.CTRL.VCNT\(1),
datab => \GRFPC0.MEM.CTRL.VCNT\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_20_0_IV_I_O3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_20_0_IV_I_O3_3\(0),
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A3_1_1_REP1\);
GRFPC0_UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2_RNIJA5E: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_438_I_M_I_O2_15\(1),
dataa => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.UN1_STDDEP_0_SQMUXA_110_I_O2_1_I_O2\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_14_I_O3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O3\(1),
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_14_I_O2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14_I_O2\(0),
dataa => \GRFPC0.EX.CTRL.RDD\,
datab => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_4_STDEP_176_SEL1_I_0_A2_I_O4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL1_I_0_A2_I_O4\,
dataa => \GRFPC0.EX.CTRL.RDD_REP2\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_3_4_0\);
\GRFPC0_FP_PIPELINE_12_STDEP_488_3_0_A2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_488_3_0_A2\(1),
dataa => \GRFPC0.WR.CTRL.RDD_REP2\,
datab => \GRFPC0.STDDEP_0_SQMUXA_170_0_O3\);
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_0_O3_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_52_3_0_O3_3\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_REP1\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
\GRFPC0_V_STDATA_14_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.V.STDATA_14\(1),
dataa => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_V_STDATA_14_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.V.STDATA_14\(2),
dataa => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_V_STDATA_14_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(3),
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_V_STDATA_14_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPC0.V.STDATA_14\(4),
dataa => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.RD_REP3\(0));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4583_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2711_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(2));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4271_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3959_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O2_9\,
dataa => \GRFPC0.MEM.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_0_A2\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_4_1\,
dataa => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_0_A2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_1\(12),
dataa => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_IV_REP2\);
\GRFPC0_OP2_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(3),
dataa => \GRFPC0.EX.RREG.RES\(3),
datab => \GRFPC0.WR.RREG.RES\(3),
datac => \GRFPC0.RFA2.RS2SEL\(1));
\GRFPC0_OP2_3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.OP2_3\(35),
dataa => \GRFPC0.EX.RREG.RES\(35),
datab => \GRFPC0.WR.RREG.RES\(35),
datac => \GRFPC0.RFA2.RS2SEL_REP1\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5120_REGDEPX2_1_I_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5120_REGDEPX2_1_I_O2\,
dataa => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\);
\GRFPU0_GRFPU_X0_CMPI1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(19),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
GRFPU0_GRFPU_X0_COMB_VST2_REG127: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG127\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(103),
dataa => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_INTI1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(14),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_CMPI1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_INF_ABS0_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31));
\GRFPU0_GRFPU_X0_CMPI1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_CMPI1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(108),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(108));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(74),
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNIFH5V_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPINC_SP\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_UN33_REST_I_A2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_UN33_REST_I_A2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN33_REST_I_A2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_CMPI1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIDJSP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
\GRFPU0_GRFPU_X0_CMPI1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(16),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(81),
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(100),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(82),
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M_0\(70),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_NZ_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_2\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD4\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD5\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT27_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_3\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD1\);
\GRFPU0_GRFPU_X0_INTI1_0_X2_0_X2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2_0_X2\(30),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(24),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(22),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(12),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(19),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(18),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(16),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(10),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(15),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(11),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(21),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(28),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(20),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(25),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(9),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_INTI1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(8),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_INTI1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(5),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_INTI1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(7),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_INTI1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(29),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(27),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(26),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(23),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(17),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_INTI1_0_X2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1_0_X2\(13),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48));
\GRFPU0_GRFPU_X0_CMPI1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_I_A2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I_I_A2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_I_A2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I_I_A2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_0_A2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_0_A2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_0_A2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_0_A2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9));
\GRFPU0_GRFPU_X0_CMPI1_0_A2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_0_A2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_0\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_CMPI1_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
GRFPU0_GRFPU_X0_ST1_OP1NX_RNICINO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_4_SQMUXA_S5_1175_0_O3\,
dataa => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_1\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9));
\GRFPU0_GRFPU_X0_CMPI1_I_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(93),
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_0_0_A2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_3_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(51),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_0_O2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(89),
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_L3_0_3_0_A2_4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_0_A2_4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
GRFPU0_GRFPU_X0_UN83_BCO_LSB_0_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN83_BCO_LSB_0_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(72),
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(71),
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(110),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(95),
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(94),
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(118),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(119),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(119));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(28),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48));
\GRFPU0_GRFPU_X0_CMPI1_I_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
GRFPU0_GRFPU_X0_COMB_EXP57_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP57_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_0_X2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0_X2\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_1\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_1_O2\(48));
\GRFPU0_GRFPU_X0_CMPI1_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_NZ_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_3\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD2\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD3\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A2_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_3\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(97),
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
GRFPU0_GRFPU_X0_COMB_VST3_REG71_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG71_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_I_O2_RNO_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_A2_1_3_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_4_0_A3\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNINOTG_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_4_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7));
\GRFPU0_GRFPU_X0_BCO_MSB_2_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIJOTG_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_0_7_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M_0\(79),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP_1_SN_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_M2\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST2.INF_0_SQMUXA_43_I\,
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\);
GRFPU0_GRFPU_X0_COMB_RNDOP19_0_O3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDOP19_0_O3\,
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(60),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_L1_1_1_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
GRFPU0_GRFPU_X0_ITER_NORM_RNIS0F99: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.NORM_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(79),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_0_A3_0_0_A2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_A3_0_0_A2\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
GRFPU0_GRFPU_X0_VITER_R_I_3_SQMUXA: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DP_REP6\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIM35E1_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.N_18471_I_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A4_3_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A4_3\(33),
dataa => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0_REP1\(0),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_11_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_11\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(31),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_2_03_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\);
\GRFPU0_GRFPU_X0_VST3_REG_37_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_VST3_REG_37_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_1_A6_0\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(53),
datab => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_I_O2\);
\GRFPU0_DIVROM0_DATA_1_MUX_2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_MUX_2\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.C_ADD0\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(10),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(2),
dataa => \GRFPU0.GRFPU_X0.C_ADD2\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(9),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(3),
dataa => \GRFPU0.GRFPU_X0.C_ADD3\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(8),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(4),
dataa => \GRFPU0.GRFPU_X0.C_ADD4\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(5),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.C_ADD5\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(6),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.C_ADD6\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(7),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.C_ADD7\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(8),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(3),
datab => \GRFPU0.GRFPU_X0.C_ADD8\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(9),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.C_ADD9\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M_0\(10),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.C_ADD10\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD0\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD2\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD3\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD4\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD5\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD6\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD7\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD8\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD9\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXP_M_M\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1_1_A2\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD10\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M2_0_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M2_3\(59),
dataa => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\,
datac => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(27),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(16),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(15),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(24),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(33),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(31),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(19),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(22),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(29),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(9),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_I_M2_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.DIVROM0.RADDR\(4));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(19),
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD13\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(36),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_TZI_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M2_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(54),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_M2\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_I_M2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3_I_M2\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(55),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1),
datac => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_GRFPU_X0_TZI_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD43\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD52\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(58),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(2),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(2),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(38),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD32\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD32\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(48),
dataa => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD42\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(58),
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD48\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(53),
dataa => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(57),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(3),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(3),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(57),
dataa => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD51\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(34),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(26),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(26),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(54),
dataa => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_COMB_RNDBIT_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
dataa => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.DRES_S\(66),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(14),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(44),
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD38\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_0\(46),
dataa => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD40\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(28),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M2\(22),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD53\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M4_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M4\(53),
dataa => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datab => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M4_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_M4\(38),
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(49),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(11),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(11),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(52),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(8),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(8),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(18),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M4_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(19),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD50\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD50\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M4_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(18),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD49\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD49\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M4_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(14),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD45\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD45\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M4_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M4\(15),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD46\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD46\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(32),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(11),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_1_0_M2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_0_M2\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
datac => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_TZI_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_DIFFIN1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_DIFFIN1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(56),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0\(63),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(61),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(60),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(59),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(58),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(57),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(56),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(55),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(54),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(53),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(52),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(51),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(48),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(57),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(6),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_TZI2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_1_0_0_M2_I_M3_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M2_I_M3\(62),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(48),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(47),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(46),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(45),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(44),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(43),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(42),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(40),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(39),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(38),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(37),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(33),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(32),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(30),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(29),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(21),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(39),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(21),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(21),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD33\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(20),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_TZI2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(13),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_TZI2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_TZI2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(47),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(13),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(13),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_INF_ABS0_3_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28));
\GRFPU0_GRFPU_X0_INF_ABS0_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25));
\GRFPU0_GRFPU_X0_INF_ABS0_3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20));
\GRFPU0_GRFPU_X0_INF_ABS0_3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17));
\GRFPU0_GRFPU_X0_INF_ABS0_3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15));
\GRFPU0_GRFPU_X0_INF_ABS0_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9));
\GRFPU0_GRFPU_X0_INF_ABS0_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5));
\GRFPU0_GRFPU_X0_INF_ABS0_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4));
\GRFPU0_GRFPU_X0_INF_ABS0_3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_S3ADDI_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(28),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(27),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(26),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(25),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(24),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(23),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(22),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(21),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(20),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(19),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(18),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(17),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(16),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(15),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(14),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_COMB_ADIFF_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(8),
dataa => \GRFPU0.GRFPU_X0.C_ADD8\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD8\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_COMB_ADIFF_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(7),
dataa => \GRFPU0.GRFPU_X0.C_ADD7\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD7\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_COMB_ADIFF_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(4),
dataa => \GRFPU0.GRFPU_X0.C_ADD4\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD4\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_COMB_ADIFF_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADIFF_1\(1),
dataa => \GRFPU0.GRFPU_X0.C_ADD1\,
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD1\,
datac => \GRFPU0.GRFPU_X0.C_ADD11\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(42),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD36\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M7_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M7_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M5_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M5_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M1_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M1_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M3_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M3_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_0_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M10_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M10_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M12_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M12_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M14_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M14_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M15_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M15_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M13_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M13_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M11_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M11_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M9_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M9_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M8_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M8_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M6_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M6_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M16_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M16_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M0_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_35\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_34\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_0_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_0_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M25_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M25_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M27_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M27_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_0_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03_0_G1\,
dataa => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M36_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M36_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M33_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M33_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M28_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M28_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M30_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M30_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M37_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M37_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M35_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M35_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(20),
dataa => \GRFPC0.FIFO.PC_1\(20),
datab => \GRFPC0.FIFO.PC_0\(20),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(16),
dataa => \GRFPC0.FIFO.PC_1\(16),
datab => \GRFPC0.FIFO.PC_0\(16),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(15),
dataa => \GRFPC0.FIFO.PC_1\(15),
datab => \GRFPC0.FIFO.PC_0\(15),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(27),
dataa => \GRFPC0.FIFO.PC_1\(27),
datab => \GRFPC0.FIFO.PC_0\(27),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(14),
dataa => \GRFPC0.FIFO.PC_1\(14),
datab => \GRFPC0.FIFO.PC_0\(14),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(31),
dataa => \GRFPC0.FIFO.PC_1\(31),
datab => \GRFPC0.FIFO.PC_0\(31),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
dataa => \GRFPC0.FIFO.PC_1\(26),
datab => \GRFPC0.FIFO.PC_0\(26),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(18),
dataa => \GRFPC0.FIFO.PC_1\(18),
datab => \GRFPC0.FIFO.PC_0\(18),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(8),
dataa => \GRFPC0.FIFO.PC_1\(8),
datab => \GRFPC0.FIFO.PC_0\(8),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(4),
dataa => \GRFPC0.FIFO.PC_1\(4),
datab => \GRFPC0.FIFO.PC_0\(4),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(3),
dataa => \GRFPC0.FIFO.PC_1\(3),
datab => \GRFPC0.FIFO.PC_0\(3),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_V_STDATA_14_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(11),
dataa => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_FP_PIPELINE_UN4_CNTX_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
dataa => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_UN4_CNTX_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
dataa => \GRFPC0.FIFO.VCNT_1\(1),
datab => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_UN4_CNTX_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(0),
dataa => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_0\(0),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_UN1_FIFO_VCNT_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1\(0),
dataa => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.VCNT_0\(0),
datac => \GRFPC0.FIFO.VCNT_1\(0));
\GRFPU0_SQRTROM0_DATA_1_MUX_4_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_4\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_2\);
\GRFPU0_SQRTROM0_DATA_1_MUX_4_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011000110110001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_4\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_2\);
\GRFPU0_SQRTROM0_DATA_1_MUX_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_MUX_5\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_2\,
datac => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_2\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_1\,
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.MULO.MRES\(91));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_A2_2_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_A2_2_10\,
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.MULO.MRES\(93));
GRFPU0_GRFPU_X0_NXX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_2\,
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.MULO.MRES\(92));
GRFPU0_GRFPU_X0_NXX_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_10\,
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.MRES\(87));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.N_18308_12\,
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.MULO.MRES\(95));
GRFPU0_GRFPU_X0_COMB_VST4_RDY4_0_A2_RNIK1U01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G3\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\,
datab => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD4\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD4\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD5\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD5\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD6\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD6\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD8\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD8\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD11\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD11\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD12\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD12\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD13\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD13\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD14\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD14\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD15\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD17\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD18\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD18\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD19\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD19\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD20\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD20\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD21\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD21\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD22\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD22\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD23\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD23\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD24\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD24\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD25\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD25\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD26\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD26\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD27\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD29\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD30\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD30\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD31\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD33\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD34\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD35\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD36\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD36\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD37\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD37\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD38\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD38\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD39\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD39\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD40\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD40\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD41\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD42\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD43\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD43\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD44\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD44\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD45\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD46\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD47\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD47\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD48\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD48\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD49\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD49\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD50\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD51\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0_1\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100010111000101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
datac => \GRFPU0.GRFPU_X0.N_18421_I_0_I_O2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G6\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\);
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__G0_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__G0_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPC0_FIFO_INST_0_RNIN4UT_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\,
dataa => \GRFPC0.FIFO.INST_1\(31),
datab => \GRFPC0.FIFO.INST_0\(31),
datac => \GRFPC0.FIFO.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M_0\(64),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_M2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101000111010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_M2\(45),
dataa => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
datab => \GRFPU0.GRFPU_X0.G_53_REP1\,
datac => \GRFPU0.GRFPU_X0.G_52\);
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3928_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3928_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(28));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(6),
dataa => \GRFPC0.FIFO.PC_1\(6),
datab => \GRFPC0.FIFO.PC_0\(6),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(2),
dataa => \GRFPC0.FIFO.PC_1\(2),
datab => \GRFPC0.FIFO.PC_0\(2),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FIFO_INST_1_RNI550U_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.RD\(0));
\GRFPC0_FIFO_INST_1_RNI3TVT_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
dataa => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.RD\(0));
\GRFPC0_FIFO_INST_0_RNI1LVT_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.RD\(0));
\GRFPC0_FIFO_INST_1_RNIVCVT_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.RD\(0));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_DEP_2_IV_I_A2_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.DEP_2_IV_I_A2_0\(0),
dataa => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_2_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_2_0_O2\,
dataa => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(28));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX_1\,
dataa => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(26));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2680_REGDEPX_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_INTI1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(3),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M38_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M38_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_4_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_4_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M29_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M29_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(52),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(53),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(53),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(12),
dataa => \GRFPC0.FIFO.PC_1\(12),
datab => \GRFPC0.FIFO.PC_0\(12),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(11),
dataa => \GRFPC0.FIFO.PC_1\(11),
datab => \GRFPC0.FIFO.PC_0\(11),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_CMPI2_I_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPC0_V_STDATA_14_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(21),
dataa => \GRFPC0.FIFO.INST_1\(21),
datab => \GRFPC0.FIFO.INST_0\(21),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(13),
dataa => \GRFPC0.FIFO.PC_1\(13),
datab => \GRFPC0.FIFO.PC_0\(13),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(21),
dataa => \GRFPC0.FIFO.PC_1\(21),
datab => \GRFPC0.FIFO.PC_0\(21),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(19),
dataa => \GRFPC0.FIFO.PC_1\(19),
datab => \GRFPC0.FIFO.PC_0\(19),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
dataa => \GRFPC0.FIFO.PC_1\(25),
datab => \GRFPC0.FIFO.PC_0\(25),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_TZI2_I_M2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2_I_M2\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_I_A4_I_M2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_A4_I_M2\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_TZI2_I_0_M3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2_I_0_M3\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD32\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD31\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(3),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD34\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD34\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M4_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_0\(40),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3\(40),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M4_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_M4_1\(40),
dataa => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O4_3\(38));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(16),
dataa => \GRFPU0.MULO.MRES_BUF\(120),
datab => \GRFPU0.FPMUL0.UN1_SIN_3_ADD47\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD47\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_O3_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_O3\(40),
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O2_RNIGPUE1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_6_0_A2_I\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2\(9));
\GRFPU0_GRFPU_X0_CMPI1_I_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD42\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD41\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD44\,
datab => \GRFPU0.MULO.MRES_BUF\(120),
datac => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(50),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(111),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(111));
\GRFPU0_GRFPU_X0_DIFFIN1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(27),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_TZI_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI_I_M2\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_TZI_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_TZI_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
GRFPU0_GRFPU_X0_COMB_DIFFIN116: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DIFFIN116\,
dataa => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD33\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD32\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M3_I_M4_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M3_I_M4\(41),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(19),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(19),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_0_O2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_0_O2\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(35),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_L3_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(3),
dataa => \GRFPU0.GRFPU_X0.L1_0_1\(3),
datab => \GRFPU0.GRFPU_X0.L1_0_A2\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_10\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(96),
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD51\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD50\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M2\(59),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(1),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(1),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M34_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M34_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M32_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M32_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_0_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M31_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M31_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_8_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_8_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18));
\GRFPU0_GRFPU_X0_L1_0_1_1_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_1_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3_I_M3\(4),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD35\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_UN118_BCO_LSB_0_1_I: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_0_1_I\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_L1_6_1_I_A4_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_I_A4\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_BIAS15_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(55),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(55),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_CMPI2_I_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
dataa => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN23_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L1_4_4\(3));
\GRFPU0_GRFPU_X0_L2_1_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_3\(2),
dataa => \GRFPU0.GRFPU_X0.UN18_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN13_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_3\(3));
\GRFPU0_GRFPU_X0_L3_0_6_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(3),
dataa => \GRFPU0.GRFPU_X0.L1_0_10\(3),
datab => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_4\(4));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_CMPI1_I_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIEJJG_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD46\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD45\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_RNO_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M\(115),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70_REP1\,
datab => \GRFPU0.MULO.MRES\(115));
\GRFPU0_GRFPU_X0_DIFFIN1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_CMPI2_I_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI2_I_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_CMPI2_0_A2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(25),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNI6PDL_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_63_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0_O4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_1\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_O2_0\(9));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(30),
dataa => \GRFPC0.FIFO.PC_1\(30),
datab => \GRFPC0.FIFO.PC_0\(30),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_V_STDATA_14_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(5),
dataa => \GRFPC0.FIFO.INST_1\(5),
datab => \GRFPC0.FIFO.INST_0\(5),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_V_STDATA_14_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(23),
dataa => \GRFPC0.FIFO.INST_1\(23),
datab => \GRFPC0.FIFO.INST_0\(23),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(23),
dataa => \GRFPC0.FIFO.PC_1\(23),
datab => \GRFPC0.FIFO.PC_0\(23),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(29),
dataa => \GRFPC0.FIFO.PC_1\(29),
datab => \GRFPC0.FIFO.PC_0\(29),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPU0_GRFPU_X0_L1_2_1_2_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_2_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD29\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD28\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD31\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M4_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_I_M4\(37),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(23),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(23),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(54),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(6),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(6),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(26),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.COMB.SHL.CNV_SHIFT2_2_36\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\);
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_0_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_2_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\);
\GRFPU0_GRFPU_X0_L2_0_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(2),
dataa => \GRFPU0.GRFPU_X0.UN213_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN208_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_4\(3));
\GRFPU0_GRFPU_X0_DIFFIN1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_CMPI2_I_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2_I\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0));
\GRFPU0_GRFPU_X0_CMPI1_I_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1_I\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_3_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_L2_1_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN153_BCO_LSB_0_A2\,
datab => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_A2\(3));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(2),
dataa => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN158_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L1_4\(3));
\GRFPU0_GRFPU_X0_L4_3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_10\(4),
datac => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5));
\GRFPU0_GRFPU_X0_INTI1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(4),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_TZI2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_TZI2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(23),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(30),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_L2_1_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_2\(2),
dataa => \GRFPU0.GRFPU_X0.UN218_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN223_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_2\(3));
\GRFPU0_GRFPU_X0_L3_0_2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(3),
dataa => \GRFPU0.GRFPU_X0.L1_0_4\(3),
datab => \GRFPU0.GRFPU_X0.L1_2_2\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_0\(4));
\GRFPU0_GRFPU_X0_L4_4_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_0\(4),
datac => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5));
\GRFPU0_GRFPU_X0_L1_6_1_2_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_2_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
dataa => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN228_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L1_4_2\(3));
GRFPU0_GRFPU_X0_UN1_ST2_DIFF_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.DIFF_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNI775L_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.L2_2\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD1\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2\);
\GRFPU0_GRFPU_X0_L1_1_1_2_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_2_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPC0_V_STDATA_14_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(10),
dataa => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_0\(10),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_RFA2_FOP_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001100110011001")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_X2\(1),
dataa => \GRFPC0.INST\(5),
datab => \GRFPC0.INST_I_X\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP2\);
\GRFPU0_GRFPU_X0_DIFFIN1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
GRFPU0_GRFPU_X0_UN1_VITER_STATE_17_SQMUXA_1_0_A2_0_RNIUACQ1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.N_3241_M_1_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_17_SQMUXA_1_0_A2_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(45),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(15),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(15),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_DIFFIN1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110001011100010")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1),
datac => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_4\(31),
dataa => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_70\,
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_REP2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_0_0_A2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_0_0_A2\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(5),
dataa => \GRFPC0.FIFO.PC_1\(5),
datab => \GRFPC0.FIFO.PC_0\(5),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\,
datab => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I_A2\(31));
\GRFPC0_V_STDATA_14_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(8),
dataa => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_0\(8),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(9),
dataa => \GRFPC0.FIFO.PC_1\(9),
datab => \GRFPC0.FIFO.PC_0\(9),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(22),
dataa => \GRFPC0.FIFO.PC_1\(22),
datab => \GRFPC0.FIFO.PC_0\(22),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(10),
dataa => \GRFPC0.FIFO.PC_1\(10),
datab => \GRFPC0.FIFO.PC_0\(10),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24),
dataa => \GRFPC0.FIFO.PC_1\(24),
datab => \GRFPC0.FIFO.PC_0\(24),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_V_STDATA_14_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(24),
dataa => \GRFPC0.FIFO.INST_1\(24),
datab => \GRFPC0.FIFO.INST_0\(24),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_V_STDATA_14_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(13),
dataa => \GRFPC0.FIFO.INST_1\(13),
datab => \GRFPC0.FIFO.INST_0\(13),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(7),
dataa => \GRFPC0.FIFO.PC_1\(7),
datab => \GRFPC0.FIFO.PC_0\(7),
datac => \GRFPC0.FIFO.RD_REP1\(0));
\GRFPC0_V_STDATA_14_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(12),
dataa => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPC0_V_STDATA_14_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(7),
dataa => \GRFPC0.FIFO.INST_1\(7),
datab => \GRFPC0.FIFO.INST_0\(7),
datac => \GRFPC0.FIFO.RD_REP3\(0));
\GRFPC0_V_STDATA_14_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.V.STDATA_14\(9),
dataa => \GRFPC0.FIFO.INST_1\(9),
datab => \GRFPC0.FIFO.INST_0\(9),
datac => \GRFPC0.FIFO.RD_REP4\(0));
\GRFPU0_GRFPU_X0_L2_0_6_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(2),
dataa => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN243_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_0\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(57),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_61_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(61),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(60),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M2\(54),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD17\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD16\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(25),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(85),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_I_M_0\(85),
dataa => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.UN1_VALLOW_REP1\);
\GRFPU0_GRFPU_X0_L2_1_4_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_4\(2),
dataa => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3));
\GRFPU0_GRFPU_X0_TZI2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M3\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
GRFPU0_GRFPU_X0_COMB_VST2_REG_38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_38\,
dataa => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
GRFPU0_GRFPU_X0_ST1_SIGN1_RNINO3O: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_I_O3\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_63_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_TZI_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_DIFFIN1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_TZI_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(15),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_TZI_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(28),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M3_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M3_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\);
\GRFPU0_GRFPU_X0_TZI_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI_I_M2\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_TZI_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_TZI_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP5\);
\GRFPU0_GRFPU_X0_TZI_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_DIFFIN1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_TZI_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_TZI_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_TZI_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(16),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.G_34_I_I_A2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_0\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_0_03: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\);
GRFPU0_GRFPU_X0_VITER_NX_0_SQMUXA_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.NX_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_M2\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datac => \GRFPU0.GRFPU_X0.ITER.V_REP3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_1_I_M2\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.V_REP3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI26R7_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.V_REP3\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNINOIB_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M4_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M3_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M3_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT27_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT27_6\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD11\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN14_C_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_1\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD9\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M2_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0_I_M2\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN14_C_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN14_C_2\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD7\);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_NZ_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.NZ_1_0\,
dataa => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
datab => \GRFPU0.GRFPU_X0.UN8_C_ADD7\);
\GRFPU0_GRFPU_X0_L3_0_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(3),
dataa => \GRFPU0.GRFPU_X0.L1_2_0\(3),
datab => \GRFPU0.GRFPU_X0.L1_0\(3),
datac => \GRFPU0.GRFPU_X0.L2\(4));
\GRFPU0_GRFPU_X0_L4_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datab => \GRFPU0.GRFPU_X0.L2\(4),
datac => \GRFPU0.GRFPU_X0.L3_0\(5));
\GRFPU0_GRFPU_X0_L2_0_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN93_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN88_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0\(3));
\GRFPU0_GRFPU_X0_L2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN103_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN98_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_2_0\(3));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(2),
dataa => \GRFPU0.GRFPU_X0.UN108_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_4_1\(3));
\GRFPU0_GRFPU_X0_L1_0_1_I_1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_I_1\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M26_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M26_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M24_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M24_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M22_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M22_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M23_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M23_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\);
\GRFPU0_GRFPU_X0_L4_6_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_4\(4),
datac => \GRFPU0.GRFPU_X0.L3_0_4\(5));
\GRFPU0_GRFPU_X0_ITADDI2_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ITADDI2_1\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
datab => \GRFPU0.GRFPU_X0.L3_0_4\(5));
GRFPU0_GRFPU_X0_ITER_ODDEXP_RNIML6C: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ITCIN\,
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIJCIB_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I_O4\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G6\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_O4\);
GRFPU0_GRFPU_X0_VITER_DBUF_4_SQMUXA_I_I_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_4_SQMUXA_I_I_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP4\);
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_0_A2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_0_A2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\);
GRFPU0_FPMUL0_CSADD_UN335_C1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.FPMUL0.CSADD.UN335_C1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
datab => \GRFPU0.FPMUL0.CS_DP_R\);
GRFPU0_FPMUL0_CSADD_UN332_C2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.FPMUL0.CSADD.UN332_C2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => \GRFPU0.FPMUL0.CS_DP_R\);
GRFPU0_FPMUL0_CSADD_UN303_MC2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.FPMUL0.CSADD.UN303_MC2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => \GRFPU0.FPMUL0.CS_DP_R\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP1\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(17),
dataa => \GRFPC0.FIFO.PC_1\(17),
datab => \GRFPC0.FIFO.PC_0\(17),
datac => \GRFPC0.FIFO.RD_REP2\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M31_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M31_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M29_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M29_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M27_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M27_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M38_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M38_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M24_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M24_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M20_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M20_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M23_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M23_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(28),
dataa => \GRFPC0.FIFO.PC_1\(28),
datab => \GRFPC0.FIFO.PC_0\(28),
datac => \GRFPC0.FIFO.RD_REP2\(0));
\GRFPC0_FP_PIPELINE_VFIFO_RD_3_I_O2_0_X2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD_3_I_O2_0_X2\(0),
dataa => \GRFPC0.FIFO.RD_REP2\(0),
datab => \GRFPC0.FP_PIPELINE.FPUSTART_7\);
GRFPU0_GRFPU_X0_UN1_VST3_EXC_4_SQMUXA_TZ: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST3.EXC51\,
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC36_RNIUI6L: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G3\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.EXC36\);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNI6I1F_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_M1\,
dataa => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.COMB.BIAS15\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(1),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD10\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(2),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD9\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(3),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD8\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(4),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD7\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(5),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD6\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(6),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD5\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(7),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(8),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(9),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD1\,
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101110001011100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M4\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G3\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(56),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(7),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_1_I_O2_RNINVMI2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G1_0_REP3\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_51__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(51),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(51));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_50__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(50),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(50));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_49__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(49),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(49));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_48__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(48),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(48));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_47__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(47),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(47));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_46__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(46),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(46));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_45__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(45),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(45));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_44__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(44),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(44));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_43__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(43),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(43));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_42__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(42),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(42));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_41__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(41),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(41));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_40__G1\,
dataa => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(40),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(40));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011100010111000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_39__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(39),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(39));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_38__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(38),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(38),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_37__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(37),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(37),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_36__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(36),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(36),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_35__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(35),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(35),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_34__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(34),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(34),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_33__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(33),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(33),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_32__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(32),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(32),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_31__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(31),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(31),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_30__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(30),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(30),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_29__G1\,
dataa => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(29),
datab => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(29),
datac => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(53));
GRFPU0_GRFPU_X0_TMP3_0_SQMUXA_I_M2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA_I_M2\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_SIGN_1_I_M3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN_1_I_M3\,
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datac => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\);
GRFPU0_GRFPU_X0_COMB_DPRES4_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES4_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI14VL_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.N_40_I_S_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_VST4_EXC_1_SQMUXA_9_0_0_O2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011101110111011")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_9_0_0_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES4_7\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.N_58_I_I_O2\,
dataa => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.UN6_SGNFX\(23));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_FLUSH0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.FLUSH0\,
dataa => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\);
GRFPC0_FP_PIPELINE_0_0_IS_RS1V_TMP_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.IS_RS1V.TMP_1\,
dataa => \GRFPC0.FIFO.INST_0\(12),
datab => \GRFPC0.FIFO.INST_0\(11));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_2_03_0_G1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03_0_G1\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M35_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M35_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M34_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M34_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M32_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M32_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M30_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M30_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M28_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M28_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M26_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M26_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M36_4_03_0_G2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101100011011000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M36_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(58),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_L4_7_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_7\(4),
datac => \GRFPU0.GRFPU_X0.L3_0_3\(5));
\GRFPU0_GRFPU_X0_L2_0_5_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(2),
dataa => \GRFPU0.GRFPU_X0.UN43_BCO_LSB\,
datab => \GRFPU0.GRFPU_X0.UN38_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3));
\GRFPU0_GRFPU_X0_TZI2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_TZI2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_TZI2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.DP_REP4\);
\GRFPU0_GRFPU_X0_L3_0_5_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(3),
dataa => \GRFPU0.GRFPU_X0.L1_2_0_A3\(3),
datab => \GRFPU0.GRFPU_X0.L1_0_5_0_A2\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_7\(4));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(2),
dataa => \GRFPU0.GRFPU_X0.UN58_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\,
datac => \GRFPU0.GRFPU_X0.L1_4_5\(3));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_12_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_I_X2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
datab => \GRFPU0.GRFPU_X0.L3_0_3\(5));
\GRFPU0_GRFPU_X0_INTI1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.INTI1\(6),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_60_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(60),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(3),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\(59),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_9_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_A2_9\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_M2_I_I_O2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0_I_O2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_0_A2_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.N_233\,
dataa => \GRFPU0.GRFPU_X0.COMB.GETINF.UN9_MODE_0_O2\,
datab => \GRFPU0.GRFPU_X0.G_51\);
GRFPU0_GRFPU_X0_ST1_V_RNIN3LN1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111011101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_O2_0\(53),
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_REP1\(21));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_0\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M3_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62_I_M3\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_62\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_O3_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101110111011101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_O3\(58),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2_REP1\);
\GRFPU0_GRFPU_X0_CMPI2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_1_A2_1_0_A2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27_1_A2_1_0_A2\(15),
dataa => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_I_O2_REP1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_0_REP1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_10_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_A2_10\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_M1_I_O2\);
\GRFPU0_GRFPU_X0_CMPI2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_CMPI2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0));
\GRFPU0_GRFPU_X0_CMPI1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.CMPI1\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD28\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD27\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD16\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD15\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP1\);
GRFPU0_GRFPU_X0_COMB_GUARD_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
dataa => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.MULO.MRES_BUF\(120));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110111011101110")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_10\,
dataa => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(85));
GRFPU0_GRFPU_X0_COMB_G_DP_1_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(3),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(4),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(5),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(6),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(7),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(8),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(9),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(10),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(11),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(12),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_S3ADDI_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI_0\(13),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_A_RNO_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(70),
dataa => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_REP1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(10),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4_0\,
dataa => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD35\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4\,
dataa => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD34\,
datac => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2_REP2\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100101011001010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
dataa => \GRFPU0.FPMUL0.UN1_SIN_3_ADD37\,
datab => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\,
datac => \GRFPU0.MULO.MRES_BUF\(120));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0\(43),
dataa => \GRFPU0.GRFPU_X0.UN177_RNDOP\(17),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(17),
datac => \GRFPU0.GRFPU_X0.G_16_0_O2\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010110010101100")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1));
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD55_RNIJOUK: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_55__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datab => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD55\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100010001000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_0__G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datab => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD0\);
GRFPU0_GRFPU_X0_ST3_STICKY_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010001000100010")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.STICKY_0_0_G0\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFV\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_2_01: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110010011100100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(50),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(52),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(53),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
GRFPU0_GRFPU_X0_COMB_STICKYI_1_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001000100010001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.STICKYI_1_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.STICKY\,
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(48),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(29),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(32),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(28),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(16),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(17),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(20),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(21),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(8),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(9),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(12),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(13),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(14),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_ADDSUBI2_1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.ADD\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_RNIU2JD_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1111000011110000")
port map (
combout => CARRY_PATCH0,
cout => N_82060,
dataa => GND,
datab => GND,
cin => N_35844);
GRFPC0_VEX_CTRL_ID_2_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD5\,
dataa => \GRFPC0.EX.CTRL.ID\(5),
datab => GND,
cin => \GRFPC0.VEX.CTRL.ID_2_CARRY_4\);
GRFPC0_VEX_CTRL_ID_2_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD4\,
cout => \GRFPC0.VEX.CTRL.ID_2_CARRY_4\,
dataa => \GRFPC0.EX.CTRL.ID\(4),
datab => GND,
cin => \GRFPC0.VEX.CTRL.ID_2_CARRY_3\);
GRFPC0_VEX_CTRL_ID_2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD3\,
cout => \GRFPC0.VEX.CTRL.ID_2_CARRY_3\,
dataa => \GRFPC0.EX.CTRL.ID\(3),
datab => GND,
cin => \GRFPC0.VEX.CTRL.ID_2_CARRY_2\);
GRFPC0_VEX_CTRL_ID_2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD2\,
cout => \GRFPC0.VEX.CTRL.ID_2_CARRY_2\,
dataa => \GRFPC0.EX.CTRL.ID\(2),
datab => GND,
cin => \GRFPC0.VEX.CTRL.ID_2_CARRY_1\);
GRFPC0_VEX_CTRL_ID_2_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD1\,
cout => \GRFPC0.VEX.CTRL.ID_2_CARRY_1\,
dataa => \GRFPC0.EX.CTRL.ID\(1),
datab => GND,
cin => \GRFPC0.VEX.CTRL.ID_2_CARRY_0\);
GRFPC0_VEX_CTRL_ID_2_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_ADD0\,
cout => \GRFPC0.VEX.CTRL.ID_2_CARRY_0\,
dataa => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\);
\GRFPU0_GRFPU_X0_UN28_EXP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(10),
dataa => \GRFPC0.OP2\(62),
datab => GND,
cin => N_36386);
\GRFPU0_GRFPU_X0_UN28_EXP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(9),
dataa => \GRFPC0.OP2\(60),
datab => \GRFPC0.OP2\(61),
cin => N_36385);
\GRFPU0_GRFPU_X0_UN28_EXP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(8),
cout => N_36386,
dataa => \GRFPC0.OP2\(60),
datab => \GRFPC0.OP2\(61),
cin => N_36384);
\GRFPU0_GRFPU_X0_UN28_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(7),
cout => N_36385,
dataa => \GRFPC0.OP2\(58),
datab => \GRFPC0.OP2\(59),
cin => N_36383);
\GRFPU0_GRFPU_X0_UN28_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(6),
cout => N_36384,
dataa => \GRFPC0.OP2\(58),
datab => \GRFPC0.OP2\(59),
cin => N_36382);
\GRFPU0_GRFPU_X0_UN28_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(5),
cout => N_36383,
dataa => \GRFPC0.OP2\(56),
datab => \GRFPC0.OP2\(57),
cin => N_36381);
\GRFPU0_GRFPU_X0_UN28_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(4),
cout => N_36382,
dataa => \GRFPC0.OP2\(56),
datab => \GRFPC0.OP2\(57),
cin => N_36380);
\GRFPU0_GRFPU_X0_UN28_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(3),
cout => N_36381,
dataa => \GRFPC0.OP2\(54),
datab => \GRFPC0.OP2\(55),
cin => N_36379);
\GRFPU0_GRFPU_X0_UN28_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(2),
cout => N_36380,
dataa => \GRFPC0.OP2\(54),
datab => \GRFPC0.OP2\(55),
cin => N_36378);
\GRFPU0_GRFPU_X0_UN28_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(1),
cout => N_36379,
dataa => \GRFPC0.OP2\(52),
datab => \GRFPC0.OP2\(53));
\GRFPU0_GRFPU_X0_UN28_EXP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36378,
dataa => \GRFPC0.OP2\(52),
datab => \GRFPC0.OP2\(53));
\GRFPU0_GRFPU_X0_UN23_EXP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datab => GND,
cin => N_36373);
\GRFPU0_GRFPU_X0_UN23_EXP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => N_36372);
\GRFPU0_GRFPU_X0_UN23_EXP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(8),
cout => N_36373,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => N_36371);
\GRFPU0_GRFPU_X0_UN23_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(7),
cout => N_36372,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => N_36370);
\GRFPU0_GRFPU_X0_UN23_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(6),
cout => N_36371,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => N_36369);
\GRFPU0_GRFPU_X0_UN23_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(5),
cout => N_36370,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
cin => N_36368);
\GRFPU0_GRFPU_X0_UN23_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(4),
cout => N_36369,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
cin => N_36367);
\GRFPU0_GRFPU_X0_UN23_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(3),
cout => N_36368,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
cin => N_36366);
\GRFPU0_GRFPU_X0_UN23_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(2),
cout => N_36367,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
cin => N_36365);
\GRFPU0_GRFPU_X0_UN23_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(1),
cout => N_36366,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_UN23_EXP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36365,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_UN3_EXP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(10),
dataa => \GRFPC0.OP1_0_IV\(62),
datab => GND,
cin => N_36360);
\GRFPU0_GRFPU_X0_UN3_EXP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(9),
dataa => \GRFPC0.OP1_0_IV\(60),
datab => \GRFPC0.OP1_0_IV\(61),
cin => N_36359);
\GRFPU0_GRFPU_X0_UN3_EXP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(8),
cout => N_36360,
dataa => \GRFPC0.OP1_0_IV\(60),
datab => \GRFPC0.OP1_0_IV\(61),
cin => N_36358);
\GRFPU0_GRFPU_X0_UN3_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(7),
cout => N_36359,
dataa => \GRFPC0.OP1_0_IV\(58),
datab => \GRFPC0.OP1_0_IV\(59),
cin => N_36357);
\GRFPU0_GRFPU_X0_UN3_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(6),
cout => N_36358,
dataa => \GRFPC0.OP1_0_IV\(58),
datab => \GRFPC0.OP1_0_IV\(59),
cin => N_36356);
\GRFPU0_GRFPU_X0_UN3_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(5),
cout => N_36357,
dataa => \GRFPC0.OP1_0_IV\(56),
datab => \GRFPC0.OP1_0_IV\(57),
cin => N_36355);
\GRFPU0_GRFPU_X0_UN3_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(4),
cout => N_36356,
dataa => \GRFPC0.OP1_0_IV\(56),
datab => \GRFPC0.OP1_0_IV\(57),
cin => N_36354);
\GRFPU0_GRFPU_X0_UN3_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(3),
cout => N_36355,
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPC0.OP1_0_IV\(55),
cin => N_36353);
\GRFPU0_GRFPU_X0_UN3_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(2),
cout => N_36354,
dataa => \GRFPC0.OP1_0_IV\(54),
datab => \GRFPC0.OP1_0_IV\(55),
cin => N_36352);
\GRFPU0_GRFPU_X0_UN3_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_EXP\(1),
cout => N_36353,
dataa => \GRFPC0.OP1_0_IV\(52),
datab => \GRFPC0.OP1_0_IV\(53));
\GRFPU0_GRFPU_X0_UN3_EXP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36352,
dataa => \GRFPC0.OP1_0_IV\(52),
datab => \GRFPC0.OP1_0_IV\(53));
\GRFPU0_GRFPU_X0_UN38_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(7),
dataa => \GRFPC0.OP2\(61),
datab => \GRFPC0.OP2\(62),
cin => N_36348);
\GRFPU0_GRFPU_X0_UN38_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(6),
dataa => \GRFPC0.OP2\(61),
datab => GND,
cin => N_36347);
\GRFPU0_GRFPU_X0_UN38_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(5),
cout => N_36348,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(60),
cin => N_36346);
\GRFPU0_GRFPU_X0_UN38_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(4),
cout => N_36347,
dataa => \GRFPC0.OP2\(59),
datab => \GRFPC0.OP2\(60),
cin => N_36345);
\GRFPU0_GRFPU_X0_UN38_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(3),
cout => N_36346,
dataa => \GRFPC0.OP2\(57),
datab => \GRFPC0.OP2\(58),
cin => N_36344);
\GRFPU0_GRFPU_X0_UN38_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(2),
cout => N_36345,
dataa => \GRFPC0.OP2\(57),
datab => \GRFPC0.OP2\(58),
cin => N_36343);
\GRFPU0_GRFPU_X0_UN38_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP\(1),
cout => N_36344,
dataa => \GRFPC0.OP2\(55),
datab => \GRFPC0.OP2\(56));
\GRFPU0_GRFPU_X0_UN38_EXP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36343,
dataa => \GRFPC0.OP2\(55),
datab => \GRFPC0.OP2\(56));
\GRFPU0_GRFPU_X0_UN13_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001001110010011")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(7),
dataa => \GRFPC0.OP1_0_IV\(61),
datab => \GRFPC0.OP1_0_IV\(62),
cin => N_36339);
\GRFPU0_GRFPU_X0_UN13_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(6),
dataa => \GRFPC0.OP1_0_IV\(61),
datab => GND,
cin => N_36338);
\GRFPU0_GRFPU_X0_UN13_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(5),
cout => N_36339,
dataa => \GRFPC0.OP1_0_IV\(59),
datab => \GRFPC0.OP1_0_IV\(60),
cin => N_36337);
\GRFPU0_GRFPU_X0_UN13_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(4),
cout => N_36338,
dataa => \GRFPC0.OP1_0_IV\(59),
datab => \GRFPC0.OP1_0_IV\(60),
cin => N_36336);
\GRFPU0_GRFPU_X0_UN13_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(3),
cout => N_36337,
dataa => \GRFPC0.OP1_0_IV\(57),
datab => \GRFPC0.OP1_0_IV\(58),
cin => N_36335);
\GRFPU0_GRFPU_X0_UN13_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(2),
cout => N_36336,
dataa => \GRFPC0.OP1_0_IV\(57),
datab => \GRFPC0.OP1_0_IV\(58),
cin => N_36334);
\GRFPU0_GRFPU_X0_UN13_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP\(1),
cout => N_36335,
dataa => \GRFPC0.OP1_0_IV\(55),
datab => \GRFPC0.OP1_0_IV\(56));
\GRFPU0_GRFPU_X0_UN13_EXP_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36334,
dataa => \GRFPC0.OP1_0_IV\(55),
datab => \GRFPC0.OP1_0_IV\(56));
\GRFPU0_GRFPU_X0_UN1_ST3_REG_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => GND,
cin => N_36329);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61),
cin => N_36328);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(3),
cout => N_36329,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61),
cin => N_36327);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(4),
cout => N_36328,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59),
cin => N_36326);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(5),
cout => N_36327,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59),
cin => N_36325);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(6),
cout => N_36326,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => N_36324);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(7),
cout => N_36325,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => N_36323);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(8),
cout => N_36324,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => N_36322);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(9),
cout => N_36323,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => N_36321);
\GRFPU0_GRFPU_X0_UN1_ST3_REG_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.REG\(10),
cout => N_36322,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_UN1_ST3_REG_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36321,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53));
GRFPU0_GRFPU_X0_UN8_C_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD11\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\);
GRFPU0_GRFPU_X0_UN8_C_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD10\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\);
GRFPU0_GRFPU_X0_UN8_C_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\);
GRFPU0_GRFPU_X0_UN8_C_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\);
GRFPU0_GRFPU_X0_UN8_C_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\);
GRFPU0_GRFPU_X0_UN8_C_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\);
GRFPU0_GRFPU_X0_UN8_C_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_C_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\);
GRFPU0_GRFPU_X0_UN8_C_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\);
GRFPU0_GRFPU_X0_UN8_C_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\);
GRFPU0_GRFPU_X0_UN8_C_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\);
GRFPU0_GRFPU_X0_UN8_C_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_C_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(0));
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100101101001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD5\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD4\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD3\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD2\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD1\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_ADD0\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_116620);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100101101001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD5\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD4\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD3\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD2\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD1\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_ADD0\,
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_116621);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100101101001")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD10\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD9\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD8\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD7\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD6\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD5\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD4\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD3\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD2\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD1\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_ADD0\,
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_116622);
\GRFPU0_GRFPU_X0_UN166_RNDOP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
cin => N_36313);
\GRFPU0_GRFPU_X0_UN166_RNDOP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => GND,
cin => N_36312);
\GRFPU0_GRFPU_X0_UN166_RNDOP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(3),
cout => N_36313,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => N_36311);
\GRFPU0_GRFPU_X0_UN166_RNDOP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
cout => N_36312,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => N_36310);
\GRFPU0_GRFPU_X0_UN166_RNDOP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(5),
cout => N_36311,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => N_36309);
\GRFPU0_GRFPU_X0_UN166_RNDOP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(6),
cout => N_36310,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => N_36308);
\GRFPU0_GRFPU_X0_UN166_RNDOP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(7),
cout => N_36309,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => N_36307);
\GRFPU0_GRFPU_X0_UN166_RNDOP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(8),
cout => N_36308,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => N_36306);
\GRFPU0_GRFPU_X0_UN166_RNDOP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(9),
cout => N_36307,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => N_36305);
\GRFPU0_GRFPU_X0_UN166_RNDOP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
cout => N_36306,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => N_36304);
\GRFPU0_GRFPU_X0_UN166_RNDOP_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(11),
cout => N_36305,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => N_36303);
\GRFPU0_GRFPU_X0_UN166_RNDOP_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(12),
cout => N_36304,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => N_36302);
\GRFPU0_GRFPU_X0_UN166_RNDOP_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(13),
cout => N_36303,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => N_36301);
\GRFPU0_GRFPU_X0_UN166_RNDOP_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(14),
cout => N_36302,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => N_36300);
\GRFPU0_GRFPU_X0_UN166_RNDOP_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(15),
cout => N_36301,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => N_36299);
\GRFPU0_GRFPU_X0_UN166_RNDOP_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(16),
cout => N_36300,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => N_36298);
\GRFPU0_GRFPU_X0_UN166_RNDOP_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(17),
cout => N_36299,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => N_36297);
\GRFPU0_GRFPU_X0_UN166_RNDOP_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
cout => N_36298,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => N_36296);
\GRFPU0_GRFPU_X0_UN166_RNDOP_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(19),
cout => N_36297,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => N_36295);
\GRFPU0_GRFPU_X0_UN166_RNDOP_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
cout => N_36296,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => N_36294);
\GRFPU0_GRFPU_X0_UN166_RNDOP_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(21),
cout => N_36295,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => N_36293);
\GRFPU0_GRFPU_X0_UN166_RNDOP_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(22),
cout => N_36294,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => N_36292);
\GRFPU0_GRFPU_X0_UN166_RNDOP_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(23),
cout => N_36293,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => N_36291);
\GRFPU0_GRFPU_X0_UN166_RNDOP_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
cout => N_36292,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => N_36290);
\GRFPU0_GRFPU_X0_UN166_RNDOP_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
cout => N_36291,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
cin => N_36289);
\GRFPU0_GRFPU_X0_UN166_RNDOP_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(26),
cout => N_36290,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
cin => N_36288);
\GRFPU0_GRFPU_X0_UN166_RNDOP_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
cout => N_36289,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => N_36287);
\GRFPU0_GRFPU_X0_UN166_RNDOP_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
cout => N_36288,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => N_36286);
\GRFPU0_GRFPU_X0_UN166_RNDOP_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
cout => N_36287,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => N_36285);
\GRFPU0_GRFPU_X0_UN166_RNDOP_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30),
cout => N_36286,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => N_36284);
\GRFPU0_GRFPU_X0_UN166_RNDOP_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31),
cout => N_36285,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => N_36283);
\GRFPU0_GRFPU_X0_UN166_RNDOP_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32),
cout => N_36284,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => N_36282);
\GRFPU0_GRFPU_X0_UN166_RNDOP_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33),
cout => N_36283,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => N_36281);
\GRFPU0_GRFPU_X0_UN166_RNDOP_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34),
cout => N_36282,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => N_36280);
\GRFPU0_GRFPU_X0_UN166_RNDOP_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35),
cout => N_36281,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => N_36279);
\GRFPU0_GRFPU_X0_UN166_RNDOP_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36),
cout => N_36280,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => N_36278);
\GRFPU0_GRFPU_X0_UN166_RNDOP_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37),
cout => N_36279,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => N_36277);
\GRFPU0_GRFPU_X0_UN166_RNDOP_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38),
cout => N_36278,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => N_36276);
\GRFPU0_GRFPU_X0_UN166_RNDOP_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39),
cout => N_36277,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => N_36275);
\GRFPU0_GRFPU_X0_UN166_RNDOP_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40),
cout => N_36276,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => N_36274);
\GRFPU0_GRFPU_X0_UN166_RNDOP_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41),
cout => N_36275,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => N_36273);
\GRFPU0_GRFPU_X0_UN166_RNDOP_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42),
cout => N_36274,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => N_36272);
\GRFPU0_GRFPU_X0_UN166_RNDOP_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43),
cout => N_36273,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => N_36271);
\GRFPU0_GRFPU_X0_UN166_RNDOP_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44),
cout => N_36272,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => N_36270);
\GRFPU0_GRFPU_X0_UN166_RNDOP_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45),
cout => N_36271,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => N_36269);
\GRFPU0_GRFPU_X0_UN166_RNDOP_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46),
cout => N_36270,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => N_36268);
\GRFPU0_GRFPU_X0_UN166_RNDOP_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47),
cout => N_36269,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => N_36267);
\GRFPU0_GRFPU_X0_UN166_RNDOP_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48),
cout => N_36268,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => N_36266);
\GRFPU0_GRFPU_X0_UN166_RNDOP_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49),
cout => N_36267,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => N_36265);
\GRFPU0_GRFPU_X0_UN166_RNDOP_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50),
cout => N_36266,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => N_36264);
\GRFPU0_GRFPU_X0_UN166_RNDOP_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51),
cout => N_36265,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_UN166_RNDOP_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36264,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD10\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD9\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD8\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD7\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD6\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD5\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD4\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(56),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD3\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD2\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD1\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_ADD0\,
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(52),
cin => N_116623);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datab => GND,
cin => N_36258);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111001001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => N_36257);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(3),
cout => N_36258,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => N_36256);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(4),
cout => N_36257,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => N_36255);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(5),
cout => N_36256,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => N_36254);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
cout => N_36255,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
cin => N_36253);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(7),
cout => N_36254,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
cin => N_36252);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(8),
cout => N_36253,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
cin => N_36251);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(9),
cout => N_36252,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
cin => N_36250);
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(10),
cout => N_36251,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_UN1_ITER_EXP_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011101110")
port map (
cout => N_36250,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
GRFPU0_GRFPU_X0_C_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100101101001")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD11\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_10\);
GRFPU0_GRFPU_X0_C_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD10\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_10\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_9\);
GRFPU0_GRFPU_X0_C_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD9\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
cin => \GRFPU0.GRFPU_X0.C_CARRY_8\);
GRFPU0_GRFPU_X0_C_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD8\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
cin => \GRFPU0.GRFPU_X0.C_CARRY_7\);
GRFPU0_GRFPU_X0_C_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD7\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
cin => \GRFPU0.GRFPU_X0.C_CARRY_6\);
GRFPU0_GRFPU_X0_C_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD6\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
cin => \GRFPU0.GRFPU_X0.C_CARRY_5\);
GRFPU0_GRFPU_X0_C_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD5\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.C_CARRY_4\);
GRFPU0_GRFPU_X0_C_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD4\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.C_CARRY_3\);
GRFPU0_GRFPU_X0_C_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD3\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.C_CARRY_2\);
GRFPU0_GRFPU_X0_C_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD2\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.C_CARRY_1\);
GRFPU0_GRFPU_X0_C_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD1\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.C_CARRY_0\);
GRFPU0_GRFPU_X0_C_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.C_ADD0\,
cout => \GRFPU0.GRFPU_X0.C_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_116624);
\GRFPU0_GRFPU_X0_UN177_RNDOP_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111001001")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
cin => N_36245);
\GRFPU0_GRFPU_X0_UN177_RNDOP_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => GND,
cin => N_36244);
\GRFPU0_GRFPU_X0_UN177_RNDOP_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(3),
cout => N_36245,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => N_36243);
\GRFPU0_GRFPU_X0_UN177_RNDOP_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4),
cout => N_36244,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => N_36242);
\GRFPU0_GRFPU_X0_UN177_RNDOP_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(5),
cout => N_36243,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => N_36241);
\GRFPU0_GRFPU_X0_UN177_RNDOP_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(6),
cout => N_36242,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => N_36240);
\GRFPU0_GRFPU_X0_UN177_RNDOP_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(7),
cout => N_36241,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => N_36239);
\GRFPU0_GRFPU_X0_UN177_RNDOP_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(8),
cout => N_36240,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => N_36238);
\GRFPU0_GRFPU_X0_UN177_RNDOP_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(9),
cout => N_36239,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => N_36237);
\GRFPU0_GRFPU_X0_UN177_RNDOP_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
cout => N_36238,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => N_36236);
\GRFPU0_GRFPU_X0_UN177_RNDOP_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(11),
cout => N_36237,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => N_36235);
\GRFPU0_GRFPU_X0_UN177_RNDOP_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(12),
cout => N_36236,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => N_36234);
\GRFPU0_GRFPU_X0_UN177_RNDOP_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(13),
cout => N_36235,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => N_36233);
\GRFPU0_GRFPU_X0_UN177_RNDOP_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(14),
cout => N_36234,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => N_36232);
\GRFPU0_GRFPU_X0_UN177_RNDOP_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(15),
cout => N_36233,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => N_36231);
\GRFPU0_GRFPU_X0_UN177_RNDOP_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(16),
cout => N_36232,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => N_36230);
\GRFPU0_GRFPU_X0_UN177_RNDOP_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(17),
cout => N_36231,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => N_36229);
\GRFPU0_GRFPU_X0_UN177_RNDOP_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
cout => N_36230,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => N_36228);
\GRFPU0_GRFPU_X0_UN177_RNDOP_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(19),
cout => N_36229,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => N_36227);
\GRFPU0_GRFPU_X0_UN177_RNDOP_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
cout => N_36228,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => N_36226);
\GRFPU0_GRFPU_X0_UN177_RNDOP_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(21),
cout => N_36227,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => N_36225);
\GRFPU0_GRFPU_X0_UN177_RNDOP_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(22),
cout => N_36226,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => N_36224);
\GRFPU0_GRFPU_X0_UN177_RNDOP_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(23),
cout => N_36225,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => N_36223);
\GRFPU0_GRFPU_X0_UN177_RNDOP_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
cout => N_36224,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => N_36222);
\GRFPU0_GRFPU_X0_UN177_RNDOP_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
cout => N_36223,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
cin => N_36221);
\GRFPU0_GRFPU_X0_UN177_RNDOP_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(26),
cout => N_36222,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
cin => N_36220);
\GRFPU0_GRFPU_X0_UN177_RNDOP_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
cout => N_36221,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => N_36219);
\GRFPU0_GRFPU_X0_UN177_RNDOP_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
cout => N_36220,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => N_36218);
\GRFPU0_GRFPU_X0_UN177_RNDOP_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
cout => N_36219,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => N_36217);
\GRFPU0_GRFPU_X0_UN177_RNDOP_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
cout => N_36218,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => N_36216);
\GRFPU0_GRFPU_X0_UN177_RNDOP_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
cout => N_36217,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => N_36215);
\GRFPU0_GRFPU_X0_UN177_RNDOP_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
cout => N_36216,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => N_36214);
\GRFPU0_GRFPU_X0_UN177_RNDOP_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33),
cout => N_36215,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => N_36213);
\GRFPU0_GRFPU_X0_UN177_RNDOP_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34),
cout => N_36214,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => N_36212);
\GRFPU0_GRFPU_X0_UN177_RNDOP_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
cout => N_36213,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => N_36211);
\GRFPU0_GRFPU_X0_UN177_RNDOP_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
cout => N_36212,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => N_36210);
\GRFPU0_GRFPU_X0_UN177_RNDOP_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
cout => N_36211,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => N_36209);
\GRFPU0_GRFPU_X0_UN177_RNDOP_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
cout => N_36210,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => N_36208);
\GRFPU0_GRFPU_X0_UN177_RNDOP_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
cout => N_36209,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => N_36207);
\GRFPU0_GRFPU_X0_UN177_RNDOP_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
cout => N_36208,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => N_36206);
\GRFPU0_GRFPU_X0_UN177_RNDOP_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
cout => N_36207,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => N_36205);
\GRFPU0_GRFPU_X0_UN177_RNDOP_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
cout => N_36206,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => N_36204);
\GRFPU0_GRFPU_X0_UN177_RNDOP_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
cout => N_36205,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => N_36203);
\GRFPU0_GRFPU_X0_UN177_RNDOP_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
cout => N_36204,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => N_36202);
\GRFPU0_GRFPU_X0_UN177_RNDOP_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
cout => N_36203,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => N_36201);
\GRFPU0_GRFPU_X0_UN177_RNDOP_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
cout => N_36202,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => N_36200);
\GRFPU0_GRFPU_X0_UN177_RNDOP_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47),
cout => N_36201,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => N_36199);
\GRFPU0_GRFPU_X0_UN177_RNDOP_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
cout => N_36200,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => N_36198);
\GRFPU0_GRFPU_X0_UN177_RNDOP_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100100111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
cout => N_36199,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => N_36197);
\GRFPU0_GRFPU_X0_UN177_RNDOP_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
cout => N_36198,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => N_36196);
\GRFPU0_GRFPU_X0_UN177_RNDOP_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111101110")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
cout => N_36197,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_UN177_RNDOP_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011101110")
port map (
cout => N_36196,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110000111100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD10\,
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\,
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\,
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\,
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_0_A2\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(0));
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010101100101")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
cin => N_36191);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datab => GND,
cin => N_36190);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
cout => N_36191,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
cin => N_36189);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
cout => N_36190,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
cin => N_36188);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
cout => N_36189,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
cin => N_36187);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
cout => N_36188,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
cin => N_36186);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
cout => N_36187,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
cin => N_36185);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
cout => N_36186,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
cin => N_36184);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
cout => N_36185,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
cin => N_36183);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
cout => N_36184,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
cin => N_36182);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
cout => N_36183,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
cin => N_36181);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
cout => N_36182,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
cin => N_36180);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
cout => N_36181,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
cin => N_36179);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
cout => N_36180,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
cin => N_36178);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
cout => N_36179,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
cin => N_36177);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
cout => N_36178,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
cin => N_36176);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
cout => N_36177,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
cin => N_36175);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
cout => N_36176,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
cin => N_36174);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
cout => N_36175,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
cin => N_36173);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
cout => N_36174,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
cin => N_36172);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
cout => N_36173,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
cin => N_36171);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
cout => N_36172,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
cin => N_36170);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
cout => N_36171,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
cin => N_36169);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
cout => N_36170,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
cin => N_36168);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
cout => N_36169,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
cin => N_36167);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
cout => N_36168,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
cin => N_36166);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
cout => N_36167,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
cin => N_36165);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
cout => N_36166,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
cin => N_36164);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
cout => N_36165,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
cin => N_36163);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
cout => N_36164,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
cin => N_36162);
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011000010001")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
cout => N_36163,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32));
\GRFPU0_GRFPU_X0_INF_ABS0_A_0_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000010001")
port map (
cout => N_36162,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32));
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100101101001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD10\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_0\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\,
dataa => \GRFPU0.GRFPU_X0.COMB.DIFFIN116\,
datab => GND,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100111101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD51\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_A2\(52),
datab => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(52),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD50\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(51),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(51),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD49\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(50),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(50),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD48\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(49),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(49),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD47\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(48),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(48),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD46\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(47),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(47),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD45\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(46),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(46),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD44\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(45),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(45),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD43\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(44),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(44),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD42\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(43),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(43),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD41\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(42),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(42),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD40\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(41),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(41),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD39\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(40),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(40),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD38\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3_I_M2\(39),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(39),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD37\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(38),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3_I_M2\(38),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD36\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(37),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(37),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD35\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(36),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(36),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD34\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(35),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(35),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD33\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(34),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(34),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD32\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(33),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(33),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD31\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(32),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(32),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD30\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(31),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(31),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD29\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(30),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(30),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD28\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(29),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(29),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD27\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(28),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(28),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD26\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(27),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(27),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD25\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(26),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(26),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD24\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(25),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(25),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD23\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(24),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(24),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD22\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(23),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(23),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD21\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(22),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(22),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD20\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(21),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(21),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD19\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(20),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(20),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD18\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(19),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(19),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD17\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(18),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(18),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD16\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(17),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(17),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD15\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(16),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(16),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD14\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(15),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(15),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD13\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(14),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(14),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD12\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(13),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(13),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD11\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(12),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(12),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD10\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(11),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(11),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(10),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(10),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(9),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(9),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(8),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(8),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(7),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(7),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(6),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(6),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M2\(5),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(5),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(4),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M2\(4),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(3),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(3),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1_I_M3\(2),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(2),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\);
GRFPU0_GRFPU_X0_UN2_DIFF1_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.DIFFIN1\(1),
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4_I_M3\(1));
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101111101011111")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(52),
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(51),
datab => GND,
cin => N_36156);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(51),
cout => N_116625,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(51),
datab => GND,
cin => N_36155);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(50),
cout => N_36156,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(49),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(50),
cin => N_36154);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(49),
cout => N_36155,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(49),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(50),
cin => N_36153);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(48),
cout => N_36154,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(47),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(48),
cin => N_36152);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(47),
cout => N_36153,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(47),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(48),
cin => N_36151);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(46),
cout => N_36152,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(45),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(46),
cin => N_36150);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(45),
cout => N_36151,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(45),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(46),
cin => N_36149);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(44),
cout => N_36150,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(43),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(44),
cin => N_36148);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(43),
cout => N_36149,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(43),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(44),
cin => N_36147);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(42),
cout => N_36148,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(41),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(42),
cin => N_36146);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(41),
cout => N_36147,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(41),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(42),
cin => N_36145);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(40),
cout => N_36146,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(39),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(40),
cin => N_36144);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(39),
cout => N_36145,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(39),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(40),
cin => N_36143);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(38),
cout => N_36144,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(37),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(38),
cin => N_36142);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(37),
cout => N_36143,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(37),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(38),
cin => N_36141);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(36),
cout => N_36142,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(35),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(36),
cin => N_36140);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(35),
cout => N_36141,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(35),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(36),
cin => N_36139);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(34),
cout => N_36140,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(33),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(34),
cin => N_36138);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(33),
cout => N_36139,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(33),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(34),
cin => N_36137);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(32),
cout => N_36138,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(31),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(32),
cin => N_36136);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(31),
cout => N_36137,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(31),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(32),
cin => N_36135);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(30),
cout => N_36136,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(30),
cin => N_36134);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(29),
cout => N_36135,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(30),
cin => N_36133);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
cout => N_36134,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(27),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(28),
cin => N_36132);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
cout => N_36133,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(27),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(28),
cin => N_36131);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
cout => N_36132,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(25),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(26),
cin => N_36130);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
cout => N_36131,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(25),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(26),
cin => N_36129);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
cout => N_36130,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(23),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(24),
cin => N_36128);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
cout => N_36129,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(23),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(24),
cin => N_36127);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
cout => N_36128,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(21),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(22),
cin => N_36126);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
cout => N_36127,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(21),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(22),
cin => N_36125);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
cout => N_36126,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(19),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(20),
cin => N_36124);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
cout => N_36125,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(19),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(20),
cin => N_36123);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
cout => N_36124,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(17),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(18),
cin => N_36122);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
cout => N_36123,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(17),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(18),
cin => N_36121);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
cout => N_36122,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(15),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(16),
cin => N_36120);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
cout => N_36121,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(15),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(16),
cin => N_36119);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
cout => N_36120,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(13),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(14),
cin => N_36118);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
cout => N_36119,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(13),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(14),
cin => N_36117);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
cout => N_36118,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(11),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(12),
cin => N_36116);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
cout => N_36117,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(11),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(12),
cin => N_36115);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
cout => N_36116,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(9),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(10),
cin => N_36114);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
cout => N_36115,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(9),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(10),
cin => N_36113);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
cout => N_36114,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(7),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(8),
cin => N_36112);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
cout => N_36113,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(7),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(8),
cin => N_36111);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
cout => N_36112,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(5),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(6),
cin => N_36110);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
cout => N_36111,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(5),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(6),
cin => N_36109);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
cout => N_36110,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(3),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(4),
cin => N_36108);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
cout => N_36109,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(3),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(4),
cin => N_36107);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
cout => N_36108,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(1),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(2),
cin => N_36105);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
cout => N_36107,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(1),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(2),
cin => N_36104);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_36104,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\);
\GRFPU0_GRFPU_X0_UN3_S3ADDO1_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
cout => N_36105,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(0),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(51),
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(50),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(51),
cin => N_36101);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(50),
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(50),
datab => GND,
cin => N_36100);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(49),
cout => N_36101,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(48),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(49),
cin => N_36099);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(48),
cout => N_36100,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(48),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(49),
cin => N_36098);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(47),
cout => N_36099,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(46),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(47),
cin => N_36097);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(46),
cout => N_36098,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(46),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(47),
cin => N_36096);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(45),
cout => N_36097,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(44),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(45),
cin => N_36095);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(44),
cout => N_36096,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(44),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(45),
cin => N_36094);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(43),
cout => N_36095,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(42),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(43),
cin => N_36093);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(42),
cout => N_36094,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(42),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(43),
cin => N_36092);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(41),
cout => N_36093,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(40),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(41),
cin => N_36091);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(40),
cout => N_36092,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(40),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(41),
cin => N_36090);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(39),
cout => N_36091,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(38),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(39),
cin => N_36089);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(38),
cout => N_36090,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(38),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(39),
cin => N_36088);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(37),
cout => N_36089,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(36),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(37),
cin => N_36087);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(36),
cout => N_36088,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(36),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(37),
cin => N_36086);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(35),
cout => N_36087,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(34),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(35),
cin => N_36085);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(34),
cout => N_36086,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(34),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(35),
cin => N_36084);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(33),
cout => N_36085,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(32),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(33),
cin => N_36083);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(32),
cout => N_36084,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(32),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(33),
cin => N_36082);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(31),
cout => N_36083,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(30),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(31),
cin => N_36081);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(30),
cout => N_36082,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(30),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(31),
cin => N_36080);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(29),
cout => N_36081,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(29),
cin => N_36079);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36080,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(29),
cin => N_36078);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36079,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(26),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(27),
cin => N_36077);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36078,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(26),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(27),
cin => N_36076);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36077,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(24),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(25),
cin => N_36075);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36076,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(24),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(25),
cin => N_36074);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36075,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(22),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(23),
cin => N_36073);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36074,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(22),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(23),
cin => N_36072);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36073,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(20),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(21),
cin => N_36071);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36072,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(20),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(21),
cin => N_36070);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36071,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(18),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(19),
cin => N_36069);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36070,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(18),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(19),
cin => N_36068);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36069,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(16),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(17),
cin => N_36067);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36068,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(16),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(17),
cin => N_36066);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36067,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(14),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(15),
cin => N_36065);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36066,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(14),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(15),
cin => N_36064);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36065,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(12),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(13),
cin => N_36063);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36064,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(12),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(13),
cin => N_36062);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36063,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(10),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(11),
cin => N_36061);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36062,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(10),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(11),
cin => N_36060);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36061,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(8),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(9),
cin => N_36059);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36060,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(8),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(9),
cin => N_36058);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36059,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(6),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(7),
cin => N_36057);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36058,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(6),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(7),
cin => N_36056);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36057,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(4),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(5),
cin => N_36055);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36056,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(4),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(5),
cin => N_36054);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36055,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(2),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(3),
cin => N_36052);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010000000")
port map (
cout => N_36054,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(2),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(3),
cin => N_36051);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_A_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_36051,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\);
\GRFPU0_GRFPU_X0_UN5_S3ADDO2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_36052,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD6\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => GND,
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_5\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datab => \GRFPU0.GRFPU_X0.ITADDI2_1\(5),
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_4\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011111001")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => \GRFPU0.GRFPU_X0.L4_6\(4),
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_3\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => \GRFPU0.GRFPU_X0.L4_6\(3),
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_2\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011111001")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
datab => \GRFPU0.GRFPU_X0.L4_6\(2),
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_1\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011001110001")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datab => \GRFPU0.GRFPU_X0.ITADDI2_1\(1),
cin => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_0\);
GRFPU0_GRFPU_X0_UN9_ITADDO_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011001110001")
port map (
combout => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN9_ITADDO_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
datab => \GRFPU0.GRFPU_X0.ITADDI2_1\(0),
cin => N_116626);
\GRFPU0_GRFPU_X0_UN1_INTO_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63),
cin => N_36045);
\GRFPU0_GRFPU_X0_UN1_INTO_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
dataa => \GRFPU0.GRFPU_X0.INTI1\(29),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2_0_X2\(30),
cin => N_36044);
\GRFPU0_GRFPU_X0_UN1_INTO_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
cout => N_36045,
dataa => \GRFPU0.GRFPU_X0.INTI1\(29),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2_0_X2\(30),
cin => N_36043);
\GRFPU0_GRFPU_X0_UN1_INTO_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
cout => N_36044,
dataa => \GRFPU0.GRFPU_X0.INTI1\(27),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(28),
cin => N_36042);
\GRFPU0_GRFPU_X0_UN1_INTO_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
cout => N_36043,
dataa => \GRFPU0.GRFPU_X0.INTI1\(27),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(28),
cin => N_36041);
\GRFPU0_GRFPU_X0_UN1_INTO_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
cout => N_36042,
dataa => \GRFPU0.GRFPU_X0.INTI1\(25),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(26),
cin => N_36040);
\GRFPU0_GRFPU_X0_UN1_INTO_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
cout => N_36041,
dataa => \GRFPU0.GRFPU_X0.INTI1\(25),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(26),
cin => N_36039);
\GRFPU0_GRFPU_X0_UN1_INTO_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
cout => N_36040,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(23),
datab => \GRFPU0.GRFPU_X0.INTI1\(24),
cin => N_36038);
\GRFPU0_GRFPU_X0_UN1_INTO_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
cout => N_36039,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(23),
datab => \GRFPU0.GRFPU_X0.INTI1\(24),
cin => N_36037);
\GRFPU0_GRFPU_X0_UN1_INTO_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
cout => N_36038,
dataa => \GRFPU0.GRFPU_X0.INTI1\(21),
datab => \GRFPU0.GRFPU_X0.INTI1\(22),
cin => N_36036);
\GRFPU0_GRFPU_X0_UN1_INTO_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
cout => N_36037,
dataa => \GRFPU0.GRFPU_X0.INTI1\(21),
datab => \GRFPU0.GRFPU_X0.INTI1\(22),
cin => N_36035);
\GRFPU0_GRFPU_X0_UN1_INTO_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
cout => N_36036,
dataa => \GRFPU0.GRFPU_X0.INTI1\(19),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(20),
cin => N_36034);
\GRFPU0_GRFPU_X0_UN1_INTO_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
cout => N_36035,
dataa => \GRFPU0.GRFPU_X0.INTI1\(19),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(20),
cin => N_36033);
\GRFPU0_GRFPU_X0_UN1_INTO_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
cout => N_36034,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(17),
datab => \GRFPU0.GRFPU_X0.INTI1\(18),
cin => N_36032);
\GRFPU0_GRFPU_X0_UN1_INTO_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
cout => N_36033,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(17),
datab => \GRFPU0.GRFPU_X0.INTI1\(18),
cin => N_36031);
\GRFPU0_GRFPU_X0_UN1_INTO_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
cout => N_36032,
dataa => \GRFPU0.GRFPU_X0.INTI1\(15),
datab => \GRFPU0.GRFPU_X0.INTI1\(16),
cin => N_36030);
\GRFPU0_GRFPU_X0_UN1_INTO_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
cout => N_36031,
dataa => \GRFPU0.GRFPU_X0.INTI1\(15),
datab => \GRFPU0.GRFPU_X0.INTI1\(16),
cin => N_36029);
\GRFPU0_GRFPU_X0_UN1_INTO_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
cout => N_36030,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(13),
datab => \GRFPU0.GRFPU_X0.INTI1\(14),
cin => N_36028);
\GRFPU0_GRFPU_X0_UN1_INTO_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
cout => N_36029,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(13),
datab => \GRFPU0.GRFPU_X0.INTI1\(14),
cin => N_36027);
\GRFPU0_GRFPU_X0_UN1_INTO_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
cout => N_36028,
dataa => \GRFPU0.GRFPU_X0.INTI1\(11),
datab => \GRFPU0.GRFPU_X0.INTI1\(12),
cin => N_36026);
\GRFPU0_GRFPU_X0_UN1_INTO_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
cout => N_36027,
dataa => \GRFPU0.GRFPU_X0.INTI1\(11),
datab => \GRFPU0.GRFPU_X0.INTI1\(12),
cin => N_36025);
\GRFPU0_GRFPU_X0_UN1_INTO_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
cout => N_36026,
dataa => \GRFPU0.GRFPU_X0.INTI1\(9),
datab => \GRFPU0.GRFPU_X0.INTI1\(10),
cin => N_36024);
\GRFPU0_GRFPU_X0_UN1_INTO_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
cout => N_36025,
dataa => \GRFPU0.GRFPU_X0.INTI1\(9),
datab => \GRFPU0.GRFPU_X0.INTI1\(10),
cin => N_36023);
\GRFPU0_GRFPU_X0_UN1_INTO_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
cout => N_36024,
dataa => \GRFPU0.GRFPU_X0.INTI1\(7),
datab => \GRFPU0.GRFPU_X0.INTI1\(8),
cin => N_36022);
\GRFPU0_GRFPU_X0_UN1_INTO_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
cout => N_36023,
dataa => \GRFPU0.GRFPU_X0.INTI1\(7),
datab => \GRFPU0.GRFPU_X0.INTI1\(8),
cin => N_36021);
\GRFPU0_GRFPU_X0_UN1_INTO_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
cout => N_36022,
dataa => \GRFPU0.GRFPU_X0.INTI1\(5),
datab => \GRFPU0.GRFPU_X0.INTI1\(6),
cin => N_36020);
\GRFPU0_GRFPU_X0_UN1_INTO_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
cout => N_36021,
dataa => \GRFPU0.GRFPU_X0.INTI1\(5),
datab => \GRFPU0.GRFPU_X0.INTI1\(6),
cin => N_36019);
\GRFPU0_GRFPU_X0_UN1_INTO_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
cout => N_36020,
dataa => \GRFPU0.GRFPU_X0.INTI1\(3),
datab => \GRFPU0.GRFPU_X0.INTI1\(4),
cin => N_36018);
\GRFPU0_GRFPU_X0_UN1_INTO_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
cout => N_36019,
dataa => \GRFPU0.GRFPU_X0.INTI1\(3),
datab => \GRFPU0.GRFPU_X0.INTI1\(4),
cin => N_36017);
\GRFPU0_GRFPU_X0_UN1_INTO_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
cout => N_36018,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(1),
datab => \GRFPU0.GRFPU_X0.INTI1\(2),
cin => N_36015);
\GRFPU0_GRFPU_X0_UN1_INTO_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
cout => N_36017,
dataa => \GRFPU0.GRFPU_X0.INTI1_0_X2\(1),
datab => \GRFPU0.GRFPU_X0.INTI1\(2),
cin => N_36014);
\GRFPU0_GRFPU_X0_UN1_INTO_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_36014,
dataa => \GRFPU0.GRFPU_X0.INTI2_1\(0),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(0));
\GRFPU0_GRFPU_X0_UN1_INTO_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
cout => N_36015,
dataa => \GRFPU0.GRFPU_X0.INTI2_1\(0),
datab => \GRFPU0.GRFPU_X0.INTI1_0_X2\(0));
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => GND,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.BIAS_4_0\(7),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.BIAS_4_0\(7),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.BIAS_4_0\(7),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010111111010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => VCC,
cin => N_116627);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011010010110")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD10\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(58),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(56),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53),
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.EXPDEC_1\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(52));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
cout => N_116628,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(50),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(51),
cin => N_35976);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
cout => N_116629,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(50),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(51),
cin => N_35975);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
cout => N_35976,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(48),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(49),
cin => N_35974);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
cout => N_35975,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(48),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(49),
cin => N_35973);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
cout => N_35974,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(46),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(47),
cin => N_35972);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
cout => N_35973,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(46),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(47),
cin => N_35971);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
cout => N_35972,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(44),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(45),
cin => N_35970);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
cout => N_35971,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(44),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(45),
cin => N_35969);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
cout => N_35970,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(42),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(43),
cin => N_35968);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
cout => N_35969,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(42),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(43),
cin => N_35967);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
cout => N_35968,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(40),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(41),
cin => N_35966);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
cout => N_35967,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(40),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(41),
cin => N_35965);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
cout => N_35966,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(38),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(39),
cin => N_35964);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
cout => N_35965,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(38),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(39),
cin => N_35963);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
cout => N_35964,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(36),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(37),
cin => N_35962);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
cout => N_35963,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(36),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(37),
cin => N_35961);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
cout => N_35962,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(34),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(35),
cin => N_35960);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
cout => N_35961,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(34),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(35),
cin => N_35959);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
cout => N_35960,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(32),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(33),
cin => N_35958);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
cout => N_35959,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(32),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(33),
cin => N_35957);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
cout => N_35958,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(30),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(31),
cin => N_35955);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
cout => N_35957,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(30),
datab => \GRFPU0.GRFPU_X0.S3ADDI\(31),
cin => N_35954);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_35954,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0\);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
cout => N_35955,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_2.M4_0\);
\GRFPU0_GRFPU_X0_UN6_SGNFX_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(51),
cin => N_35951);
\GRFPU0_GRFPU_X0_UN6_SGNFX_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
cout => N_116630,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(51),
cin => N_35950);
\GRFPU0_GRFPU_X0_UN6_SGNFX_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20),
cout => N_35951,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(49),
cin => N_35949);
\GRFPU0_GRFPU_X0_UN6_SGNFX_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
cout => N_35950,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(49),
cin => N_35948);
\GRFPU0_GRFPU_X0_UN6_SGNFX_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
cout => N_35949,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(47),
cin => N_35947);
\GRFPU0_GRFPU_X0_UN6_SGNFX_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
cout => N_35948,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(47),
cin => N_35946);
\GRFPU0_GRFPU_X0_UN6_SGNFX_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
cout => N_35947,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(45),
cin => N_35945);
\GRFPU0_GRFPU_X0_UN6_SGNFX_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
cout => N_35946,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(45),
cin => N_35944);
\GRFPU0_GRFPU_X0_UN6_SGNFX_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
cout => N_35945,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(43),
cin => N_35943);
\GRFPU0_GRFPU_X0_UN6_SGNFX_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
cout => N_35944,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(43),
cin => N_35942);
\GRFPU0_GRFPU_X0_UN6_SGNFX_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
cout => N_35943,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(41),
cin => N_35941);
\GRFPU0_GRFPU_X0_UN6_SGNFX_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
cout => N_35942,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(41),
cin => N_35940);
\GRFPU0_GRFPU_X0_UN6_SGNFX_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
cout => N_35941,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(39),
cin => N_35939);
\GRFPU0_GRFPU_X0_UN6_SGNFX_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
cout => N_35940,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(39),
cin => N_35938);
\GRFPU0_GRFPU_X0_UN6_SGNFX_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
cout => N_35939,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(37),
cin => N_35937);
\GRFPU0_GRFPU_X0_UN6_SGNFX_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
cout => N_35938,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(37),
cin => N_35936);
\GRFPU0_GRFPU_X0_UN6_SGNFX_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
cout => N_35937,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(35),
cin => N_35935);
\GRFPU0_GRFPU_X0_UN6_SGNFX_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5),
cout => N_35936,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(35),
cin => N_35934);
\GRFPU0_GRFPU_X0_UN6_SGNFX_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
cout => N_35935,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(33),
cin => N_35933);
\GRFPU0_GRFPU_X0_UN6_SGNFX_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
cout => N_35934,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(33),
cin => N_35932);
\GRFPU0_GRFPU_X0_UN6_SGNFX_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2),
cout => N_35933,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(31),
cin => N_35930);
\GRFPU0_GRFPU_X0_UN6_SGNFX_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1),
cout => N_35932,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(31),
cin => N_35929);
\GRFPU0_GRFPU_X0_UN6_SGNFX_A_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_35929,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4\);
\GRFPU0_GRFPU_X0_UN6_SGNFX_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0),
cout => N_35930,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC_1.M4\);
\GRFPU0_GRFPU_X0_UN8_DIFF2_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001110010011100")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(53),
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD51\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD52\,
cin => N_35926);
\GRFPU0_GRFPU_X0_UN8_DIFF2_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD51\,
datab => GND,
cin => N_35925);
\GRFPU0_GRFPU_X0_UN8_DIFF2_51_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
cout => N_35926,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD49\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD50\,
cin => N_35924);
\GRFPU0_GRFPU_X0_UN8_DIFF2_50_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
cout => N_35925,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD49\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD50\,
cin => N_35923);
\GRFPU0_GRFPU_X0_UN8_DIFF2_49_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
cout => N_35924,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD47\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD48\,
cin => N_35922);
\GRFPU0_GRFPU_X0_UN8_DIFF2_48_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
cout => N_35923,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD47\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD48\,
cin => N_35921);
\GRFPU0_GRFPU_X0_UN8_DIFF2_47_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
cout => N_35922,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD45\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD46\,
cin => N_35920);
\GRFPU0_GRFPU_X0_UN8_DIFF2_46_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
cout => N_35921,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD45\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD46\,
cin => N_35919);
\GRFPU0_GRFPU_X0_UN8_DIFF2_45_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
cout => N_35920,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD43\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD44\,
cin => N_35918);
\GRFPU0_GRFPU_X0_UN8_DIFF2_44_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
cout => N_35919,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD43\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD44\,
cin => N_35917);
\GRFPU0_GRFPU_X0_UN8_DIFF2_43_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
cout => N_35918,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD41\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD42\,
cin => N_35916);
\GRFPU0_GRFPU_X0_UN8_DIFF2_42_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
cout => N_35917,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD41\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD42\,
cin => N_35915);
\GRFPU0_GRFPU_X0_UN8_DIFF2_41_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
cout => N_35916,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD39\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD40\,
cin => N_35914);
\GRFPU0_GRFPU_X0_UN8_DIFF2_40_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
cout => N_35915,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD39\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD40\,
cin => N_35913);
\GRFPU0_GRFPU_X0_UN8_DIFF2_39_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
cout => N_35914,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD37\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD38\,
cin => N_35912);
\GRFPU0_GRFPU_X0_UN8_DIFF2_38_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
cout => N_35913,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD37\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD38\,
cin => N_35911);
\GRFPU0_GRFPU_X0_UN8_DIFF2_37_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
cout => N_35912,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD35\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD36\,
cin => N_35910);
\GRFPU0_GRFPU_X0_UN8_DIFF2_36_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
cout => N_35911,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD35\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD36\,
cin => N_35909);
\GRFPU0_GRFPU_X0_UN8_DIFF2_35_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
cout => N_35910,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD33\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD34\,
cin => N_35908);
\GRFPU0_GRFPU_X0_UN8_DIFF2_34_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
cout => N_35909,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD33\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD34\,
cin => N_35907);
\GRFPU0_GRFPU_X0_UN8_DIFF2_33_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
cout => N_35908,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD31\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD32\,
cin => N_35906);
\GRFPU0_GRFPU_X0_UN8_DIFF2_32_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
cout => N_35907,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD31\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD32\,
cin => N_35905);
\GRFPU0_GRFPU_X0_UN8_DIFF2_31_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
cout => N_35906,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD29\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD30\,
cin => N_35904);
\GRFPU0_GRFPU_X0_UN8_DIFF2_30_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
cout => N_35905,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD29\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD30\,
cin => N_35903);
\GRFPU0_GRFPU_X0_UN8_DIFF2_29_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
cout => N_35904,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD27\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD28\,
cin => N_35902);
\GRFPU0_GRFPU_X0_UN8_DIFF2_28_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(28),
cout => N_35903,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD27\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD28\,
cin => N_35901);
\GRFPU0_GRFPU_X0_UN8_DIFF2_27_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(27),
cout => N_35902,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD25\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD26\,
cin => N_35900);
\GRFPU0_GRFPU_X0_UN8_DIFF2_26_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
cout => N_35901,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD25\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD26\,
cin => N_35899);
\GRFPU0_GRFPU_X0_UN8_DIFF2_25_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
cout => N_35900,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD23\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD24\,
cin => N_35898);
\GRFPU0_GRFPU_X0_UN8_DIFF2_24_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
cout => N_35899,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD23\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD24\,
cin => N_35897);
\GRFPU0_GRFPU_X0_UN8_DIFF2_23_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
cout => N_35898,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD21\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD22\,
cin => N_35896);
\GRFPU0_GRFPU_X0_UN8_DIFF2_22_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
cout => N_35897,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD21\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD22\,
cin => N_35895);
\GRFPU0_GRFPU_X0_UN8_DIFF2_21_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
cout => N_35896,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD19\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD20\,
cin => N_35894);
\GRFPU0_GRFPU_X0_UN8_DIFF2_20_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
cout => N_35895,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD19\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD20\,
cin => N_35893);
\GRFPU0_GRFPU_X0_UN8_DIFF2_19_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
cout => N_35894,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD17\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD18\,
cin => N_35892);
\GRFPU0_GRFPU_X0_UN8_DIFF2_18_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
cout => N_35893,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD17\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD18\,
cin => N_35891);
\GRFPU0_GRFPU_X0_UN8_DIFF2_17_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
cout => N_35892,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD15\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD16\,
cin => N_35890);
\GRFPU0_GRFPU_X0_UN8_DIFF2_16_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
cout => N_35891,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD15\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD16\,
cin => N_35889);
\GRFPU0_GRFPU_X0_UN8_DIFF2_15_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
cout => N_35890,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD13\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD14\,
cin => N_35888);
\GRFPU0_GRFPU_X0_UN8_DIFF2_14_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
cout => N_35889,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD13\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD14\,
cin => N_35887);
\GRFPU0_GRFPU_X0_UN8_DIFF2_13_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
cout => N_35888,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD11\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD12\,
cin => N_35886);
\GRFPU0_GRFPU_X0_UN8_DIFF2_12_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
cout => N_35887,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD11\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD12\,
cin => N_35885);
\GRFPU0_GRFPU_X0_UN8_DIFF2_11_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
cout => N_35886,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD9\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD10\,
cin => N_35884);
\GRFPU0_GRFPU_X0_UN8_DIFF2_10_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
cout => N_35885,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD9\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD10\,
cin => N_35883);
\GRFPU0_GRFPU_X0_UN8_DIFF2_9_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
cout => N_35884,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD7\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD8\,
cin => N_35882);
\GRFPU0_GRFPU_X0_UN8_DIFF2_8_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
cout => N_35883,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD7\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD8\,
cin => N_35881);
\GRFPU0_GRFPU_X0_UN8_DIFF2_7_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
cout => N_35882,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD5\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD6\,
cin => N_35880);
\GRFPU0_GRFPU_X0_UN8_DIFF2_6_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
cout => N_35881,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD5\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD6\,
cin => N_35879);
\GRFPU0_GRFPU_X0_UN8_DIFF2_5_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
cout => N_35880,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD3\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD4\,
cin => N_35878);
\GRFPU0_GRFPU_X0_UN8_DIFF2_4_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
cout => N_35879,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD3\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD4\,
cin => N_35877);
\GRFPU0_GRFPU_X0_UN8_DIFF2_3_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110001100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
cout => N_35878,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD1\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD2\,
cin => N_35876);
\GRFPU0_GRFPU_X0_UN8_DIFF2_2_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010100010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
cout => N_35877,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD1\,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD2\,
cin => N_35875);
\GRFPU0_GRFPU_X0_UN8_DIFF2_1_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
cout => N_35876,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD0\,
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0));
\GRFPU0_GRFPU_X0_UN8_DIFF2_0_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000000100010")
port map (
cout => N_35875,
dataa => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD0\,
datab => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_62_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(62),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => GND,
cin => N_82060);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1100001111000011")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(59),
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
cin => N_35843);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011111100")
port map (
cout => N_35844,
dataa => GND,
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
cin => N_35842);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_57_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000101011110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(57),
cout => N_35843,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => GND,
cin => N_35841);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_56_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101011110101")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(56),
cout => N_35842,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => GND,
cin => N_35840);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_55_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101100111110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(55),
cout => N_35841,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
cin => N_35839);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_54_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(54),
cout => N_35840,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
cin => N_35838);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_53_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100101110111")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(53),
cout => N_35839,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_33_52_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001110111")
port map (
cout => N_35838,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1010010110100101")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD55\,
dataa => \GRFPU0.GRFPU_X0.ST2.ADD\,
datab => GND,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011111001")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD54\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\,
dataa => \GRFPU0.GRFPU_X0.ST2.ADD\,
datab => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD53\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(53),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD52\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(52),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD51\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(51),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD50\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(50),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD49\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(49),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD48\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(48),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD47\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(47),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD46\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(46),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD45\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(45),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD44\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(44),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD43\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(43),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD42\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(42),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD41\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(41),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD40\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(40),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD39\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(39),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD38\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(38),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD37\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(37),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD36\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(36),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD35\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(35),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD34\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(34),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD33\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(33),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD32\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(32),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD31\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(31),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD30\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(30),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD29\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(29),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD28\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(28),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD27\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(27),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD26\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(26),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD25\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(25),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD24\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(24),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD23\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(23),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD22\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(22),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD21\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(21),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD20\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(20),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD19\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(19),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD18\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(18),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD17\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(17),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD16\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(16),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD15\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(15),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD14\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(14),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD13\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(13),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD12\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(12),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD11\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(11),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD10\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(10),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD9\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(9),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD8\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(8),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD7\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(7),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD6\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(6),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD5\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(5),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD4\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(4),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD3\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(3),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110110010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD2\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(2),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD1\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.ADD\,
datab => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100100100010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD0\,
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.STICKYI_1_1\,
datab => \GRFPU0.GRFPU_X0.ADDSUBI2_1\(0));
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(121),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010100000")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD51\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD50\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD49\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD48\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD47\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD46\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD45\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD44\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD43\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD42\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD41\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD40\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD39\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD38\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD37\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD36\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD35\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD34\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD33\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD32\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD31\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD30\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => \GRFPU0.FPMUL0.CSADD.UN335_C1\,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD29\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\,
dataa => \GRFPU0.FPMUL0.CS_DP_R\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD28\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD27\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD26\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD25\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD24\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD23\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD22\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD21\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD20\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD19\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD18\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD17\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD16\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD15\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD14\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD13\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD12\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD11\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD10\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(78),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD9\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(77),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD8\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(76),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD7\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(75),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD6\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(74),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD5\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(73),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD4\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(72),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD3\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(71),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD2\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(70),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM1_I_ADD1\,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(69),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\);
GRFPU0_FPMUL0_UN2_MSUM1_I_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(68),
datab => \GRFPU0.FPMUL0.CS_DP_R\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(121),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_54\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010100000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_53\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD53\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_52\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD52\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_51\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD51\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_50\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD50\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_49\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD49\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_48\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD48\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_47\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD47\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_46\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD46\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_45\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD45\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_44\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD44\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_43\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD43\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_42\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD42\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_41\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD41\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_40\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD40\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_39\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD39\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_38\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD38\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_37\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD37\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_36\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD36\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_35\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD35\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_34\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD34\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_33\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD33\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_32\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD32\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => \GRFPU0.FPMUL0.CSADD.UN335_C1\,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_31\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD31\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_31\,
dataa => \GRFPU0.FPMUL0.CS_DP_R\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_30\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD30\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_29\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD29\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_28\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD28\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD27\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD26\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD25\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD24\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD23\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD22\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD21\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD20\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD19\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD18\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD17\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD16\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD15\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_2_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_2_ADD14\,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => GND,
cin => N_116631);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIH7LI9_121_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.MULO.MRES_BUF\(121),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(121),
datab => GND,
cin => N_35830);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIB0DV8_119_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.MULO.MRES_BUF\(120),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
cin => N_35829);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIQC079_119_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(119),
cout => N_35830,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
cin => N_35828);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIPE388_118_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(118),
cout => N_35829,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
cin => N_35827);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8RMF8_118_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(117),
cout => N_35828,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
cin => N_35826);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI41QG7_115_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(116),
cout => N_35827,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
cin => N_35825);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJDDO7_115_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(115),
cout => N_35826,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
cin => N_35824);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJJGP6_113_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(114),
cout => N_35825,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
cin => N_35823);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI20417_113_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(113),
cout => N_35824,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
cin => N_35822);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI66726_111_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(112),
cout => N_35823,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
cin => N_35821);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNILIQ96_111_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(111),
cout => N_35822,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
cin => N_35820);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITOTA5_109_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(110),
cout => N_35821,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
cin => N_35819);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIC5HI5_109_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(109),
cout => N_35820,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
cin => N_35818);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHFKJ4_107_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(108),
cout => N_35819,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
cin => N_35817);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0S7R4_107_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(107),
cout => N_35818,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
cin => N_35816);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2ABS3_105_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(106),
cout => N_35817,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
cin => N_35815);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHMU34_105_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(105),
cout => N_35816,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
cin => N_35814);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIN4253_103_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(104),
cout => N_35815,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
cin => N_35813);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6HLC3_103_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(103),
cout => N_35814,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
cin => N_35812);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGVOD2_101_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(102),
cout => N_35813,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
cin => N_35811);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVBCL2_101_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(101),
cout => N_35812,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
cin => N_35810);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDQFM1_99_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(100),
cout => N_35811,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
cin => N_35809);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIS63U1_99_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(99),
cout => N_35810,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
cin => N_35808);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIIB171_97_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(98),
cout => N_35809,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
cin => N_35807);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1OKE1_97_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(97),
cout => N_35808,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
cin => N_35806);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVUDV_95_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(96),
cout => N_35807,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
cin => N_35805);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIEB171_95_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(95),
cout => N_35806,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
cin => N_35804);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIG2RN_93_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(94),
cout => N_35805,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
cin => N_35803);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVEEV_93_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(93),
cout => N_35804,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
cin => N_35802);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5M8G_91_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(92),
cout => N_35803,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
cin => N_35801);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIK2SN_91_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(91),
cout => N_35802,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
cin => N_35800);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIUPM8_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.MRES\(90),
cout => N_35801,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
cin => N_116632);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNID6AG_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(89),
cout => N_35800,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
cin => N_35798);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1IN8_87_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.MRES\(87),
cout => N_35798,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
cin => N_116633);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD78: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110000111100")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD78\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD77\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD76: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD76\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD75: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD75\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD74: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD74\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD73: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD73\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD72: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD72\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD71\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD70: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD70\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD69: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD69\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD68: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD68\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD67: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD67\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD66: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD66\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD65\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD64\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD63\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD62\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD61\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU_ML\(0));
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD78: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110000111100")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD78\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_77\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD77\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_77\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_76\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD76: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD76\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_76\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_75\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD75: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD75\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_75\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_74\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD74: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD74\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_74\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_73\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD73: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD73\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_73\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD72: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD72\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_72\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD71\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_71\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD70: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD70\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_70\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD69: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD69\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_69\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD68: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD68\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_68\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD67: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD67\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_67\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD66: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD66\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_66\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD65\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_65\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD64\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_64\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD63\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_63\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD62\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_62\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD61\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_61\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_A_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_MU_ML\(0));
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_15_RNO: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110000111100")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_77\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_77\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_76\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD76: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_76\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_75\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD75: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_75\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_74\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD74: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_74\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_73\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD73: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_73\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD72: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_72\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD71\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_71\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD70: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD70\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_70\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD69: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD69\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_69\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD68: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD68\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_68\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD67: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD67\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_67\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD66: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD66\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_66\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD65\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_65\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD64\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_64\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD63\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_63\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD62\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_62\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD61\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_61\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_ML_A_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_MU_ML\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNO_59_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.MULO.DRES_S\(118),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
datab => GND,
cin => N_35767);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNO_58_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110001101100")
port map (
combout => \GRFPU0.MULO.DRES_S\(117),
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
cin => N_35766);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAD01B_116_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(116),
cout => N_35767,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
cin => N_35765);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINVM9A_0_114_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(115),
cout => N_35766,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
cin => N_35764);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINVM9A_114_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(114),
cout => N_35765,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
cin => N_35763);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8IDI9_112_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(113),
cout => N_35764,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
cin => N_35762);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8IDI9_0_112_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(112),
cout => N_35763,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
cin => N_35761);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIT44R8_110_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(111),
cout => N_35762,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
cin => N_35760);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIT44R8_0_110_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(110),
cout => N_35761,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
cin => N_35759);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMNQ38_108_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(109),
cout => N_35760,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
cin => N_35758);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMNQ38_0_108_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(108),
cout => N_35759,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
cin => N_35757);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5IHC7_106_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(107),
cout => N_35758,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
cin => N_35756);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5IHC7_0_106_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(106),
cout => N_35757,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
cin => N_35755);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOC8L6_104_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(105),
cout => N_35756,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
cin => N_35754);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOC8L6_0_104_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(104),
cout => N_35755,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
cin => N_35753);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIF7VT5_0_102_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(103),
cout => N_35754,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
cin => N_35752);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIF7VT5_102_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(102),
cout => N_35753,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
cin => N_35751);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIA2M65_100_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(101),
cout => N_35752,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
cin => N_35750);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIA2M65_0_100_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(100),
cout => N_35751,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
cin => N_35749);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9TCF4_0_99_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(99),
cout => N_35750,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
cin => N_35748);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9TCF4_99_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(98),
cout => N_35749,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
cin => N_35747);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIK8P74_0_96_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(97),
cout => N_35748,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
cin => N_35746);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIK8P74_96_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(96),
cout => N_35747,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
cin => N_35745);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI34604_94_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(95),
cout => N_35746,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
cin => N_35744);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI34604_0_94_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(94),
cout => N_35745,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
cin => N_35743);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMFJO3_0_92_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(93),
cout => N_35744,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
cin => N_35742);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMFJO3_92_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(92),
cout => N_35743,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
cin => N_35741);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDB1H3_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(91),
cout => N_35742,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
cin => N_35740);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDB1H3_0_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(90),
cout => N_35741,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
cin => N_35739);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8NF93_88_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(89),
cout => N_35740,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
cin => N_35738);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8NF93_0_88_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(88),
cout => N_35739,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
cin => N_35737);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIL2S13_86_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(87),
cout => N_35738,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
cin => N_35736);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIL2S13_0_86_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(86),
cout => N_35737,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
cin => N_35735);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6U8Q2_84_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(85),
cout => N_35736,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
cin => N_35734);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6U8Q2_0_84_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(84),
cout => N_35735,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
cin => N_35733);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIR9MI2_0_82_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(83),
cout => N_35734,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
cin => N_35732);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIR9MI2_82_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(82),
cout => N_35733,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
cin => N_35731);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIK54B2_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(81),
cout => N_35732,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
cin => N_35730);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIK54B2_0_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(80),
cout => N_35731,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
cin => N_35729);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHHI32_78_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(79),
cout => N_35730,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(78),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
cin => N_35728);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHHI32_0_78_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(78),
cout => N_35729,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(78),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
cin => N_35727);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0TUR1_0_76_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(77),
cout => N_35728,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(76),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(77),
cin => N_35726);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0TUR1_76_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(76),
cout => N_35727,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(76),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(77),
cin => N_35725);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJOBK1_74_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(75),
cout => N_35726,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(74),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(75),
cin => N_35724);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJOBK1_0_74_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(74),
cout => N_35725,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(74),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(75),
cin => N_35723);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIA4PC1_72_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(73),
cout => N_35724,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(72),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(73),
cin => N_35722);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIA4PC1_0_72_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(72),
cout => N_35723,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(72),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(73),
cin => N_35721);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI50751_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(71),
cout => N_35722,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(70),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(71),
cin => N_35720);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI50751_0_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(70),
cout => N_35721,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(70),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(71),
cin => N_35719);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI4CLT_0_68_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(69),
cout => N_35720,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(68),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(69),
cin => N_35718);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI4CLT_68_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(68),
cout => N_35719,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(68),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(69),
cin => N_35717);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNILN1M_0_66_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110110010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(67),
cout => N_35718,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(66),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(67),
cin => N_35715);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNILN1M_66_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010000000")
port map (
combout => \GRFPU0.MULO.DRES_S\(66),
cout => N_35717,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(66),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(67),
cin => N_35714);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RNIAJEE: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_35714,
dataa => \GRFPU0.FPMUL0.CS_ITER_R_0_0\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65));
GRFPU0_FPMUL0_CS_ITER_R_0_0_RNIAJEE_0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010001000")
port map (
cout => N_35715,
dataa => \GRFPU0.FPMUL0.CS_ITER_R_0_0\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINTFGA_120_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_54\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI13R4A_119_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000010100000")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_53\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5C6P9_118_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD53\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_52\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIALHD9_117_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD52\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_51\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGUS19_116_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD51\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_50\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIN78M8_115_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD50\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_49\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVGJA8_114_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD49\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_48\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8QUU7_113_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD48\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_47\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNII3AJ7_112_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD47\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_46\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITCL77_111_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD46\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_45\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9M0S6_110_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD45\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_44\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMVBG6_109_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD44\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_43\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITCN46_108_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD43\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_42\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5Q2P5_107_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD42\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_41\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIE7ED5_106_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD41\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_40\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOKP15_105_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD40\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_39\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI325M4_104_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD39\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_38\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIFFGA4_103_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD38\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_37\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISSRU3_102_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD37\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_36\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAA7J3_101_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD36\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_35\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIPNI73_100_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD35\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_34\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI95UR2_99_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD34\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_33\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIU84O2_98_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD33\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_32\);
GRFPU0_FPMUL0_CSADD_UN332_C2_RNIKGAK2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD32\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
datab => \GRFPU0.FPMUL0.CSADD.UN332_C2\,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_31\);
GRFPU0_FPMUL0_CS_DP_R_RNI3TIF2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD31\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_31\,
dataa => \GRFPU0.FPMUL0.CS_DP_R\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_30\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNID9GA2_95_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD30\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_29\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6TM62_94_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD29\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_28\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0LT22_93_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD28\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIRG4V1_92_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD27\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINGBR1_91_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD26\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIKKIN1_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD25\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIISPJ1_89_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD24\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI800G1_88_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD23\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIV76C1_87_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD22\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINJC81_86_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD21\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIG3J41_85_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD20\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIANP01_84_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD19\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5F0T_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD18\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1B7P_82_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD17\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIUAEL_81_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD16\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISELH_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD15\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => GND,
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIRMSD_79_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN1_SIN_3_ADD14\,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
datab => GND,
cin => N_116634);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAJ9QB_120_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101001011010")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIKOKEB_119_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD50\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIO103B_118_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD49\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITABNA_117_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD48\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI3KMBA_116_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD47\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAT10A_115_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD46\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNII6DK9_114_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD45\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIRFO89_113_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD44\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5P3T8_112_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD43\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIG2FH8_111_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD42\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISBQ58_110_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD41\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9L5Q7_109_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD40\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIG2HE7_108_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD39\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOFS27_107_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD38\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1T7N6_106_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD37\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIBAJB6_105_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD36\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMNUV5_104_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD35\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI25AK5_103_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD34\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIFIL85_102_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD33\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITV0T4_101_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD32\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNICDCH4_100_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD31\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\);
GRFPU0_FPMUL0_CSADD_UN303_MC2_RNISQN54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD30\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
datab => \GRFPU0.FPMUL0.CSADD.UN303_MC2\,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\);
GRFPU0_FPMUL0_CS_DP_R_RNIUN9K3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110100110010000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD29\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\,
dataa => \GRFPU0.FPMUL0.CS_DP_R\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6S6F3_97_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD28\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIT7DB3_96_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD27\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNILNJ73_95_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD26\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIEBQ33_94_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD25\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI83103_93_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD24\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI3V7S2_92_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD23\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVUEO2_91_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD22\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIS2MK2_90_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD21\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIQATG2_89_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD20\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGE3D2_88_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD19\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI7M992_87_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD18\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIV1G52_86_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD17\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOHM12_85_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD16\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNII5TT1_84_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD15\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDT3Q1_83_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD14\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9PAM1_82_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD13\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6PHI1_81_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD12\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI4TOE1_80_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD11\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI350B1_79_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD10\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIQ8671_78_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD9\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(78),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIIGC31_77_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD8\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(77),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIBSIV_76_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD7\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(76),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5CPR_75_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD6\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(75),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI000O_74_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD5\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(74),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISN6K_73_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD4\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(73),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIPJDG_72_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD3\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(72),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINJKC_71_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD2\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(71),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMNR8_70_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0101101010100000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD1\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(70),
datab => GND,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMV25_69_\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.UN2_MSUM2_I_ADD0\,
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(69),
datab => \GRFPU0.FPMUL0.CS_DP_R\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD73: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73\,
cout => N_116635,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD72: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_72\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_71\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD71\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD70: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_70\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD70\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD69: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_69\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD69\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD68: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_68\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD68\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD67: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_67\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD67\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD66: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_66\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD66\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_65\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD65\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_64\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD64\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_63\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD63\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_62\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD62\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_61\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD61\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD60\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD59\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD58\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD57\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD56\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD55\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD54\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD71\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD53\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD70\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD52\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD69\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD51\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD68\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD50\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD67\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD49\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD66\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD48\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD65\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD64\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD46\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD63\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD45\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD62\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD44\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD61\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD43\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD60\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD42\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD59\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD41\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD58\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD40\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD57\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD39\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD56\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD38\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD55\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD37\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD54\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD36\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD71\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD53\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD70\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD52\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD69\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD51\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD68\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD50\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD67\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD49\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD66\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD48\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD65\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD64\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD46\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD63\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD45\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD62\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD44\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD61\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD43\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD60\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD42\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD59\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD41\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD58\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD40\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD57\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD39\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD56\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD38\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD55\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD37\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_1_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD54\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD78: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD78\,
cout => N_116636,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_77\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD77: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD77\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_77\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_76\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD76: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD76\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_76\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_75\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD75: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD75\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_75\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_74\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD74: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD74\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_74\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_73\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD73: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD73\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_73\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD72: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD72\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_72\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD71: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD71\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_71\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD70: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD70\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_70\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD69: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD69\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_69\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD68: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD68\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_68\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD67: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD67\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_67\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD66: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD66\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_66\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD65: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD65\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_65\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD64: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD64\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_64\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD63\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_63\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD62\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_62\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD61\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_61\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD35\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD34\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD33\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD32\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD31\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD30\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD29\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD28\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD27\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD26\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD25\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD24\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD23\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD22\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD21\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD20\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD19\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD18\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD35\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD34\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD33\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD32\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD31\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD30\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD29\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD28\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD27\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD26\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD25\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD24\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD23\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD22\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD21\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD20\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD19\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD18\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD17\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD35\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD16\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD34\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD15\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD33\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD14\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD32\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD13\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD31\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD12\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD30\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD11\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD29\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD10\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD28\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD9\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD27\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD8\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD26\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD7\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD25\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD6\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD24\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD5\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD23\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD4\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD22\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD3\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD21\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD2\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD20\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD1\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD19\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD0\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD12\,
cout => N_116637,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD48\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD48\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD11\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD47\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD10\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD46\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD46\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD9\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD45\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD45\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD8\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD44\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD44\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD7\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD43\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD43\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD6\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD42\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD42\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD5\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD41\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD41\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD4\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD40\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD40\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD3\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD39\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD39\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD2\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD38\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD38\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD1\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD37\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD37\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD0\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD36\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61\,
cout => N_116638,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_60\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD78\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD78\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_59\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD77\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD77\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_58\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD76\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD76\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_57\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD75\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD75\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_56\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD74\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD74\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_55\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD73\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD73\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_54\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML_A_ADD72\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD72\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_53\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD71\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_52\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD70\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_51\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD69\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_50\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD68\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_49\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD67\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD48\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_48\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD66\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD47\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_47\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD65\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD46\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_46\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD64\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD45\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_45\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD63\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD44\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_44\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD62\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0011110011000000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD43\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_43\,
dataa => GND,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD61\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD42\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_42\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD78\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD60\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD41\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_41\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD77\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD59\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD40\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_40\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD76\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD58\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD39\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_39\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD75\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD57\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD38\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_38\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD74\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD56\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD37\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_37\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD73\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD55\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD36\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_36\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD72\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD54\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD35\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_35\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD35\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD53\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD34\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_34\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD34\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD52\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD33\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_33\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD33\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD51\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD32\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_32\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD32\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD50\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD31\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_31\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD31\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD49\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD30\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_30\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD30\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD48\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD29\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_29\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD29\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD28\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_28\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD28\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD46\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD27\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_27\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD27\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD45\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD26\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_26\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD26\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD44\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD25\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_25\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD25\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD43\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD24\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_24\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD24\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD42\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD23\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_23\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD23\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD41\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD22\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_22\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD22\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD40\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD21\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_21\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD21\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD39\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD20\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_20\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD20\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD38\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD19\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_19\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD19\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD37\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD18\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_18\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD18\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD36\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD17\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_17\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD53\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD35\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD16\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_16\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD52\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD34\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD15\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_15\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD51\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD33\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD14\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_14\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD50\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD32\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD13\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_13\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD49\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD31\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD12\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_12\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD48\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD30\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD11\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_11\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD47\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD29\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD10\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_10\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD46\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD28\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD9\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_9\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD45\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD27\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD8\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_8\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD44\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD26\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD7\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_7\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD43\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD25\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD6\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_6\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD42\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD24\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD5\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_5\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD41\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD23\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD4\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_4\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD40\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD22\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD3\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_3\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD39\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD21\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD2\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_2\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD38\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD20\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001011011101000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD1\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_1\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD37\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD19\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_2_ADD0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0110011010001000")
port map (
combout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD0\,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_CARRY_0\,
dataa => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_ADD36\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD18\);
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101010111")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001111111101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011110000111101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_0_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110110011001101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_3\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101011111111010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011110101010000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110100101011010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_1_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001100110011001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_2_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101100101011")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_2_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010000101111010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_2_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_2_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010011011010011")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_2_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_3_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000101010101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_3_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010010101010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_3_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111000000001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_3_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_3_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000011000011110")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_3_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_4_6__ROM_3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000010101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_3\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_4_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111101010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_4_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0101010101101010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_4_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111100001111000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_4_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_4_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001100110011001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_4_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_SQRTROM0_DATA_1_5_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1011111111000000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_5_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_5_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0100101111000011")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_5_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_6_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111010101010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_6_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111010101010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_6_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1101010000001010")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_6_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001010010100101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_7_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_7_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0010101011111101")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_7_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_SQRTROM0_DATA_1_7_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000010110101001")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_7_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111111111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111000011111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_0_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1010101010101011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_3\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000100000001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_3\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011111111100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000111100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001100111001100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_1_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110101001010100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_4\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000011111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_4\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111111100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000001111100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110011100011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_2_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110110100101101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000100010001000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100011111000111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111000111000111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_3_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001001001001001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_4_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111111100000011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_4_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_4_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1000011100011100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_4_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_4_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001101101100100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_4_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_5_6__ROM_5\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011100000111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_5\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_5_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100011111000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_5_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111111000000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_5_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000111000011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_5_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_5_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011011001101")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_5_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_6_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111111100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_6_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000111100001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_6_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0110011001100110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_DIVROM0_DATA_1_7_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111111100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_7_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_7_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100000111100001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_7_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_7_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100011001100110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_7_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_8_6__ROM_2\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000001111111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_2\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_8_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111110000000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_8_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011110000011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_8_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_8_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011100110001100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_8_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_9_6__ROM_4\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111100011111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_4\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_9_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1110000011100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_9_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111110000011111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_9_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_9_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1001110011100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_9_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_10_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110001100011")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_10_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_11_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011111111111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_11_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_11_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111100000011111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_11_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_11_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011100011100111")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_11_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_12_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0011111100000001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_12_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_12_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1100011100001110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_12_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_13_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000011111100000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_13_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_13_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0111100011100001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_13_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_14_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "1111111011111110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_14_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_14_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111000011110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_14_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_14_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001110000111100")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_14_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_15_6__ROM_1\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000000000001")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_15_6__ROM_1\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_15_6__ROM_0\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0000000111111110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_15_6__ROM_0\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_15_6_0__ROM\: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "datac",
    lut_mask => "0001111000011110")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_15_6_0__ROM\,
dataa => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2));
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1101010011010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT4\,
cout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.N_5\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(4),
datab => \GRFPC0.RFA2.FID\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(3),
datab => \GRFPC0.RFA2.FID\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(2),
datab => \GRFPC0.RFA2.FID\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(1),
datab => \GRFPC0.RFA2.FID\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.LT_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.IDCST\(0),
datab => \GRFPC0.RFA2.FID\(0));
GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.N_5\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(4),
datab => \GRFPC0.RFA2.FID\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_3\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(3),
datab => \GRFPC0.RFA2.FID\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(2),
datab => \GRFPC0.RFA2.FID\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_1\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(1),
datab => \GRFPC0.RFA2.FID\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.LT_0\,
dataa => \GRFPU0.GRFPU_X0.ST3.IDCST\(0),
datab => \GRFPC0.RFA2.FID\(0));
GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1101010011010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT4\,
dataa => \GRFPU0.GRFPU_X0.ST2.IDCST\(4),
datab => \GRFPC0.RFA2.FID\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_3\,
dataa => \GRFPU0.GRFPU_X0.ST2.IDCST\(3),
datab => \GRFPC0.RFA2.FID\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_2\,
dataa => \GRFPU0.GRFPU_X0.ST2.IDCST\(2),
datab => \GRFPC0.RFA2.FID\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_1\,
dataa => \GRFPU0.GRFPU_X0.ST2.IDCST\(1),
datab => \GRFPC0.RFA2.FID\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.LT_0\,
dataa => \GRFPU0.GRFPU_X0.ST2.IDCST\(0),
datab => \GRFPC0.RFA2.FID\(0));
GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1101010011010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT4\,
dataa => \GRFPU0.GRFPU_X0.ST1.IDCST\(4),
datab => \GRFPC0.RFA2.FID\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_3\,
dataa => \GRFPU0.GRFPU_X0.ST1.IDCST\(3),
datab => \GRFPC0.RFA2.FID\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_2\,
dataa => \GRFPU0.GRFPU_X0.ST1.IDCST\(2),
datab => \GRFPC0.RFA2.FID\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.IDCST\(1),
datab => \GRFPC0.RFA2.FID\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.LT_0\,
dataa => \GRFPU0.GRFPU_X0.ST1.IDCST\(0),
datab => \GRFPC0.RFA2.FID\(0));
GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.N_5\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD4\,
datab => \GRFPC0.RFA2.FID\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_3\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD3\,
datab => \GRFPC0.RFA2.FID\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_2\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD2\,
datab => \GRFPC0.RFA2.FID\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_1\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD1\,
datab => \GRFPC0.RFA2.FID\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.LT_0\,
dataa => \GRFPC0.VEX.CTRL.ID_2_ADD0\,
datab => \GRFPC0.RFA2.FID\(0));
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.N_6\,
dataa => \GRFPU0.GRFPU_X0.L3_2_0_A2\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_4\);
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_4\,
dataa => \GRFPU0.GRFPU_X0.L4_3\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_3\);
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_3\,
dataa => \GRFPU0.GRFPU_X0.L4_3\(3),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_2\);
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_2\,
dataa => \GRFPU0.GRFPU_X0.L4_3\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_1\);
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_1\,
dataa => \GRFPU0.GRFPU_X0.L4_3\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
cin => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_0\);
GRFPU0_GRFPU_X0_COMB_UN1_L4_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.LT_0\,
dataa => \GRFPU0.GRFPU_X0.L4_3\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_GRFPU_X0_COMB_IEXC5_LT5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1101010011010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT5\,
dataa => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
cin => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_4\);
GRFPU0_GRFPU_X0_COMB_IEXC5_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_4\,
dataa => \GRFPU0.GRFPU_X0.L4_7\(4),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(4),
cin => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_3\);
GRFPU0_GRFPU_X0_COMB_IEXC5_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_3\,
dataa => \GRFPU0.GRFPU_X0.L4_7\(3),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
cin => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_2\);
GRFPU0_GRFPU_X0_COMB_IEXC5_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_2\,
dataa => \GRFPU0.GRFPU_X0.L4_7\(2),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
cin => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_1\);
GRFPU0_GRFPU_X0_COMB_IEXC5_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_1\,
dataa => \GRFPU0.GRFPU_X0.L4_7\(1),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
cin => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_0\);
GRFPU0_GRFPU_X0_COMB_IEXC5_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.IEXC5.LT_0\,
dataa => \GRFPU0.GRFPU_X0.L4_7\(0),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(0));
GRFPU0_GRFPU_X0_COMB_LOB2_LT5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1101010011010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT5\,
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.N_6\,
dataa => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_4\);
GRFPU0_GRFPU_X0_COMB_LOB2_LT4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_4\,
dataa => \GRFPU0.GRFPU_X0.L4\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_3\);
GRFPU0_GRFPU_X0_COMB_LOB2_LT3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_3\,
dataa => \GRFPU0.GRFPU_X0.L4\(3),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_2\);
GRFPU0_GRFPU_X0_COMB_LOB2_LT2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_2\,
dataa => \GRFPU0.GRFPU_X0.L4\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_1\);
GRFPU0_GRFPU_X0_COMB_LOB2_LT1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000011010100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_1\,
dataa => \GRFPU0.GRFPU_X0.L4\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
cin => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_0\);
GRFPU0_GRFPU_X0_COMB_LOB2_LT0: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "0000000001000100")
port map (
cout => \GRFPU0.GRFPU_X0.COMB.LOB2.LT_0\,
dataa => \GRFPU0.GRFPU_X0.L4\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_63\,
cout => N_116639,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_62: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_62\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_61: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_61\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_60: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_60\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_59: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_59\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_58: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_58\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_57: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_57\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_56: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_56\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_55: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_55\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_54: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_54\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_53: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_53\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_52: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_52\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_51: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_51\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_50: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_50\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_49: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_49\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_48: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_48\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_47: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_47\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_46: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_46\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_45: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_45\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_44: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_44\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_43: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_43\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_42: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_42\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_41: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_41\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_40: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_40\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_39: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_39\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_38: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_38\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_37: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_37\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_36: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_36\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_35: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_35\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_34: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_34\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_33: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_33\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_32: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_32\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(31),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(31),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_31: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_31\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(30),
datab => \GRFPU0.GRFPU_X0.CMPI2\(30),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_30: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_30\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(29),
datab => \GRFPU0.GRFPU_X0.CMPI2\(29),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_29: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_29\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(28),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(28),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_28: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_28\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\,
dataa => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(27),
datab => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(27),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_27: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_27\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(26),
datab => \GRFPU0.GRFPU_X0.CMPI2\(26),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_26: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_26\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(25),
datab => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(25),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_25: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_25\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(24),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(24),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_24: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_24\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\,
dataa => \GRFPU0.GRFPU_X0.CMPI1_I_I_A2\(23),
datab => \GRFPU0.GRFPU_X0.CMPI2_I_I_A2\(23),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_23: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_23\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(22),
datab => \GRFPU0.GRFPU_X0.CMPI2\(22),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_22: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_22\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(21),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(21),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_21: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_21\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(20),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(20),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_20: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_20\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(19),
datab => \GRFPU0.GRFPU_X0.CMPI2\(19),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_19: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_19\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(18),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(18),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_18: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_18\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(17),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(17),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_17: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_17\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(16),
datab => \GRFPU0.GRFPU_X0.CMPI2\(16),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_16: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_16\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(15),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(15),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_15: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_15\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(14),
datab => \GRFPU0.GRFPU_X0.CMPI2\(14),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_14: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_14\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(13),
datab => \GRFPU0.GRFPU_X0.CMPI2\(13),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_13: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_13\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(12),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(12),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_12: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_12\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(11),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(11),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_11: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_11\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(10),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(10),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_10: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_10\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\,
dataa => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(9),
datab => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(9),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_9: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_9\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(8),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(8),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_8: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_8\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(7),
datab => \GRFPU0.GRFPU_X0.CMPI2\(7),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_7: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_7\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(6),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(6),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_6: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_6\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\,
dataa => \GRFPU0.GRFPU_X0.CMPI1_0_A2\(5),
datab => \GRFPU0.GRFPU_X0.CMPI2_0_A2\(5),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_5: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_5\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(4),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(4),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_4: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_4\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(3),
datab => \GRFPU0.GRFPU_X0.CMPI2\(3),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_3: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_3\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(2),
datab => \GRFPU0.GRFPU_X0.CMPI2\(2),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_2: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100111010100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_2\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\,
dataa => \GRFPU0.GRFPU_X0.CMPI2_I\(1),
datab => \GRFPU0.GRFPU_X0.CMPI1_I\(1),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_1: cycloneiii_lcell_comb generic map (
     sum_lutc_input => "cin",
    lut_mask => "1001100101000100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.COMB.LESS2_1\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\,
dataa => \GRFPU0.GRFPU_X0.CMPI1\(0),
datab => \GRFPU0.GRFPU_X0.CMPI2\(0));
N_141802 <= not \GRFPC0.OP1_0_IV\(52);
N_141803 <= not \GRFPC0.OP1_0_IV\(55);
\GRFPU0_GRFPU_X0_ST4_SEL_REP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(1),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_REP1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(2),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_REP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_REP1\(0),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_REP2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_0__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_REP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP_REP1\(0),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_0__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_REP3_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_REP2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP2\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_REP1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP1\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_REP2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE_REP2\(0),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_REP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE_REP1\(0),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_43: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_35799,
d => N_35799_RETI,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_42: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(88),
d => \GRFPU0.MULO.MRES_RETI\(88),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_87_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(87),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(87),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_88_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(88),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(88),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_4__G4_RETO\,
d => \GRFPC0.FPUSEL_6_0_4__G4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_108: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD49\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_107: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD49\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_3440_I_M_0_RETO\,
d => \GRFPU0.GRFPU_X0.N_3440_I_M_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.UN1_REST_RETO\,
d => \GRFPU0.GRFPU_X0.UN1_REST\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M_RETO\(63),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M_RETO\(63),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_106: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(2),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_105: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(20),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_104: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_CARRY_73\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_51: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_50: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD13\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD13_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_79_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(79),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(79),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_49: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_48: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD13\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD13_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_78_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(78),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_41: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_35796,
d => N_35796_RETI,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_40: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(85),
d => \GRFPU0.MULO.MRES_RETI\(85),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_85_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(85),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(85),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_86_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(86),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(86),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(86),
d => \GRFPU0.MULO.MRES_RETI\(86),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_102: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD50\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_101: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD50\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_99: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(3),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_98: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(21),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.VALID_REP1_RETO\,
d => \GRFPC0.DIV.VALID_REP1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_21: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.UN1_WRENX2_2_3_RETO\,
d => N_114885,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_M1_RETO\(0),
d => \GRFPC0.FPUSEL_6_M1\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.UN1_WRENX2_2_1_RETO\,
d => \GRFPC0.UN1_WRENX2_2_1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_6__G0_3_0_RETO\,
d => \GRFPC0.FPUSEL_6_0_6__G0_3_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_3__G7_0_X_RETO\,
d => N_114886,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_3__G1_0_RETO\,
d => \GRFPC0.FPUSEL_6_0_3__G1_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_7__G0_I_M4_RETO\,
d => \GRFPC0.FPUSEL_6_0_7__G0_I_M4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_46: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD12\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD12_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_44: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD12\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD12_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_77_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(77),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_36: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(83),
d => \GRFPU0.MULO.MRES_RETI\(83),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_83_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(83),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(83),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_84_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(84),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(84),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_34: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(84),
d => \GRFPU0.MULO.MRES_RETI\(84),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_96: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD51\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_95: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD51\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_93: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(4),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_92: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(22),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_42: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD11\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD11_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_40: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD11\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD11_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_76_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(76),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(81),
d => \GRFPU0.MULO.MRES_RETI\(81),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_81_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(81),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(81),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_82_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(82),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(82),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(82),
d => \GRFPU0.MULO.MRES_RETI\(82),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_3__G0_E_1_RETO\,
d => N_114887,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_11: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_3__G0_E_3_RETO\,
d => N_114888,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.1.EXEN7_RETO\,
d => N_114889,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_4__G4_RETO\,
d => \GRFPC0.FPUSEL_1_0_4__G4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_90: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD52\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_89: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD52\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_3__G7_RETO\,
d => \GRFPC0.FPUSEL_1_0_3__G7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_1_0_3__G1_RETO\,
d => \GRFPC0.FPUSEL_1_0_3__G1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_87: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(5),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_86: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(23),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3_RETO\,
d => \GRFPC0.RFA2.RS2SEL_0_0_7__G0_I_M3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.1.DIVEN10_4_RETO\,
d => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0_RETO\,
d => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.1.WR2EN10_RETO\,
d => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.UN1_WRENX10_I_RETO\,
d => \GRFPC0.UN1_WRENX10_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD10\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD10_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_36: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD10\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD10_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_75_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(75),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_28: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(79),
d => \GRFPU0.MULO.MRES_RETI\(79),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_80_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(80),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(80),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(80),
d => \GRFPU0.MULO.MRES_RETI\(80),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_84: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD53\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_83: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD53\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_81: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(6),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_80: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML_RETO\(24),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_ML\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_34: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD9\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD9_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD9\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD9_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_74_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(74),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(77),
d => \GRFPU0.MULO.MRES_RETI\(77),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(78),
d => \GRFPU0.MULO.MRES_RETI\(78),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_78: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD54\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_77: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD54\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD8\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD8_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_28: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD8\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD8_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_73_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(73),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(75),
d => \GRFPU0.MULO.MRES_RETI\(75),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(76),
d => \GRFPU0.MULO.MRES_RETI\(76),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_75: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD55\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_74: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD55\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD7\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD7_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_72_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(72),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD7\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD7_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(73),
d => \GRFPU0.MULO.MRES_RETI\(73),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(74),
d => \GRFPU0.MULO.MRES_RETI\(74),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_72: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD56\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_71: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD56\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD6\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD6_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_71_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(71),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD6\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD6_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(71),
d => \GRFPU0.MULO.MRES_RETI\(71),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(72),
d => \GRFPU0.MULO.MRES_RETI\(72),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_69: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD57\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_68: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD57\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD5\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD5_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD5\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD5_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_70_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(70),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_8: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(69),
d => \GRFPU0.MULO.MRES_RETI\(69),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_69_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(69),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(70),
d => \GRFPU0.MULO.MRES_RETI\(70),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_66: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD58\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_65: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD58\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VST2.REG127_RETO\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG127\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.UINT17_RETO\,
d => \GRFPU0.GRFPU_X0.COMB.UINT17\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_REG_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0_RETO\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I_0_63__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD4\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD4_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD4\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD4_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(67),
d => \GRFPU0.MULO.MRES_RETI\(67),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_67_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(67),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_68_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(68),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(68),
d => \GRFPU0.MULO.MRES_RETI\(68),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_63: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD59\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_62: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD59\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD3\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD3_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD3\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD3_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RESV_RETO\,
d => \GRFPC0.MEM.RREG.RESV\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_RETO\,
d => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_3__G0_E_RETO\,
d => N_114890,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_R2_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(66),
d => \GRFPU0.MULO.MRES_RETI\(66),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_ITER_R_0_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.CS_ITER_R_0_0\,
d => \GRFPU0.GRFPU_X0.N_13452_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_66_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(66),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_60: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD60\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_59: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD60\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_ADD2\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_ADD2_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.CSADD.S1_1\(68),
d => \GRFPU0.FPMUL0.CSADD.S1_1_RETI\(68),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_ADD2\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_ADD2_RETI\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.CS_DP_R\,
d => \GRFPU0.GRFPU_X0.N_13472_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_57: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD61\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_56: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD61\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_54: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_RETO\(98),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2\(98),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_53: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD62\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_65_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(65),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(65),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_51: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD63\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_49: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD64\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_47: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD65\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_45: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD66\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_43: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD67\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_41: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD68\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_39: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD69\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RESV_RETO\,
d => \GRFPC0.EX.RREG.RESV\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_RETO\,
d => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
d => N_114891,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_37: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD70\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_35: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD71\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_33: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD72\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD72\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD73\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_29: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_1_ADD73\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD74\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD75\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_21: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD76\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD77\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78_RETO\,
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_ML_A_ADD78\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_RETO\(115),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2\(115),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(8),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(9),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(10),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(11),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(12),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU_RETO\(13),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU_MU_MU_MU_MU\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(31),
d => N_114766,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(30),
d => N_114765,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(29),
d => N_114764,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(28),
d => N_114763,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(27),
d => N_114762,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(26),
d => N_114761,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(25),
d => N_114760,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(24),
d => N_114759,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(23),
d => N_114758,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(22),
d => N_114757,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(21),
d => N_114756,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(20),
d => N_114755,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(19),
d => N_114754,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(18),
d => N_114753,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(17),
d => N_114752,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(16),
d => N_114751,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(15),
d => N_114750,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(14),
d => N_114749,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(13),
d => N_114748,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(12),
d => N_114747,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(11),
d => N_114746,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(10),
d => N_114745,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(9),
d => N_114744,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(8),
d => N_114743,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(7),
d => N_114742,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(6),
d => N_114741,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(5),
d => N_114740,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(4),
d => N_114739,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(3),
d => N_114738,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(2),
d => N_114737,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(31),
d => N_114736,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(30),
d => N_114735,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(29),
d => N_114734,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(28),
d => N_114733,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(27),
d => N_114732,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(26),
d => N_114731,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(25),
d => N_114730,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(24),
d => N_114729,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(23),
d => N_114728,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(22),
d => N_114727,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(21),
d => N_114726,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(20),
d => N_114725,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(19),
d => N_114724,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(18),
d => N_114723,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(17),
d => N_114722,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(16),
d => N_114721,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(15),
d => N_114720,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(14),
d => N_114719,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(13),
d => N_114718,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(12),
d => N_114717,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(11),
d => N_114716,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(10),
d => N_114715,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(9),
d => N_114714,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(8),
d => N_114713,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(7),
d => N_114712,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(6),
d => N_114711,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(5),
d => N_114710,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(4),
d => N_114709,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(3),
d => N_114708,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(2),
d => N_114707,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(1),
d => N_114706,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(0),
d => N_114705,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(31),
d => N_114704,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(30),
d => N_114703,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(29),
d => N_114702,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(28),
d => N_114701,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(27),
d => N_114700,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(26),
d => N_114699,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(25),
d => N_114698,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(24),
d => N_114697,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(23),
d => N_114696,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(22),
d => N_114695,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(21),
d => N_114694,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(20),
d => N_114693,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(19),
d => N_114692,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(18),
d => N_114691,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(17),
d => N_114690,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(16),
d => N_114689,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(15),
d => N_114688,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(14),
d => N_114687,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(13),
d => N_114686,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(12),
d => N_114685,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(11),
d => N_114684,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(10),
d => N_114683,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(9),
d => N_114682,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(8),
d => N_114681,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(7),
d => N_114680,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(6),
d => N_114679,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(5),
d => N_114678,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(4),
d => N_114677,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(3),
d => N_114676,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(2),
d => N_114675,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(31),
d => N_114674,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(30),
d => N_114673,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(29),
d => N_114672,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(28),
d => N_114671,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(27),
d => N_114670,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(26),
d => N_114669,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(25),
d => N_114668,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(24),
d => N_114667,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(23),
d => N_114666,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(22),
d => N_114665,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(21),
d => N_114664,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(20),
d => N_114663,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(19),
d => N_114662,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(18),
d => N_114661,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(17),
d => N_114660,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(16),
d => N_114659,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(15),
d => N_114658,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(14),
d => N_114657,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(13),
d => N_114656,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(12),
d => N_114655,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(11),
d => N_114654,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(10),
d => N_114653,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(9),
d => N_114652,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(8),
d => N_114651,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(7),
d => N_114650,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(6),
d => N_114649,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(5),
d => N_114648,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(4),
d => N_114647,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(3),
d => N_114646,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(2),
d => N_114645,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(1),
d => N_114644,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(0),
d => N_114643,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(31),
d => N_114642,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(30),
d => N_114641,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(29),
d => N_114640,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(28),
d => N_114639,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(27),
d => N_114638,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(26),
d => N_114637,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(25),
d => N_114636,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(24),
d => N_114635,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(23),
d => N_114634,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(22),
d => N_114633,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(21),
d => N_114632,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(20),
d => N_114631,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(19),
d => N_114630,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(18),
d => N_114629,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(17),
d => N_114628,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(16),
d => N_114627,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(15),
d => N_114626,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(14),
d => N_114625,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(13),
d => N_114624,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(12),
d => N_114623,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(11),
d => N_114622,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(10),
d => N_114621,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(9),
d => N_114620,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(8),
d => N_114619,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(7),
d => N_114618,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(6),
d => N_114617,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(5),
d => N_114616,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(4),
d => N_114615,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(3),
d => N_114614,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(2),
d => N_114613,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(31),
d => N_114612,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(30),
d => N_114611,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(29),
d => N_114610,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(28),
d => N_114609,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(27),
d => N_114608,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(26),
d => N_114607,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(25),
d => N_114606,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(24),
d => N_114605,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(23),
d => N_114604,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(22),
d => N_114603,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(21),
d => N_114602,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(20),
d => N_114601,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(19),
d => N_114600,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(18),
d => N_114599,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(17),
d => N_114598,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(16),
d => N_114597,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(15),
d => N_114596,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(14),
d => N_114595,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(13),
d => N_114594,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(12),
d => N_114593,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(11),
d => N_114592,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(10),
d => N_114591,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(9),
d => N_114590,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(8),
d => N_114589,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(7),
d => N_114588,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(6),
d => N_114587,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(5),
d => N_114586,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(4),
d => N_114585,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(3),
d => N_114584,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(2),
d => N_114583,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(1),
d => N_114582,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(0),
d => N_114581,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(31),
d => N_114580,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(30),
d => N_114579,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(29),
d => N_114578,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(28),
d => N_114577,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(27),
d => N_114576,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(26),
d => N_114575,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(25),
d => N_114574,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(24),
d => N_114573,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(23),
d => N_114572,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(22),
d => N_114571,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(21),
d => N_114570,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(20),
d => N_114569,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(19),
d => N_114568,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(18),
d => N_114567,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(17),
d => N_114566,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(16),
d => N_114565,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(15),
d => N_114564,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(14),
d => N_114563,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(13),
d => N_114562,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(12),
d => N_114561,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(11),
d => N_114560,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(10),
d => N_114559,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(9),
d => N_114558,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(8),
d => N_114557,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(7),
d => N_114556,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(6),
d => N_114555,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(5),
d => N_114554,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(4),
d => N_114553,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(3),
d => N_114552,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(2),
d => N_114551,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(31),
d => N_114550,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(30),
d => N_114549,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(29),
d => N_114548,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(28),
d => N_114547,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(27),
d => N_114546,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(26),
d => N_114545,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(25),
d => N_114544,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(24),
d => N_114543,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(23),
d => N_114542,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(22),
d => N_114541,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(21),
d => N_114540,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(20),
d => N_114539,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(19),
d => N_114538,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(18),
d => N_114537,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(17),
d => N_114536,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(16),
d => N_114535,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(15),
d => N_114534,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(14),
d => N_114533,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(13),
d => N_114532,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(12),
d => N_114531,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(11),
d => N_114530,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(10),
d => N_114529,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(9),
d => N_114528,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(8),
d => N_114527,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(7),
d => N_114526,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(6),
d => N_114525,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(5),
d => N_114524,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(4),
d => N_114523,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(3),
d => N_114522,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(2),
d => N_114521,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(1),
d => N_114520,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(0),
d => N_114519,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PEND\,
d => N_114518,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_EMAXP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
d => N_114517,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_FLUSH0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
d => N_114516,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_REP2_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG_REP2\(63),
d => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_REP1_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG_REP1\(63),
d => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_NORM_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.NORM_REP1\,
d => \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP6\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP5\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP4\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP3\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP2\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP_REP1\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_REP3_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP3\(1),
d => \GRFPU0.GRFPU_X0.N_19845_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_REP2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP2\(1),
d => \GRFPU0.GRFPU_X0.N_19845_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_REP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL_REP1\(1),
d => \GRFPU0.GRFPU_X0.N_19845_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_REP1_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES_REP1\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_55__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V_REP4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V_REP4\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V_REP3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V_REP2\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V_REP1\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_REP1_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2_REP1\(63),
d => \GRFPC0.OP2\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SQRT_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SQRT_REP2\,
d => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SQRT_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SQRT_REP1\,
d => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RS2D_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2D_REP1\,
d => N_114892,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_VALID_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.VALID_REP1\,
d => \GRFPC0.DIV.VALID_0_0_G0_X\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RDD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RDD_REP1\,
d => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_RDD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RDD_REP1\,
d => \GRFPC0.WR2.CTRL.RDD\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_REP4_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_REP4\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_REP3_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_REP3\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_REP2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_REP2\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_REP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_REP1\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_LD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.LD_REP1\,
d => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD_REP4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDD_REP4\,
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD_REP3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDD_REP3\,
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDD_REP2\,
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDD_REP1\,
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDD_REP3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDD_REP3\,
d => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDD_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDD_REP2\,
d => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDD_REP1\,
d => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP4_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP4\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP3_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP3\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP2\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP1\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP2\(1),
d => \GRFPC0.FPUSEL_1_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_REP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_REP1\(1),
d => \GRFPC0.FPUSEL_1_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_REP2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL_REP2\(1),
d => \GRFPC0.FPUSEL_6_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_REP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL_REP1\(1),
d => \GRFPC0.FPUSEL_6_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD_REP5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD_REP5\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD_REP4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD_REP4\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD_REP3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD_REP3\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD_REP2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD_REP2\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD_REP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD_REP1\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_8__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_20__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(3),
d => \GRFPU0.GRFPU_X0.N_10132\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(63),
d => \GRFPC0.WR.RREG.RES_0_0_63__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(62),
d => \GRFPC0.WR.RREG.RES_0_0_62__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(61),
d => \GRFPC0.WR.RREG.RES_0_0_61__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(60),
d => \GRFPC0.WR.RREG.RES_0_0_60__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(59),
d => \GRFPC0.WR.RREG.RES_0_0_59__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(58),
d => \GRFPC0.WR.RREG.RES_0_0_58__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(57),
d => \GRFPC0.WR.RREG.RES_0_0_57__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(56),
d => \GRFPC0.WR.RREG.RES_0_0_56__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(55),
d => \GRFPC0.WR.RREG.RES_0_0_55__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(54),
d => \GRFPC0.WR.RREG.RES_0_0_54__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(53),
d => \GRFPC0.WR.RREG.RES_0_0_53__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(52),
d => \GRFPC0.WR.RREG.RES_0_0_52__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(51),
d => \GRFPC0.WR.RREG.RES_0_0_51__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(50),
d => \GRFPC0.WR.RREG.RES_0_0_50__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(49),
d => \GRFPC0.WR.RREG.RES_0_0_49__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(48),
d => \GRFPC0.WR.RREG.RES_0_0_48__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(47),
d => \GRFPC0.WR.RREG.RES_0_0_47__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(46),
d => \GRFPC0.WR.RREG.RES_0_0_46__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(45),
d => \GRFPC0.WR.RREG.RES_0_0_45__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(44),
d => \GRFPC0.WR.RREG.RES_0_0_44__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(43),
d => \GRFPC0.WR.RREG.RES_0_0_43__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(42),
d => \GRFPC0.WR.RREG.RES_0_0_42__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(41),
d => \GRFPC0.WR.RREG.RES_0_0_41__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP2,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(40),
d => \GRFPC0.WR.RREG.RES_0_0_40__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(39),
d => \GRFPC0.WR.RREG.RES_0_0_39__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(38),
d => \GRFPC0.WR.RREG.RES_0_0_38__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(37),
d => \GRFPC0.WR.RREG.RES_0_0_37__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(36),
d => \GRFPC0.WR.RREG.RES_0_0_36__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(35),
d => \GRFPC0.WR.RREG.RES_0_0_35__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(34),
d => \GRFPC0.WR.RREG.RES_0_0_34__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(33),
d => \GRFPC0.WR.RREG.RES_0_0_33__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(32),
d => \GRFPC0.WR.RREG.RES_0_0_32__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(31),
d => \GRFPC0.WR.RREG.RES_0_0_31__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(30),
d => \GRFPC0.WR.RREG.RES_0_0_30__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(29),
d => \GRFPC0.WR.RREG.RES_0_0_29__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(28),
d => \GRFPC0.WR.RREG.RES_0_0_28__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(27),
d => \GRFPC0.WR.RREG.RES_0_0_27__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(26),
d => \GRFPC0.WR.RREG.RES_0_0_26__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(25),
d => \GRFPC0.WR.RREG.RES_0_0_25__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(24),
d => \GRFPC0.WR.RREG.RES_0_0_24__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(23),
d => \GRFPC0.WR.RREG.RES_0_0_23__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(22),
d => \GRFPC0.WR.RREG.RES_0_0_22__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(21),
d => \GRFPC0.WR.RREG.RES_0_0_21__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(20),
d => \GRFPC0.WR.RREG.RES_0_0_20__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(19),
d => \GRFPC0.WR.RREG.RES_0_0_19__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(18),
d => \GRFPC0.WR.RREG.RES_0_0_18__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(17),
d => \GRFPC0.WR.RREG.RES_0_0_17__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X_REP1,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(16),
d => \GRFPC0.WR.RREG.RES_0_0_16__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(15),
d => \GRFPC0.WR.RREG.RES_0_0_15__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(14),
d => \GRFPC0.WR.RREG.RES_0_0_14__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(13),
d => \GRFPC0.WR.RREG.RES_0_0_13__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(12),
d => \GRFPC0.WR.RREG.RES_0_0_12__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(11),
d => \GRFPC0.WR.RREG.RES_0_0_11__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(10),
d => \GRFPC0.WR.RREG.RES_0_0_10__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(9),
d => \GRFPC0.WR.RREG.RES_0_0_9__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(8),
d => \GRFPC0.WR.RREG.RES_0_0_8__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(7),
d => \GRFPC0.WR.RREG.RES_0_0_7__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(6),
d => \GRFPC0.WR.RREG.RES_0_0_6__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(5),
d => \GRFPC0.WR.RREG.RES_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(4),
d => \GRFPC0.WR.RREG.RES_0_0_4__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(3),
d => \GRFPC0.WR.RREG.RES_0_0_3__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(2),
d => \GRFPC0.WR.RREG.RES_0_0_2__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(1),
d => \GRFPC0.WR.RREG.RES_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(0),
d => \GRFPC0.WR.RREG.RES_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(63),
d => \GRFPC0.MEM.RREG.RES_0_0_63__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(62),
d => \GRFPC0.MEM.RREG.RES_0_0_62__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(61),
d => \GRFPC0.MEM.RREG.RES_0_0_61__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(60),
d => \GRFPC0.MEM.RREG.RES_0_0_60__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(59),
d => \GRFPC0.MEM.RREG.RES_0_0_59__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(58),
d => \GRFPC0.MEM.RREG.RES_0_0_58__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(57),
d => \GRFPC0.MEM.RREG.RES_0_0_57__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(56),
d => \GRFPC0.MEM.RREG.RES_0_0_56__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(55),
d => \GRFPC0.MEM.RREG.RES_0_0_55__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(54),
d => \GRFPC0.MEM.RREG.RES_0_0_54__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(53),
d => \GRFPC0.MEM.RREG.RES_0_0_53__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(52),
d => \GRFPC0.MEM.RREG.RES_0_0_52__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(51),
d => \GRFPC0.MEM.RREG.RES_0_0_51__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(50),
d => \GRFPC0.MEM.RREG.RES_0_0_50__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(49),
d => \GRFPC0.MEM.RREG.RES_0_0_49__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(48),
d => \GRFPC0.MEM.RREG.RES_0_0_48__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(47),
d => \GRFPC0.MEM.RREG.RES_0_0_47__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(46),
d => \GRFPC0.MEM.RREG.RES_0_0_46__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(45),
d => \GRFPC0.MEM.RREG.RES_0_0_45__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(44),
d => \GRFPC0.MEM.RREG.RES_0_0_44__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(43),
d => \GRFPC0.MEM.RREG.RES_0_0_43__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(42),
d => \GRFPC0.MEM.RREG.RES_0_0_42__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(41),
d => \GRFPC0.MEM.RREG.RES_0_0_41__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(40),
d => \GRFPC0.MEM.RREG.RES_0_0_40__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(39),
d => \GRFPC0.MEM.RREG.RES_0_0_39__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(38),
d => \GRFPC0.MEM.RREG.RES_0_0_38__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(37),
d => \GRFPC0.MEM.RREG.RES_0_0_37__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(36),
d => \GRFPC0.MEM.RREG.RES_0_0_36__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(35),
d => \GRFPC0.MEM.RREG.RES_0_0_35__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(34),
d => \GRFPC0.MEM.RREG.RES_0_0_34__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(33),
d => \GRFPC0.MEM.RREG.RES_0_0_33__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(32),
d => \GRFPC0.MEM.RREG.RES_0_0_32__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(31),
d => \GRFPC0.MEM.RREG.RES_0_0_31__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(30),
d => \GRFPC0.MEM.RREG.RES_0_0_30__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(29),
d => \GRFPC0.MEM.RREG.RES_0_0_29__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(28),
d => \GRFPC0.MEM.RREG.RES_0_0_28__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(27),
d => \GRFPC0.MEM.RREG.RES_0_0_27__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(26),
d => \GRFPC0.MEM.RREG.RES_0_0_26__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(25),
d => \GRFPC0.MEM.RREG.RES_0_0_25__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(24),
d => \GRFPC0.MEM.RREG.RES_0_0_24__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(23),
d => \GRFPC0.MEM.RREG.RES_0_0_23__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(22),
d => \GRFPC0.MEM.RREG.RES_0_0_22__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(21),
d => \GRFPC0.MEM.RREG.RES_0_0_21__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(20),
d => \GRFPC0.MEM.RREG.RES_0_0_20__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(19),
d => \GRFPC0.MEM.RREG.RES_0_0_19__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(18),
d => \GRFPC0.MEM.RREG.RES_0_0_18__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(17),
d => \GRFPC0.MEM.RREG.RES_0_0_17__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(16),
d => \GRFPC0.MEM.RREG.RES_0_0_16__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(15),
d => \GRFPC0.MEM.RREG.RES_0_0_15__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(14),
d => \GRFPC0.MEM.RREG.RES_0_0_14__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(13),
d => \GRFPC0.MEM.RREG.RES_0_0_13__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(12),
d => \GRFPC0.MEM.RREG.RES_0_0_12__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(11),
d => \GRFPC0.MEM.RREG.RES_0_0_11__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(10),
d => \GRFPC0.MEM.RREG.RES_0_0_10__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(9),
d => \GRFPC0.MEM.RREG.RES_0_0_9__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(8),
d => \GRFPC0.MEM.RREG.RES_0_0_8__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(7),
d => \GRFPC0.MEM.RREG.RES_0_0_7__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(6),
d => \GRFPC0.MEM.RREG.RES_0_0_6__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(5),
d => \GRFPC0.MEM.RREG.RES_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(4),
d => \GRFPC0.MEM.RREG.RES_0_0_4__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(3),
d => \GRFPC0.MEM.RREG.RES_0_0_3__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(2),
d => \GRFPC0.MEM.RREG.RES_0_0_2__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(1),
d => \GRFPC0.MEM.RREG.RES_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(0),
d => \GRFPC0.MEM.RREG.RES_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(5),
d => \GRFPC0.WR2.RREG.EXCT_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(4),
d => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(3),
d => \GRFPC0.WR2.RREG.EXCT_0_0_3__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(2),
d => \GRFPC0.WR2.RREG.EXCT_0_0_2__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(1),
d => \GRFPC0.WR2.RREG.EXCT_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(0),
d => \GRFPC0.WR2.RREG.EXCT_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(5),
d => \GRFPC0.WR.RREG.EXCT_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(4),
d => \GRFPC0.WR.RREG.EXCT_0_0_4__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(3),
d => \GRFPC0.WR.RREG.EXCT_0_0_3__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(2),
d => \GRFPC0.WR.RREG.EXCT_0_0_2__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(1),
d => \GRFPC0.WR.RREG.EXCT_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(0),
d => \GRFPC0.WR.RREG.EXCT_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => G_2026_X,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(5),
d => \GRFPC0.MEM.RREG.EXCT_0_0_5__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(4),
d => \GRFPC0.MEM.RREG.EXCT_0_0_4__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(3),
d => \GRFPC0.MEM.RREG.EXCT_0_0_3__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(2),
d => \GRFPC0.MEM.RREG.EXCT_0_0_2__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(1),
d => \GRFPC0.MEM.RREG.EXCT_0_0_1__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(0),
d => \GRFPC0.MEM.RREG.EXCT_0_0_0__G0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STATE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STATE\(1),
d => \GRFPC0.R.STATE_0_0_1__G2\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.R.STATE_0_0_0__G0_0_X\,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_R_STATE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STATE\(0),
d => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.R.STATE_0_0_0__G0_0_X\,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_FPR_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.RDY\,
d => \GRFPU0.GRFPU_X0.RDY_F0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RDD\,
d => \GRFPC0.WR2.CTRL.RDD\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_FLUSH: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FLUSH\,
d => \GRFPC0.N_17807_I_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_DIVLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.DIVLCK\,
d => \GRFPC0.FP_PIPELINE.DEPMUX.RES_U\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2DEP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2DEP\,
d => \GRFPC0.RFA2.RS2DEP_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1DEP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1DEP\,
d => \GRFPC0.RFA2.RS1DEP_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_VALID: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.VALID\,
d => \GRFPC0.DIV.VALID_0_0_G0_X\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RESV\,
d => \GRFPC0.WR2.RREG.RESV_0_0_G0_0_X\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_WR_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RESV\,
d => \GRFPC0.WR.RREG.RESV_0_0_G0_0_X\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_MEM_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RESV\,
d => \GRFPC0.MEM.RREG.RESV_0_0_A4_0_G0_0_X\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_DIV_EXEC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXEC\,
d => \GRFPC0.DIV.EXEC_0_0_G0_X\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RESV\,
d => \GRFPC0.EX.RREG.RESV_0_0_G0_0_X\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_RFA2_FOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FOP\(0),
d => \GRFPC0.RFA2.FOP_0_0_0_0__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FOP\(1),
d => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL\(2),
d => \GRFPC0.FPUSEL_6\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL\(1),
d => \GRFPC0.FPUSEL_6_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(1),
d => \GRFPC0.FPUSEL_1_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(0),
d => \GRFPC0.FPRIN.ALLOW_0_0__G0_1\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV\(1),
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(2),
d => \GRFPU0.GRFPU_X0.ALLOW_0_2__G1\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_RFA_RS1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(0),
d => N_114893,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(1),
d => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(2),
d => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(3),
d => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(4),
d => \RETGRFPC0.FP_PIPELINE.RS1_6_0_X\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(0),
d => \GRFPC0.FID_1_IV_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(1),
d => \GRFPC0.FID_1_IV_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(2),
d => \GRFPC0.FID_1_IV_0_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(3),
d => \GRFPC0.FID_1_IV_0_0_3__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(4),
d => \GRFPC0.FID_1_IV_0_0_4__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FID\(5),
d => \GRFPC0.FID_1_IV_0_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(0),
d => \GRFPC0.INST_I_M2\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(1),
d => N_114894,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(2),
d => N_114895,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(3),
d => N_114896,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(4),
d => N_114897,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(0),
d => \GRFPC0.WR2.CTRL.RD\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(1),
d => \GRFPC0.WR2.CTRL.RD\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(2),
d => \GRFPC0.WR2.CTRL.RD\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(3),
d => \GRFPC0.WR2.CTRL.RD\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(4),
d => \GRFPC0.WR2.CTRL.RD\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(0),
d => N_114898,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(1),
d => N_114899,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(2),
d => N_114900,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(3),
d => N_114901,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(4),
d => N_114902,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(5),
d => N_114903,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMAX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMAX\,
d => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMIN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMIN\,
d => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_ADD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ADD\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1_U\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_INF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.INF\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_0_0_G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_DIFFV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMINM1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMINM1\,
d => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_ADDOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
d => \RETGRFPU0.GRFPU_X0.COMB.VST4.ADDOF_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_MOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MOF\,
d => \GRFPU0.GRFPU_X0.N_19993_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
d => \GRFPU0.GRFPU_X0.ST3.DEFERNX\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.DEFERNX\,
d => \GRFPU0.GRFPU_X0.ST2.DEFERNX\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DEFERNX\,
d => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_STICKY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.STICKY\,
d => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RDY\,
d => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_ZERO: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ZERO\,
d => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RDY\,
d => \GRFPU0.GRFPU_X0.N_20087_I_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_INF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.INF\,
d => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_ZERO: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ZERO\,
d => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_QSNAN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
d => \GRFPU0.GRFPU_X0.ST3.QSNAN_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.RDY\,
d => \GRFPU0.GRFPU_X0.ST4.RDY_0_0_G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_QSNAN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.QSNAN\,
d => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_STICKY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.STICKY\,
d => \GRFPU0.GRFPU_X0.ST3.STICKY_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_EMINM1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
d => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DIFFV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DIFFN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFFN\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
d => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_OP2NX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
d => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_OP1NX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
d => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.V\,
d => \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SIGN2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
d => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SIGN1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
d => \GRFPU0.GRFPU_X0.ST1.SIGN1_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.V\,
d => \GRFPU0.GRFPU_X0.N_56_I_0_G0_1\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.V\,
d => \GRFPU0.GRFPU_X0.ST2.V_0_0_G0_1\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_IOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.IOF\,
d => \RETGRFPU0.GRFPU_X0.COMB.ITER_OF\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_GUARDS_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_GUARDS_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_4_03\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\,
sload => \GRFPU0.GRFPU_X0.C_ADD11_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(4),
d => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(5),
d => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_24__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_22__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_11__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_7__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_2__G0_I_0\,
clk => N_4,
clrn => VCC,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
d => \GRFPU0.GRFPU_X0.ST2.EXPT_0\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
d => \GRFPU0.GRFPU_X0.ST2.EXPT_0\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(2),
d => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
d => \GRFPU0.GRFPU_X0.N_20002_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(1),
d => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_1__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
d => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_2__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
d => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_0_3__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(4),
d => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0_4__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(5),
d => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
d => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(0),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(1),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(2),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(3),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_3__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(4),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_4__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.IDCST\(5),
d => \GRFPU0.GRFPU_X0.ST1.IDCST_0_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(0),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(1),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(2),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(3),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(4),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.IDCST\(5),
d => \GRFPU0.GRFPU_X0.ST2.IDCST\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(0),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(1),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(2),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(3),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(4),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.IDCST\(5),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_0__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_1__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_2__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_3__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_5__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_6__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_7__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_8__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_9__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_10__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_11__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_12__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_13__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_14__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_15__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_16__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_17__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_18__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_19__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_20__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_21__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_22__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_23__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_24__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_25__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_26__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_27__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_28__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_29__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_32__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_33__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_34__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_35__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_36__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_37__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_38__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_39__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_40__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_41__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_42__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_43__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_44__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_45__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_46__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_47__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_48__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_49__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_50__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_51__G0_I_M4_0\,
sload => \GRFPU0.MULO.MRES_BUF_I\(121),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_1__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(0),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(1),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(2),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_2__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(3),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_3__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(4),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_4__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(5),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(6),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_6__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(7),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_7__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(8),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_8__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(9),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_9__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(10),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_10__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(11),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_11__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(12),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_12__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(13),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_13__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(14),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_14__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(15),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_15__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(16),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_16__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(17),
d => \GRFPU0.GRFPU_X0.VST3.REG_37_0_17__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_4_03_0_G0\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(19),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(21),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(21),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(22),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(22),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(23),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(23),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(24),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(24),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(25),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(25),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(26),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(26),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(27),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(27),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(28),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(28),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(63),
d => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__G2\,
sload => \GRFPU0.GRFPU_X0.G_53_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_32__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_33__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(34),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(34),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_35__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_36__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_37__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_38__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_39__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_40__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_41__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_42__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_43__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_44__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_45__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_46__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_47__G3\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(48),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(48),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(49),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(49),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(50),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(50),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(51),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(51),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(52),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(52),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(52),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(53),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(53),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(53),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(54),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(54),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(54),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(55),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(55),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(56),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(56),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(56),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(57),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(57),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0\(57),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(58),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(58),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(58),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(59),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(59),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(59),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(60),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(60),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(60),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(61),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M3\(61),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(61),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(62),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0_0_M2_I_M3\(62),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6\(62),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_REG_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(63),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1_0\(63),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I\(63),
sload => \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(60),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(0),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(1),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(2),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(3),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(4),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(5),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(6),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(7),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(8),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(9),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(10),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(11),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(12),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(13),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(14),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(15),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(16),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(17),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(18),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(19),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(20),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(21),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(22),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(23),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(24),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(26),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(27),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(28),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_29__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_30__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_31__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_32__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_33__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_34__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_35__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_36__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_37__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_38__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_39__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_40__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_41__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_42__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_43__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_44__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_45__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_46__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_47__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_48__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_49__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_50__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1_0_51__G1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
sload => \GRFPU0.GRFPU_X0.ST3.FLOP_I\(1),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(0),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1_1_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1_SQMUXA\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
d => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_IV_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(0),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(2),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(3),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(4),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(4),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(5),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(6),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(6),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(7),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(8),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(8),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(9),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(9),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(10),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M3\(11),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M2\(11),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(12),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(12),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(13),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(14),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(14),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_M3\(15),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(15),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(16),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(17),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0\(18),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(18),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(19),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(21),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(1),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(21),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(22),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(2),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(22),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(23),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(3),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(23),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(24),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(24),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(25),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(5),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(25),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(26),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(6),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(27),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(7),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(27),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(28),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(8),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(28),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(29),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(9),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(30),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(10),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(30),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(31),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(11),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(31),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(32),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(12),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(33),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(13),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(33),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(34),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(14),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(35),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(35),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(36),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(16),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(37),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(17),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(37),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(38),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(18),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(38),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(39),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(19),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(39),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(40),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(20),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(40),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(41),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(21),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(41),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(42),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(22),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(42),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(43),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(23),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(43),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(44),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(24),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(44),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(45),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(25),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(45),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(46),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(26),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(47),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(27),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(47),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(48),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(28),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(48),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(49),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(29),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(49),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(50),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3_I_M2\(30),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(50),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(51),
d => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(51),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
d => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD3\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD5\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD7\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD8\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD9\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD10\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD11\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD12\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD13\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD14\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD15\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD16\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD17\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD18\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD19\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD20\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD21\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD22\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD23\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD24\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD25\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD26\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(27),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD27\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(28),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD28\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD29\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD30\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD31\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD32\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD33\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD34\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD35\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD36\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD37\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD38\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD39\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD40\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD41\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD42\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD43\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD44\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD45\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD46\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD47\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD48\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD49\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD50\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
d => \GRFPU0.GRFPU_X0.UN2_DIFF1_ADD51\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
d => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0),
d => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_0_IV\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2),
d => \GRFPU0.GRFPU_X0.ALLOW_0_2__G1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
d => \GRFPU0.GRFPU_X0.N_19857_I_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
d => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_1_I_I_1\,
clk => N_4,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_6__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
d => \GRFPU0.GRFPU_X0.N_19862_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
d => \GRFPU0.GRFPU_X0.N_19861_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_1_IV\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(14),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(15),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(52),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(53),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(54),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(55),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(56),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(57),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(58),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(59),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV\(60),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_I_M2\(1),
clk => N_4,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
d => \GRFPU0.GRFPU_X0.N_19845_I_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_7__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_6__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_4__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_3__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD1\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD3\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD4\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD5\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD6\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD7\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD8\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD9\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD10\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD11\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD12\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD13\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD14\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD15\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD16\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD17\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD18\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD19\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD20\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD21\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD22\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD23\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD24\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD25\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD26\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD27\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD28\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD29\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD30\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD31\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD32\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD33\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD34\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD35\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD36\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD37\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD38\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD39\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD40\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD41\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD42\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD43\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD44\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD45\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD46\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD47\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD48\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_4_03_0_G0\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD49\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD50\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD51\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD52\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD53\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_ADD54\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_4_03\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_55__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_6\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_8\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_9\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_11\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_13\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_14\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_15\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_16\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_17\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_18\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_19\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_20\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_21\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_22\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_23\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_24\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_25\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_26\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_27\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_28\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_6\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_8\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_9\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_11\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_13\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_14\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_15\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_16\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_17\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_18\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_19\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_20\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_21\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_22\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_23\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_24\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_25\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_26\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_27\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_28\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1_I\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
d => \GRFPU0.GRFPU_X0.ST1.FLOP_REP2\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_0__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
d => \GRFPU0.GRFPU_X0.EXP_1_SQMUXA_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_2__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_3__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_4__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_6__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_7__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
d => \GRFPU0.GRFPU_X0.VST1.FLOP_1_0_8__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
d => \GRFPU0.GRFPU_X0.L4_4_REP1\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
d => \GRFPU0.GRFPU_X0.L4_4_REP3\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
d => \GRFPU0.GRFPU_X0.L4_4_REP2\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
d => \GRFPU0.GRFPU_X0.L4_4_REP3\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
d => \GRFPU0.GRFPU_X0.L4_4\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
d => \GRFPU0.GRFPU_X0.L3_REP1_REP1\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(0),
d => \GRFPU0.GRFPU_X0.VST2.EXC_8_0_0__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(1),
d => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
d => \RETGRFPC0.OP2\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
d => \RETGRFPC0.OP2\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
d => \GRFPC0.OP2\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
d => \GRFPC0.OP2\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
d => \RETGRFPC0.OP2\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
d => \GRFPC0.OP2_I_M2\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
d => \GRFPC0.OP2\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
d => \GRFPC0.OP2\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
d => \RETGRFPC0.OP2\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
d => \GRFPC0.OP2\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
d => \RETGRFPC0.OP2\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
d => \GRFPC0.OP2\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
d => \GRFPC0.OP2\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
d => \GRFPC0.OP2_I_M2\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
d => \RETGRFPC0.OP2\(14),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
d => \GRFPC0.OP2\(15),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
d => \RETGRFPC0.OP2\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
d => \GRFPC0.OP2\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
d => \GRFPC0.OP2\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
d => \GRFPC0.OP2\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
d => \GRFPC0.OP2\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
d => \GRFPC0.OP2\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
d => \GRFPC0.OP2\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
d => \GRFPC0.OP2\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
d => \GRFPC0.OP2\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
d => \RETGRFPC0.OP2\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
d => \GRFPC0.OP2\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
d => \RETGRFPC0.OP2\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
d => \GRFPC0.OP2\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
d => \RETGRFPC0.OP2\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
d => \GRFPC0.OP2\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
d => \RETGRFPC0.OP2\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
d => \GRFPC0.OP2\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
d => \GRFPC0.OP2\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
d => \GRFPC0.OP2\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
d => \GRFPC0.OP2\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
d => \GRFPC0.OP2\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
d => \GRFPC0.OP2\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
d => \GRFPC0.OP2\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
d => \GRFPC0.OP2\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
d => \GRFPC0.OP2\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
d => \GRFPC0.OP2\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
d => \GRFPC0.OP2\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
d => \GRFPC0.OP2\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
d => \GRFPC0.OP2\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
d => \GRFPC0.OP2_I_M2\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
d => \GRFPC0.OP2\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
d => \GRFPC0.OP2\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
d => \GRFPC0.OP2\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
d => \GRFPC0.OP2\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
d => \GRFPC0.OP2\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
d => \GRFPC0.OP2\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
d => \GRFPC0.OP2\(52),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
d => \GRFPC0.OP2\(53),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
d => \GRFPC0.OP2\(54),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
d => \GRFPC0.OP2\(55),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
d => \GRFPC0.OP2\(56),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
d => \GRFPC0.OP2\(57),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
d => \GRFPC0.OP2\(58),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
d => \GRFPC0.OP2\(59),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
d => \GRFPC0.OP2\(60),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
d => \GRFPC0.OP2\(61),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
d => \GRFPC0.OP2\(62),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
d => \GRFPC0.OP2\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(0),
d => \GRFPC0.OP1_0_IV\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(1),
d => \GRFPC0.OP1_0_IV\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(2),
d => \GRFPC0.OP1_0_IV\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(3),
d => \GRFPC0.OP1_0_IV\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(4),
d => \GRFPC0.OP1_0_IV\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(5),
d => \GRFPC0.OP1_0_IV\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(6),
d => \GRFPC0.OP1_0_IV\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(7),
d => \GRFPC0.OP1_0_IV\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(8),
d => \GRFPC0.OP1_0_IV\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(9),
d => \GRFPC0.OP1_0_IV\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(10),
d => \GRFPC0.OP1_0_IV\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(11),
d => \GRFPC0.OP1_0_IV\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(12),
d => \GRFPC0.OP1_0_IV\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(13),
d => \GRFPC0.OP1_0_IV_I_A2\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(14),
d => \GRFPC0.OP1_0_IV\(14),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(15),
d => \GRFPC0.OP1_0_IV\(15),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(16),
d => \GRFPC0.OP1_0_IV\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(17),
d => \GRFPC0.OP1_0_IV\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(18),
d => \GRFPC0.OP1_0_IV\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(19),
d => \GRFPC0.OP1_0_IV\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(20),
d => \GRFPC0.OP1_0_IV\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(21),
d => \GRFPC0.OP1_0_IV\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(22),
d => \GRFPC0.OP1_0_IV\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(23),
d => \GRFPC0.OP1_0_IV\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(24),
d => \GRFPC0.OP1_0_IV\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(25),
d => \GRFPC0.OP1_0_IV\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(26),
d => \GRFPC0.OP1_0_IV\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(27),
d => \GRFPC0.OP1_0_IV\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(28),
d => \GRFPC0.OP1_0_IV\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
d => \GRFPC0.OP1_0_IV\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
d => \GRFPC0.OP1_0_IV\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
d => \GRFPC0.OP1_0_IV\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
d => \GRFPC0.OP1_0_IV\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
d => \GRFPC0.OP1_0_IV\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
d => \GRFPC0.OP1_0_IV\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
d => \GRFPC0.OP1_0_IV\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
d => \GRFPC0.OP1_0_IV\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
d => \GRFPC0.OP1_0_IV\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
d => \GRFPC0.OP1_0_IV\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
d => \GRFPC0.OP1_0_IV\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
d => \GRFPC0.OP1_0_IV\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
d => \GRFPC0.OP1_0_IV\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
d => \GRFPC0.OP1_0_IV\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
d => \GRFPC0.OP1_0_IV\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
d => \GRFPC0.OP1_0_IV\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
d => \GRFPC0.OP1_0_IV_I_A2\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
d => \GRFPC0.OP1_0_IV\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
d => \GRFPC0.OP1_0_IV\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
d => \GRFPC0.OP1_0_IV\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
d => \GRFPC0.OP1_0_IV\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
d => \GRFPC0.OP1_0_IV\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
d => \GRFPC0.OP1_0_IV\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
d => \GRFPC0.OP1_0_IV\(52),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
d => \GRFPC0.OP1_0_IV\(53),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
d => \GRFPC0.OP1_0_IV\(54),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
d => \GRFPC0.OP1_0_IV\(55),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
d => \GRFPC0.OP1_0_IV\(56),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
d => \GRFPC0.OP1_0_IV\(57),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
d => \GRFPC0.OP1_0_IV\(58),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
d => \GRFPC0.OP1_0_IV\(59),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
d => \GRFPC0.OP1_0_IV\(60),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
d => \GRFPC0.OP1_0_IV\(61),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
d => \GRFPC0.OP1_0_IV\(62),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
d => \GRFPC0.OP1_0_IV\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_REP3\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(0),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(1),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(2),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(3),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(4),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(5),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(6),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(7),
d => \RETGRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(16),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(17),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(18),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(19),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(20),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(21),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(22),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(23),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(24),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(25),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(26),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(27),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(28),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(29),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(30),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(31),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(32),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(33),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(34),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(35),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(36),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(37),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(38),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(39),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(40),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(40),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(41),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(42),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(43),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(44),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(45),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(46),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(47),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(48),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(49),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(50),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(51),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(52),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(52),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(53),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(53),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(54),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(54),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(55),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(55),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(56),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(56),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(57),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(57),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(58),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(58),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(59),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(59),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(60),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(60),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(61),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(61),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(62),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(62),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(63),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(63),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_64_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(64),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(64),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_NX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.NX\,
d => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G0_E_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SGNFEQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
d => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SQRT: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SQRT\,
d => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_NORM: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.NORM\,
d => \GRFPU0.GRFPU_X0.ITER.NORM_1_0_G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_LOB: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.LOB\,
d => \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.V_REP3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_ODDEXP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
d => \GRFPU0.GRFPU_X0.ITER.ODDEXP_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ST1.V\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SIGN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SIGN\,
d => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_M3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_EMIN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EMIN\,
d => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_BMLSB_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
d => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__G0_I_M3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_BMLSB_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
d => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__G0_I_M3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(0),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(1),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(2),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(3),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(4),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(5),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(5),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(6),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(6),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(7),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(7),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(8),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(8),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(9),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(9),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(10),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(10),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(11),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(11),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(12),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(12),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(13),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(13),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(14),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M4\(14),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(15),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(15),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(16),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2\(16),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(17),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M2\(17),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(18),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(18),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(19),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(19),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(20),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(20),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(21),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(21),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(22),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(22),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(23),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(23),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(24),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(24),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(25),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(25),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(26),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(26),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(27),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(27),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(28),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(28),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(29),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(29),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(30),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(30),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(31),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(31),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(32),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(32),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(33),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(33),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(34),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(34),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(35),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(35),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(36),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(36),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(37),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(37),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M3\(38),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(38),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(39),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M3\(39),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(40),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2_I_M3\(40),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(41),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(41),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(42),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(42),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(43),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(43),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(44),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(44),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(45),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(45),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(46),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(46),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(47),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(47),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1_I_M2\(48),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(48),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(49),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(49),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(50),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(50),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
d => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_1\(51),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
asdata => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_2\(51),
sload => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(52),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(53),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(54),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(55),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(56),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(57),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(58),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_59__G3_0_1210_I\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
d => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_60__G3_0_1238_I\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
d => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_0__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
d => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_1__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
d => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_REP3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
d => \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
d => \GRFPU0.GRFPU_X0.ITER.EXPOP_0_0_1__G2\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(0),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(1),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(2),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(3),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(4),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.IDCST\(5),
d => \GRFPU0.GRFPU_X0.ST1.IDCST\(5),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_EXC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXC\,
d => \GRFPC0.DIV.EXC_1_0_G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RS2D: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2D\,
d => N_114904,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_WRITE_RD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.WRITE_RD\,
d => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_READ_RS1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.READ_RS1\,
d => \GRFPC0.RFA.READ_RS1_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RS1D: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1D\,
d => N_114905,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_FIFO_FULL: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.FULL\,
d => \GRFPC0.FIFO.FULL_0_0_G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_D_FSTLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.FSTLCK\,
d => \GRFPC0.D.FSTLCK_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDD\,
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_D_FLDLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.FLDLCK\,
d => \GRFPC0.D.FLDLCK_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDWR\,
d => \GRFPC0.EX.CTRL.RDWR_0_0_G1_0_1307\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.SEQERR\,
d => \GRFPC0.WR2.CTRL.SEQERR_0_0_G1_0_1326_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.AFSR\,
d => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1347_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PEND\,
d => \GRFPC0.MEM.CTRL.PEND_0_0_G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PEND\,
d => \GRFPC0.EX.CTRL.PEND_0_0_G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PEND\,
d => \GRFPC0.WR.CTRL.PEND_0_0_G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_INST_1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(31),
d => N_109,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(31),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(31),
d => N_109,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(31),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(21),
d => N_99,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(21),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(21),
d => N_99,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(21),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_WR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.WR\(0),
d => \GRFPC0.FIFO.WR_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.STDFQ\,
d => \GRFPC0.WR2.CTRL.STDFQ_0_0_G1_0_1368_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RDWR\,
d => \GRFPC0.WR2.CTRL.RDWR_0_0_G1_0_1385_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.LD\,
d => \GRFPC0.WR2.CTRL.LD_0_0_G1_0_1395_A2_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.DIV\,
d => \GRFPC0.WR2.CTRL.DIV_0_0_G1_0_1405_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.CCWR\,
d => \GRFPC0.WR2.CTRL.CCWR_0_0_G1_0_1418_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.SEQERR\,
d => \GRFPC0.WR.CTRL.SEQERR_0_0_G1_0_1431_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDWR\,
d => \GRFPC0.WR.CTRL.RDWR_0_0_G1_0_1446_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.LD\,
d => \GRFPC0.WR.CTRL.LD_0_0_G1_0_1460_A2_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.DIV\,
d => \GRFPC0.WR.CTRL.DIV_0_0_G1_0_1470_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.CCWR\,
d => \GRFPC0.WR.CTRL.CCWR_0_0_G1_0_1485_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.AFSR\,
d => \GRFPC0.WR.CTRL.AFSR_0_0_G1_0_1500_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.SEQERR\,
d => \GRFPC0.MEM.CTRL.SEQERR_0_0_G1_0_1516_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDWR\,
d => \GRFPC0.MEM.CTRL.RDWR_0_0_G1_0_1534_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.LD\,
d => \GRFPC0.MEM.CTRL.LD_0_0_G1_0_1551_A2_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.DIV\,
d => \GRFPC0.MEM.CTRL.DIV_0_0_G1_0_1562_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.CCWR\,
d => \GRFPC0.MEM.CTRL.CCWR_0_0_G1_0_1580_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.AFSR\,
d => \GRFPC0.MEM.CTRL.AFSR_0_0_G1_0_1598_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_ST: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.ST\,
d => \GRFPC0.RFA.ST_0_0_G1_0_1622_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.DIV\,
d => \GRFPC0.EX.CTRL.DIV_0_0_G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.SEQERR\,
d => \GRFPC0.EX.CTRL.SEQERR_0_0_G1_0_1642_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.CCWR\,
d => \GRFPC0.EX.CTRL.CCWR_0_0_G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.SEQERR\,
d => \GRFPC0.RFA.SEQERR_0_0_G1_0_1661_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.LD\,
d => \GRFPC0.EX.CTRL.LD_0_0_G1_0_1683_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.AFSR\,
d => \GRFPC0.EX.CTRL.AFSR_0_0_G1_0_1698_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_EXC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.EXC\,
d => \GRFPC0.WR2.EXC_0_0_G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RDD\,
d => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.STDFQ\,
d => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.STDFQ\,
d => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDD\,
d => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.STDFQ\,
d => \GRFPC0.EX.CTRL.STDFQ_0_0_G1_0_1712_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PEND\,
d => \GRFPC0.WR2.CTRL.PEND_0_0_G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.STDFQ\,
d => \GRFPC0.RFA.STDFQ_0_0_G1_0_1733_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RDWR\,
d => \GRFPC0.RFA.RDWR_0_0_G1_0_1756_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RDD\,
d => \GRFPC0.RFA.RDD_0_0_G1_0_1784_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.LD\,
d => \GRFPC0.RFA.LD_0_0_G1_0_1809_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.AFSR\,
d => \GRFPC0.RFA.AFSR_0_0_G1_0_1834_A2\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(7),
d => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1856_I_A3\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_DIV_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(7),
d => \GRFPC0.WR2.CTRL.ID\(7),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RS1V\,
d => \GRFPC0.WR2.CTRL.RS1V\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_R_FSR_NONSTD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.NONSTD\,
d => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RS1V\,
d => \GRFPC0.WR.CTRL.RS1V\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_WR_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RS1V\,
d => \GRFPC0.MEM.CTRL.RS1V\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RS1V\,
d => \GRFPC0.EX.CTRL.RS1V\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_EX_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RS1V\,
d => \GRFPC0.RFA.READ_RS1\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(7),
d => \GRFPC0.MEM.CTRL.ID\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(7),
d => \GRFPC0.WR.CTRL.ID\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(7),
d => \GRFPC0.EX.CTRL.ID\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.VCNT\(0),
d => \GRFPC0.MEM.CTRL.VCNT\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CNT\(0),
d => N_386,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CNT\(1),
d => N_387,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(0),
d => \GRFPC0.EX.CTRL.RD\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(1),
d => \GRFPC0.EX.CTRL.RD\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(2),
d => \GRFPC0.EX.CTRL.RD\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(3),
d => \GRFPC0.EX.CTRL.RD\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(4),
d => \GRFPC0.EX.CTRL.RD\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(0),
d => N_103,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(1),
d => N_104,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(2),
d => N_105,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(3),
d => N_106,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(4),
d => N_107,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(0),
d => \GRFPC0.WR.CTRL.RD\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(1),
d => \GRFPC0.WR.CTRL.RD\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(2),
d => \GRFPC0.WR.CTRL.RD\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(3),
d => \GRFPC0.WR.CTRL.RD\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(4),
d => \GRFPC0.WR.CTRL.RD\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(0),
d => \GRFPC0.EX.CTRL.ID\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(1),
d => \GRFPC0.EX.CTRL.ID\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(2),
d => \GRFPC0.EX.CTRL.ID\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(3),
d => \GRFPC0.EX.CTRL.ID\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(4),
d => \GRFPC0.EX.CTRL.ID\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(5),
d => \GRFPC0.EX.CTRL.ID\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(0),
d => \GRFPC0.WR.CTRL.ID\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(1),
d => \GRFPC0.WR.CTRL.ID\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(2),
d => \GRFPC0.WR.CTRL.ID\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(3),
d => \GRFPC0.WR.CTRL.ID\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(4),
d => \GRFPC0.WR.CTRL.ID\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(5),
d => \GRFPC0.WR.CTRL.ID\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(0),
d => \GRFPC0.MEM.CTRL.RD\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(1),
d => \GRFPC0.MEM.CTRL.RD\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(2),
d => \GRFPC0.MEM.CTRL.RD\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(3),
d => \GRFPC0.MEM.CTRL.RD\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(4),
d => \GRFPC0.MEM.CTRL.RD\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(0),
d => \GRFPC0.MEM.CTRL.ID\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(1),
d => \GRFPC0.MEM.CTRL.ID\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(2),
d => \GRFPC0.MEM.CTRL.ID\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(3),
d => \GRFPC0.MEM.CTRL.ID\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(4),
d => \GRFPC0.MEM.CTRL.ID\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(5),
d => \GRFPC0.MEM.CTRL.ID\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.VCNT\(0),
d => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_VCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.VCNT\(1),
d => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(0),
d => N_114906,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(1),
d => N_114907,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(2),
d => \GRFPC0.DIV.EXCT_0_0_2__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(3),
d => N_114908,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(4),
d => N_114909,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(5),
d => \GRFPU0.GRFPU_X0.COMB.VEXC_5_5_I_0\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(0),
d => \RETGRFPC0.DIV.RESULT_0_0_0__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(1),
d => \RETGRFPC0.DIV.RESULT_0_0_1__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(2),
d => \GRFPC0.DIV.RESULT_0_0_2__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(3),
d => \GRFPC0.DIV.RESULT_0_0_3__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(4),
d => \RETGRFPC0.DIV.RESULT_0_0_4__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(5),
d => \GRFPC0.DIV.RESULT_0_0_5__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(6),
d => \GRFPC0.DIV.RESULT_0_0_6__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(7),
d => \GRFPC0.DIV.RESULT_0_0_7__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(8),
d => \RETGRFPC0.DIV.RESULT_0_0_8__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(9),
d => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(10),
d => \RETGRFPC0.DIV.RESULT_0_0_10__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(11),
d => \GRFPC0.DIV.RESULT_0_0_11__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(12),
d => \GRFPC0.DIV.RESULT_0_0_12__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(13),
d => \GRFPC0.DIV.RESULT_0_0_13__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(14),
d => \RETGRFPC0.DIV.RESULT_0_0_14__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(15),
d => \GRFPC0.DIV.RESULT_0_0_15__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(16),
d => \RETGRFPC0.DIV.RESULT_0_0_16__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(17),
d => \GRFPC0.DIV.RESULT_0_0_17__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(18),
d => \GRFPC0.DIV.RESULT_0_0_18__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(19),
d => \GRFPC0.DIV.RESULT_0_0_19__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(20),
d => \GRFPC0.DIV.RESULT_0_0_20__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(21),
d => \GRFPC0.DIV.RESULT_0_0_21__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(22),
d => \GRFPC0.DIV.RESULT_0_0_22__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(23),
d => \GRFPC0.DIV.RESULT_0_0_23__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(24),
d => \GRFPC0.DIV.RESULT_0_0_24__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(25),
d => \RETGRFPC0.DIV.RESULT_0_0_25__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(26),
d => \GRFPC0.DIV.RESULT_0_0_26__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(27),
d => \RETGRFPC0.DIV.RESULT_0_0_27__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(28),
d => \GRFPC0.DIV.RESULT_0_0_28__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(29),
d => \RETGRFPC0.DIV.RESULT_0_0_29__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(30),
d => \GRFPC0.DIV.RESULT_0_0_30__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(31),
d => \RETGRFPC0.DIV.RESULT_0_0_31__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(32),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(33),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(34),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(35),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(36),
d => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(37),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(38),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(39),
d => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(40),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(41),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(41),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(42),
d => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(43),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(43),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(44),
d => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(45),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(46),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(47),
d => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(48),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(49),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(50),
d => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(51),
d => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(52),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(52),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(53),
d => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(54),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(54),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(55),
d => \GRFPC0.DIV.RESULT_0_0_55__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(56),
d => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(57),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(58),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(59),
d => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(60),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(60),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(61),
d => \GRFPU0.GRFPU_X0.RES_1_6_I\(61),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(62),
d => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(63),
d => \GRFPU0.GRFPU_X0.ST4.REG\(63),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2_REP2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.VCNT\(0),
d => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_VCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.VCNT\(1),
d => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.RD\(0),
d => \GRFPC0.R.FSR.RD_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.RD\(1),
d => \GRFPC0.R.FSR.RD_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(0),
d => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(1),
d => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(2),
d => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(3),
d => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(4),
d => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(0),
d => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(1),
d => \GRFPC0.EX.RREG.EXCT_0_0_1__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(2),
d => \GRFPC0.EX.RREG.EXCT_0_0_2__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(3),
d => \GRFPC0.EX.RREG.EXCT_0_0_3__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(4),
d => \GRFPC0.EX.RREG.EXCT_0_0_4__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(5),
d => \GRFPC0.EX.RREG.EXCT_0_0_5__G0_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(0),
d => \GRFPC0.OP1_0_IV\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_0__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(1),
d => \GRFPC0.OP1_0_IV\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_1__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(2),
d => \GRFPC0.OP1_0_IV\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_2__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(3),
d => \GRFPC0.OP1_0_IV\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_3__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(4),
d => \GRFPC0.OP1_0_IV\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_4__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(5),
d => \GRFPC0.OP1_0_IV\(5),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_5__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(6),
d => \GRFPC0.OP1_0_IV\(6),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_6__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(7),
d => \GRFPC0.OP1_0_IV\(7),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_7__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(8),
d => \GRFPC0.OP1_0_IV\(8),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_8__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(9),
d => \GRFPC0.OP1_0_IV\(9),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_9__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(10),
d => \GRFPC0.OP1_0_IV\(10),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_10__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(11),
d => \GRFPC0.OP1_0_IV\(11),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_11__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(12),
d => \GRFPC0.OP1_0_IV\(12),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_12__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(13),
d => \GRFPC0.OP1_0_IV_I_A2\(13),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_13__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(14),
d => \GRFPC0.OP1_0_IV\(14),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_14__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(15),
d => \GRFPC0.OP1_0_IV\(15),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_15__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(16),
d => \GRFPC0.OP1_0_IV\(16),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_16__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(17),
d => \GRFPC0.OP1_0_IV\(17),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_17__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(18),
d => \GRFPC0.OP1_0_IV\(18),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_18__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(19),
d => \GRFPC0.OP1_0_IV\(19),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_19__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(20),
d => \GRFPC0.OP1_0_IV\(20),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_20__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(21),
d => \GRFPC0.OP1_0_IV\(21),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_21__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(22),
d => \GRFPC0.OP1_0_IV\(22),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_22__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(23),
d => \GRFPC0.OP1_0_IV\(23),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_23__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(24),
d => \GRFPC0.OP1_0_IV\(24),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_24__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(25),
d => \GRFPC0.OP1_0_IV\(25),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_25__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(26),
d => \GRFPC0.OP1_0_IV\(26),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_26__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(27),
d => \GRFPC0.OP1_0_IV\(27),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_27__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(28),
d => \GRFPC0.OP1_0_IV\(28),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_28__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(29),
d => \GRFPC0.OP1_0_IV\(29),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_29__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(30),
d => \GRFPC0.OP1_0_IV\(30),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_30__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(31),
d => \GRFPC0.OP1_0_IV\(31),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_31__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(32),
d => \GRFPC0.OP1_0_IV\(32),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(32),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(33),
d => \GRFPC0.OP1_0_IV\(33),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(33),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(34),
d => \GRFPC0.OP1_0_IV\(34),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(34),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(35),
d => \GRFPC0.OP1_0_IV\(35),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(35),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(36),
d => \GRFPC0.OP1_0_IV\(36),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(37),
d => \GRFPC0.OP1_0_IV\(37),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(37),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(38),
d => \GRFPC0.OP1_0_IV\(38),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(38),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(39),
d => \GRFPC0.OP1_0_IV\(39),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(39),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(40),
d => \GRFPC0.OP1_0_IV\(40),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(40),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(41),
d => \GRFPC0.OP1_0_IV\(41),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(41),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(42),
d => \GRFPC0.OP1_0_IV\(42),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(43),
d => \GRFPC0.OP1_0_IV\(43),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(43),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(44),
d => \GRFPC0.OP1_0_IV\(44),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_44__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(45),
d => \GRFPC0.OP1_0_IV_I_A2\(45),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(45),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(46),
d => \GRFPC0.OP1_0_IV\(46),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(46),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(47),
d => \GRFPC0.OP1_0_IV\(47),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_47__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(48),
d => \GRFPC0.OP1_0_IV\(48),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(48),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(49),
d => \GRFPC0.OP1_0_IV\(49),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(49),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(50),
d => \GRFPC0.OP1_0_IV\(50),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_50__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(51),
d => \GRFPC0.OP1_0_IV\(51),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(52),
d => \GRFPC0.OP1_0_IV\(52),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(52),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(53),
d => \GRFPC0.OP1_0_IV\(53),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_53__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(54),
d => \GRFPC0.OP1_0_IV\(54),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(54),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(55),
d => \GRFPC0.OP1_0_IV\(55),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.DIV.RESULT_0_0_55__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(56),
d => \GRFPC0.OP1_0_IV\(56),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_56__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(57),
d => \GRFPC0.OP1_0_IV\(57),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(57),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(58),
d => \GRFPC0.OP1_0_IV\(58),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(58),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(59),
d => \GRFPC0.OP1_0_IV\(59),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_59__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(60),
d => \GRFPC0.OP1_0_IV\(60),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(60),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(61),
d => \GRFPC0.OP1_0_IV\(61),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.RES_1_6_I\(61),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(62),
d => \GRFPC0.OP1_0_IV\(62),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPC0.WR.RREG.RES_0_0_62__G3\,
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(63),
d => \GRFPC0.OP1_0_IV\(63),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA_0_M2_X\,
asdata => \GRFPU0.GRFPU_X0.ST4.REG\(63),
sload => N_38_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(0),
d => \GRFPC0.R.STDATA_0_0_0__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.R.STDATA_0_0_0__G2\,
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(1),
d => \GRFPC0.R.STDATA_0_0_1__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.R.STDATA_0_0_1__G2\,
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(2),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(2),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(3),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(3),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(4),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(4),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(5),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(5),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(6),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(6),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(6),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(7),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(7),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(8),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(8),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(8),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(9),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(9),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(9),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(10),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(10),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(11),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(11),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(11),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(12),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(12),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(12),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(13),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(13),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(13),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(14),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(14),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(14),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(15),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(15),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(15),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(16),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(16),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(16),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(17),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(17),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(17),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(18),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(18),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(18),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(19),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(19),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(19),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(20),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(20),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(20),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(21),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(21),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(21),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(22),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(22),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(22),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(23),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(23),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(23),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(24),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(24),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(25),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(25),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(25),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(26),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(26),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(26),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(27),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(27),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(27),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(28),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(28),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(28),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(29),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(29),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(29),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(30),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(30),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(30),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(31),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(31),
sload => \GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_DIV_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(0),
d => \GRFPC0.WR2.CTRL.ID\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(1),
d => \GRFPC0.WR2.CTRL.ID\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(2),
d => \GRFPC0.WR2.CTRL.ID\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(3),
d => \GRFPC0.WR2.CTRL.ID\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(4),
d => \GRFPC0.WR2.CTRL.ID\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(5),
d => \GRFPC0.WR2.CTRL.ID\(5),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(0),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(0),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(0),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(1),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(1),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(2),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(2),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(2),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(3),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(3),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(3),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(4),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(4),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(4),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(5),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(5),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(5),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(6),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(6),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(6),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(7),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(7),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(7),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(8),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(8),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(8),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(9),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(9),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(9),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(10),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(10),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(10),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(11),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(11),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(11),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(12),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(12),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(12),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(13),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1_I_M2\(13),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2_I_M2\(13),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(14),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(14),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(14),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(15),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(15),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(15),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(16),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(16),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(16),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(17),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(17),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(17),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(18),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(18),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(18),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(19),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(19),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(19),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(20),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(20),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(20),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(21),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(21),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(21),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(22),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(22),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(22),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(23),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(23),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(23),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(24),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(24),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(24),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(25),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(25),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(25),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(26),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(26),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(26),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(27),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(27),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(27),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(28),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(28),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(28),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(29),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(29),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(29),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(30),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(30),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(30),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(31),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(31),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(31),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(32),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(32),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(32),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(33),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(33),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(33),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(34),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(34),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(34),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(35),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(35),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(35),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(36),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(36),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(36),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(37),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(37),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(37),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(38),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(38),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(38),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(39),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(39),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(39),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(40),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(40),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(40),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(41),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(41),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(41),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(42),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(42),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(42),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(43),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(43),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(43),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(44),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(44),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(44),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(45),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1_I_M2\(45),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2_I_M2\(45),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(46),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(46),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(46),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(47),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(47),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(47),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(48),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(48),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(48),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(49),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(49),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(49),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(50),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(50),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(50),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(51),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(51),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(51),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(52),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(52),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(52),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(53),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(53),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(53),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(54),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(54),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(54),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(55),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(55),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(55),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(56),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(56),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(56),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(57),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(57),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(57),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(58),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(58),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(58),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(59),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(59),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(59),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(60),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(60),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(60),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(61),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(61),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(61),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(62),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(62),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(62),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(63),
d => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_1\(63),
clk => N_4,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_X\,
asdata => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES_1_2\(63),
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_FSR_FCC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FCC\(0),
d => \GRFPC0.R.FSR.FCC_0_0_0__G0_I_M4_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FCC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FCC\(1),
d => \GRFPC0.R.FSR.FCC_0_0_1__G0_I_M4_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(0),
d => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.RFA.RD\(0),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(1),
d => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.RFA.RD\(1),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(2),
d => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.RFA.RD\(2),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(3),
d => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.RFA.RD\(3),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(4),
d => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.RFA.RD\(4),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_R_FSR_FTT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(0),
d => \GRFPC0.R.FSR.FTT_0_0_0__G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FTT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(1),
d => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FTT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(2),
d => \GRFPC0.R.FSR.FTT_0_0_2__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(0),
d => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(1),
d => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(2),
d => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(3),
d => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(4),
d => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(0),
d => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(1),
d => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(2),
d => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(3),
d => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(4),
d => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_INST_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(0),
d => N_78,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(0),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(1),
d => N_79,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(1),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(2),
d => N_80,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(2),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(3),
d => N_81,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(3),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(4),
d => N_82,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(4),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(5),
d => N_83,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(5),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(6),
d => N_84,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(6),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(7),
d => N_85,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(7),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(8),
d => N_86,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(8),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(9),
d => N_87,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(9),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(10),
d => N_88,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(10),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(11),
d => N_89,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(11),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(12),
d => N_90,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(12),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(13),
d => N_91,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(13),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(14),
d => N_92,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(14),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(15),
d => N_93,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(15),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(16),
d => N_94,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(16),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(17),
d => N_95,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(17),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(18),
d => N_96,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(18),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(19),
d => N_97,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(19),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(0),
d => N_78,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(0),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(1),
d => N_79,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(1),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(2),
d => N_80,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(2),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(3),
d => N_81,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(3),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(4),
d => N_82,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(4),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(5),
d => N_83,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(5),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(6),
d => N_84,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(6),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(7),
d => N_85,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(7),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(8),
d => N_86,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(8),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(9),
d => N_87,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(9),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(10),
d => N_88,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(10),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(11),
d => N_89,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(11),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(12),
d => N_90,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(12),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(13),
d => N_91,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(13),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(14),
d => N_92,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(14),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(15),
d => N_93,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(15),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(16),
d => N_94,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(16),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(17),
d => N_95,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(17),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(18),
d => N_96,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(18),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(19),
d => N_97,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(19),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(23),
d => N_101,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(23),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(24),
d => N_102,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(24),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(25),
d => N_103,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(25),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(26),
d => N_104,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(26),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(27),
d => N_105,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(27),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(28),
d => N_106,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(28),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(29),
d => N_107,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_0\(29),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(23),
d => N_101,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(23),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(24),
d => N_102,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(24),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(25),
d => N_103,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(25),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(26),
d => N_104,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(26),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(27),
d => N_105,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(27),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(28),
d => N_106,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(28),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(29),
d => N_107,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.INST_1\(29),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_EX_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(0),
d => \GRFPC0.V.STDATA_14_I_M2\(0),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(30),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(1),
d => \GRFPC0.V.STDATA_14\(1),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(31),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(2),
d => \GRFPC0.V.STDATA_14\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(2),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(3),
d => \GRFPC0.V.STDATA_14\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(3),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(4),
d => \GRFPC0.V.STDATA_14\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(4),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(5),
d => \GRFPC0.V.STDATA_14\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(5),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(6),
d => \GRFPC0.V.STDATA_14_REP0\(6),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(6),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(7),
d => \GRFPC0.V.STDATA_14\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(7),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(8),
d => \GRFPC0.V.STDATA_14\(8),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(8),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(9),
d => \GRFPC0.V.STDATA_14\(9),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(9),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(10),
d => \GRFPC0.V.STDATA_14\(10),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(10),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(11),
d => \GRFPC0.V.STDATA_14_REP1\(11),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(11),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(12),
d => \GRFPC0.V.STDATA_14\(12),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(12),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(13),
d => \GRFPC0.V.STDATA_14\(13),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(13),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(14),
d => \GRFPC0.V.STDATA_14\(14),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(14),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(15),
d => \GRFPC0.V.STDATA_14\(15),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(15),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(16),
d => \GRFPC0.V.STDATA_14\(16),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(16),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(17),
d => \GRFPC0.V.STDATA_14_I_M2\(17),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(17),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(18),
d => \GRFPC0.V.STDATA_14\(18),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(18),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(19),
d => \GRFPC0.V.STDATA_14_I_M2\(19),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(19),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(20),
d => \GRFPC0.EX.CTRL.INST_0_0_20__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(21),
d => \GRFPC0.V.STDATA_14\(21),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(21),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(22),
d => \GRFPC0.EX.CTRL.INST_0_0_22__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(23),
d => \GRFPC0.V.STDATA_14\(23),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(23),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(24),
d => \GRFPC0.V.STDATA_14\(24),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(24),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(25),
d => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(25),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(26),
d => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(26),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(27),
d => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(27),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(28),
d => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(28),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(29),
d => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(29),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(30),
d => \GRFPC0.EX.CTRL.INST_0_0_30__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(31),
d => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1287_M3\,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_1_0_I_M2_X\(31),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(2),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(2),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(0),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(3),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(3),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(1),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(4),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(4),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(2),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(5),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(5),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(3),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(6),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(6),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(4),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(7),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(7),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(5),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(8),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(8),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(6),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(9),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(9),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(7),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(10),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(10),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(8),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(11),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(11),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(9),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(12),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(12),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(10),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(13),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(13),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(11),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(14),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(14),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(12),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(15),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(15),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(13),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(16),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(16),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(14),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(17),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(17),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(15),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(18),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(18),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(16),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(19),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(19),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(17),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(20),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(20),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(18),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(21),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(21),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(19),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(22),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(22),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(20),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(23),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(23),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(21),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(24),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(22),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(25),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(23),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(26),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(24),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(27),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(27),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(25),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(28),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(28),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(26),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(29),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3_I_M2\(29),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(27),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(30),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(30),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(28),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(31),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(31),
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1_0_I_M2_X\(29),
sload => \GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_FIFO_PC_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(2),
d => N_48,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(2),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(3),
d => N_49,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(3),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(4),
d => N_50,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(4),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(5),
d => N_51,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(5),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(6),
d => N_52,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(6),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(7),
d => N_53,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(7),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(8),
d => N_54,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(8),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(9),
d => N_55,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(9),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(10),
d => N_56,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(10),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(11),
d => N_57,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(11),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(12),
d => N_58,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(12),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(13),
d => N_59,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(13),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(14),
d => N_60,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(14),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(15),
d => N_61,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(15),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(16),
d => N_62,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(16),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(17),
d => N_63,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(17),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(18),
d => N_64,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(18),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(19),
d => N_65,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(19),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(20),
d => N_66,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(20),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(21),
d => N_67,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(21),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(22),
d => N_68,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(22),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(23),
d => N_69,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(23),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(24),
d => N_70,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(24),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(25),
d => N_71,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(25),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(26),
d => N_72,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(26),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(27),
d => N_73,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(27),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(28),
d => N_74,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(28),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(29),
d => N_75,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(29),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(30),
d => N_76,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(30),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(31),
d => N_77,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_0\(31),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_0_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(2),
d => N_48,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(2),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(3),
d => N_49,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(3),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(4),
d => N_50,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(4),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(5),
d => N_51,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(5),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(6),
d => N_52,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(6),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(7),
d => N_53,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(7),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(8),
d => N_54,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(8),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(9),
d => N_55,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(9),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(10),
d => N_56,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(10),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(11),
d => N_57,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(11),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(12),
d => N_58,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(12),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(13),
d => N_59,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(13),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(14),
d => N_60,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(14),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(15),
d => N_61,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(15),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(16),
d => N_62,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(16),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(17),
d => N_63,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(17),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(18),
d => N_64,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(18),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(19),
d => N_65,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(19),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(20),
d => N_66,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(20),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(21),
d => N_67,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(21),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(22),
d => N_68,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(22),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(23),
d => N_69,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(23),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(24),
d => N_70,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(24),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(25),
d => N_71,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(25),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(26),
d => N_72,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(26),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(27),
d => N_73,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(27),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(28),
d => N_74,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(28),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(29),
d => N_75,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(29),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(30),
d => N_76,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(30),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(31),
d => N_77,
clk => N_4,
clrn => VCC,
ena => N_38,
asdata => \GRFPC0.FIFO.PC_1\(31),
sclr => N_3_I,
sload => \GRFPC0.VFIFO.INST_1_1_0_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_VCNT_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(0),
d => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_1880_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(1),
d => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_1911_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(2),
d => \GRFPC0.FIFO.VCNT_0_0_0_2__G2_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(0),
d => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_1943_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(1),
d => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_1973_I\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(2),
d => \GRFPC0.FIFO.VCNT_1_0_0_2__G2_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_D_STDLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(0),
d => \GRFPC0.D.STDLCK_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(1),
d => \GRFPC0.D.STDLCK_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(2),
d => \GRFPC0.D.STDLCK_0_0_2__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(3),
d => \GRFPC0.D.STDLCK_0_0_3__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(4),
d => \GRFPC0.D.STDLCK_0_0_4__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(5),
d => \GRFPC0.D.STDLCK_0_0_5__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(6),
d => \GRFPC0.D.STDLCK_0_0_6__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(7),
d => \GRFPC0.D.STDLCK_0_0_7__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(8),
d => \GRFPC0.D.STDLCK_0_0_8__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(9),
d => \GRFPC0.D.STDLCK_0_0_9__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(10),
d => \GRFPC0.D.STDLCK_0_0_10__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(11),
d => \GRFPC0.D.STDLCK_0_0_11__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(12),
d => \GRFPC0.D.STDLCK_0_0_12__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(13),
d => \GRFPC0.D.STDLCK_0_0_13__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(14),
d => \GRFPC0.D.STDLCK_0_0_14__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(15),
d => \GRFPC0.D.STDLCK_0_0_15__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(0),
d => \GRFPC0.D.LDLCK_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(1),
d => \GRFPC0.D.LDLCK_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(2),
d => \GRFPC0.D.LDLCK_0_0_2__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(3),
d => \GRFPC0.D.LDLCK_0_0_3__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(4),
d => \GRFPC0.D.LDLCK_0_0_4__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(5),
d => \GRFPC0.D.LDLCK_0_0_5__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(6),
d => \GRFPC0.D.LDLCK_0_0_6__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(7),
d => \GRFPC0.D.LDLCK_0_0_7__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(8),
d => \GRFPC0.D.LDLCK_0_0_8__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(9),
d => \GRFPC0.D.LDLCK_0_0_9__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(10),
d => \GRFPC0.D.LDLCK_0_0_10__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(11),
d => \GRFPC0.D.LDLCK_0_0_11__G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(12),
d => \GRFPC0.D.LDLCK_0_0_12__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(13),
d => \GRFPC0.D.LDLCK_0_0_13__G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(14),
d => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(15),
d => \GRFPC0.D.LDLCK_0_0_15__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(16),
d => \GRFPC0.D.LDLCK_0_0_16__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(17),
d => \GRFPC0.D.LDLCK_0_0_17__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(18),
d => \GRFPC0.D.LDLCK_0_0_18__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(19),
d => \GRFPC0.D.LDLCK_0_0_19__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(20),
d => \GRFPC0.D.LDLCK_0_0_20__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(21),
d => \GRFPC0.D.LDLCK_0_0_21__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(22),
d => \GRFPC0.D.LDLCK_0_0_22__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(23),
d => \GRFPC0.D.LDLCK_0_0_23__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(24),
d => \GRFPC0.D.LDLCK_0_0_24__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(25),
d => \GRFPC0.D.LDLCK_0_0_25__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(26),
d => \GRFPC0.D.LDLCK_0_0_26__G1_0\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(27),
d => \GRFPC0.D.LDLCK_0_0_27__G1_X\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(28),
d => \GRFPC0.D.LDLCK_0_0_28__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(29),
d => \GRFPC0.D.LDLCK_0_0_29__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(30),
d => \GRFPC0.D.LDLCK_0_0_30__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(31),
d => \GRFPC0.D.LDLCK_0_0_31__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(0),
d => \GRFPC0.D.STLCK_0_0_0__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(1),
d => \GRFPC0.D.STLCK_0_0_1__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(2),
d => \GRFPC0.D.STLCK_0_0_2__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(3),
d => \GRFPC0.D.STLCK_0_0_3__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(4),
d => \GRFPC0.D.STLCK_0_0_4__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(5),
d => \GRFPC0.D.STLCK_0_0_5__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(6),
d => \GRFPC0.D.STLCK_0_0_6__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(7),
d => \GRFPC0.D.STLCK_0_0_7__G1_6\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(8),
d => \GRFPC0.D.STLCK_0_0_8__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(9),
d => \GRFPC0.D.STLCK_0_0_9__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(10),
d => \GRFPC0.D.STLCK_0_0_10__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(11),
d => \GRFPC0.D.STLCK_0_0_11__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(12),
d => \GRFPC0.D.STLCK_0_0_12__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(13),
d => \GRFPC0.D.STLCK_0_0_13__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(14),
d => \GRFPC0.D.STLCK_0_0_14__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(15),
d => \GRFPC0.D.STLCK_0_0_15__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(16),
d => \GRFPC0.D.STLCK_0_0_16__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(17),
d => \GRFPC0.D.STLCK_0_0_17__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(18),
d => \GRFPC0.D.STLCK_0_0_18__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(19),
d => \GRFPC0.D.STLCK_0_0_19__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(20),
d => \GRFPC0.D.STLCK_0_0_20__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(21),
d => \GRFPC0.D.STLCK_0_0_21__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(22),
d => \GRFPC0.D.STLCK_0_0_22__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(23),
d => \GRFPC0.D.STLCK_0_0_23__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(24),
d => \GRFPC0.D.STLCK_0_0_24__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(25),
d => \GRFPC0.D.STLCK_0_0_25__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(26),
d => \GRFPC0.D.STLCK_0_0_26__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(27),
d => \GRFPC0.D.STLCK_0_0_27__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(28),
d => \GRFPC0.D.STLCK_0_0_28__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(29),
d => \GRFPC0.D.STLCK_0_0_29__G1_5\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(30),
d => \GRFPC0.D.STLCK_0_0_30__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(31),
d => \GRFPC0.D.STLCK_0_0_31__G1\,
clk => N_4,
clrn => VCC,
ena => N_38,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_G0_0_O3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD0\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD1\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD2\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD3\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(4),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD4\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD5\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
d => \GRFPU0.GRFPU_X0.UN9_ITADDO_ADD6\,
clk => N_4,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(0),
d => \GRFPC0.VEX.CTRL.ID_2_ADD0\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(1),
d => \GRFPC0.VEX.CTRL.ID_2_ADD1\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(2),
d => \GRFPC0.VEX.CTRL.ID_2_ADD2\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(3),
d => \GRFPC0.VEX.CTRL.ID_2_ADD3\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(4),
d => \GRFPC0.VEX.CTRL.ID_2_ADD4\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(5),
d => \GRFPC0.VEX.CTRL.ID_2_ADD5\,
clk => N_4,
clrn => VCC,
ena => N_38,
sclr => N_3_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
d => \GRFPU0.GRFPU_X0.ST1.EXP2_M\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
d => N_141802,
clk => N_4,
clrn => VCC,
asdata => N_141803,
sclr => \GRFPU0.GRFPU_X0.ST1.V_0_0_G4_I\,
sload => \GRFPC0.V.STDATA_14_I\(6),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(38),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1_40_M8_I\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(44),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(51),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_2\(52),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(54),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_0\(55),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(56),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(57),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I\(58),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
d => \RETGRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(0),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(1),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(2),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(3),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(4),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(5),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(6),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(7),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(8),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(9),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
d => \GRFPU0.GRFPU_X0.ITER.EXP_M\(10),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(52),
d => \GRFPU0.GRFPU_X0.L3_0_7\(0),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(52),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(53),
d => \GRFPU0.GRFPU_X0.L3_0_7\(1),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(53),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(54),
d => \GRFPU0.GRFPU_X0.L3_0_7\(2),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0\(54),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(55),
d => \GRFPU0.GRFPU_X0.L3_0_7\(3),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(55),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(56),
d => \GRFPU0.GRFPU_X0.L3_0_7\(4),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(56),
sload => \GRFPU0.GRFPU_X0.COMB.UINT17_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(57),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(57),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(57),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(58),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(58),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(58),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(59),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_S\(59),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(59),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(60),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(60),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(60),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(61),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2\(61),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(61),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(62),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(62),
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48_I_M3\(62),
sload => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(29),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(29),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(30),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(30),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(31),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_37\(31),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(32),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(33),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(34),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(35),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(36),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(37),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(38),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_47\(38),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(39),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(40),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(41),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_47\(41),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(42),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(43),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(44),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(45),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(46),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_47\(46),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(47),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(48),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(49),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_47\(49),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(50),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G4\,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(51),
d => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_4_03\,
clk => N_4,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.VST3.REG_47\(51),
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\,
sload => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(52),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(53),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(54),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(55),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_3__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(56),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_4__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(57),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_5__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(58),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_6__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(59),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_7__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(60),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(61),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(62),
d => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_10__G0_0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_89_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(89),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(89),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_90_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(90),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(90),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_91_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(91),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(91),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_92_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(92),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(92),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_93_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(93),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(93),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_94_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(94),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(94),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_95_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(95),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(95),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_96_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(96),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(96),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_97_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(97),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(97),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_98_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(98),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(98),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_99_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(99),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(99),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_100_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(100),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(100),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_101_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(101),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(101),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_102_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(102),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(102),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_103_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(103),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(103),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_104_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(104),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(104),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_105_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(105),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(105),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_106_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(106),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(106),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_107_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(107),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(107),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_108_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(108),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(108),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_109_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(109),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(109),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_110_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(110),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(110),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_111_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(111),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(111),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_112_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(112),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(112),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_113_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(113),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(113),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_114_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(114),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(114),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_115_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(115),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(115),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_116_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(116),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(116),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_117_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(117),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(117),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_118_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(118),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(118),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_119_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(119),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(119),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_120_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(120),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(120),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_121_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R2\(121),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(121),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(16),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IND\(16),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(17),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IND\(17),
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(18),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(19),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(20),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(21),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(22),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(23),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(24),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD6\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(25),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(26),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD8\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(27),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD9\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(28),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(29),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD11\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(30),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(31),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD13\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(32),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD14\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(33),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD15\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(34),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD16\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(35),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_ADD17\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(36),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(37),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(38),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(39),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(40),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(41),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(42),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD6\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(43),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(44),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD8\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(45),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD9\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(46),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(47),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD11\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(48),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(49),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD13\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(50),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD14\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(51),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD15\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(52),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD16\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(53),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD17\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(54),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD18\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(55),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD19\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(56),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD20\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(57),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD21\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(58),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD22\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(59),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD23\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(60),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD24\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(61),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD25\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(62),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD26\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(63),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD27\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_64_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(64),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD28\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_65_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(65),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD29\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_66_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(66),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD30\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_67_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(67),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD31\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_68_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(68),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD32\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_69_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(69),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD33\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_70_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(70),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD34\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_71_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(71),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_2_ADD35\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_72_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(72),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD0\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_73_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(73),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD1\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_74_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(74),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD2\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_75_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(75),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD3\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_76_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(76),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD4\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_77_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(77),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD5\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_78_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(78),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD6\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_79_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(79),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD7\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_80_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(80),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD8\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_81_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(81),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD9\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_82_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(82),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD10\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_83_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(83),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD11\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1_84_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1\(84),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_ADD12\,
clk => N_4,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
N_3 <= RST_INTERNAL;
N_4 <= CLK_INTERNAL;
N_38 <= HOLDN_INTERNAL;
N_39 <= CPI_FLUSH_INTERNAL;
N_40 <= CPI_EXACK_INTERNAL;
N_41 <= CPI_A_RS1_INTERNAL;
N_42 <= CPI_A_RS1_INTERNAL_0;
N_43 <= CPI_A_RS1_INTERNAL_1;
N_44 <= CPI_A_RS1_INTERNAL_2;
N_45 <= CPI_A_RS1_INTERNAL_3;
N_46 <= CPI_D_PC_INTERNAL;
N_47 <= CPI_D_PC_INTERNAL_0;
N_48 <= CPI_D_PC_INTERNAL_1;
N_49 <= CPI_D_PC_INTERNAL_2;
N_50 <= CPI_D_PC_INTERNAL_3;
N_51 <= CPI_D_PC_INTERNAL_4;
N_52 <= CPI_D_PC_INTERNAL_5;
N_53 <= CPI_D_PC_INTERNAL_6;
N_54 <= CPI_D_PC_INTERNAL_7;
N_55 <= CPI_D_PC_INTERNAL_8;
N_56 <= CPI_D_PC_INTERNAL_9;
N_57 <= CPI_D_PC_INTERNAL_10;
N_58 <= CPI_D_PC_INTERNAL_11;
N_59 <= CPI_D_PC_INTERNAL_12;
N_60 <= CPI_D_PC_INTERNAL_13;
N_61 <= CPI_D_PC_INTERNAL_14;
N_62 <= CPI_D_PC_INTERNAL_15;
N_63 <= CPI_D_PC_INTERNAL_16;
N_64 <= CPI_D_PC_INTERNAL_17;
N_65 <= CPI_D_PC_INTERNAL_18;
N_66 <= CPI_D_PC_INTERNAL_19;
N_67 <= CPI_D_PC_INTERNAL_20;
N_68 <= CPI_D_PC_INTERNAL_21;
N_69 <= CPI_D_PC_INTERNAL_22;
N_70 <= CPI_D_PC_INTERNAL_23;
N_71 <= CPI_D_PC_INTERNAL_24;
N_72 <= CPI_D_PC_INTERNAL_25;
N_73 <= CPI_D_PC_INTERNAL_26;
N_74 <= CPI_D_PC_INTERNAL_27;
N_75 <= CPI_D_PC_INTERNAL_28;
N_76 <= CPI_D_PC_INTERNAL_29;
N_77 <= CPI_D_PC_INTERNAL_30;
N_78 <= CPI_D_INST_INTERNAL;
N_79 <= CPI_D_INST_INTERNAL_0;
N_80 <= CPI_D_INST_INTERNAL_1;
N_81 <= CPI_D_INST_INTERNAL_2;
N_82 <= CPI_D_INST_INTERNAL_3;
N_83 <= CPI_D_INST_INTERNAL_4;
N_84 <= CPI_D_INST_INTERNAL_5;
N_85 <= CPI_D_INST_INTERNAL_6;
N_86 <= CPI_D_INST_INTERNAL_7;
N_87 <= CPI_D_INST_INTERNAL_8;
N_88 <= CPI_D_INST_INTERNAL_9;
N_89 <= CPI_D_INST_INTERNAL_10;
N_90 <= CPI_D_INST_INTERNAL_11;
N_91 <= CPI_D_INST_INTERNAL_12;
N_92 <= CPI_D_INST_INTERNAL_13;
N_93 <= CPI_D_INST_INTERNAL_14;
N_94 <= CPI_D_INST_INTERNAL_15;
N_95 <= CPI_D_INST_INTERNAL_16;
N_96 <= CPI_D_INST_INTERNAL_17;
N_97 <= CPI_D_INST_INTERNAL_18;
N_98 <= CPI_D_INST_INTERNAL_19;
N_99 <= CPI_D_INST_INTERNAL_20;
N_100 <= CPI_D_INST_INTERNAL_21;
N_101 <= CPI_D_INST_INTERNAL_22;
N_102 <= CPI_D_INST_INTERNAL_23;
N_103 <= CPI_D_INST_INTERNAL_24;
N_104 <= CPI_D_INST_INTERNAL_25;
N_105 <= CPI_D_INST_INTERNAL_26;
N_106 <= CPI_D_INST_INTERNAL_27;
N_107 <= CPI_D_INST_INTERNAL_28;
N_108 <= CPI_D_INST_INTERNAL_29;
N_109 <= CPI_D_INST_INTERNAL_30;
N_110 <= CPI_D_CNT_INTERNAL;
N_111 <= CPI_D_CNT_INTERNAL_0;
N_112 <= CPI_D_TRAP_INTERNAL;
N_113 <= CPI_D_ANNUL_INTERNAL;
N_114 <= CPI_D_PV_INTERNAL;
N_115 <= CPI_A_PC_INTERNAL;
N_116 <= CPI_A_PC_INTERNAL_0;
N_117 <= CPI_A_PC_INTERNAL_1;
N_118 <= CPI_A_PC_INTERNAL_2;
N_119 <= CPI_A_PC_INTERNAL_3;
N_120 <= CPI_A_PC_INTERNAL_4;
N_121 <= CPI_A_PC_INTERNAL_5;
N_122 <= CPI_A_PC_INTERNAL_6;
N_123 <= CPI_A_PC_INTERNAL_7;
N_124 <= CPI_A_PC_INTERNAL_8;
N_125 <= CPI_A_PC_INTERNAL_9;
N_126 <= CPI_A_PC_INTERNAL_10;
N_127 <= CPI_A_PC_INTERNAL_11;
N_128 <= CPI_A_PC_INTERNAL_12;
N_129 <= CPI_A_PC_INTERNAL_13;
N_130 <= CPI_A_PC_INTERNAL_14;
N_131 <= CPI_A_PC_INTERNAL_15;
N_132 <= CPI_A_PC_INTERNAL_16;
N_133 <= CPI_A_PC_INTERNAL_17;
N_134 <= CPI_A_PC_INTERNAL_18;
N_135 <= CPI_A_PC_INTERNAL_19;
N_136 <= CPI_A_PC_INTERNAL_20;
N_137 <= CPI_A_PC_INTERNAL_21;
N_138 <= CPI_A_PC_INTERNAL_22;
N_139 <= CPI_A_PC_INTERNAL_23;
N_140 <= CPI_A_PC_INTERNAL_24;
N_141 <= CPI_A_PC_INTERNAL_25;
N_142 <= CPI_A_PC_INTERNAL_26;
N_143 <= CPI_A_PC_INTERNAL_27;
N_144 <= CPI_A_PC_INTERNAL_28;
N_145 <= CPI_A_PC_INTERNAL_29;
N_146 <= CPI_A_PC_INTERNAL_30;
N_147 <= CPI_A_INST_INTERNAL;
N_148 <= CPI_A_INST_INTERNAL_0;
N_149 <= CPI_A_INST_INTERNAL_1;
N_150 <= CPI_A_INST_INTERNAL_2;
N_151 <= CPI_A_INST_INTERNAL_3;
N_152 <= CPI_A_INST_INTERNAL_4;
N_153 <= CPI_A_INST_INTERNAL_5;
N_154 <= CPI_A_INST_INTERNAL_6;
N_155 <= CPI_A_INST_INTERNAL_7;
N_156 <= CPI_A_INST_INTERNAL_8;
N_157 <= CPI_A_INST_INTERNAL_9;
N_158 <= CPI_A_INST_INTERNAL_10;
N_159 <= CPI_A_INST_INTERNAL_11;
N_160 <= CPI_A_INST_INTERNAL_12;
N_161 <= CPI_A_INST_INTERNAL_13;
N_162 <= CPI_A_INST_INTERNAL_14;
N_163 <= CPI_A_INST_INTERNAL_15;
N_164 <= CPI_A_INST_INTERNAL_16;
N_165 <= CPI_A_INST_INTERNAL_17;
N_166 <= CPI_A_INST_INTERNAL_18;
N_167 <= CPI_A_INST_INTERNAL_19;
N_168 <= CPI_A_INST_INTERNAL_20;
N_169 <= CPI_A_INST_INTERNAL_21;
N_170 <= CPI_A_INST_INTERNAL_22;
N_171 <= CPI_A_INST_INTERNAL_23;
N_172 <= CPI_A_INST_INTERNAL_24;
N_173 <= CPI_A_INST_INTERNAL_25;
N_174 <= CPI_A_INST_INTERNAL_26;
N_175 <= CPI_A_INST_INTERNAL_27;
N_176 <= CPI_A_INST_INTERNAL_28;
N_177 <= CPI_A_INST_INTERNAL_29;
N_178 <= CPI_A_INST_INTERNAL_30;
N_179 <= CPI_A_CNT_INTERNAL;
N_180 <= CPI_A_CNT_INTERNAL_0;
N_181 <= CPI_A_TRAP_INTERNAL;
N_182 <= CPI_A_ANNUL_INTERNAL;
N_183 <= CPI_A_PV_INTERNAL;
N_184 <= CPI_E_PC_INTERNAL;
N_185 <= CPI_E_PC_INTERNAL_0;
N_186 <= CPI_E_PC_INTERNAL_1;
N_187 <= CPI_E_PC_INTERNAL_2;
N_188 <= CPI_E_PC_INTERNAL_3;
N_189 <= CPI_E_PC_INTERNAL_4;
N_190 <= CPI_E_PC_INTERNAL_5;
N_191 <= CPI_E_PC_INTERNAL_6;
N_192 <= CPI_E_PC_INTERNAL_7;
N_193 <= CPI_E_PC_INTERNAL_8;
N_194 <= CPI_E_PC_INTERNAL_9;
N_195 <= CPI_E_PC_INTERNAL_10;
N_196 <= CPI_E_PC_INTERNAL_11;
N_197 <= CPI_E_PC_INTERNAL_12;
N_198 <= CPI_E_PC_INTERNAL_13;
N_199 <= CPI_E_PC_INTERNAL_14;
N_200 <= CPI_E_PC_INTERNAL_15;
N_201 <= CPI_E_PC_INTERNAL_16;
N_202 <= CPI_E_PC_INTERNAL_17;
N_203 <= CPI_E_PC_INTERNAL_18;
N_204 <= CPI_E_PC_INTERNAL_19;
N_205 <= CPI_E_PC_INTERNAL_20;
N_206 <= CPI_E_PC_INTERNAL_21;
N_207 <= CPI_E_PC_INTERNAL_22;
N_208 <= CPI_E_PC_INTERNAL_23;
N_209 <= CPI_E_PC_INTERNAL_24;
N_210 <= CPI_E_PC_INTERNAL_25;
N_211 <= CPI_E_PC_INTERNAL_26;
N_212 <= CPI_E_PC_INTERNAL_27;
N_213 <= CPI_E_PC_INTERNAL_28;
N_214 <= CPI_E_PC_INTERNAL_29;
N_215 <= CPI_E_PC_INTERNAL_30;
N_216 <= CPI_E_INST_INTERNAL;
N_217 <= CPI_E_INST_INTERNAL_0;
N_218 <= CPI_E_INST_INTERNAL_1;
N_219 <= CPI_E_INST_INTERNAL_2;
N_220 <= CPI_E_INST_INTERNAL_3;
N_221 <= CPI_E_INST_INTERNAL_4;
N_222 <= CPI_E_INST_INTERNAL_5;
N_223 <= CPI_E_INST_INTERNAL_6;
N_224 <= CPI_E_INST_INTERNAL_7;
N_225 <= CPI_E_INST_INTERNAL_8;
N_226 <= CPI_E_INST_INTERNAL_9;
N_227 <= CPI_E_INST_INTERNAL_10;
N_228 <= CPI_E_INST_INTERNAL_11;
N_229 <= CPI_E_INST_INTERNAL_12;
N_230 <= CPI_E_INST_INTERNAL_13;
N_231 <= CPI_E_INST_INTERNAL_14;
N_232 <= CPI_E_INST_INTERNAL_15;
N_233 <= CPI_E_INST_INTERNAL_16;
N_234 <= CPI_E_INST_INTERNAL_17;
N_235 <= CPI_E_INST_INTERNAL_18;
N_236 <= CPI_E_INST_INTERNAL_19;
N_237 <= CPI_E_INST_INTERNAL_20;
N_238 <= CPI_E_INST_INTERNAL_21;
N_239 <= CPI_E_INST_INTERNAL_22;
N_240 <= CPI_E_INST_INTERNAL_23;
N_241 <= CPI_E_INST_INTERNAL_24;
N_242 <= CPI_E_INST_INTERNAL_25;
N_243 <= CPI_E_INST_INTERNAL_26;
N_244 <= CPI_E_INST_INTERNAL_27;
N_245 <= CPI_E_INST_INTERNAL_28;
N_246 <= CPI_E_INST_INTERNAL_29;
N_247 <= CPI_E_INST_INTERNAL_30;
N_248 <= CPI_E_CNT_INTERNAL;
N_249 <= CPI_E_CNT_INTERNAL_0;
N_250 <= CPI_E_TRAP_INTERNAL;
N_251 <= CPI_E_ANNUL_INTERNAL;
N_252 <= CPI_E_PV_INTERNAL;
N_253 <= CPI_M_PC_INTERNAL;
N_254 <= CPI_M_PC_INTERNAL_0;
N_255 <= CPI_M_PC_INTERNAL_1;
N_256 <= CPI_M_PC_INTERNAL_2;
N_257 <= CPI_M_PC_INTERNAL_3;
N_258 <= CPI_M_PC_INTERNAL_4;
N_259 <= CPI_M_PC_INTERNAL_5;
N_260 <= CPI_M_PC_INTERNAL_6;
N_261 <= CPI_M_PC_INTERNAL_7;
N_262 <= CPI_M_PC_INTERNAL_8;
N_263 <= CPI_M_PC_INTERNAL_9;
N_264 <= CPI_M_PC_INTERNAL_10;
N_265 <= CPI_M_PC_INTERNAL_11;
N_266 <= CPI_M_PC_INTERNAL_12;
N_267 <= CPI_M_PC_INTERNAL_13;
N_268 <= CPI_M_PC_INTERNAL_14;
N_269 <= CPI_M_PC_INTERNAL_15;
N_270 <= CPI_M_PC_INTERNAL_16;
N_271 <= CPI_M_PC_INTERNAL_17;
N_272 <= CPI_M_PC_INTERNAL_18;
N_273 <= CPI_M_PC_INTERNAL_19;
N_274 <= CPI_M_PC_INTERNAL_20;
N_275 <= CPI_M_PC_INTERNAL_21;
N_276 <= CPI_M_PC_INTERNAL_22;
N_277 <= CPI_M_PC_INTERNAL_23;
N_278 <= CPI_M_PC_INTERNAL_24;
N_279 <= CPI_M_PC_INTERNAL_25;
N_280 <= CPI_M_PC_INTERNAL_26;
N_281 <= CPI_M_PC_INTERNAL_27;
N_282 <= CPI_M_PC_INTERNAL_28;
N_283 <= CPI_M_PC_INTERNAL_29;
N_284 <= CPI_M_PC_INTERNAL_30;
N_285 <= CPI_M_INST_INTERNAL;
N_286 <= CPI_M_INST_INTERNAL_0;
N_287 <= CPI_M_INST_INTERNAL_1;
N_288 <= CPI_M_INST_INTERNAL_2;
N_289 <= CPI_M_INST_INTERNAL_3;
N_290 <= CPI_M_INST_INTERNAL_4;
N_291 <= CPI_M_INST_INTERNAL_5;
N_292 <= CPI_M_INST_INTERNAL_6;
N_293 <= CPI_M_INST_INTERNAL_7;
N_294 <= CPI_M_INST_INTERNAL_8;
N_295 <= CPI_M_INST_INTERNAL_9;
N_296 <= CPI_M_INST_INTERNAL_10;
N_297 <= CPI_M_INST_INTERNAL_11;
N_298 <= CPI_M_INST_INTERNAL_12;
N_299 <= CPI_M_INST_INTERNAL_13;
N_300 <= CPI_M_INST_INTERNAL_14;
N_301 <= CPI_M_INST_INTERNAL_15;
N_302 <= CPI_M_INST_INTERNAL_16;
N_303 <= CPI_M_INST_INTERNAL_17;
N_304 <= CPI_M_INST_INTERNAL_18;
N_305 <= CPI_M_INST_INTERNAL_19;
N_306 <= CPI_M_INST_INTERNAL_20;
N_307 <= CPI_M_INST_INTERNAL_21;
N_308 <= CPI_M_INST_INTERNAL_22;
N_309 <= CPI_M_INST_INTERNAL_23;
N_310 <= CPI_M_INST_INTERNAL_24;
N_311 <= CPI_M_INST_INTERNAL_25;
N_312 <= CPI_M_INST_INTERNAL_26;
N_313 <= CPI_M_INST_INTERNAL_27;
N_314 <= CPI_M_INST_INTERNAL_28;
N_315 <= CPI_M_INST_INTERNAL_29;
N_316 <= CPI_M_INST_INTERNAL_30;
N_317 <= CPI_M_CNT_INTERNAL;
N_318 <= CPI_M_CNT_INTERNAL_0;
N_319 <= CPI_M_TRAP_INTERNAL;
N_320 <= CPI_M_ANNUL_INTERNAL;
N_321 <= CPI_M_PV_INTERNAL;
N_322 <= CPI_X_PC_INTERNAL;
N_323 <= CPI_X_PC_INTERNAL_0;
N_324 <= CPI_X_PC_INTERNAL_1;
N_325 <= CPI_X_PC_INTERNAL_2;
N_326 <= CPI_X_PC_INTERNAL_3;
N_327 <= CPI_X_PC_INTERNAL_4;
N_328 <= CPI_X_PC_INTERNAL_5;
N_329 <= CPI_X_PC_INTERNAL_6;
N_330 <= CPI_X_PC_INTERNAL_7;
N_331 <= CPI_X_PC_INTERNAL_8;
N_332 <= CPI_X_PC_INTERNAL_9;
N_333 <= CPI_X_PC_INTERNAL_10;
N_334 <= CPI_X_PC_INTERNAL_11;
N_335 <= CPI_X_PC_INTERNAL_12;
N_336 <= CPI_X_PC_INTERNAL_13;
N_337 <= CPI_X_PC_INTERNAL_14;
N_338 <= CPI_X_PC_INTERNAL_15;
N_339 <= CPI_X_PC_INTERNAL_16;
N_340 <= CPI_X_PC_INTERNAL_17;
N_341 <= CPI_X_PC_INTERNAL_18;
N_342 <= CPI_X_PC_INTERNAL_19;
N_343 <= CPI_X_PC_INTERNAL_20;
N_344 <= CPI_X_PC_INTERNAL_21;
N_345 <= CPI_X_PC_INTERNAL_22;
N_346 <= CPI_X_PC_INTERNAL_23;
N_347 <= CPI_X_PC_INTERNAL_24;
N_348 <= CPI_X_PC_INTERNAL_25;
N_349 <= CPI_X_PC_INTERNAL_26;
N_350 <= CPI_X_PC_INTERNAL_27;
N_351 <= CPI_X_PC_INTERNAL_28;
N_352 <= CPI_X_PC_INTERNAL_29;
N_353 <= CPI_X_PC_INTERNAL_30;
N_354 <= CPI_X_INST_INTERNAL;
N_355 <= CPI_X_INST_INTERNAL_0;
N_356 <= CPI_X_INST_INTERNAL_1;
N_357 <= CPI_X_INST_INTERNAL_2;
N_358 <= CPI_X_INST_INTERNAL_3;
N_359 <= CPI_X_INST_INTERNAL_4;
N_360 <= CPI_X_INST_INTERNAL_5;
N_361 <= CPI_X_INST_INTERNAL_6;
N_362 <= CPI_X_INST_INTERNAL_7;
N_363 <= CPI_X_INST_INTERNAL_8;
N_364 <= CPI_X_INST_INTERNAL_9;
N_365 <= CPI_X_INST_INTERNAL_10;
N_366 <= CPI_X_INST_INTERNAL_11;
N_367 <= CPI_X_INST_INTERNAL_12;
N_368 <= CPI_X_INST_INTERNAL_13;
N_369 <= CPI_X_INST_INTERNAL_14;
N_370 <= CPI_X_INST_INTERNAL_15;
N_371 <= CPI_X_INST_INTERNAL_16;
N_372 <= CPI_X_INST_INTERNAL_17;
N_373 <= CPI_X_INST_INTERNAL_18;
N_374 <= CPI_X_INST_INTERNAL_19;
N_375 <= CPI_X_INST_INTERNAL_20;
N_376 <= CPI_X_INST_INTERNAL_21;
N_377 <= CPI_X_INST_INTERNAL_22;
N_378 <= CPI_X_INST_INTERNAL_23;
N_379 <= CPI_X_INST_INTERNAL_24;
N_380 <= CPI_X_INST_INTERNAL_25;
N_381 <= CPI_X_INST_INTERNAL_26;
N_382 <= CPI_X_INST_INTERNAL_27;
N_383 <= CPI_X_INST_INTERNAL_28;
N_384 <= CPI_X_INST_INTERNAL_29;
N_385 <= CPI_X_INST_INTERNAL_30;
N_386 <= CPI_X_CNT_INTERNAL;
N_387 <= CPI_X_CNT_INTERNAL_0;
N_388 <= CPI_X_TRAP_INTERNAL;
N_389 <= CPI_X_ANNUL_INTERNAL;
N_390 <= CPI_X_PV_INTERNAL;
N_391 <= CPI_LDDATA_INTERNAL;
N_392 <= CPI_LDDATA_INTERNAL_0;
N_393 <= CPI_LDDATA_INTERNAL_1;
N_394 <= CPI_LDDATA_INTERNAL_2;
N_395 <= CPI_LDDATA_INTERNAL_3;
N_396 <= CPI_LDDATA_INTERNAL_4;
N_397 <= CPI_LDDATA_INTERNAL_5;
N_398 <= CPI_LDDATA_INTERNAL_6;
N_399 <= CPI_LDDATA_INTERNAL_7;
N_400 <= CPI_LDDATA_INTERNAL_8;
N_401 <= CPI_LDDATA_INTERNAL_9;
N_402 <= CPI_LDDATA_INTERNAL_10;
N_403 <= CPI_LDDATA_INTERNAL_11;
N_404 <= CPI_LDDATA_INTERNAL_12;
N_405 <= CPI_LDDATA_INTERNAL_13;
N_406 <= CPI_LDDATA_INTERNAL_14;
N_407 <= CPI_LDDATA_INTERNAL_15;
N_408 <= CPI_LDDATA_INTERNAL_16;
N_409 <= CPI_LDDATA_INTERNAL_17;
N_410 <= CPI_LDDATA_INTERNAL_18;
N_411 <= CPI_LDDATA_INTERNAL_19;
N_412 <= CPI_LDDATA_INTERNAL_20;
N_413 <= CPI_LDDATA_INTERNAL_21;
N_414 <= CPI_LDDATA_INTERNAL_22;
N_415 <= CPI_LDDATA_INTERNAL_23;
N_416 <= CPI_LDDATA_INTERNAL_24;
N_417 <= CPI_LDDATA_INTERNAL_25;
N_418 <= CPI_LDDATA_INTERNAL_26;
N_419 <= CPI_LDDATA_INTERNAL_27;
N_420 <= CPI_LDDATA_INTERNAL_28;
N_421 <= CPI_LDDATA_INTERNAL_29;
N_422 <= CPI_LDDATA_INTERNAL_30;
N_423 <= CPI_DBG_ENABLE_INTERNAL;
N_424 <= CPI_DBG_WRITE_INTERNAL;
N_425 <= CPI_DBG_FSR_INTERNAL;
N_426 <= CPI_DBG_ADDR_INTERNAL;
N_427 <= CPI_DBG_ADDR_INTERNAL_0;
N_428 <= CPI_DBG_ADDR_INTERNAL_1;
N_429 <= CPI_DBG_ADDR_INTERNAL_2;
N_430 <= CPI_DBG_ADDR_INTERNAL_3;
N_431 <= CPI_DBG_DATA_INTERNAL;
N_432 <= CPI_DBG_DATA_INTERNAL_0;
N_433 <= CPI_DBG_DATA_INTERNAL_1;
N_434 <= CPI_DBG_DATA_INTERNAL_2;
N_435 <= CPI_DBG_DATA_INTERNAL_3;
N_436 <= CPI_DBG_DATA_INTERNAL_4;
N_437 <= CPI_DBG_DATA_INTERNAL_5;
N_438 <= CPI_DBG_DATA_INTERNAL_6;
N_439 <= CPI_DBG_DATA_INTERNAL_7;
N_440 <= CPI_DBG_DATA_INTERNAL_8;
N_441 <= CPI_DBG_DATA_INTERNAL_9;
N_442 <= CPI_DBG_DATA_INTERNAL_10;
N_443 <= CPI_DBG_DATA_INTERNAL_11;
N_444 <= CPI_DBG_DATA_INTERNAL_12;
N_445 <= CPI_DBG_DATA_INTERNAL_13;
N_446 <= CPI_DBG_DATA_INTERNAL_14;
N_447 <= CPI_DBG_DATA_INTERNAL_15;
N_448 <= CPI_DBG_DATA_INTERNAL_16;
N_449 <= CPI_DBG_DATA_INTERNAL_17;
N_450 <= CPI_DBG_DATA_INTERNAL_18;
N_451 <= CPI_DBG_DATA_INTERNAL_19;
N_452 <= CPI_DBG_DATA_INTERNAL_20;
N_453 <= CPI_DBG_DATA_INTERNAL_21;
N_454 <= CPI_DBG_DATA_INTERNAL_22;
N_455 <= CPI_DBG_DATA_INTERNAL_23;
N_456 <= CPI_DBG_DATA_INTERNAL_24;
N_457 <= CPI_DBG_DATA_INTERNAL_25;
N_458 <= CPI_DBG_DATA_INTERNAL_26;
N_459 <= CPI_DBG_DATA_INTERNAL_27;
N_460 <= CPI_DBG_DATA_INTERNAL_28;
N_461 <= CPI_DBG_DATA_INTERNAL_29;
N_462 <= CPI_DBG_DATA_INTERNAL_30;
N_0 <= CPO_DATAZ(0);
N_1_54 <= CPO_DATAZ(1);
N_2_40 <= CPO_DATAZ(2);
N_3_0 <= CPO_DATAZ(3);
N_4_0 <= CPO_DATAZ(4);
N_5_24 <= CPO_DATAZ(5);
N_6_2 <= CPO_DATAZ(6);
N_7_0 <= CPO_DATAZ(7);
N_8_0 <= CPO_DATAZ(8);
N_9_22 <= CPO_DATAZ(9);
N_10_0 <= CPO_DATAZ(10);
N_11_0 <= CPO_DATAZ(11);
N_12_0 <= CPO_DATAZ(12);
N_13_0 <= CPO_DATAZ(13);
N_14_0 <= CPO_DATAZ(14);
N_15_0 <= CPO_DATAZ(15);
N_16_0 <= CPO_DATAZ(16);
N_17_0 <= CPO_DATAZ(17);
N_18_0 <= CPO_DATAZ(18);
N_19_0 <= CPO_DATAZ(19);
N_20_0 <= CPO_DATAZ(20);
N_21_0 <= CPO_DATAZ(21);
N_22_0 <= CPO_DATAZ(22);
N_23_0 <= CPO_DATAZ(23);
N_24_0 <= CPO_DATAZ(24);
N_25_0 <= CPO_DATAZ(25);
N_26_0 <= CPO_DATAZ(26);
N_27_0 <= CPO_DATAZ(27);
N_28_0 <= CPO_DATAZ(28);
N_29_0 <= CPO_DATAZ(29);
N_30_0 <= CPO_DATAZ(30);
N_31_0 <= CPO_DATAZ(31);
N_32_0 <= CPO_EXCZ;
N_33_0 <= CPO_CCZ(0);
N_34_0 <= CPO_CCZ(1);
N_35_0 <= CPO_CCVZ;
N_36_0 <= CPO_LDLOCKZ;
N_37_0 <= VCC;
N_38_0 <= CPO_DBG_DATAZ(0);
N_39_0 <= CPO_DBG_DATAZ(1);
N_40_0 <= CPO_DBG_DATAZ(2);
N_41_0 <= CPO_DBG_DATAZ(3);
N_42_0 <= CPO_DBG_DATAZ(4);
N_43_0 <= CPO_DBG_DATAZ(5);
N_44_0 <= CPO_DBG_DATAZ(6);
N_45_0 <= CPO_DBG_DATAZ(7);
N_46_0 <= CPO_DBG_DATAZ(8);
N_47_0 <= CPO_DBG_DATAZ(9);
N_48_0 <= CPO_DBG_DATAZ(10);
N_49_0 <= CPO_DBG_DATAZ(11);
N_50_0 <= CPO_DBG_DATAZ(12);
N_51_0 <= CPO_DBG_DATAZ(13);
N_52_0 <= CPO_DBG_DATAZ(14);
N_53_0 <= CPO_DBG_DATAZ(15);
N_54_0 <= CPO_DBG_DATAZ(16);
N_55_0 <= CPO_DBG_DATAZ(17);
N_56_0 <= CPO_DBG_DATAZ(18);
N_57_0 <= CPO_DBG_DATAZ(19);
N_58_0 <= CPO_DBG_DATAZ(20);
N_59_0 <= CPO_DBG_DATAZ(21);
N_60_0 <= CPO_DBG_DATAZ(22);
N_61_0 <= CPO_DBG_DATAZ(23);
N_62_0 <= CPO_DBG_DATAZ(24);
N_63_0 <= CPO_DBG_DATAZ(25);
N_64_0 <= CPO_DBG_DATAZ(26);
N_65_0 <= CPO_DBG_DATAZ(27);
N_66_0 <= CPO_DBG_DATAZ(28);
N_67_0 <= CPO_DBG_DATAZ(29);
N_68_0 <= CPO_DBG_DATAZ(30);
N_69_0 <= CPO_DBG_DATAZ(31);
N_70_0 <= RFI2_RD1ADDRZ(0);
N_71_0 <= RFI2_RD1ADDRZ(1);
N_72_0 <= RFI2_RD1ADDRZ(2);
N_73_0 <= RFI2_RD1ADDRZ(3);
N_74_0 <= RFI2_RD2ADDRZ(0);
N_75_0 <= RFI2_RD2ADDRZ(1);
N_76_0 <= RFI2_RD2ADDRZ(2);
N_77_0 <= RFI2_RD2ADDRZ(3);
N_78_0 <= RFI2_WRADDRZ(0);
N_79_0 <= RFI2_WRADDRZ(1);
N_80_0 <= RFI2_WRADDRZ(2);
N_81_0 <= RFI2_WRADDRZ(3);
N_82_0 <= RFI1_WRDATAZ(0);
N_83_0 <= RFI1_WRDATAZ(1);
N_84_0 <= RFI1_WRDATAZ(2);
N_85_0 <= RFI1_WRDATAZ(3);
N_86_0 <= RFI1_WRDATAZ(4);
N_87_0 <= RFI1_WRDATAZ(5);
N_88_0 <= RFI1_WRDATAZ(6);
N_89_0 <= RFI1_WRDATAZ(7);
N_90_0 <= RFI1_WRDATAZ(8);
N_91_0 <= RFI1_WRDATAZ(9);
N_92_0 <= RFI1_WRDATAZ(10);
N_93_0 <= RFI1_WRDATAZ(11);
N_94_0 <= RFI1_WRDATAZ(12);
N_95_0 <= RFI1_WRDATAZ(13);
N_96_0 <= RFI1_WRDATAZ(14);
N_97_0 <= RFI1_WRDATAZ(15);
N_98_0 <= RFI1_WRDATAZ(16);
N_99_0 <= RFI1_WRDATAZ(17);
N_100_0 <= RFI1_WRDATAZ(18);
N_101_0 <= RFI1_WRDATAZ(19);
N_102_0 <= RFI1_WRDATAZ(20);
N_103_0 <= RFI1_WRDATAZ(21);
N_104_0 <= RFI1_WRDATAZ(22);
N_105_0 <= RFI1_WRDATAZ(23);
N_106_0 <= RFI1_WRDATAZ(24);
N_107_0 <= RFI1_WRDATAZ(25);
N_108_0 <= RFI1_WRDATAZ(26);
N_109_0 <= RFI1_WRDATAZ(27);
N_110_0 <= RFI1_WRDATAZ(28);
N_111_0 <= RFI1_WRDATAZ(29);
N_112_0 <= RFI1_WRDATAZ(30);
N_113_0 <= RFI1_WRDATAZ(31);
N_114_0 <= RFI1_REN1Z;
N_115_0 <= RFI1_REN2Z;
N_116_0 <= RFI1_WRENZ;
N_117_0 <= RFI2_RD1ADDRZ(0);
N_118_0 <= RFI2_RD1ADDRZ(1);
N_119_0 <= RFI2_RD1ADDRZ(2);
N_120_0 <= RFI2_RD1ADDRZ(3);
N_121_0 <= RFI2_RD2ADDRZ(0);
N_122_0 <= RFI2_RD2ADDRZ(1);
N_123_0 <= RFI2_RD2ADDRZ(2);
N_124_0 <= RFI2_RD2ADDRZ(3);
N_125_0 <= RFI2_WRADDRZ(0);
N_126_0 <= RFI2_WRADDRZ(1);
N_127_0 <= RFI2_WRADDRZ(2);
N_128_0 <= RFI2_WRADDRZ(3);
N_129_0 <= RFI2_WRDATAZ(0);
N_130_0 <= RFI2_WRDATAZ(1);
N_131_0 <= RFI2_WRDATAZ(2);
N_132_0 <= RFI2_WRDATAZ(3);
N_133_0 <= RFI2_WRDATAZ(4);
N_134_0 <= RFI2_WRDATAZ(5);
N_135_0 <= RFI2_WRDATAZ(6);
N_136_0 <= RFI2_WRDATAZ(7);
N_137_0 <= RFI2_WRDATAZ(8);
N_138_0 <= RFI2_WRDATAZ(9);
N_139_0 <= RFI2_WRDATAZ(10);
N_140_0 <= RFI2_WRDATAZ(11);
N_141_0 <= RFI2_WRDATAZ(12);
N_142_0 <= RFI2_WRDATAZ(13);
N_143_0 <= RFI2_WRDATAZ(14);
N_144_0 <= RFI2_WRDATAZ(15);
N_145_0 <= RFI2_WRDATAZ(16);
N_146_0 <= RFI2_WRDATAZ(17);
N_147_0 <= RFI2_WRDATAZ(18);
N_148_0 <= RFI2_WRDATAZ(19);
N_149_0 <= RFI2_WRDATAZ(20);
N_150_0 <= RFI2_WRDATAZ(21);
N_151_0 <= RFI2_WRDATAZ(22);
N_152_0 <= RFI2_WRDATAZ(23);
N_153_0 <= RFI2_WRDATAZ(24);
N_154_0 <= RFI2_WRDATAZ(25);
N_155_0 <= RFI2_WRDATAZ(26);
N_156_0 <= RFI2_WRDATAZ(27);
N_157_0 <= RFI2_WRDATAZ(28);
N_158_0 <= RFI2_WRDATAZ(29);
N_159_0 <= RFI2_WRDATAZ(30);
N_160_0 <= RFI2_WRDATAZ(31);
N_161_0 <= RFI2_REN1Z;
N_162_0 <= RFI2_REN2Z;
N_163_0 <= RFI2_WRENZ;
N_627 <= RFO1_DATA1_INTERNAL;
N_628 <= RFO1_DATA1_INTERNAL_0;
N_629 <= RFO1_DATA1_INTERNAL_1;
N_630 <= RFO1_DATA1_INTERNAL_2;
N_631 <= RFO1_DATA1_INTERNAL_3;
N_632 <= RFO1_DATA1_INTERNAL_4;
N_633 <= RFO1_DATA1_INTERNAL_5;
N_634 <= RFO1_DATA1_INTERNAL_6;
N_635 <= RFO1_DATA1_INTERNAL_7;
N_636 <= RFO1_DATA1_INTERNAL_8;
N_637 <= RFO1_DATA1_INTERNAL_9;
N_638 <= RFO1_DATA1_INTERNAL_10;
N_639 <= RFO1_DATA1_INTERNAL_11;
N_640 <= RFO1_DATA1_INTERNAL_12;
N_641 <= RFO1_DATA1_INTERNAL_13;
N_642 <= RFO1_DATA1_INTERNAL_14;
N_643 <= RFO1_DATA1_INTERNAL_15;
N_644 <= RFO1_DATA1_INTERNAL_16;
N_645 <= RFO1_DATA1_INTERNAL_17;
N_646 <= RFO1_DATA1_INTERNAL_18;
N_647 <= RFO1_DATA1_INTERNAL_19;
N_648 <= RFO1_DATA1_INTERNAL_20;
N_649 <= RFO1_DATA1_INTERNAL_21;
N_650 <= RFO1_DATA1_INTERNAL_22;
N_651 <= RFO1_DATA1_INTERNAL_23;
N_652 <= RFO1_DATA1_INTERNAL_24;
N_653 <= RFO1_DATA1_INTERNAL_25;
N_654 <= RFO1_DATA1_INTERNAL_26;
N_655 <= RFO1_DATA1_INTERNAL_27;
N_656 <= RFO1_DATA1_INTERNAL_28;
N_657 <= RFO1_DATA1_INTERNAL_29;
N_658 <= RFO1_DATA1_INTERNAL_30;
N_659 <= RFO1_DATA2_INTERNAL;
N_660 <= RFO1_DATA2_INTERNAL_0;
N_661 <= RFO1_DATA2_INTERNAL_1;
N_662 <= RFO1_DATA2_INTERNAL_2;
N_663 <= RFO1_DATA2_INTERNAL_3;
N_664 <= RFO1_DATA2_INTERNAL_4;
N_665 <= RFO1_DATA2_INTERNAL_5;
N_666 <= RFO1_DATA2_INTERNAL_6;
N_667 <= RFO1_DATA2_INTERNAL_7;
N_668 <= RFO1_DATA2_INTERNAL_8;
N_669 <= RFO1_DATA2_INTERNAL_9;
N_670 <= RFO1_DATA2_INTERNAL_10;
N_671 <= RFO1_DATA2_INTERNAL_11;
N_672 <= RFO1_DATA2_INTERNAL_12;
N_673 <= RFO1_DATA2_INTERNAL_13;
N_674 <= RFO1_DATA2_INTERNAL_14;
N_675 <= RFO1_DATA2_INTERNAL_15;
N_676 <= RFO1_DATA2_INTERNAL_16;
N_677 <= RFO1_DATA2_INTERNAL_17;
N_678 <= RFO1_DATA2_INTERNAL_18;
N_679 <= RFO1_DATA2_INTERNAL_19;
N_680 <= RFO1_DATA2_INTERNAL_20;
N_681 <= RFO1_DATA2_INTERNAL_21;
N_682 <= RFO1_DATA2_INTERNAL_22;
N_683 <= RFO1_DATA2_INTERNAL_23;
N_684 <= RFO1_DATA2_INTERNAL_24;
N_685 <= RFO1_DATA2_INTERNAL_25;
N_686 <= RFO1_DATA2_INTERNAL_26;
N_687 <= RFO1_DATA2_INTERNAL_27;
N_688 <= RFO1_DATA2_INTERNAL_28;
N_689 <= RFO1_DATA2_INTERNAL_29;
N_690 <= RFO1_DATA2_INTERNAL_30;
N_691 <= RFO2_DATA1_INTERNAL;
N_692 <= RFO2_DATA1_INTERNAL_0;
N_693 <= RFO2_DATA1_INTERNAL_1;
N_694 <= RFO2_DATA1_INTERNAL_2;
N_695 <= RFO2_DATA1_INTERNAL_3;
N_696 <= RFO2_DATA1_INTERNAL_4;
N_697 <= RFO2_DATA1_INTERNAL_5;
N_698 <= RFO2_DATA1_INTERNAL_6;
N_699 <= RFO2_DATA1_INTERNAL_7;
N_700 <= RFO2_DATA1_INTERNAL_8;
N_701 <= RFO2_DATA1_INTERNAL_9;
N_702 <= RFO2_DATA1_INTERNAL_10;
N_703 <= RFO2_DATA1_INTERNAL_11;
N_704 <= RFO2_DATA1_INTERNAL_12;
N_705 <= RFO2_DATA1_INTERNAL_13;
N_706 <= RFO2_DATA1_INTERNAL_14;
N_707 <= RFO2_DATA1_INTERNAL_15;
N_708 <= RFO2_DATA1_INTERNAL_16;
N_709 <= RFO2_DATA1_INTERNAL_17;
N_710 <= RFO2_DATA1_INTERNAL_18;
N_711 <= RFO2_DATA1_INTERNAL_19;
N_712 <= RFO2_DATA1_INTERNAL_20;
N_713 <= RFO2_DATA1_INTERNAL_21;
N_714 <= RFO2_DATA1_INTERNAL_22;
N_715 <= RFO2_DATA1_INTERNAL_23;
N_716 <= RFO2_DATA1_INTERNAL_24;
N_717 <= RFO2_DATA1_INTERNAL_25;
N_718 <= RFO2_DATA1_INTERNAL_26;
N_719 <= RFO2_DATA1_INTERNAL_27;
N_720 <= RFO2_DATA1_INTERNAL_28;
N_721 <= RFO2_DATA1_INTERNAL_29;
N_722 <= RFO2_DATA1_INTERNAL_30;
N_723 <= RFO2_DATA2_INTERNAL;
N_724 <= RFO2_DATA2_INTERNAL_0;
N_725 <= RFO2_DATA2_INTERNAL_1;
N_726 <= RFO2_DATA2_INTERNAL_2;
N_727 <= RFO2_DATA2_INTERNAL_3;
N_728 <= RFO2_DATA2_INTERNAL_4;
N_729 <= RFO2_DATA2_INTERNAL_5;
N_730 <= RFO2_DATA2_INTERNAL_6;
N_731 <= RFO2_DATA2_INTERNAL_7;
N_732 <= RFO2_DATA2_INTERNAL_8;
N_733 <= RFO2_DATA2_INTERNAL_9;
N_734 <= RFO2_DATA2_INTERNAL_10;
N_735 <= RFO2_DATA2_INTERNAL_11;
N_736 <= RFO2_DATA2_INTERNAL_12;
N_737 <= RFO2_DATA2_INTERNAL_13;
N_738 <= RFO2_DATA2_INTERNAL_14;
N_739 <= RFO2_DATA2_INTERNAL_15;
N_740 <= RFO2_DATA2_INTERNAL_16;
N_741 <= RFO2_DATA2_INTERNAL_17;
N_742 <= RFO2_DATA2_INTERNAL_18;
N_743 <= RFO2_DATA2_INTERNAL_19;
N_744 <= RFO2_DATA2_INTERNAL_20;
N_745 <= RFO2_DATA2_INTERNAL_21;
N_746 <= RFO2_DATA2_INTERNAL_22;
N_747 <= RFO2_DATA2_INTERNAL_23;
N_748 <= RFO2_DATA2_INTERNAL_24;
N_749 <= RFO2_DATA2_INTERNAL_25;
N_750 <= RFO2_DATA2_INTERNAL_26;
N_751 <= RFO2_DATA2_INTERNAL_27;
N_752 <= RFO2_DATA2_INTERNAL_28;
N_753 <= RFO2_DATA2_INTERNAL_29;
N_754 <= RFO2_DATA2_INTERNAL_30;
\GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2_I\ <= not \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\;
\GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_I\ <= not \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\;
\GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2_I\(21) <= not \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_O2\(21);
\GRFPU0.GRFPU_X0.COMB.UINT17_I\ <= not \GRFPU0.GRFPU_X0.COMB.UINT17\;
\GRFPU0.GRFPU_X0.ST1.V_0_0_G4_I\ <= not \GRFPU0.GRFPU_X0.ST1.V_0_0_G4\;
\GRFPC0.V.STDATA_14_I\(6) <= not \GRFPC0.V.STDATA_14\(6);
N_3_I <= not N_3;
\GRFPC0.VFIFO.INST_1_1_0_I\ <= not \GRFPC0.VFIFO.INST_1_1_0\;
\GRFPC0.VFIFO.INST_0_1_0_I\ <= not \GRFPC0.VFIFO.INST_0_1_0\;
\GRFPC0.FP_PIPELINE.UN109_HOLDN_0_I\ <= not \GRFPC0.FP_PIPELINE.UN109_HOLDN_0\;
\GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X_I\ <= not \GRFPC0.FP_PIPELINE.UN1_HOLDN_I_S_X\;
\GRFPC0.FP_PIPELINE.V.STDATA_1S2_I\ <= not \GRFPC0.FP_PIPELINE.V.STDATA_1S2\;
N_38_I <= not N_38;
\GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0_I\ <= not \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_SN_M4_0\;
\GRFPU0.GRFPU_X0.COMB.VST2.DIFF2_I\ <= not \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\;
\GRFPU0.GRFPU_X0.ST3.FLOP_I\(1) <= not \GRFPU0.GRFPU_X0.ST3.FLOP\(1);
\GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2_I\ <= not \GRFPU0.GRFPU_X0.COMB.VST4.RDY4_0_A2\;
\GRFPU0.GRFPU_X0.G_53_I\ <= not \GRFPU0.GRFPU_X0.G_53\;
\GRFPU0.MULO.MRES_BUF_I\(121) <= not \GRFPU0.MULO.MRES_BUF\(121);
\GRFPU0.GRFPU_X0.COMB.SHV2LTO10_I\ <= not \GRFPU0.GRFPU_X0.COMB.SHV2LTO10\;
\GRFPU0.GRFPU_X0.C_ADD11_I\ <= not \GRFPU0.GRFPU_X0.C_ADD11\;
cpo_data(0) <= N_0;
cpo_data(1) <= N_1_54;
cpo_data(2) <= N_2_40;
cpo_data(3) <= N_3_0;
cpo_data(4) <= N_4_0;
cpo_data(5) <= N_5_24;
cpo_data(6) <= N_6_2;
cpo_data(7) <= N_7_0;
cpo_data(8) <= N_8_0;
cpo_data(9) <= N_9_22;
cpo_data(10) <= N_10_0;
cpo_data(11) <= N_11_0;
cpo_data(12) <= N_12_0;
cpo_data(13) <= N_13_0;
cpo_data(14) <= N_14_0;
cpo_data(15) <= N_15_0;
cpo_data(16) <= N_16_0;
cpo_data(17) <= N_17_0;
cpo_data(18) <= N_18_0;
cpo_data(19) <= N_19_0;
cpo_data(20) <= N_20_0;
cpo_data(21) <= N_21_0;
cpo_data(22) <= N_22_0;
cpo_data(23) <= N_23_0;
cpo_data(24) <= N_24_0;
cpo_data(25) <= N_25_0;
cpo_data(26) <= N_26_0;
cpo_data(27) <= N_27_0;
cpo_data(28) <= N_28_0;
cpo_data(29) <= N_29_0;
cpo_data(30) <= N_30_0;
cpo_data(31) <= N_31_0;
cpo_exc <= N_32_0;
cpo_cc(0) <= N_33_0;
cpo_cc(1) <= N_34_0;
cpo_ccv <= N_35_0;
cpo_ldlock <= N_36_0;
cpo_holdn <= N_37_0;
cpo_dbg_data(0) <= N_38_0;
cpo_dbg_data(1) <= N_39_0;
cpo_dbg_data(2) <= N_40_0;
cpo_dbg_data(3) <= N_41_0;
cpo_dbg_data(4) <= N_42_0;
cpo_dbg_data(5) <= N_43_0;
cpo_dbg_data(6) <= N_44_0;
cpo_dbg_data(7) <= N_45_0;
cpo_dbg_data(8) <= N_46_0;
cpo_dbg_data(9) <= N_47_0;
cpo_dbg_data(10) <= N_48_0;
cpo_dbg_data(11) <= N_49_0;
cpo_dbg_data(12) <= N_50_0;
cpo_dbg_data(13) <= N_51_0;
cpo_dbg_data(14) <= N_52_0;
cpo_dbg_data(15) <= N_53_0;
cpo_dbg_data(16) <= N_54_0;
cpo_dbg_data(17) <= N_55_0;
cpo_dbg_data(18) <= N_56_0;
cpo_dbg_data(19) <= N_57_0;
cpo_dbg_data(20) <= N_58_0;
cpo_dbg_data(21) <= N_59_0;
cpo_dbg_data(22) <= N_60_0;
cpo_dbg_data(23) <= N_61_0;
cpo_dbg_data(24) <= N_62_0;
cpo_dbg_data(25) <= N_63_0;
cpo_dbg_data(26) <= N_64_0;
cpo_dbg_data(27) <= N_65_0;
cpo_dbg_data(28) <= N_66_0;
cpo_dbg_data(29) <= N_67_0;
cpo_dbg_data(30) <= N_68_0;
cpo_dbg_data(31) <= N_69_0;
rfi1_rd1addr(0) <= N_70_0;
rfi1_rd1addr(1) <= N_71_0;
rfi1_rd1addr(2) <= N_72_0;
rfi1_rd1addr(3) <= N_73_0;
rfi1_rd2addr(0) <= N_74_0;
rfi1_rd2addr(1) <= N_75_0;
rfi1_rd2addr(2) <= N_76_0;
rfi1_rd2addr(3) <= N_77_0;
rfi1_wraddr(0) <= N_78_0;
rfi1_wraddr(1) <= N_79_0;
rfi1_wraddr(2) <= N_80_0;
rfi1_wraddr(3) <= N_81_0;
rfi1_wrdata(0) <= N_82_0;
rfi1_wrdata(1) <= N_83_0;
rfi1_wrdata(2) <= N_84_0;
rfi1_wrdata(3) <= N_85_0;
rfi1_wrdata(4) <= N_86_0;
rfi1_wrdata(5) <= N_87_0;
rfi1_wrdata(6) <= N_88_0;
rfi1_wrdata(7) <= N_89_0;
rfi1_wrdata(8) <= N_90_0;
rfi1_wrdata(9) <= N_91_0;
rfi1_wrdata(10) <= N_92_0;
rfi1_wrdata(11) <= N_93_0;
rfi1_wrdata(12) <= N_94_0;
rfi1_wrdata(13) <= N_95_0;
rfi1_wrdata(14) <= N_96_0;
rfi1_wrdata(15) <= N_97_0;
rfi1_wrdata(16) <= N_98_0;
rfi1_wrdata(17) <= N_99_0;
rfi1_wrdata(18) <= N_100_0;
rfi1_wrdata(19) <= N_101_0;
rfi1_wrdata(20) <= N_102_0;
rfi1_wrdata(21) <= N_103_0;
rfi1_wrdata(22) <= N_104_0;
rfi1_wrdata(23) <= N_105_0;
rfi1_wrdata(24) <= N_106_0;
rfi1_wrdata(25) <= N_107_0;
rfi1_wrdata(26) <= N_108_0;
rfi1_wrdata(27) <= N_109_0;
rfi1_wrdata(28) <= N_110_0;
rfi1_wrdata(29) <= N_111_0;
rfi1_wrdata(30) <= N_112_0;
rfi1_wrdata(31) <= N_113_0;
rfi1_ren1 <= N_114_0;
rfi1_ren2 <= N_115_0;
rfi1_wren <= N_116_0;
rfi2_rd1addr(0) <= N_117_0;
rfi2_rd1addr(1) <= N_118_0;
rfi2_rd1addr(2) <= N_119_0;
rfi2_rd1addr(3) <= N_120_0;
rfi2_rd2addr(0) <= N_121_0;
rfi2_rd2addr(1) <= N_122_0;
rfi2_rd2addr(2) <= N_123_0;
rfi2_rd2addr(3) <= N_124_0;
rfi2_wraddr(0) <= N_125_0;
rfi2_wraddr(1) <= N_126_0;
rfi2_wraddr(2) <= N_127_0;
rfi2_wraddr(3) <= N_128_0;
rfi2_wrdata(0) <= N_129_0;
rfi2_wrdata(1) <= N_130_0;
rfi2_wrdata(2) <= N_131_0;
rfi2_wrdata(3) <= N_132_0;
rfi2_wrdata(4) <= N_133_0;
rfi2_wrdata(5) <= N_134_0;
rfi2_wrdata(6) <= N_135_0;
rfi2_wrdata(7) <= N_136_0;
rfi2_wrdata(8) <= N_137_0;
rfi2_wrdata(9) <= N_138_0;
rfi2_wrdata(10) <= N_139_0;
rfi2_wrdata(11) <= N_140_0;
rfi2_wrdata(12) <= N_141_0;
rfi2_wrdata(13) <= N_142_0;
rfi2_wrdata(14) <= N_143_0;
rfi2_wrdata(15) <= N_144_0;
rfi2_wrdata(16) <= N_145_0;
rfi2_wrdata(17) <= N_146_0;
rfi2_wrdata(18) <= N_147_0;
rfi2_wrdata(19) <= N_148_0;
rfi2_wrdata(20) <= N_149_0;
rfi2_wrdata(21) <= N_150_0;
rfi2_wrdata(22) <= N_151_0;
rfi2_wrdata(23) <= N_152_0;
rfi2_wrdata(24) <= N_153_0;
rfi2_wrdata(25) <= N_154_0;
rfi2_wrdata(26) <= N_155_0;
rfi2_wrdata(27) <= N_156_0;
rfi2_wrdata(28) <= N_157_0;
rfi2_wrdata(29) <= N_158_0;
rfi2_wrdata(30) <= N_159_0;
rfi2_wrdata(31) <= N_160_0;
rfi2_ren1 <= N_161_0;
rfi2_ren2 <= N_162_0;
rfi2_wren <= N_163_0;
RST_INTERNAL <= rst;
CLK_INTERNAL <= clk;
HOLDN_INTERNAL <= holdn;
CPI_FLUSH_INTERNAL <= cpi_flush;
CPI_EXACK_INTERNAL <= cpi_exack;
CPI_A_RS1_INTERNAL <= cpi_a_rs1(0);
CPI_A_RS1_INTERNAL_0 <= cpi_a_rs1(1);
CPI_A_RS1_INTERNAL_1 <= cpi_a_rs1(2);
CPI_A_RS1_INTERNAL_2 <= cpi_a_rs1(3);
CPI_A_RS1_INTERNAL_3 <= cpi_a_rs1(4);
CPI_D_PC_INTERNAL <= cpi_d_pc(0);
CPI_D_PC_INTERNAL_0 <= cpi_d_pc(1);
CPI_D_PC_INTERNAL_1 <= cpi_d_pc(2);
CPI_D_PC_INTERNAL_2 <= cpi_d_pc(3);
CPI_D_PC_INTERNAL_3 <= cpi_d_pc(4);
CPI_D_PC_INTERNAL_4 <= cpi_d_pc(5);
CPI_D_PC_INTERNAL_5 <= cpi_d_pc(6);
CPI_D_PC_INTERNAL_6 <= cpi_d_pc(7);
CPI_D_PC_INTERNAL_7 <= cpi_d_pc(8);
CPI_D_PC_INTERNAL_8 <= cpi_d_pc(9);
CPI_D_PC_INTERNAL_9 <= cpi_d_pc(10);
CPI_D_PC_INTERNAL_10 <= cpi_d_pc(11);
CPI_D_PC_INTERNAL_11 <= cpi_d_pc(12);
CPI_D_PC_INTERNAL_12 <= cpi_d_pc(13);
CPI_D_PC_INTERNAL_13 <= cpi_d_pc(14);
CPI_D_PC_INTERNAL_14 <= cpi_d_pc(15);
CPI_D_PC_INTERNAL_15 <= cpi_d_pc(16);
CPI_D_PC_INTERNAL_16 <= cpi_d_pc(17);
CPI_D_PC_INTERNAL_17 <= cpi_d_pc(18);
CPI_D_PC_INTERNAL_18 <= cpi_d_pc(19);
CPI_D_PC_INTERNAL_19 <= cpi_d_pc(20);
CPI_D_PC_INTERNAL_20 <= cpi_d_pc(21);
CPI_D_PC_INTERNAL_21 <= cpi_d_pc(22);
CPI_D_PC_INTERNAL_22 <= cpi_d_pc(23);
CPI_D_PC_INTERNAL_23 <= cpi_d_pc(24);
CPI_D_PC_INTERNAL_24 <= cpi_d_pc(25);
CPI_D_PC_INTERNAL_25 <= cpi_d_pc(26);
CPI_D_PC_INTERNAL_26 <= cpi_d_pc(27);
CPI_D_PC_INTERNAL_27 <= cpi_d_pc(28);
CPI_D_PC_INTERNAL_28 <= cpi_d_pc(29);
CPI_D_PC_INTERNAL_29 <= cpi_d_pc(30);
CPI_D_PC_INTERNAL_30 <= cpi_d_pc(31);
CPI_D_INST_INTERNAL <= cpi_d_inst(0);
CPI_D_INST_INTERNAL_0 <= cpi_d_inst(1);
CPI_D_INST_INTERNAL_1 <= cpi_d_inst(2);
CPI_D_INST_INTERNAL_2 <= cpi_d_inst(3);
CPI_D_INST_INTERNAL_3 <= cpi_d_inst(4);
CPI_D_INST_INTERNAL_4 <= cpi_d_inst(5);
CPI_D_INST_INTERNAL_5 <= cpi_d_inst(6);
CPI_D_INST_INTERNAL_6 <= cpi_d_inst(7);
CPI_D_INST_INTERNAL_7 <= cpi_d_inst(8);
CPI_D_INST_INTERNAL_8 <= cpi_d_inst(9);
CPI_D_INST_INTERNAL_9 <= cpi_d_inst(10);
CPI_D_INST_INTERNAL_10 <= cpi_d_inst(11);
CPI_D_INST_INTERNAL_11 <= cpi_d_inst(12);
CPI_D_INST_INTERNAL_12 <= cpi_d_inst(13);
CPI_D_INST_INTERNAL_13 <= cpi_d_inst(14);
CPI_D_INST_INTERNAL_14 <= cpi_d_inst(15);
CPI_D_INST_INTERNAL_15 <= cpi_d_inst(16);
CPI_D_INST_INTERNAL_16 <= cpi_d_inst(17);
CPI_D_INST_INTERNAL_17 <= cpi_d_inst(18);
CPI_D_INST_INTERNAL_18 <= cpi_d_inst(19);
CPI_D_INST_INTERNAL_19 <= cpi_d_inst(20);
CPI_D_INST_INTERNAL_20 <= cpi_d_inst(21);
CPI_D_INST_INTERNAL_21 <= cpi_d_inst(22);
CPI_D_INST_INTERNAL_22 <= cpi_d_inst(23);
CPI_D_INST_INTERNAL_23 <= cpi_d_inst(24);
CPI_D_INST_INTERNAL_24 <= cpi_d_inst(25);
CPI_D_INST_INTERNAL_25 <= cpi_d_inst(26);
CPI_D_INST_INTERNAL_26 <= cpi_d_inst(27);
CPI_D_INST_INTERNAL_27 <= cpi_d_inst(28);
CPI_D_INST_INTERNAL_28 <= cpi_d_inst(29);
CPI_D_INST_INTERNAL_29 <= cpi_d_inst(30);
CPI_D_INST_INTERNAL_30 <= cpi_d_inst(31);
CPI_D_CNT_INTERNAL <= cpi_d_cnt(0);
CPI_D_CNT_INTERNAL_0 <= cpi_d_cnt(1);
CPI_D_TRAP_INTERNAL <= cpi_d_trap;
CPI_D_ANNUL_INTERNAL <= cpi_d_annul;
CPI_D_PV_INTERNAL <= cpi_d_pv;
CPI_A_PC_INTERNAL <= cpi_a_pc(0);
CPI_A_PC_INTERNAL_0 <= cpi_a_pc(1);
CPI_A_PC_INTERNAL_1 <= cpi_a_pc(2);
CPI_A_PC_INTERNAL_2 <= cpi_a_pc(3);
CPI_A_PC_INTERNAL_3 <= cpi_a_pc(4);
CPI_A_PC_INTERNAL_4 <= cpi_a_pc(5);
CPI_A_PC_INTERNAL_5 <= cpi_a_pc(6);
CPI_A_PC_INTERNAL_6 <= cpi_a_pc(7);
CPI_A_PC_INTERNAL_7 <= cpi_a_pc(8);
CPI_A_PC_INTERNAL_8 <= cpi_a_pc(9);
CPI_A_PC_INTERNAL_9 <= cpi_a_pc(10);
CPI_A_PC_INTERNAL_10 <= cpi_a_pc(11);
CPI_A_PC_INTERNAL_11 <= cpi_a_pc(12);
CPI_A_PC_INTERNAL_12 <= cpi_a_pc(13);
CPI_A_PC_INTERNAL_13 <= cpi_a_pc(14);
CPI_A_PC_INTERNAL_14 <= cpi_a_pc(15);
CPI_A_PC_INTERNAL_15 <= cpi_a_pc(16);
CPI_A_PC_INTERNAL_16 <= cpi_a_pc(17);
CPI_A_PC_INTERNAL_17 <= cpi_a_pc(18);
CPI_A_PC_INTERNAL_18 <= cpi_a_pc(19);
CPI_A_PC_INTERNAL_19 <= cpi_a_pc(20);
CPI_A_PC_INTERNAL_20 <= cpi_a_pc(21);
CPI_A_PC_INTERNAL_21 <= cpi_a_pc(22);
CPI_A_PC_INTERNAL_22 <= cpi_a_pc(23);
CPI_A_PC_INTERNAL_23 <= cpi_a_pc(24);
CPI_A_PC_INTERNAL_24 <= cpi_a_pc(25);
CPI_A_PC_INTERNAL_25 <= cpi_a_pc(26);
CPI_A_PC_INTERNAL_26 <= cpi_a_pc(27);
CPI_A_PC_INTERNAL_27 <= cpi_a_pc(28);
CPI_A_PC_INTERNAL_28 <= cpi_a_pc(29);
CPI_A_PC_INTERNAL_29 <= cpi_a_pc(30);
CPI_A_PC_INTERNAL_30 <= cpi_a_pc(31);
CPI_A_INST_INTERNAL <= cpi_a_inst(0);
CPI_A_INST_INTERNAL_0 <= cpi_a_inst(1);
CPI_A_INST_INTERNAL_1 <= cpi_a_inst(2);
CPI_A_INST_INTERNAL_2 <= cpi_a_inst(3);
CPI_A_INST_INTERNAL_3 <= cpi_a_inst(4);
CPI_A_INST_INTERNAL_4 <= cpi_a_inst(5);
CPI_A_INST_INTERNAL_5 <= cpi_a_inst(6);
CPI_A_INST_INTERNAL_6 <= cpi_a_inst(7);
CPI_A_INST_INTERNAL_7 <= cpi_a_inst(8);
CPI_A_INST_INTERNAL_8 <= cpi_a_inst(9);
CPI_A_INST_INTERNAL_9 <= cpi_a_inst(10);
CPI_A_INST_INTERNAL_10 <= cpi_a_inst(11);
CPI_A_INST_INTERNAL_11 <= cpi_a_inst(12);
CPI_A_INST_INTERNAL_12 <= cpi_a_inst(13);
CPI_A_INST_INTERNAL_13 <= cpi_a_inst(14);
CPI_A_INST_INTERNAL_14 <= cpi_a_inst(15);
CPI_A_INST_INTERNAL_15 <= cpi_a_inst(16);
CPI_A_INST_INTERNAL_16 <= cpi_a_inst(17);
CPI_A_INST_INTERNAL_17 <= cpi_a_inst(18);
CPI_A_INST_INTERNAL_18 <= cpi_a_inst(19);
CPI_A_INST_INTERNAL_19 <= cpi_a_inst(20);
CPI_A_INST_INTERNAL_20 <= cpi_a_inst(21);
CPI_A_INST_INTERNAL_21 <= cpi_a_inst(22);
CPI_A_INST_INTERNAL_22 <= cpi_a_inst(23);
CPI_A_INST_INTERNAL_23 <= cpi_a_inst(24);
CPI_A_INST_INTERNAL_24 <= cpi_a_inst(25);
CPI_A_INST_INTERNAL_25 <= cpi_a_inst(26);
CPI_A_INST_INTERNAL_26 <= cpi_a_inst(27);
CPI_A_INST_INTERNAL_27 <= cpi_a_inst(28);
CPI_A_INST_INTERNAL_28 <= cpi_a_inst(29);
CPI_A_INST_INTERNAL_29 <= cpi_a_inst(30);
CPI_A_INST_INTERNAL_30 <= cpi_a_inst(31);
CPI_A_CNT_INTERNAL <= cpi_a_cnt(0);
CPI_A_CNT_INTERNAL_0 <= cpi_a_cnt(1);
CPI_A_TRAP_INTERNAL <= cpi_a_trap;
CPI_A_ANNUL_INTERNAL <= cpi_a_annul;
CPI_A_PV_INTERNAL <= cpi_a_pv;
CPI_E_PC_INTERNAL <= cpi_e_pc(0);
CPI_E_PC_INTERNAL_0 <= cpi_e_pc(1);
CPI_E_PC_INTERNAL_1 <= cpi_e_pc(2);
CPI_E_PC_INTERNAL_2 <= cpi_e_pc(3);
CPI_E_PC_INTERNAL_3 <= cpi_e_pc(4);
CPI_E_PC_INTERNAL_4 <= cpi_e_pc(5);
CPI_E_PC_INTERNAL_5 <= cpi_e_pc(6);
CPI_E_PC_INTERNAL_6 <= cpi_e_pc(7);
CPI_E_PC_INTERNAL_7 <= cpi_e_pc(8);
CPI_E_PC_INTERNAL_8 <= cpi_e_pc(9);
CPI_E_PC_INTERNAL_9 <= cpi_e_pc(10);
CPI_E_PC_INTERNAL_10 <= cpi_e_pc(11);
CPI_E_PC_INTERNAL_11 <= cpi_e_pc(12);
CPI_E_PC_INTERNAL_12 <= cpi_e_pc(13);
CPI_E_PC_INTERNAL_13 <= cpi_e_pc(14);
CPI_E_PC_INTERNAL_14 <= cpi_e_pc(15);
CPI_E_PC_INTERNAL_15 <= cpi_e_pc(16);
CPI_E_PC_INTERNAL_16 <= cpi_e_pc(17);
CPI_E_PC_INTERNAL_17 <= cpi_e_pc(18);
CPI_E_PC_INTERNAL_18 <= cpi_e_pc(19);
CPI_E_PC_INTERNAL_19 <= cpi_e_pc(20);
CPI_E_PC_INTERNAL_20 <= cpi_e_pc(21);
CPI_E_PC_INTERNAL_21 <= cpi_e_pc(22);
CPI_E_PC_INTERNAL_22 <= cpi_e_pc(23);
CPI_E_PC_INTERNAL_23 <= cpi_e_pc(24);
CPI_E_PC_INTERNAL_24 <= cpi_e_pc(25);
CPI_E_PC_INTERNAL_25 <= cpi_e_pc(26);
CPI_E_PC_INTERNAL_26 <= cpi_e_pc(27);
CPI_E_PC_INTERNAL_27 <= cpi_e_pc(28);
CPI_E_PC_INTERNAL_28 <= cpi_e_pc(29);
CPI_E_PC_INTERNAL_29 <= cpi_e_pc(30);
CPI_E_PC_INTERNAL_30 <= cpi_e_pc(31);
CPI_E_INST_INTERNAL <= cpi_e_inst(0);
CPI_E_INST_INTERNAL_0 <= cpi_e_inst(1);
CPI_E_INST_INTERNAL_1 <= cpi_e_inst(2);
CPI_E_INST_INTERNAL_2 <= cpi_e_inst(3);
CPI_E_INST_INTERNAL_3 <= cpi_e_inst(4);
CPI_E_INST_INTERNAL_4 <= cpi_e_inst(5);
CPI_E_INST_INTERNAL_5 <= cpi_e_inst(6);
CPI_E_INST_INTERNAL_6 <= cpi_e_inst(7);
CPI_E_INST_INTERNAL_7 <= cpi_e_inst(8);
CPI_E_INST_INTERNAL_8 <= cpi_e_inst(9);
CPI_E_INST_INTERNAL_9 <= cpi_e_inst(10);
CPI_E_INST_INTERNAL_10 <= cpi_e_inst(11);
CPI_E_INST_INTERNAL_11 <= cpi_e_inst(12);
CPI_E_INST_INTERNAL_12 <= cpi_e_inst(13);
CPI_E_INST_INTERNAL_13 <= cpi_e_inst(14);
CPI_E_INST_INTERNAL_14 <= cpi_e_inst(15);
CPI_E_INST_INTERNAL_15 <= cpi_e_inst(16);
CPI_E_INST_INTERNAL_16 <= cpi_e_inst(17);
CPI_E_INST_INTERNAL_17 <= cpi_e_inst(18);
CPI_E_INST_INTERNAL_18 <= cpi_e_inst(19);
CPI_E_INST_INTERNAL_19 <= cpi_e_inst(20);
CPI_E_INST_INTERNAL_20 <= cpi_e_inst(21);
CPI_E_INST_INTERNAL_21 <= cpi_e_inst(22);
CPI_E_INST_INTERNAL_22 <= cpi_e_inst(23);
CPI_E_INST_INTERNAL_23 <= cpi_e_inst(24);
CPI_E_INST_INTERNAL_24 <= cpi_e_inst(25);
CPI_E_INST_INTERNAL_25 <= cpi_e_inst(26);
CPI_E_INST_INTERNAL_26 <= cpi_e_inst(27);
CPI_E_INST_INTERNAL_27 <= cpi_e_inst(28);
CPI_E_INST_INTERNAL_28 <= cpi_e_inst(29);
CPI_E_INST_INTERNAL_29 <= cpi_e_inst(30);
CPI_E_INST_INTERNAL_30 <= cpi_e_inst(31);
CPI_E_CNT_INTERNAL <= cpi_e_cnt(0);
CPI_E_CNT_INTERNAL_0 <= cpi_e_cnt(1);
CPI_E_TRAP_INTERNAL <= cpi_e_trap;
CPI_E_ANNUL_INTERNAL <= cpi_e_annul;
CPI_E_PV_INTERNAL <= cpi_e_pv;
CPI_M_PC_INTERNAL <= cpi_m_pc(0);
CPI_M_PC_INTERNAL_0 <= cpi_m_pc(1);
CPI_M_PC_INTERNAL_1 <= cpi_m_pc(2);
CPI_M_PC_INTERNAL_2 <= cpi_m_pc(3);
CPI_M_PC_INTERNAL_3 <= cpi_m_pc(4);
CPI_M_PC_INTERNAL_4 <= cpi_m_pc(5);
CPI_M_PC_INTERNAL_5 <= cpi_m_pc(6);
CPI_M_PC_INTERNAL_6 <= cpi_m_pc(7);
CPI_M_PC_INTERNAL_7 <= cpi_m_pc(8);
CPI_M_PC_INTERNAL_8 <= cpi_m_pc(9);
CPI_M_PC_INTERNAL_9 <= cpi_m_pc(10);
CPI_M_PC_INTERNAL_10 <= cpi_m_pc(11);
CPI_M_PC_INTERNAL_11 <= cpi_m_pc(12);
CPI_M_PC_INTERNAL_12 <= cpi_m_pc(13);
CPI_M_PC_INTERNAL_13 <= cpi_m_pc(14);
CPI_M_PC_INTERNAL_14 <= cpi_m_pc(15);
CPI_M_PC_INTERNAL_15 <= cpi_m_pc(16);
CPI_M_PC_INTERNAL_16 <= cpi_m_pc(17);
CPI_M_PC_INTERNAL_17 <= cpi_m_pc(18);
CPI_M_PC_INTERNAL_18 <= cpi_m_pc(19);
CPI_M_PC_INTERNAL_19 <= cpi_m_pc(20);
CPI_M_PC_INTERNAL_20 <= cpi_m_pc(21);
CPI_M_PC_INTERNAL_21 <= cpi_m_pc(22);
CPI_M_PC_INTERNAL_22 <= cpi_m_pc(23);
CPI_M_PC_INTERNAL_23 <= cpi_m_pc(24);
CPI_M_PC_INTERNAL_24 <= cpi_m_pc(25);
CPI_M_PC_INTERNAL_25 <= cpi_m_pc(26);
CPI_M_PC_INTERNAL_26 <= cpi_m_pc(27);
CPI_M_PC_INTERNAL_27 <= cpi_m_pc(28);
CPI_M_PC_INTERNAL_28 <= cpi_m_pc(29);
CPI_M_PC_INTERNAL_29 <= cpi_m_pc(30);
CPI_M_PC_INTERNAL_30 <= cpi_m_pc(31);
CPI_M_INST_INTERNAL <= cpi_m_inst(0);
CPI_M_INST_INTERNAL_0 <= cpi_m_inst(1);
CPI_M_INST_INTERNAL_1 <= cpi_m_inst(2);
CPI_M_INST_INTERNAL_2 <= cpi_m_inst(3);
CPI_M_INST_INTERNAL_3 <= cpi_m_inst(4);
CPI_M_INST_INTERNAL_4 <= cpi_m_inst(5);
CPI_M_INST_INTERNAL_5 <= cpi_m_inst(6);
CPI_M_INST_INTERNAL_6 <= cpi_m_inst(7);
CPI_M_INST_INTERNAL_7 <= cpi_m_inst(8);
CPI_M_INST_INTERNAL_8 <= cpi_m_inst(9);
CPI_M_INST_INTERNAL_9 <= cpi_m_inst(10);
CPI_M_INST_INTERNAL_10 <= cpi_m_inst(11);
CPI_M_INST_INTERNAL_11 <= cpi_m_inst(12);
CPI_M_INST_INTERNAL_12 <= cpi_m_inst(13);
CPI_M_INST_INTERNAL_13 <= cpi_m_inst(14);
CPI_M_INST_INTERNAL_14 <= cpi_m_inst(15);
CPI_M_INST_INTERNAL_15 <= cpi_m_inst(16);
CPI_M_INST_INTERNAL_16 <= cpi_m_inst(17);
CPI_M_INST_INTERNAL_17 <= cpi_m_inst(18);
CPI_M_INST_INTERNAL_18 <= cpi_m_inst(19);
CPI_M_INST_INTERNAL_19 <= cpi_m_inst(20);
CPI_M_INST_INTERNAL_20 <= cpi_m_inst(21);
CPI_M_INST_INTERNAL_21 <= cpi_m_inst(22);
CPI_M_INST_INTERNAL_22 <= cpi_m_inst(23);
CPI_M_INST_INTERNAL_23 <= cpi_m_inst(24);
CPI_M_INST_INTERNAL_24 <= cpi_m_inst(25);
CPI_M_INST_INTERNAL_25 <= cpi_m_inst(26);
CPI_M_INST_INTERNAL_26 <= cpi_m_inst(27);
CPI_M_INST_INTERNAL_27 <= cpi_m_inst(28);
CPI_M_INST_INTERNAL_28 <= cpi_m_inst(29);
CPI_M_INST_INTERNAL_29 <= cpi_m_inst(30);
CPI_M_INST_INTERNAL_30 <= cpi_m_inst(31);
CPI_M_CNT_INTERNAL <= cpi_m_cnt(0);
CPI_M_CNT_INTERNAL_0 <= cpi_m_cnt(1);
CPI_M_TRAP_INTERNAL <= cpi_m_trap;
CPI_M_ANNUL_INTERNAL <= cpi_m_annul;
CPI_M_PV_INTERNAL <= cpi_m_pv;
CPI_X_PC_INTERNAL <= cpi_x_pc(0);
CPI_X_PC_INTERNAL_0 <= cpi_x_pc(1);
CPI_X_PC_INTERNAL_1 <= cpi_x_pc(2);
CPI_X_PC_INTERNAL_2 <= cpi_x_pc(3);
CPI_X_PC_INTERNAL_3 <= cpi_x_pc(4);
CPI_X_PC_INTERNAL_4 <= cpi_x_pc(5);
CPI_X_PC_INTERNAL_5 <= cpi_x_pc(6);
CPI_X_PC_INTERNAL_6 <= cpi_x_pc(7);
CPI_X_PC_INTERNAL_7 <= cpi_x_pc(8);
CPI_X_PC_INTERNAL_8 <= cpi_x_pc(9);
CPI_X_PC_INTERNAL_9 <= cpi_x_pc(10);
CPI_X_PC_INTERNAL_10 <= cpi_x_pc(11);
CPI_X_PC_INTERNAL_11 <= cpi_x_pc(12);
CPI_X_PC_INTERNAL_12 <= cpi_x_pc(13);
CPI_X_PC_INTERNAL_13 <= cpi_x_pc(14);
CPI_X_PC_INTERNAL_14 <= cpi_x_pc(15);
CPI_X_PC_INTERNAL_15 <= cpi_x_pc(16);
CPI_X_PC_INTERNAL_16 <= cpi_x_pc(17);
CPI_X_PC_INTERNAL_17 <= cpi_x_pc(18);
CPI_X_PC_INTERNAL_18 <= cpi_x_pc(19);
CPI_X_PC_INTERNAL_19 <= cpi_x_pc(20);
CPI_X_PC_INTERNAL_20 <= cpi_x_pc(21);
CPI_X_PC_INTERNAL_21 <= cpi_x_pc(22);
CPI_X_PC_INTERNAL_22 <= cpi_x_pc(23);
CPI_X_PC_INTERNAL_23 <= cpi_x_pc(24);
CPI_X_PC_INTERNAL_24 <= cpi_x_pc(25);
CPI_X_PC_INTERNAL_25 <= cpi_x_pc(26);
CPI_X_PC_INTERNAL_26 <= cpi_x_pc(27);
CPI_X_PC_INTERNAL_27 <= cpi_x_pc(28);
CPI_X_PC_INTERNAL_28 <= cpi_x_pc(29);
CPI_X_PC_INTERNAL_29 <= cpi_x_pc(30);
CPI_X_PC_INTERNAL_30 <= cpi_x_pc(31);
CPI_X_INST_INTERNAL <= cpi_x_inst(0);
CPI_X_INST_INTERNAL_0 <= cpi_x_inst(1);
CPI_X_INST_INTERNAL_1 <= cpi_x_inst(2);
CPI_X_INST_INTERNAL_2 <= cpi_x_inst(3);
CPI_X_INST_INTERNAL_3 <= cpi_x_inst(4);
CPI_X_INST_INTERNAL_4 <= cpi_x_inst(5);
CPI_X_INST_INTERNAL_5 <= cpi_x_inst(6);
CPI_X_INST_INTERNAL_6 <= cpi_x_inst(7);
CPI_X_INST_INTERNAL_7 <= cpi_x_inst(8);
CPI_X_INST_INTERNAL_8 <= cpi_x_inst(9);
CPI_X_INST_INTERNAL_9 <= cpi_x_inst(10);
CPI_X_INST_INTERNAL_10 <= cpi_x_inst(11);
CPI_X_INST_INTERNAL_11 <= cpi_x_inst(12);
CPI_X_INST_INTERNAL_12 <= cpi_x_inst(13);
CPI_X_INST_INTERNAL_13 <= cpi_x_inst(14);
CPI_X_INST_INTERNAL_14 <= cpi_x_inst(15);
CPI_X_INST_INTERNAL_15 <= cpi_x_inst(16);
CPI_X_INST_INTERNAL_16 <= cpi_x_inst(17);
CPI_X_INST_INTERNAL_17 <= cpi_x_inst(18);
CPI_X_INST_INTERNAL_18 <= cpi_x_inst(19);
CPI_X_INST_INTERNAL_19 <= cpi_x_inst(20);
CPI_X_INST_INTERNAL_20 <= cpi_x_inst(21);
CPI_X_INST_INTERNAL_21 <= cpi_x_inst(22);
CPI_X_INST_INTERNAL_22 <= cpi_x_inst(23);
CPI_X_INST_INTERNAL_23 <= cpi_x_inst(24);
CPI_X_INST_INTERNAL_24 <= cpi_x_inst(25);
CPI_X_INST_INTERNAL_25 <= cpi_x_inst(26);
CPI_X_INST_INTERNAL_26 <= cpi_x_inst(27);
CPI_X_INST_INTERNAL_27 <= cpi_x_inst(28);
CPI_X_INST_INTERNAL_28 <= cpi_x_inst(29);
CPI_X_INST_INTERNAL_29 <= cpi_x_inst(30);
CPI_X_INST_INTERNAL_30 <= cpi_x_inst(31);
CPI_X_CNT_INTERNAL <= cpi_x_cnt(0);
CPI_X_CNT_INTERNAL_0 <= cpi_x_cnt(1);
CPI_X_TRAP_INTERNAL <= cpi_x_trap;
CPI_X_ANNUL_INTERNAL <= cpi_x_annul;
CPI_X_PV_INTERNAL <= cpi_x_pv;
CPI_LDDATA_INTERNAL <= cpi_lddata(0);
CPI_LDDATA_INTERNAL_0 <= cpi_lddata(1);
CPI_LDDATA_INTERNAL_1 <= cpi_lddata(2);
CPI_LDDATA_INTERNAL_2 <= cpi_lddata(3);
CPI_LDDATA_INTERNAL_3 <= cpi_lddata(4);
CPI_LDDATA_INTERNAL_4 <= cpi_lddata(5);
CPI_LDDATA_INTERNAL_5 <= cpi_lddata(6);
CPI_LDDATA_INTERNAL_6 <= cpi_lddata(7);
CPI_LDDATA_INTERNAL_7 <= cpi_lddata(8);
CPI_LDDATA_INTERNAL_8 <= cpi_lddata(9);
CPI_LDDATA_INTERNAL_9 <= cpi_lddata(10);
CPI_LDDATA_INTERNAL_10 <= cpi_lddata(11);
CPI_LDDATA_INTERNAL_11 <= cpi_lddata(12);
CPI_LDDATA_INTERNAL_12 <= cpi_lddata(13);
CPI_LDDATA_INTERNAL_13 <= cpi_lddata(14);
CPI_LDDATA_INTERNAL_14 <= cpi_lddata(15);
CPI_LDDATA_INTERNAL_15 <= cpi_lddata(16);
CPI_LDDATA_INTERNAL_16 <= cpi_lddata(17);
CPI_LDDATA_INTERNAL_17 <= cpi_lddata(18);
CPI_LDDATA_INTERNAL_18 <= cpi_lddata(19);
CPI_LDDATA_INTERNAL_19 <= cpi_lddata(20);
CPI_LDDATA_INTERNAL_20 <= cpi_lddata(21);
CPI_LDDATA_INTERNAL_21 <= cpi_lddata(22);
CPI_LDDATA_INTERNAL_22 <= cpi_lddata(23);
CPI_LDDATA_INTERNAL_23 <= cpi_lddata(24);
CPI_LDDATA_INTERNAL_24 <= cpi_lddata(25);
CPI_LDDATA_INTERNAL_25 <= cpi_lddata(26);
CPI_LDDATA_INTERNAL_26 <= cpi_lddata(27);
CPI_LDDATA_INTERNAL_27 <= cpi_lddata(28);
CPI_LDDATA_INTERNAL_28 <= cpi_lddata(29);
CPI_LDDATA_INTERNAL_29 <= cpi_lddata(30);
CPI_LDDATA_INTERNAL_30 <= cpi_lddata(31);
CPI_DBG_ENABLE_INTERNAL <= cpi_dbg_enable;
CPI_DBG_WRITE_INTERNAL <= cpi_dbg_write;
CPI_DBG_FSR_INTERNAL <= cpi_dbg_fsr;
CPI_DBG_ADDR_INTERNAL <= cpi_dbg_addr(0);
CPI_DBG_ADDR_INTERNAL_0 <= cpi_dbg_addr(1);
CPI_DBG_ADDR_INTERNAL_1 <= cpi_dbg_addr(2);
CPI_DBG_ADDR_INTERNAL_2 <= cpi_dbg_addr(3);
CPI_DBG_ADDR_INTERNAL_3 <= cpi_dbg_addr(4);
CPI_DBG_DATA_INTERNAL <= cpi_dbg_data(0);
CPI_DBG_DATA_INTERNAL_0 <= cpi_dbg_data(1);
CPI_DBG_DATA_INTERNAL_1 <= cpi_dbg_data(2);
CPI_DBG_DATA_INTERNAL_2 <= cpi_dbg_data(3);
CPI_DBG_DATA_INTERNAL_3 <= cpi_dbg_data(4);
CPI_DBG_DATA_INTERNAL_4 <= cpi_dbg_data(5);
CPI_DBG_DATA_INTERNAL_5 <= cpi_dbg_data(6);
CPI_DBG_DATA_INTERNAL_6 <= cpi_dbg_data(7);
CPI_DBG_DATA_INTERNAL_7 <= cpi_dbg_data(8);
CPI_DBG_DATA_INTERNAL_8 <= cpi_dbg_data(9);
CPI_DBG_DATA_INTERNAL_9 <= cpi_dbg_data(10);
CPI_DBG_DATA_INTERNAL_10 <= cpi_dbg_data(11);
CPI_DBG_DATA_INTERNAL_11 <= cpi_dbg_data(12);
CPI_DBG_DATA_INTERNAL_12 <= cpi_dbg_data(13);
CPI_DBG_DATA_INTERNAL_13 <= cpi_dbg_data(14);
CPI_DBG_DATA_INTERNAL_14 <= cpi_dbg_data(15);
CPI_DBG_DATA_INTERNAL_15 <= cpi_dbg_data(16);
CPI_DBG_DATA_INTERNAL_16 <= cpi_dbg_data(17);
CPI_DBG_DATA_INTERNAL_17 <= cpi_dbg_data(18);
CPI_DBG_DATA_INTERNAL_18 <= cpi_dbg_data(19);
CPI_DBG_DATA_INTERNAL_19 <= cpi_dbg_data(20);
CPI_DBG_DATA_INTERNAL_20 <= cpi_dbg_data(21);
CPI_DBG_DATA_INTERNAL_21 <= cpi_dbg_data(22);
CPI_DBG_DATA_INTERNAL_22 <= cpi_dbg_data(23);
CPI_DBG_DATA_INTERNAL_23 <= cpi_dbg_data(24);
CPI_DBG_DATA_INTERNAL_24 <= cpi_dbg_data(25);
CPI_DBG_DATA_INTERNAL_25 <= cpi_dbg_data(26);
CPI_DBG_DATA_INTERNAL_26 <= cpi_dbg_data(27);
CPI_DBG_DATA_INTERNAL_27 <= cpi_dbg_data(28);
CPI_DBG_DATA_INTERNAL_28 <= cpi_dbg_data(29);
CPI_DBG_DATA_INTERNAL_29 <= cpi_dbg_data(30);
CPI_DBG_DATA_INTERNAL_30 <= cpi_dbg_data(31);
RFO1_DATA1_INTERNAL <= rfo1_data1(0);
RFO1_DATA1_INTERNAL_0 <= rfo1_data1(1);
RFO1_DATA1_INTERNAL_1 <= rfo1_data1(2);
RFO1_DATA1_INTERNAL_2 <= rfo1_data1(3);
RFO1_DATA1_INTERNAL_3 <= rfo1_data1(4);
RFO1_DATA1_INTERNAL_4 <= rfo1_data1(5);
RFO1_DATA1_INTERNAL_5 <= rfo1_data1(6);
RFO1_DATA1_INTERNAL_6 <= rfo1_data1(7);
RFO1_DATA1_INTERNAL_7 <= rfo1_data1(8);
RFO1_DATA1_INTERNAL_8 <= rfo1_data1(9);
RFO1_DATA1_INTERNAL_9 <= rfo1_data1(10);
RFO1_DATA1_INTERNAL_10 <= rfo1_data1(11);
RFO1_DATA1_INTERNAL_11 <= rfo1_data1(12);
RFO1_DATA1_INTERNAL_12 <= rfo1_data1(13);
RFO1_DATA1_INTERNAL_13 <= rfo1_data1(14);
RFO1_DATA1_INTERNAL_14 <= rfo1_data1(15);
RFO1_DATA1_INTERNAL_15 <= rfo1_data1(16);
RFO1_DATA1_INTERNAL_16 <= rfo1_data1(17);
RFO1_DATA1_INTERNAL_17 <= rfo1_data1(18);
RFO1_DATA1_INTERNAL_18 <= rfo1_data1(19);
RFO1_DATA1_INTERNAL_19 <= rfo1_data1(20);
RFO1_DATA1_INTERNAL_20 <= rfo1_data1(21);
RFO1_DATA1_INTERNAL_21 <= rfo1_data1(22);
RFO1_DATA1_INTERNAL_22 <= rfo1_data1(23);
RFO1_DATA1_INTERNAL_23 <= rfo1_data1(24);
RFO1_DATA1_INTERNAL_24 <= rfo1_data1(25);
RFO1_DATA1_INTERNAL_25 <= rfo1_data1(26);
RFO1_DATA1_INTERNAL_26 <= rfo1_data1(27);
RFO1_DATA1_INTERNAL_27 <= rfo1_data1(28);
RFO1_DATA1_INTERNAL_28 <= rfo1_data1(29);
RFO1_DATA1_INTERNAL_29 <= rfo1_data1(30);
RFO1_DATA1_INTERNAL_30 <= rfo1_data1(31);
RFO1_DATA2_INTERNAL <= rfo1_data2(0);
RFO1_DATA2_INTERNAL_0 <= rfo1_data2(1);
RFO1_DATA2_INTERNAL_1 <= rfo1_data2(2);
RFO1_DATA2_INTERNAL_2 <= rfo1_data2(3);
RFO1_DATA2_INTERNAL_3 <= rfo1_data2(4);
RFO1_DATA2_INTERNAL_4 <= rfo1_data2(5);
RFO1_DATA2_INTERNAL_5 <= rfo1_data2(6);
RFO1_DATA2_INTERNAL_6 <= rfo1_data2(7);
RFO1_DATA2_INTERNAL_7 <= rfo1_data2(8);
RFO1_DATA2_INTERNAL_8 <= rfo1_data2(9);
RFO1_DATA2_INTERNAL_9 <= rfo1_data2(10);
RFO1_DATA2_INTERNAL_10 <= rfo1_data2(11);
RFO1_DATA2_INTERNAL_11 <= rfo1_data2(12);
RFO1_DATA2_INTERNAL_12 <= rfo1_data2(13);
RFO1_DATA2_INTERNAL_13 <= rfo1_data2(14);
RFO1_DATA2_INTERNAL_14 <= rfo1_data2(15);
RFO1_DATA2_INTERNAL_15 <= rfo1_data2(16);
RFO1_DATA2_INTERNAL_16 <= rfo1_data2(17);
RFO1_DATA2_INTERNAL_17 <= rfo1_data2(18);
RFO1_DATA2_INTERNAL_18 <= rfo1_data2(19);
RFO1_DATA2_INTERNAL_19 <= rfo1_data2(20);
RFO1_DATA2_INTERNAL_20 <= rfo1_data2(21);
RFO1_DATA2_INTERNAL_21 <= rfo1_data2(22);
RFO1_DATA2_INTERNAL_22 <= rfo1_data2(23);
RFO1_DATA2_INTERNAL_23 <= rfo1_data2(24);
RFO1_DATA2_INTERNAL_24 <= rfo1_data2(25);
RFO1_DATA2_INTERNAL_25 <= rfo1_data2(26);
RFO1_DATA2_INTERNAL_26 <= rfo1_data2(27);
RFO1_DATA2_INTERNAL_27 <= rfo1_data2(28);
RFO1_DATA2_INTERNAL_28 <= rfo1_data2(29);
RFO1_DATA2_INTERNAL_29 <= rfo1_data2(30);
RFO1_DATA2_INTERNAL_30 <= rfo1_data2(31);
RFO2_DATA1_INTERNAL <= rfo2_data1(0);
RFO2_DATA1_INTERNAL_0 <= rfo2_data1(1);
RFO2_DATA1_INTERNAL_1 <= rfo2_data1(2);
RFO2_DATA1_INTERNAL_2 <= rfo2_data1(3);
RFO2_DATA1_INTERNAL_3 <= rfo2_data1(4);
RFO2_DATA1_INTERNAL_4 <= rfo2_data1(5);
RFO2_DATA1_INTERNAL_5 <= rfo2_data1(6);
RFO2_DATA1_INTERNAL_6 <= rfo2_data1(7);
RFO2_DATA1_INTERNAL_7 <= rfo2_data1(8);
RFO2_DATA1_INTERNAL_8 <= rfo2_data1(9);
RFO2_DATA1_INTERNAL_9 <= rfo2_data1(10);
RFO2_DATA1_INTERNAL_10 <= rfo2_data1(11);
RFO2_DATA1_INTERNAL_11 <= rfo2_data1(12);
RFO2_DATA1_INTERNAL_12 <= rfo2_data1(13);
RFO2_DATA1_INTERNAL_13 <= rfo2_data1(14);
RFO2_DATA1_INTERNAL_14 <= rfo2_data1(15);
RFO2_DATA1_INTERNAL_15 <= rfo2_data1(16);
RFO2_DATA1_INTERNAL_16 <= rfo2_data1(17);
RFO2_DATA1_INTERNAL_17 <= rfo2_data1(18);
RFO2_DATA1_INTERNAL_18 <= rfo2_data1(19);
RFO2_DATA1_INTERNAL_19 <= rfo2_data1(20);
RFO2_DATA1_INTERNAL_20 <= rfo2_data1(21);
RFO2_DATA1_INTERNAL_21 <= rfo2_data1(22);
RFO2_DATA1_INTERNAL_22 <= rfo2_data1(23);
RFO2_DATA1_INTERNAL_23 <= rfo2_data1(24);
RFO2_DATA1_INTERNAL_24 <= rfo2_data1(25);
RFO2_DATA1_INTERNAL_25 <= rfo2_data1(26);
RFO2_DATA1_INTERNAL_26 <= rfo2_data1(27);
RFO2_DATA1_INTERNAL_27 <= rfo2_data1(28);
RFO2_DATA1_INTERNAL_28 <= rfo2_data1(29);
RFO2_DATA1_INTERNAL_29 <= rfo2_data1(30);
RFO2_DATA1_INTERNAL_30 <= rfo2_data1(31);
RFO2_DATA2_INTERNAL <= rfo2_data2(0);
RFO2_DATA2_INTERNAL_0 <= rfo2_data2(1);
RFO2_DATA2_INTERNAL_1 <= rfo2_data2(2);
RFO2_DATA2_INTERNAL_2 <= rfo2_data2(3);
RFO2_DATA2_INTERNAL_3 <= rfo2_data2(4);
RFO2_DATA2_INTERNAL_4 <= rfo2_data2(5);
RFO2_DATA2_INTERNAL_5 <= rfo2_data2(6);
RFO2_DATA2_INTERNAL_6 <= rfo2_data2(7);
RFO2_DATA2_INTERNAL_7 <= rfo2_data2(8);
RFO2_DATA2_INTERNAL_8 <= rfo2_data2(9);
RFO2_DATA2_INTERNAL_9 <= rfo2_data2(10);
RFO2_DATA2_INTERNAL_10 <= rfo2_data2(11);
RFO2_DATA2_INTERNAL_11 <= rfo2_data2(12);
RFO2_DATA2_INTERNAL_12 <= rfo2_data2(13);
RFO2_DATA2_INTERNAL_13 <= rfo2_data2(14);
RFO2_DATA2_INTERNAL_14 <= rfo2_data2(15);
RFO2_DATA2_INTERNAL_15 <= rfo2_data2(16);
RFO2_DATA2_INTERNAL_16 <= rfo2_data2(17);
RFO2_DATA2_INTERNAL_17 <= rfo2_data2(18);
RFO2_DATA2_INTERNAL_18 <= rfo2_data2(19);
RFO2_DATA2_INTERNAL_19 <= rfo2_data2(20);
RFO2_DATA2_INTERNAL_20 <= rfo2_data2(21);
RFO2_DATA2_INTERNAL_21 <= rfo2_data2(22);
RFO2_DATA2_INTERNAL_22 <= rfo2_data2(23);
RFO2_DATA2_INTERNAL_23 <= rfo2_data2(24);
RFO2_DATA2_INTERNAL_24 <= rfo2_data2(25);
RFO2_DATA2_INTERNAL_25 <= rfo2_data2(26);
RFO2_DATA2_INTERNAL_26 <= rfo2_data2(27);
RFO2_DATA2_INTERNAL_27 <= rfo2_data2(28);
RFO2_DATA2_INTERNAL_28 <= rfo2_data2(29);
RFO2_DATA2_INTERNAL_29 <= rfo2_data2(30);
RFO2_DATA2_INTERNAL_30 <= rfo2_data2(31);
end beh;

